diff -pruN 6.0.0-3/CMakeLists.txt 6.3.0-1/CMakeLists.txt
--- 6.0.0-3/CMakeLists.txt	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/CMakeLists.txt	2024-05-31 13:26:56.000000000 +0000
@@ -3,14 +3,14 @@
 
 cmake_minimum_required(VERSION 3.16)
 
-set(KF_VERSION "6.0.0") # handled by release scripts
-set(KF_DEP_VERSION "6.0.0") # handled by release scripts
+set(KF_VERSION "6.3.0") # handled by release scripts
+set(KF_DEP_VERSION "6.3.0") # handled by release scripts
 project(KNewStuff VERSION ${KF_VERSION})
 
 set(CMAKE_CXX_EXTENSIONS OFF)
 
 include(FeatureSummary)
-find_package(ECM 6.0.0 NO_MODULE)
+find_package(ECM 6.3.0 NO_MODULE)
 set_package_properties(ECM PROPERTIES TYPE REQUIRED DESCRIPTION "Extra CMake Modules." URL "https://commits.kde.org/extra-cmake-modules")
 feature_summary(WHAT REQUIRED_PACKAGES_NOT_FOUND FATAL_ON_MISSING_REQUIRED_PACKAGES)
 set(CMAKE_MODULE_PATH ${ECM_MODULE_PATH})
diff -pruN 6.0.0-3/README.md 6.3.0-1/README.md
--- 6.0.0-3/README.md	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/README.md	2024-05-31 13:26:56.000000000 +0000
@@ -99,6 +99,7 @@ As an example, the file might look like
     Categories=KDE Wallpaper 1920x1200,KDE Wallpaper 1600x1200
     XdgTargetDir=wallpapers
     Uncompress=archive
+    ContentWarning=Static
 
 ### Name
 
@@ -163,6 +164,13 @@ Uncompress can be one of: `always`, `nev
 * `kpackage`: Require that the downloaded file is a kpackage, and use the KPackage framework for handling installation and removal (since 5.70).
   See also the note on [KPackage Support below](#kpackage-support) below.
 
+### ContentWarning
+
+Depending on store categories, downloaded content might be of more intrinsically innocuous nature such as Images or simple text files—or potentially more security-sensitive, for instance containing executable JavaScript code.
+For this reason, the `ContentWarning` key can be set to one of two values appropriate for the content type:
+* `Static`: for static contents such as images (this is the default value).
+* `Executable`: for content that can include executable scripts such as JavaScript or QML, or textual metadata like .desktop files that can specify executables which will then be run by the application.
+
 ### Entry and Download Item Tag Filter
 
 Use the `TagFilter` and `DownloadTagFilter` options to set filters based on the abstract tags which can be present
diff -pruN 6.0.0-3/autotests/core/data/enginetest.knsrc.in 6.3.0-1/autotests/core/data/enginetest.knsrc.in
--- 6.0.0-3/autotests/core/data/enginetest.knsrc.in	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/autotests/core/data/enginetest.knsrc.in	2024-05-31 13:26:56.000000000 +0000
@@ -5,4 +5,5 @@ Categories=KDE Wallpaper 1920x1200,KDE W
 UploadCategories=KDE Wallpaper 800x600
 TargetDir=icons
 UseLabel=UseLabelTest
-AdoptionCommand=/bin/true
\ No newline at end of file
+ContentWarning=Executables
+AdoptionCommand=/bin/true
diff -pruN 6.0.0-3/autotests/core/knewstuffenginetest.cpp 6.3.0-1/autotests/core/knewstuffenginetest.cpp
--- 6.0.0-3/autotests/core/knewstuffenginetest.cpp	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/autotests/core/knewstuffenginetest.cpp	2024-05-31 13:26:56.000000000 +0000
@@ -47,6 +47,7 @@ void EngineTest::testPropertiesReading()
              QStringList({QStringLiteral("KDE Wallpaper 1920x1200"), QStringLiteral("KDE Wallpaper 1600x1200")}));
     QCOMPARE(engine->useLabel(), QStringLiteral("UseLabelTest"));
     QVERIFY(engine->hasAdoptionCommand());
+    QCOMPARE(engine->contentWarningType(), EngineBase::ContentWarningType::Executables);
 }
 
 void EngineTest::testProviderFileLoading()
diff -pruN 6.0.0-3/debian/changelog 6.3.0-1/debian/changelog
--- 6.0.0-3/debian/changelog	2024-05-15 05:58:18.000000000 +0000
+++ 6.3.0-1/debian/changelog	2024-06-09 12:59:22.000000000 +0000
@@ -1,3 +1,12 @@
+kf6-knewstuff (6.3.0-1) experimental; urgency=medium
+
+  [ Patrick Franz ]
+  * New upstream release (6.3.0).
+  * Update build-deps and deps with the info from cmake.
+  * Update symbols from buildlogs.
+
+ -- Patrick Franz <deltaone@debian.org>  Sun, 09 Jun 2024 14:59:22 +0200
+
 kf6-knewstuff (6.0.0-3) experimental; urgency=medium
 
   * Team upload.
diff -pruN 6.0.0-3/debian/control 6.3.0-1/debian/control
--- 6.0.0-3/debian/control	2024-05-14 14:15:20.000000000 +0000
+++ 6.3.0-1/debian/control	2024-06-08 09:38:31.000000000 +0000
@@ -9,16 +9,16 @@ Build-Depends: cmake (>= 3.16~),
                dh-sequence-kf6,
                dh-sequence-pkgkde-symbolshelper,
                doxygen,
-               extra-cmake-modules (>= 6.0.0~),
+               extra-cmake-modules (>= 6.3.0~),
                gettext,
-               libkf6archive-dev (>= 6.0.0~),
-               libkf6attica-dev (>= 6.0.0~),
-               libkf6config-dev (>= 6.0.0~),
-               libkf6coreaddons-dev (>= 6.0.0~),
-               libkf6i18n-dev (>= 6.0.0~),
-               libkf6package-dev (>= 6.0.0~),
+               libkf6archive-dev (>= 6.3.0~),
+               libkf6attica-dev (>= 6.3.0~),
+               libkf6config-dev (>= 6.3.0~),
+               libkf6coreaddons-dev (>= 6.3.0~),
+               libkf6i18n-dev (>= 6.3.0~),
+               libkf6package-dev (>= 6.3.0~),
                libkf6syndication-dev (>= 6.0.0~),
-               libkf6widgetsaddons-dev (>= 6.0.0~),
+               libkf6widgetsaddons-dev (>= 6.3.0~),
                libkirigami-dev (>= 2.12.0~),
                libxkbcommon-dev,
                qt6-base-dev (>= 6.5.0+dfsg~),
diff -pruN 6.0.0-3/debian/libkf6newstuffcore6.symbols 6.3.0-1/debian/libkf6newstuffcore6.symbols
--- 6.0.0-3/debian/libkf6newstuffcore6.symbols	2024-05-15 05:57:27.000000000 +0000
+++ 6.3.0-1/debian/libkf6newstuffcore6.symbols	2024-06-08 16:33:29.000000000 +0000
@@ -1,4 +1,4 @@
-# SymbolsHelper-Confirmed: 6.0.0 amd64 arm64 armel armhf i386 mips64el powerpc ppc64 ppc64el riscv64
+# SymbolsHelper-Confirmed: 6.3.0 amd64
 libKF6NewStuffCore.so.6 libkf6newstuffcore6 #MINVER#
 * Build-Depends-Package: libkf6newstuff-dev
  _ZGVZN9QMetaType21registerConverterImplI5QListIN7KNSCore5EntryEE9QIterableI13QMetaSequenceEEEbSt8functionIFbPKvPvEES_S_E10unregister@Base 6.0.0
@@ -34,6 +34,7 @@ libKF6NewStuffCore.so.6 libkf6newstuffco
  _ZN7KNSCore10EngineBase20uploadEnabledChangedEv@Base 6.0.0
  _ZN7KNSCore10EngineBase21signalProvidersLoadedEv@Base 6.0.0
  _ZN7KNSCore10EngineBase22slotProviderFileLoadedERK12QDomDocument@Base 6.0.0
+ _ZN7KNSCore10EngineBase25contentWarningTypeChangedEv@Base 6.3.0
  _ZN7KNSCore10EngineBase25signalSearchPresetsLoadedERK5QListINS_8Provider12SearchPresetEE@Base 6.0.0
  _ZN7KNSCore10EngineBase29signalCategoriesMetadataLodedERK5QListINS_8Provider16CategoryMetadataEE@Base 6.0.0
  _ZN7KNSCore10EngineBase4initERK7QString@Base 6.0.0
@@ -297,6 +298,7 @@ libKF6NewStuffCore.so.6 libkf6newstuffco
  _ZNK7KNSCore10EngineBase15atticaProvidersEv@Base 6.0.0
  _ZNK7KNSCore10EngineBase15defaultProviderEv@Base 6.0.0
  _ZNK7KNSCore10EngineBase17downloadTagFilterEv@Base 6.0.0
+ _ZNK7KNSCore10EngineBase18contentWarningTypeEv@Base 6.3.0
  _ZNK7KNSCore10EngineBase18hasAdoptionCommandEv@Base 6.0.0
  _ZNK7KNSCore10EngineBase4nameEv@Base 6.0.0
  _ZNK7KNSCore10EngineBase5cacheEv@Base 6.0.0
@@ -413,7 +415,6 @@ libKF6NewStuffCore.so.6 libkf6newstuffco
  (optional=templinst|arch=!armel !riscv64)_ZTISt11_Mutex_baseILN9__gnu_cxx12_Lock_policyE2EE@Base 6.0.0
  (optional=templinst|arch=armel riscv64)_ZTISt16_Sp_counted_baseILN9__gnu_cxx12_Lock_policyE1EE@Base 6.0.0
  (optional=templinst|arch=!armel !riscv64)_ZTISt16_Sp_counted_baseILN9__gnu_cxx12_Lock_policyE2EE@Base 6.0.0
- (optional=templinst)_ZTISt19_Sp_make_shared_tag@Base 6.0.0
  _ZTIZN9QMetaType17registerConverterI5QListIN7KNSCore5EntryEE9QIterableI13QMetaSequenceEN9QtPrivate33QSequentialIterableConvertFunctorIS4_EEEEbT1_EUlPKvPvE_@Base 6.0.0
  _ZTIZN9QMetaType17registerConverterI5QListISt4pairI10QByteArrayS3_EE9QIterableI13QMetaSequenceEN9QtPrivate33QSequentialIterableConvertFunctorIS5_EEEEbT1_EUlPKvPvE_@Base 6.0.0
  _ZTIZN9QMetaType17registerConverterISt4pairI10QByteArrayS2_EN17QtMetaTypePrivate25QPairVariantInterfaceImplENS4_35QPairVariantInterfaceConvertFunctorIS3_EEEEbT1_EUlPKvPvE_@Base 6.0.0
diff -pruN 6.0.0-3/debian/upstream/signing-key.asc 6.3.0-1/debian/upstream/signing-key.asc
--- 6.0.0-3/debian/upstream/signing-key.asc	2024-05-14 09:19:18.000000000 +0000
+++ 6.3.0-1/debian/upstream/signing-key.asc	2024-06-07 22:16:49.000000000 +0000
@@ -80,3 +80,24 @@ RUqSlBSJqC4WqZmkB73i16MljvT0+4v2upmud4JK
 oS4=
 =yOFv
 -----END PGP PUBLIC KEY BLOCK-----
+-----BEGIN PGP PUBLIC KEY BLOCK-----
+
+mDMEZZxtxBYJKwYBBAHaRw8BAQdAm/8PHszWuXJwUEeEwowgbi7fIeUDP/r9X14f
+Azm23ay0JU5pY29sYXMgRmVsbGEgPG5pY29sYXMuZmVsbGFAa2RlLm9yZz6IkwQT
+FgoAOxYhBJCpaKyoRTfMJ7meryyN9Yem1KrBBQJlnG8zAhsDBQsJCAcCAiICBhUK
+CQgLAgQWAgMBAh4HAheAAAoJECyN9Yem1KrBeP4BAIKpXwECsL4VtZtg2h6uUCZg
+e6oALUd6LYH6+DAM2cGzAP9nRCB06lOnWPiz3PccQDeGPGTl4fJXM63rXIKvxI8n
+C7QkTmljb2xhcyBGZWxsYSA8bmljb2xhcy5mZWxsYUBnbXguZGU+iJMEExYKADsW
+IQSQqWisqEU3zCe5nq8sjfWHptSqwQUCZZxtxAIbAwULCQgHAgIiAgYVCgkICwIE
+FgIDAQIeBwIXgAAKCRAsjfWHptSqwb/cAQDdwi3Ujltdb58uFEN9Wxvv2a/PmJJr
+v76mHWmXqia0UwD/fpQfF7W6Iv6tEoqE2VQjMdboRqumV2m9lDyB3OPwtg+4MwRl
+nG3EFgkrBgEEAdpHDwEBB0ABCziM0Ive6TFO3hWrLxpYFCti3xUL7fLLdJqIJYHc
+O4h4BBgWCgAgFiEEkKlorKhFN8wnuZ6vLI31h6bUqsEFAmWcbcQCGyAACgkQLI31
+h6bUqsFXfQD9G8xNZ6QbfOeP/ARYPH7xUcc2U4/kPjoP8+R/MRnshPMBANDv6T3y
+BxoNXQRYK65x7ghXOSZcQyBLfVuSQshzf/oBuDgEZZxtxBIKKwYBBAGXVQEFAQEH
+QAOAXtH8j+F4XstbXodRsjUSLSQx3doS6cssY8XiZWZ5AwEIB4h4BBgWCgAgFiEE
+kKlorKhFN8wnuZ6vLI31h6bUqsEFAmWcbcQCGwwACgkQLI31h6bUqsFomwD/Zy41
+I8jssyuukIKsRefmsvFeeMKEJgFp0WuZQaZnKEIBANbtyBSxCOkD+5GYm1cjG6nr
+yPRSi/2EuYie6axT6ZIN
+=Noyp
+-----END PGP PUBLIC KEY BLOCK-----
diff -pruN 6.0.0-3/metainfo.yaml 6.3.0-1/metainfo.yaml
--- 6.0.0-3/metainfo.yaml	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/metainfo.yaml	2024-05-31 13:26:56.000000000 +0000
@@ -1,7 +1,6 @@
 # SPDX-FileCopyrightText: none
 # SPDX-License-Identifier: CC0-1.0
 
-maintainer: leinir
 description: Support for downloading application assets from the network
 tier: 3
 type: solution
diff -pruN 6.0.0-3/po/af/knewstuff6.po 6.3.0-1/po/af/knewstuff6.po
--- 6.0.0-3/po/af/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/af/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -3,7 +3,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4 stable\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2006-01-12 16:33+0200\n"
 "Last-Translator: JUANITA FRANZ <JUANITA.FRANZ@VR-WEB.DE>\n"
 "Language-Team: AFRIKAANS <translate-discuss-af@lists.sourceforge.net>\n"
@@ -48,7 +48,7 @@ msgstr "Nee teks was vervang."
 msgid "You are now a fan."
 msgstr ""
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -119,7 +119,7 @@ msgstr "Opstelling lêers"
 msgid "Use"
 msgstr "Onskadu"
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -127,18 +127,18 @@ msgid ""
 "This is a critical error and should be reported to the application author"
 msgstr ""
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, fuzzy, kde-format
 #| msgid "Loading resource '%1' failed!"
 msgid "Loading of providers from file: %1 failed"
 msgstr "Laai van hulpbron '%1' het gevaal!"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr ""
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, fuzzy, kde-format
 #| msgid "Error parsing providers list."
 msgid "Error initializing provider."
@@ -286,14 +286,14 @@ msgid ""
 "the update"
 msgstr ""
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, fuzzy, kde-format
 msgid ""
 "Failed to adopt '%1'\n"
 "%2"
 msgstr "Kan nie hulpbron '%1' laai nie"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, fuzzy, kde-format
 #| msgid "Categories"
 msgctxt ""
@@ -301,7 +301,7 @@ msgctxt ""
 msgid "All Categories"
 msgstr "Katagoriee"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, fuzzy, kde-format
 #| msgctxt "QFile"
 #| msgid "Unknown error"
@@ -328,14 +328,14 @@ msgstr ""
 msgid "Download New %1…"
 msgstr "Laai nuwe %1 af"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, fuzzy, kde-format
 #| msgid "Download New %1"
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "Laai nuwe %1 af"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
 msgctxt ""
@@ -344,13 +344,13 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "Laai 'New Stuff' af"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, fuzzy, kde-format
 #| msgid "Resource Installation Error"
 msgid "Pick Your Installation Option"
 msgstr "Hulpbron Installasie Fout"
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -359,12 +359,12 @@ msgid ""
 "this through the naming of the items."
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "Installeer"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -372,7 +372,7 @@ msgctxt ""
 msgid "Installing %1 from %2"
 msgstr "Installeer"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -380,10 +380,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -392,10 +392,10 @@ msgctxt ""
 msgid "Install"
 msgstr "Installeer"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -403,24 +403,24 @@ msgctxt ""
 msgid "Install…"
 msgstr "Installeer"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, fuzzy, kde-format
 #| msgid "Update"
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "Update"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "Installeer"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -428,14 +428,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -446,12 +446,12 @@ msgid ""
 "to the KDE Community in a bug report</a>."
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, fuzzy, kde-format
 #| msgid "Comment"
 msgctxt ""
@@ -460,19 +460,19 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "Kommentaar"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, fuzzy, kde-format
 #| msgid "Rating"
 msgid "Rating:"
 msgstr "Gradering"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, fuzzy, kde-format
 #| msgid "Homepage"
 msgid "Homepage:"
 msgstr "Tuisblad"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -481,12 +481,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -494,73 +494,81 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr ""
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, fuzzy, kde-format
 #| msgid "&Tile"
 msgid "Tiles"
 msgstr "Teël"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "Ikoone"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, fuzzy, kde-format
 #| msgid "Preview URL:"
 msgid "Preview"
 msgstr "Voorskou URL:"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, fuzzy, kde-format
 #| msgid "Details"
 msgid "Detailed Tiles View Mode"
 msgstr "Details"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, fuzzy, kde-format
 #| msgid "Icon Size"
 msgid "Icons Only View Mode"
 msgstr "Ikoon Grootte"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, fuzzy, kde-format
 #| msgid "Details"
 msgid "Large Preview View Mode"
 msgstr "Details"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr ""
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, fuzzy, kde-format
 #| msgid "Install"
 msgid "Installed"
 msgstr "Installeer"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, fuzzy, kde-format
 #| msgid "Update"
 msgid "Updateable"
 msgstr "Update"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, fuzzy, kde-format
 #| msgid "Show all options"
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "Vertoon alle opsies"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, fuzzy, kde-format
 #| msgid "Show all options"
 msgctxt ""
@@ -568,7 +576,7 @@ msgctxt ""
 msgid "Show Only Installed Entries"
 msgstr "Vertoon alle opsies"
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, fuzzy, kde-format
 #| msgid "Show all options"
 msgctxt ""
@@ -577,31 +585,31 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr "Vertoon alle opsies"
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, fuzzy, kde-format
 #| msgctxt "QAccel"
 #| msgid "Percent"
 msgid "Recent"
 msgstr "Percent"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr ""
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, fuzzy, kde-format
 #| msgid "Rating"
 msgid "Rating"
 msgstr "Gradering"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, fuzzy, kde-format
 #| msgid "Download"
 msgid "Downloads"
 msgstr "Aflaai"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, fuzzy, kde-format
 #| msgid "Most Downloads"
 msgctxt ""
@@ -610,7 +618,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "Meeste keer afgelaai"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -618,14 +626,14 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr ""
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, fuzzy, kde-format
 #| msgid "Highest Rated"
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "Hoogste Geag"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, fuzzy, kde-format
 #| msgid "Most Downloads"
 msgctxt ""
@@ -633,49 +641,49 @@ msgctxt ""
 msgid "Show Most Downloaded First"
 msgstr "Meeste keer afgelaai"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, fuzzy, kde-format
 #| msgid "&Upload"
 msgid "Upload…"
 msgstr "Laai op"
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr ""
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, fuzzy, kde-format
 #| msgid "&Go To..."
 msgid "Go to…"
 msgstr "Gaan Na..."
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, fuzzy, kde-format
 #| msgid "S&earch:"
 msgid "Search…"
 msgstr "Soek:"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, fuzzy, kde-format
 #| msgid "Categories"
 msgid "Category:"
 msgstr "Katagoriee"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, fuzzy, kde-format
 #| msgid "Continue operation"
 msgid "Contribute your own…"
 msgstr "Gaan voort operasie"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, kde-format
 msgctxt ""
 "Placeholder title for when a comment has no subject, but does have a rating"
 msgid "<i>(no title)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -683,20 +691,20 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, fuzzy, kde-format
 #| msgid "Categories"
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "Katagoriee"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -704,7 +712,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -712,16 +720,16 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, fuzzy, kde-format
 #| msgid "Download"
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
 msgstr "Aflaai"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, fuzzy, kde-format
 #| msgid "<b>Error</b>: %1: %2"
 msgctxt ""
@@ -730,7 +738,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "<b>Fout</b>: %1: %2"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -738,7 +746,7 @@ msgctxt ""
 msgid "Working…"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, fuzzy, kde-format
 #| msgid "Update"
 msgctxt ""
@@ -747,7 +755,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "Update"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -758,7 +766,7 @@ msgid ""
 "bug report</a>."
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt "Label for the busy indicator showing an item is installing"
@@ -779,13 +787,13 @@ msgstr "Geen fout het voorgekom"
 msgid "Please try again later."
 msgstr "Vul asseblief 'n naam in."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, fuzzy, kde-format
 #| msgid "None"
 msgid "None"
 msgstr "Geen"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, fuzzy, kde-format
 #| msgid "(%1/s)"
 msgctxt ""
@@ -793,14 +801,14 @@ msgctxt ""
 msgid "(%1/%2)"
 msgstr "(%1/s)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "Laai 'New Stuff' af"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, fuzzy, kde-format
 #| msgid "Information"
 msgctxt ""
@@ -808,21 +816,21 @@ msgctxt ""
 msgid "Updating information…"
 msgstr "Informasie"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, fuzzy, kde-format
 #| msgid "Store"
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "Stoor"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, fuzzy, kde-format
 #| msgid "Hide %1"
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "Steek %1 weg"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, fuzzy, kde-format
 #| msgid "&Open with '%1'"
 msgctxt ""
@@ -831,7 +839,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "Maak oop met '%1'"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, fuzzy, kde-format
 #| msgid "&Send Email"
 msgctxt ""
@@ -840,7 +848,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "Stuur E-pos"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -848,10 +856,10 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -863,20 +871,20 @@ msgid ""
 "content added."
 msgstr ""
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, fuzzy, kde-format
 #| msgid "Loading Applet"
 msgid "Loading data"
 msgstr "Laaiïng van Miniprogram"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, fuzzy, kde-format
 #| msgid "Install"
 msgid "Installing"
 msgstr "Installeer"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -886,41 +894,41 @@ msgid ""
 "please contact the person in charge of your permissions."
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, fuzzy, kde-format
 #| msgid "Back"
 msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "Terug"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, fuzzy, kde-format
 #| msgid "Saturday"
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "Saterdag"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, fuzzy, kde-format
 #| msgid "Restart"
 msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "Herbegin"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, fuzzy, kde-format
 #| msgid "New"
 msgctxt "Knewstuff5"
 msgid "New"
 msgstr "Nuwe"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, fuzzy, kde-format
 #| msgctxt "Opposite to End"
 #| msgid "Home"
@@ -928,39 +936,39 @@ msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Begin"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, fuzzy, kde-format
 #| msgid "Up"
 msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "Op"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, fuzzy, kde-format
 msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "Skrip"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, fuzzy, kde-format
 #| msgid "Show all options"
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "Vertoon alle opsies"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -993,10 +1001,16 @@ msgstr ""
 #: widgets/action.cpp:28 widgets/button.cpp:70
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
-msgid "Download New Stuff..."
+msgctxt "@action"
+msgid "Download New Stuff…"
 msgstr "Laai 'New Stuff' af"
 
 #, fuzzy
+#~| msgid "Download New Stuff"
+#~ msgid "Download New Stuff..."
+#~ msgstr "Laai 'New Stuff' af"
+
+#, fuzzy
 #~| msgid "Install"
 #~ msgid "Initializing"
 #~ msgstr "Installeer"
diff -pruN 6.0.0-3/po/ar/knewstuff6.po 6.3.0-1/po/ar/knewstuff6.po
--- 6.0.0-3/po/ar/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/ar/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -3,8 +3,8 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
-"PO-Revision-Date: 2024-01-20 18:43+0400\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
+"PO-Revision-Date: 2024-05-09 09:45+0400\n"
 "Last-Translator: Zayed Al-Saidi <zayed.alsaidi@gmail.com>\n"
 "Language-Team: ar\n"
 "Language: ar\n"
@@ -53,7 +53,7 @@ msgstr "أرسل صوتك بنجاح."
 msgid "You are now a fan."
 msgstr "تم تسجيل صوتك."
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -119,7 +119,7 @@ msgstr "ملف الضبط غير صال
 msgid "Use"
 msgstr "استخدم"
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -130,17 +130,17 @@ msgstr ""
 "%2\n"
 "هذا خطأ فادح ويجب إبلاغ مؤلف التطبيق"
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr "فشل تحميل المزودين من ملف: %1"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr "لا يمكن تحميل مزودي الحصول على الأشياء الجديدة من ملف: %1"
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr "خطأ في تهيئة المزود."
@@ -304,7 +304,7 @@ msgid ""
 "the update"
 msgstr "فشلنا في التعرف على رابط جيد لتحديث %1 ، ولا يمكننا إجراء التحديث"
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, kde-format
 msgid ""
 "Failed to adopt '%1'\n"
@@ -313,14 +313,14 @@ msgstr ""
 "فشل في الاعتماد  '%1'\n"
 "%2"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, kde-format
 msgctxt ""
 "The first entry in the category selection list (also the default value)"
 msgid "All Categories"
 msgstr "جميع التصنيفات"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, kde-format
 msgctxt ""
 "The string passed back in the case the requested category is not known"
@@ -345,13 +345,13 @@ msgstr "أشياء جديدة"
 msgid "Download New %1…"
 msgstr "نزّل %1…"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, kde-format
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "نزّل أشياء %1"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, kde-format
 msgctxt ""
 "A placeholder title used in the dialog when there is no better title "
@@ -359,12 +359,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "نزِل أشياء جديدة"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr "اختر خيار تثبيتك"
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -377,19 +377,19 @@ msgstr ""
 "المتاحة ، فيرجى الاتصال بمؤلف هذا العنصر واطلب منه توضيح ذلك من خلال تسمية "
 "العناصر."
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "ثبّت"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, kde-format
 msgctxt ""
 "A passive notification shown when installation of an item is initiated"
 msgid "Installing %1 from %2"
 msgstr "يثبّت %1 من %2"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -397,10 +397,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr "%1 لِـ %2"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, kde-format
 msgctxt ""
 "Request installation of this item, available when there is exactly one "
@@ -408,32 +408,32 @@ msgctxt ""
 msgid "Install"
 msgstr "ثبّت"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, kde-format
 msgctxt ""
 "Show installation options, where there is more than one downloadable item"
 msgid "Install…"
 msgstr "ثبّت…"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, kde-format
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "حدّث"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, kde-format
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "أزل"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -441,14 +441,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr "يعمل حاليا على العنصر %1 بواسطة %2. الرجاء الانتظار…"
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr "يحدث حاليا العنصر %1 بواسطة %2. الرجاء الانتظار…"
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -462,12 +462,12 @@ msgstr ""
 "enter_bug.cgi?product=frameworks-knewstuff\">الرجاء التبليغ مجتمع كِيدِي في "
 "تقرير علة</a>."
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr "التعليقات والمراجعات:"
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a new sub page with comments (comments "
@@ -475,17 +475,17 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "%1 تعليقات ومراجعات"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, kde-format
 msgid "Rating:"
 msgstr "التّقييم:"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, kde-format
 msgid "Homepage:"
 msgstr "الصّفحة الرّئيسيّة:"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -494,12 +494,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr "افتح الصفحة الرئيسية لـ %1"
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr "كيف تتبرع:"
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -507,74 +507,85 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr "تعرف على كيفية التبرع لهذا المشروع"
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+"توخى الحذر عند الوصول إلى المحتوى الذي أنشأه المستخدم الموضح هنا، لأنه قد "
+"يحتوي على تعليمات برمجية قابلة للتنفيذ لم تفحص من قبل كيدي أو الموزع الخاص "
+"بك من حيث السلامة أو الاستقرار أو الجودة"
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
-"المحتوى المتاح هنا مرفوع من قبل مستخدمين مثلك، ولم يراجع من قبل الموزع الخاص "
-"بك من أجل الوظائف أو الاستقرار."
+"المحتوى الذي أنشأه المستخدم والموضح هنا لم يفحص من قبل كيدي أو الموزع الخاص "
+"بك من حيث الأداء الوظيفي أو الجودة."
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, kde-format
 msgid "Tiles"
 msgstr "القراميد"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "الأيقونات"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, kde-format
 msgid "Preview"
 msgstr "المعاينة"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, kde-format
 msgid "Detailed Tiles View Mode"
 msgstr "وضع عرض التفاصيل القراميد"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, kde-format
 msgid "Icons Only View Mode"
 msgstr "وضع عرض الأيقونات فقط"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, kde-format
 msgid "Large Preview View Mode"
 msgstr "وضع عرض المصغرات الكبيرة"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr "كلّ شيء"
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "الأكثر تثبيتاً"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, kde-format
 msgid "Updateable"
 msgstr "القابل للتحديث"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, kde-format
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "اعرض كلّ المدخلات"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr "أظهر المدخلات المثبتة فقط"
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -582,27 +593,27 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr "أظهر المدخلات القابلة للتحديث فقط"
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, kde-format
 msgid "Recent"
 msgstr "الحديثة"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr "أبجديّ"
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "الأفضل تقييماً"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, kde-format
 msgid "Downloads"
 msgstr "التنزيلات"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on when items were most "
@@ -610,7 +621,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "أظهر الأحدث أولا"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -618,57 +629,57 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr "افرز أبجديًا بواسطة الاسم"
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, kde-format
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "أظهر الأعلى تقيما أولا"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on number of downloads"
 msgid "Show Most Downloaded First"
 msgstr "أظهر الأكثر تحميلاً أولا"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, kde-format
 msgid "Upload…"
 msgstr "يرفع…"
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr "تعلم كيف تضيف أشيائك إلى هذه القائمة"
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, kde-format
 msgid "Go to…"
 msgstr "اذهب إلى…"
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, kde-format
 msgid "Search…"
 msgstr "ابحث…"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "التصنيف:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, kde-format
 msgid "Contribute your own…"
 msgstr "ساهم بما معك…"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, kde-format
 msgctxt ""
 "Placeholder title for when a comment has no subject, but does have a rating"
 msgid "<i>(no title)</i>"
 msgstr "<i>(بدون عنوان)</i>"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -676,19 +687,19 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr "%1 <i>(المؤلف)</i>"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr "التعليقات والمراجعات لـ %1"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, kde-format
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "أظهر كلّ التعليقات"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -696,7 +707,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr "أظهر المراجعات فقط"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -704,15 +715,15 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr "أظهر المراجعات و الردود"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, kde-format
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
 msgstr "%1 تنزيل"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, kde-format
 msgctxt ""
 "Subheading for the tile view, located immediately underneath the name of the "
@@ -720,7 +731,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "بواسطة <i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -728,7 +739,7 @@ msgctxt ""
 msgid "Working…"
 msgstr "يعمل…"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is in the process of being "
@@ -736,7 +747,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "يحدّث…"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -749,7 +760,7 @@ msgstr ""
 "غير صالح أو في حالة مجهولة . <a href=\"https://bugs.kde.org/enter_bug.cgi?"
 "product=frameworks-knewstuff\">الرجاء التبليغ مجتمع كِيدِي في تقرير علة</a>."
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, kde-format
 msgctxt "Label for the busy indicator showing an item is installing"
 msgid "Installing…"
@@ -766,44 +777,44 @@ msgstr "حدث خطأ"
 msgid "Please try again later."
 msgstr "الرجاء المحاولة مرة أخرى في وقت لاحق."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, kde-format
 msgid "None"
 msgstr "بلا"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, kde-format
 msgctxt ""
 "A text representation of the rating, shown as a fraction of the max value"
 msgid "(%1/%2)"
 msgstr "(%1/%2)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, kde-format
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "يرفع: %1"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, kde-format
 msgctxt ""
 "A text shown beside a busy indicator suggesting that data is being fetched"
 msgid "Updating information…"
 msgstr "يحدث المعلومات…"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, kde-format
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "متجر كِيدِي"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, kde-format
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "مزودك:"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, kde-format
 msgctxt ""
 "Text for an action which causes the specified website to be opened using the "
@@ -811,7 +822,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "افتح موقع : %1"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, kde-format
 msgctxt ""
 "Text for an action which will attempt to send an email using the user's "
@@ -819,7 +830,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "أرسل بريدًا إلى: %1"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -827,15 +838,14 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 "لتحميل إدخالات جديدة ، أو لإضافة محتوى إلى إدخال موجود في متجر كِيدِي ، يرجى "
 "فتح موقع الويب وتسجيل الدخول. بمجرد القيام بذلك ، ستتمكن من العثور على إدخال "
 "\"منتجاتي\" في القائمة التي تنبثق عندما انقر فوق رمز المستخدم الخاص بك. انقر "
-"فوق هذا الإدخال للانتقال إلى نظام إدارة المنتج ، حيث يمكنك العمل على "
-"منتجاتك. "
+"فوق هذا الإدخال للانتقال إلى نظام إدارة المنتج ، حيث يمكنك العمل على منتجاتك."
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -852,18 +862,18 @@ msgstr ""
 "الإضافة. بدلاً من ذلك ، قد يُطلب منك الاتصال بمديري الموقع مباشرةً لإضافة محتوى "
 "جديد."
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "يحمّل البيانات"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "يثبّت"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -875,73 +885,73 @@ msgstr ""
 "لست مخولاً للحصول على الأشياء الجديدة. إذا كنت تعتقد أن هذا عن طريق الخطأ ، "
 "فيرجى الاتصال بالمسؤول عن الأذونات الخاصة بك."
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "عُد"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr "الرائج"
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "مُختارة"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "أعد التّشغيل"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "New"
 msgstr "جديد"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "المنزل"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr "الرف"
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "الأعلى"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "مستحسن"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "الاشتراكات"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "كلّ المدخلات"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -985,8 +995,12 @@ msgstr ""
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
 #, kde-format
-msgid "Download New Stuff..."
-msgstr "نزِل أشياء جديدة..."
+msgctxt "@action"
+msgid "Download New Stuff…"
+msgstr "نزِل أشياء جديدة…"
+
+#~ msgid "Download New Stuff..."
+#~ msgstr "نزِل أشياء جديدة..."
 
 #~ msgctxt ""
 #~ "A message which is shown when the user attempts to display a specific "
diff -pruN 6.0.0-3/po/as/knewstuff6.po 6.3.0-1/po/as/knewstuff6.po
--- 6.0.0-3/po/as/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/as/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -7,7 +7,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4_as\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2008-12-26 15:19+0530\n"
 "Last-Translator: Amitakhya Phukan <অমিতাক্ষ ফুকন>\n"
 "Language-Team: Assamese <fedora-trans-as@redhat.com>\n"
@@ -53,7 +53,7 @@ msgstr "কোনো লিপি প্
 msgid "You are now a fan."
 msgstr ""
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -121,7 +121,7 @@ msgstr "বিন্যাস নথি
 msgid "Use"
 msgstr ""
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -129,17 +129,17 @@ msgid ""
 "This is a critical error and should be reported to the application author"
 msgstr ""
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr ""
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr ""
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr ""
@@ -285,7 +285,7 @@ msgid ""
 "the update"
 msgstr ""
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, fuzzy, kde-format
 #| msgid "Failed to load file '%1'"
 msgid ""
@@ -293,7 +293,7 @@ msgid ""
 "%2"
 msgstr "নথিপত্ৰ '%1' লোড কৰিবলৈ ব্যৰ্থ"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, fuzzy, kde-format
 #| msgid "Pages"
 msgctxt ""
@@ -301,7 +301,7 @@ msgctxt ""
 msgid "All Categories"
 msgstr "পৃষ্ঠা"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, fuzzy, kde-format
 #| msgid "Unknown error"
 msgctxt ""
@@ -327,14 +327,14 @@ msgstr ""
 msgid "Download New %1…"
 msgstr "নতুন %1 ডাউনলোড কৰক"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, fuzzy, kde-format
 #| msgid "Download New %1"
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "নতুন %1 ডাউনলোড কৰক"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
 msgctxt ""
@@ -343,12 +343,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "নতুন বস্তু ডাউনলোড কৰক"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -357,12 +357,12 @@ msgid ""
 "this through the naming of the items."
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "সংস্থাপন কৰক"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -370,7 +370,7 @@ msgctxt ""
 msgid "Installing %1 from %2"
 msgstr "সংস্থাপন কৰক"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -378,10 +378,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -390,10 +390,10 @@ msgctxt ""
 msgid "Install"
 msgstr "সংস্থাপন কৰক"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -401,24 +401,24 @@ msgctxt ""
 msgid "Install…"
 msgstr "সংস্থাপন কৰক"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, fuzzy, kde-format
 #| msgid "Update"
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "উন্নয়ন কৰক"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, fuzzy, kde-format
 #| msgid "Uninstall"
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "গুচাওক"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -426,14 +426,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -444,12 +444,12 @@ msgid ""
 "to the KDE Community in a bug report</a>."
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, fuzzy, kde-format
 #| msgid "View Comments"
 msgctxt ""
@@ -458,19 +458,19 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "মন্তব্য প্ৰদৰ্শন কৰা হ'ব"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, fuzzy, kde-format
 #| msgid "Rating: "
 msgid "Rating:"
 msgstr "গুৰুত্বৰ মান:"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, fuzzy, kde-format
 #| msgid "Homepage"
 msgid "Homepage:"
 msgstr "হোম পৃষ্ঠা"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -479,12 +479,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -492,79 +492,87 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr ""
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, fuzzy, kde-format
 #| msgid "File"
 msgid "Tiles"
 msgstr "নথিপত্ৰ"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "আইকন"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, fuzzy, kde-format
 #| msgid "No Preview"
 msgid "Preview"
 msgstr "পূৰ্বৰূপ অনুপস্থিত"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, kde-format
 msgid "Detailed Tiles View Mode"
 msgstr ""
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, fuzzy, kde-format
 #| msgid "Icons Only"
 msgid "Icons Only View Mode"
 msgstr "অকল আইকন"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, fuzzy, kde-format
 #| msgid "Preview URL:"
 msgid "Large Preview View Mode"
 msgstr "পূৰ্বৰূপ প্ৰদৰ্শনৰ URL:"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr ""
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, fuzzy, kde-format
 #| msgid "Install"
 msgid "Installed"
 msgstr "সংস্থাপন কৰক"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, fuzzy, kde-format
 #| msgid "Update"
 msgid "Updateable"
 msgstr "উন্নয়ন কৰক"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, fuzzy, kde-format
 #| msgid "Pages"
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "পৃষ্ঠা"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -572,31 +580,31 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Open Recent"
 msgid "Recent"
 msgstr "সম্প্ৰতি ব্যৱহৃত খোলক"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr ""
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, fuzzy, kde-format
 #| msgid "Rating: "
 msgid "Rating"
 msgstr "গুৰুত্বৰ মান:"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, fuzzy, kde-format
 #| msgid "Download"
 msgid "Downloads"
 msgstr "ডাউন্‌লোড কৰা হ'ব"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt ""
@@ -605,7 +613,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "প্ৰথমে পঞ্জিকা প্ৰদৰ্শিত হ'ব"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -613,14 +621,14 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr ""
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "প্ৰথমে পঞ্জিকা প্ৰদৰ্শিত হ'ব"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, fuzzy, kde-format
 #| msgid "Most Downloads"
 msgctxt ""
@@ -628,42 +636,42 @@ msgctxt ""
 msgid "Show Most Downloaded First"
 msgstr "সৰ্বাধিকবাৰ ডাউন্‌লোড কৰা হৈছে"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, fuzzy, kde-format
 #| msgid "&Replace..."
 msgid "Upload…"
 msgstr "প্ৰতিস্থাপন...(&R)"
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr ""
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, fuzzy, kde-format
 #| msgid "&Go To..."
 msgid "Go to…"
 msgstr "-লৈ যাওক...(&G)"
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, fuzzy, kde-format
 #| msgid "S&earch:"
 msgid "Search…"
 msgstr "অনুসন্ধান:(&e)"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, fuzzy, kde-format
 #| msgid "Character:"
 msgid "Category:"
 msgstr "অক্ষৰ:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, fuzzy, kde-format
 #| msgid "Continue operation"
 msgid "Contribute your own…"
 msgstr "কাৰ্য্যত আগবাঢ়ক"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, fuzzy, kde-format
 #| msgctxt "@note/rich"
 #| msgid "<i>Note</i>: %1"
@@ -672,7 +680,7 @@ msgctxt ""
 msgid "<i>(no title)</i>"
 msgstr "<i>টোকা</i>: %1"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -680,20 +688,20 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, fuzzy, kde-format
 #| msgid "Pages"
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "পৃষ্ঠা"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -701,7 +709,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -709,16 +717,16 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, fuzzy, kde-format
 #| msgid "Download"
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
 msgstr "ডাউন্‌লোড কৰা হ'ব"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, fuzzy, kde-format
 #| msgctxt "@interface/rich"
 #| msgid "<i>%1</i>"
@@ -728,7 +736,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "<i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -736,7 +744,7 @@ msgctxt ""
 msgid "Working…"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, fuzzy, kde-format
 #| msgid "Update"
 msgctxt ""
@@ -745,7 +753,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "উন্নয়ন কৰক"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -756,7 +764,7 @@ msgid ""
 "bug report</a>."
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt "Label for the busy indicator showing an item is installing"
@@ -775,14 +783,14 @@ msgstr ""
 msgid "Please try again later."
 msgstr "অনুগ্ৰহ কৰি নাম লিখক:"
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, fuzzy, kde-format
 #| msgctxt "No border line"
 #| msgid "None"
 msgid "None"
 msgstr "শূণ্য"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, fuzzy, kde-format
 #| msgid "(%1/s)"
 msgctxt ""
@@ -790,14 +798,14 @@ msgctxt ""
 msgid "(%1/%2)"
 msgstr "(%1/s)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "নতুন বস্তু ডাউনলোড কৰক"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, fuzzy, kde-format
 #| msgid "Billing Information:"
 msgctxt ""
@@ -805,21 +813,21 @@ msgctxt ""
 msgid "Updating information…"
 msgstr "বিল সংক্ৰান্ত তথ্য"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, fuzzy, kde-format
 #| msgid "Store"
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "সংৰক্ষণ কৰা হ'ব"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, fuzzy, kde-format
 #| msgid "Provider: %1"
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "উপলব্ধকৰোঁতা: %1"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, fuzzy, kde-format
 #| msgid "&Open with '%1'"
 msgctxt ""
@@ -828,7 +836,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "'%1' সহযোগে খোলক (&O)"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, fuzzy, kde-format
 #| msgid "&Send Email"
 msgctxt ""
@@ -837,7 +845,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "ঈ-মেইল কৰক (&S)"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -845,10 +853,10 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -860,20 +868,20 @@ msgid ""
 "content added."
 msgstr ""
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, fuzzy, kde-format
 #| msgid "Loading Applet"
 msgid "Loading data"
 msgstr "এপ্লেট তুলি লোৱা হৈছে"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, fuzzy, kde-format
 #| msgid "Install"
 msgid "Installing"
 msgstr "সংস্থাপন কৰক"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -883,7 +891,7 @@ msgid ""
 "please contact the person in charge of your permissions."
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Back"
@@ -891,20 +899,20 @@ msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "পূৰ্ববৰ্তী"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, fuzzy, kde-format
 #| msgid "Saturday"
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "Saturday"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, fuzzy, kde-format
 #| msgctxt "@action:button Restart find & replace"
 #| msgid "Restart"
@@ -912,7 +920,7 @@ msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "পুনৰাৰম্ভ কৰক"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "New"
@@ -920,7 +928,7 @@ msgctxt "Knewstuff5"
 msgid "New"
 msgstr "নতুন"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Home"
@@ -928,13 +936,13 @@ msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Home"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Up"
@@ -942,7 +950,7 @@ msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "Up"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, fuzzy, kde-format
 #| msgctxt "dictionary variant"
 #| msgid "extended"
@@ -950,21 +958,21 @@ msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "প্ৰসাৰিত"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, fuzzy, kde-format
 #| msgid "Description"
 msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "বিৱৰণ"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, fuzzy, kde-format
 #| msgid "Pages"
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "পৃষ্ঠা"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -997,10 +1005,16 @@ msgstr ""
 #: widgets/action.cpp:28 widgets/button.cpp:70
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
-msgid "Download New Stuff..."
+msgctxt "@action"
+msgid "Download New Stuff…"
 msgstr "নতুন বস্তু ডাউনলোড কৰক"
 
 #, fuzzy
+#~| msgid "Download New Stuff"
+#~ msgid "Download New Stuff..."
+#~ msgstr "নতুন বস্তু ডাউনলোড কৰক"
+
+#, fuzzy
 #~| msgid "Install"
 #~ msgid "Initializing"
 #~ msgstr "সংস্থাপন কৰক"
diff -pruN 6.0.0-3/po/ast/knewstuff6.po 6.3.0-1/po/ast/knewstuff6.po
--- 6.0.0-3/po/ast/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/ast/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -6,7 +6,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: knewstuff\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2023-11-07 21:27+0100\n"
 "Last-Translator: Enol P. <enolp@softastur.org>\n"
 "Language-Team: \n"
@@ -50,7 +50,7 @@ msgstr ""
 msgid "You are now a fan."
 msgstr ""
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -114,7 +114,7 @@ msgstr ""
 msgid "Use"
 msgstr ""
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -122,17 +122,17 @@ msgid ""
 "This is a critical error and should be reported to the application author"
 msgstr ""
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr ""
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr ""
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr ""
@@ -272,21 +272,21 @@ msgid ""
 "the update"
 msgstr ""
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, kde-format
 msgid ""
 "Failed to adopt '%1'\n"
 "%2"
 msgstr ""
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, kde-format
 msgctxt ""
 "The first entry in the category selection list (also the default value)"
 msgid "All Categories"
 msgstr ""
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, kde-format
 msgctxt ""
 "The string passed back in the case the requested category is not known"
@@ -310,13 +310,13 @@ msgstr ""
 msgid "Download New %1…"
 msgstr ""
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, kde-format
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr ""
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, kde-format
 msgctxt ""
 "A placeholder title used in the dialog when there is no better title "
@@ -324,12 +324,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -338,19 +338,19 @@ msgid ""
 "this through the naming of the items."
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, kde-format
 msgctxt ""
 "A passive notification shown when installation of an item is initiated"
 msgid "Installing %1 from %2"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -358,10 +358,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, kde-format
 msgctxt ""
 "Request installation of this item, available when there is exactly one "
@@ -369,32 +369,32 @@ msgctxt ""
 msgid "Install"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, kde-format
 msgctxt ""
 "Show installation options, where there is more than one downloadable item"
 msgid "Install…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, kde-format
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, kde-format
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -402,14 +402,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -420,12 +420,12 @@ msgid ""
 "to the KDE Community in a bug report</a>."
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a new sub page with comments (comments "
@@ -433,17 +433,17 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, kde-format
 msgid "Rating:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, kde-format
 msgid "Homepage:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -452,12 +452,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -465,72 +465,80 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr ""
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, kde-format
 msgid "Tiles"
 msgstr ""
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr ""
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, kde-format
 msgid "Preview"
 msgstr ""
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, kde-format
 msgid "Detailed Tiles View Mode"
 msgstr ""
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, kde-format
 msgid "Icons Only View Mode"
 msgstr ""
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, kde-format
 msgid "Large Preview View Mode"
 msgstr ""
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr ""
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr ""
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, kde-format
 msgid "Updateable"
 msgstr ""
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, kde-format
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -538,27 +546,27 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, kde-format
 msgid "Recent"
 msgstr ""
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr ""
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr ""
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, kde-format
 msgid "Downloads"
 msgstr ""
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on when items were most "
@@ -566,7 +574,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr ""
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -574,57 +582,57 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr ""
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, kde-format
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr ""
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on number of downloads"
 msgid "Show Most Downloaded First"
 msgstr ""
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, kde-format
 msgid "Upload…"
 msgstr ""
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr ""
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, kde-format
 msgid "Go to…"
 msgstr ""
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, kde-format
 msgid "Search…"
 msgstr ""
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr ""
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, kde-format
 msgid "Contribute your own…"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, kde-format
 msgctxt ""
 "Placeholder title for when a comment has no subject, but does have a rating"
 msgid "<i>(no title)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -632,19 +640,19 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, kde-format
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -652,7 +660,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -660,15 +668,15 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, kde-format
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, kde-format
 msgctxt ""
 "Subheading for the tile view, located immediately underneath the name of the "
@@ -676,7 +684,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -684,7 +692,7 @@ msgctxt ""
 msgid "Working…"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is in the process of being "
@@ -692,7 +700,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -703,7 +711,7 @@ msgid ""
 "bug report</a>."
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, kde-format
 msgctxt "Label for the busy indicator showing an item is installing"
 msgid "Installing…"
@@ -720,44 +728,44 @@ msgstr ""
 msgid "Please try again later."
 msgstr ""
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, kde-format
 msgid "None"
 msgstr ""
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, kde-format
 msgctxt ""
 "A text representation of the rating, shown as a fraction of the max value"
 msgid "(%1/%2)"
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, kde-format
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, kde-format
 msgctxt ""
 "A text shown beside a busy indicator suggesting that data is being fetched"
 msgid "Updating information…"
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, kde-format
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, kde-format
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, kde-format
 msgctxt ""
 "Text for an action which causes the specified website to be opened using the "
@@ -765,7 +773,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, kde-format
 msgctxt ""
 "Text for an action which will attempt to send an email using the user's "
@@ -773,7 +781,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -781,10 +789,10 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -796,18 +804,18 @@ msgid ""
 "content added."
 msgstr ""
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr ""
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr ""
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -817,73 +825,73 @@ msgid ""
 "please contact the person in charge of your permissions."
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Back"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "New"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Home"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Up"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -915,5 +923,6 @@ msgstr ""
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
 #, kde-format
-msgid "Download New Stuff..."
+msgctxt "@action"
+msgid "Download New Stuff…"
 msgstr ""
diff -pruN 6.0.0-3/po/az/knewstuff6.po 6.3.0-1/po/az/knewstuff6.po
--- 6.0.0-3/po/az/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/az/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -6,7 +6,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: knewstuff\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2023-01-14 23:42+0400\n"
 "Last-Translator: Kheyyam <xxmn77@gmail.com>\n"
 "Language-Team: Azerbaijani <kde-i18n-doc@kde.org>\n"
@@ -55,7 +55,7 @@ msgstr "Seçiminiz qeydə alındı."
 msgid "You are now a fan."
 msgstr "İndi siz artıq bu əlavənin fanatısınız."
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -126,7 +126,7 @@ msgstr "Konfiqurasiya faylı yararsızd
 msgid "Use"
 msgstr "İstifadə etmək"
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, fuzzy, kde-format
 #| msgid ""
 #| "Could not initialise the installation handler for %1\n"
@@ -139,17 +139,17 @@ msgstr ""
 "%1 üçün quraşdırma idarəedicisini başlatmaq olmur\n"
 "Bu kritik bir səhvdir və tətbiq müəllifinə bildirilməlidir"
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr "Təminatçıların: %1 faylından yüklənməsində xəta"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr "Fayl: %1 -dən təminatçı siyahısını yükləmək mümkün olmadı"
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr "Təminatçının başladılmasında xəta."
@@ -319,7 +319,7 @@ msgstr ""
 "%1 yenilənməsi üçün yararlı bir keçid müəyyənləşdirə və yenilənməni həyata "
 "keçirə bilmədik"
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, kde-format
 msgid ""
 "Failed to adopt '%1'\n"
@@ -328,14 +328,14 @@ msgstr ""
 "\"%1\" qəbul edilə bilmədi.\n"
 "%2"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, kde-format
 msgctxt ""
 "The first entry in the category selection list (also the default value)"
 msgid "All Categories"
 msgstr "Bütün Koteqoriyalar"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, kde-format
 msgctxt ""
 "The string passed back in the case the requested category is not known"
@@ -366,13 +366,13 @@ msgstr "Doldurmaq"
 msgid "Download New %1…"
 msgstr "Yeni %1 yüklə"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, kde-format
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "Yeni %1 yüklə"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, kde-format
 msgctxt ""
 "A placeholder title used in the dialog when there is no better title "
@@ -380,12 +380,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "Yeni materialı yüklə"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr "Materialın quraşdırılma variantını seşin"
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -398,19 +398,19 @@ msgstr ""
 "deyilsə, bu materailın müəllifi ilə əlaqə yaradın və əşyaların adlarının "
 "açıqlanmasını ondan xahiş edin."
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "Quraşdır"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, kde-format
 msgctxt ""
 "A passive notification shown when installation of an item is initiated"
 msgid "Installing %1 from %2"
 msgstr "%1 elementinin %2 ünvanından quraşdırılması"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -418,10 +418,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr "%2 tərəfindən %1"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, kde-format
 msgctxt ""
 "Request installation of this item, available when there is exactly one "
@@ -429,10 +429,10 @@ msgctxt ""
 msgid "Install"
 msgstr "Quraşdırmaq"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -440,22 +440,22 @@ msgctxt ""
 msgid "Install…"
 msgstr "Quraşdır"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, kde-format
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "Yeniləmək"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, kde-format
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "Silmək"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, fuzzy, kde-format
 #| msgctxt ""
 #| "Status message to be shown when the entry is in the process of being "
@@ -467,7 +467,7 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr "%2 tərəfindən %1 komponenti işləyir. Lütfən gözləyin..."
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, fuzzy, kde-format
 #| msgctxt ""
 #| "Status message to be shown when the entry is in the process of being "
@@ -478,7 +478,7 @@ msgctxt ""
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr "%2 tərəfindən %1 komponenti yenilənir. Lütfən gözləyin..."
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -492,12 +492,12 @@ msgstr ""
 "bugs.kde.org/enter_bug.cgi?product=frameworks-knewstuff\">Lütfən bu xəta "
 "haqqında KDE Cəmiyyətinə xəta hesabatı göndərin</a>."
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr "Şərhlər və rəylər:"
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a new sub page with comments (comments "
@@ -505,17 +505,17 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "%1 Rəy və Şərh"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, kde-format
 msgid "Rating:"
 msgstr "Qiymət:"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, kde-format
 msgid "Homepage:"
 msgstr "Ev səhifəsi:"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -524,12 +524,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr "%1 səhifəsini açın"
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr "Necə ianə verməli:"
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -537,75 +537,86 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr "Bu layihəyə necə maddi kömək göstərməyi öyrənin"
 
-#: qtquick/qml/Page.qml:141
-#, kde-format
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
+#, fuzzy, kde-format
+#| msgid ""
+#| "The content available here has been uploaded by users like you, and has "
+#| "not been reviewed by your distributor for functionality or stability."
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 "Burada mövcud olan məzmun sizin kimi istifadəçilər tərəfindən yüklənib və "
 "distribyutorunuz tərəfindən funksionallıq və sabitlik baxımından nəzərdən "
 "keçirilməyib."
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, kde-format
 msgid "Tiles"
 msgstr "Mozaikalar"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "Nişanlar"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, kde-format
 msgid "Preview"
 msgstr "İlk baxış"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, kde-format
 msgid "Detailed Tiles View Mode"
 msgstr "Mozaik görünüş rejimi"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, kde-format
 msgid "Icons Only View Mode"
 msgstr "Yalnız nişanlarla görünüş rejimi"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, kde-format
 msgid "Large Preview View Mode"
 msgstr "Geniş ilk baxış rejimi"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr "Hamısı"
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "Quraşdırılan"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, kde-format
 msgid "Updateable"
 msgstr "Yenilənə bilənlər"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, kde-format
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "Bütün girişləri göstərmək"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr "Yalnız quraşdırılmış girişləri göstərmək"
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -613,27 +624,27 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr "Yalnız yenilənəbilən girişləri göstərmək"
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, kde-format
 msgid "Recent"
 msgstr "Ən yeni"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr "Əlifba sırası ilə"
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "Ən qiymətli"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, kde-format
 msgid "Downloads"
 msgstr "Endirmələr"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on when items were most "
@@ -641,7 +652,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "Öncə ən yeniləri"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -649,60 +660,60 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr "Adına görə əlifba sırası ilə"
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, kde-format
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "Öncə ən çox qiymətləndirilənlər"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on number of downloads"
 msgid "Show Most Downloaded First"
 msgstr "Öncə ən çox endirilənlər"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, fuzzy, kde-format
 #| msgid "Upload..."
 msgid "Upload…"
 msgstr "Yükləmək..."
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr "Bu siyahıya ən yeni elementinizi necə əlavə edəcəyinizi öyrənin"
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, fuzzy, kde-format
 #| msgid "Go to..."
 msgid "Go to…"
 msgstr "Keçmək..."
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, fuzzy, kde-format
 #| msgid "Search:"
 msgid "Search…"
 msgstr "Axtar:"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "Kateqoriya:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, kde-format
 msgid "Contribute your own…"
 msgstr "Öz işinizi əlavə edin..."
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, kde-format
 msgctxt ""
 "Placeholder title for when a comment has no subject, but does have a rating"
 msgid "<i>(no title)</i>"
 msgstr "<i>(başlıqsız)</i>"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -710,19 +721,19 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr "%1 <i>(müəllif)</i>"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr "%1 üçün Rəylər və Şərhlər"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, kde-format
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "Bütün şərhləri göstərmək"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -730,7 +741,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr "Yalnız ryləri göstərmək"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -738,15 +749,15 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr "Rəyləri və Cavabları göstərmək"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, kde-format
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
 msgstr "%1 yüklənən"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, kde-format
 msgctxt ""
 "Subheading for the tile view, located immediately underneath the name of the "
@@ -754,7 +765,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "<i>%1</i> tərəfindən"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, fuzzy, kde-format
 #| msgctxt ""
 #| "Label for the busy indicator showing an item is being installed OR "
@@ -766,7 +777,7 @@ msgctxt ""
 msgid "Working…"
 msgstr "İşləyir..."
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, fuzzy, kde-format
 #| msgid "Updating"
 msgctxt ""
@@ -775,7 +786,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "Yenilənmə"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -789,7 +800,7 @@ msgstr ""
 "product=frameworks-knewstuff\">Lütfən bu xəta haqqında KDE Cəmiyyətinə xəta "
 "hesabatı göndərin</a>."
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt "Label for the busy indicator showing an item is installing"
@@ -807,19 +818,19 @@ msgstr "Xəta baş verdi"
 msgid "Please try again later."
 msgstr "Lütfən sonra yenidən cəhd edin."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, kde-format
 msgid "None"
 msgstr "Heç biri"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, kde-format
 msgctxt ""
 "A text representation of the rating, shown as a fraction of the max value"
 msgid "(%1/%2)"
 msgstr "(%1/%2)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, fuzzy, kde-format
 #| msgctxt "@knewstuff5"
 #| msgid "Upload New Stuff: %1"
@@ -827,7 +838,7 @@ msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "Yeni elementi yükləmək: %1"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, fuzzy, kde-format
 #| msgctxt ""
 #| "A text shown beside a busy indicator suggesting that data is being fetched"
@@ -837,19 +848,19 @@ msgctxt ""
 msgid "Updating information…"
 msgstr "Məlumatlar yenilənir..."
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, kde-format
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "KDE Mağazası"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, kde-format
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "Sizin təminatçı"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, kde-format
 msgctxt ""
 "Text for an action which causes the specified website to be opened using the "
@@ -857,7 +868,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "Veb-səhifəni açın: %1"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, kde-format
 msgctxt ""
 "Text for an action which will attempt to send an email using the user's "
@@ -865,15 +876,22 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "E-poçt göndərin: %1"
 
-#: qtquick/qml/UploadPage.qml:154
-#, kde-format
+#: qtquick/qml/UploadPage.qml:159
+#, fuzzy, kde-format
+#| msgctxt "A description of how to upload content to a generic provider"
+#| msgid ""
+#| "To upload new entries, or to add content to an existing entry on the KDE "
+#| "Store, please open the website and log in. Once you have done this, you "
+#| "will be able to find the My Products entry in the menu which pops up when "
+#| "you click your user icon. Click on this entry to go to the product "
+#| "management system, where you can work on your products ."
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
 "To upload new entries, or to add content to an existing entry on the KDE "
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 "Yeni yazını və ya mövcud yazının məzmununu KDE Mağazasına əlavə etmək üçün "
 "lütfən, veb-səhifəni açın və hesabınıza daxil olun. Siz bunu etdikdə, "
@@ -881,7 +899,7 @@ msgstr ""
 "yazılar'ı tapa biləcəksiniz. Bu yazıya vurmaqla məhsullarınızın üzərində "
 "işləmək üçün məhsulun idarə edilməsi sistemi açılacaqdır."
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -900,18 +918,18 @@ msgstr ""
 "üçün siz saytın menecerləri ilə əlaqə yaradaraq onlardan bunu xahiş edə "
 "bilərsiniz."
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "Verilənlər yüklənir"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "Quraşdırılma"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -923,73 +941,73 @@ msgstr ""
 "Ən yeni materailları yükləmək səlahiyyətiniz yoxdur. Bunun səhv olduğunu "
 "düşünürsənsə, icazə almaq üçün məsul şəxslə əlaqə saxlayın."
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "Geriyə"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr "Tanınmış"
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "Məsləhət görülən"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "Yenidən başlatmaq"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "New"
 msgstr "Yeni"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Ev ünvanı"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr "Rəf"
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "Yuxarı"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "Tövsiyyə olunan"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "Abunələr"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "Bütün girişlər"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -1047,9 +1065,17 @@ msgstr ""
 " Belə URL ünvanının nümunəsi: kns://peruse.knsrc/api.kde-look.org/1316714"
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
-#, kde-format
-msgid "Download New Stuff..."
-msgstr "Yeni materialı yüklə..."
+#, fuzzy, kde-format
+#| msgctxt ""
+#| "A placeholder title used in the dialog when there is no better title "
+#| "available"
+#| msgid "Download New Stuff"
+msgctxt "@action"
+msgid "Download New Stuff…"
+msgstr "Yeni materialı yüklə"
+
+#~ msgid "Download New Stuff..."
+#~ msgstr "Yeni materialı yüklə..."
 
 #~ msgctxt ""
 #~ "A message which is shown when the user attempts to display a specific "
diff -pruN 6.0.0-3/po/be/knewstuff6.po 6.3.0-1/po/be/knewstuff6.po
--- 6.0.0-3/po/be/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/be/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -14,7 +14,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2009-09-06 15:21+0300\n"
 "Last-Translator: Darafei Praliaskouski <komzpa@gmail.com>\n"
 "Language-Team: Belarusian <i18n@mova.org>\n"
@@ -62,7 +62,7 @@ msgstr "Тэкст не заменены
 msgid "You are now a fan."
 msgstr ""
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -131,7 +131,7 @@ msgstr "Файлы настаўленн
 msgid "Use"
 msgstr ""
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -139,17 +139,17 @@ msgid ""
 "This is a critical error and should be reported to the application author"
 msgstr ""
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr ""
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr ""
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr ""
@@ -294,7 +294,7 @@ msgid ""
 "the update"
 msgstr ""
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, fuzzy, kde-format
 #| msgid "Failed to load file '%1'"
 msgid ""
@@ -302,7 +302,7 @@ msgid ""
 "%2"
 msgstr "Немагчыма загрузіць файл '%1'"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, fuzzy, kde-format
 #| msgid "Pages"
 msgctxt ""
@@ -310,7 +310,7 @@ msgctxt ""
 msgid "All Categories"
 msgstr "Старонкі"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, fuzzy, kde-format
 #| msgid "Unknown error"
 msgctxt ""
@@ -336,14 +336,14 @@ msgstr ""
 msgid "Download New %1…"
 msgstr "Сцягнуць новую %1"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, fuzzy, kde-format
 #| msgid "Download New %1"
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "Сцягнуць новую %1"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
 msgctxt ""
@@ -352,12 +352,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "Сцягнцуь новыя файлы"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -366,12 +366,12 @@ msgid ""
 "this through the naming of the items."
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "Устанавіць"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -379,7 +379,7 @@ msgctxt ""
 msgid "Installing %1 from %2"
 msgstr "Устанавіць"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -387,10 +387,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -399,10 +399,10 @@ msgctxt ""
 msgid "Install"
 msgstr "Устанавіць"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -410,24 +410,24 @@ msgctxt ""
 msgid "Install…"
 msgstr "Устанавіць"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, fuzzy, kde-format
 #| msgid "Update"
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "Абнавіць"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, fuzzy, kde-format
 #| msgid "Uninstall"
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "Выдаліць"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -435,14 +435,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -453,12 +453,12 @@ msgid ""
 "to the KDE Community in a bug report</a>."
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, fuzzy, kde-format
 #| msgid "Comments"
 msgctxt ""
@@ -467,19 +467,19 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "Каментары"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, fuzzy, kde-format
 #| msgid "Rating: "
 msgid "Rating:"
 msgstr "Рэйтынг:"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, fuzzy, kde-format
 #| msgid "Homepage"
 msgid "Homepage:"
 msgstr "Хатняя старонка"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -488,12 +488,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -501,73 +501,81 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr ""
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, fuzzy, kde-format
 #| msgid "File"
 msgid "Tiles"
 msgstr "Файл"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "Значкі"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, fuzzy, kde-format
 #| msgid "Show Preview"
 msgid "Preview"
 msgstr "Паказваць прагляд"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, fuzzy, kde-format
 #| msgid "Detailed View"
 msgid "Detailed Tiles View Mode"
 msgstr "Падрабязны выгляд"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, fuzzy, kde-format
 #| msgid "Icons Only"
 msgid "Icons Only View Mode"
 msgstr "Толькі значкі"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, fuzzy, kde-format
 #| msgid "Detailed View"
 msgid "Large Preview View Mode"
 msgstr "Падрабязны выгляд"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr ""
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, fuzzy, kde-format
 #| msgid "Install"
 msgid "Installed"
 msgstr "Устанавіць"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, fuzzy, kde-format
 #| msgid "Update"
 msgid "Updateable"
 msgstr "Абнавіць"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, fuzzy, kde-format
 #| msgid "&Show All Entries"
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "Паказаць усе опцыі"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, fuzzy, kde-format
 #| msgid "&Show All Entries"
 msgctxt ""
@@ -575,7 +583,7 @@ msgctxt ""
 msgid "Show Only Installed Entries"
 msgstr "Паказаць усе опцыі"
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, fuzzy, kde-format
 #| msgid "&Show All Entries"
 msgctxt ""
@@ -584,30 +592,30 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr "Паказаць усе опцыі"
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, fuzzy, kde-format
 #| msgid "Open &Recent"
 msgid "Recent"
 msgstr "Адкрыць &ранейшы файл"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr ""
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, fuzzy, kde-format
 #| msgid "Rating: "
 msgid "Rating"
 msgstr "Рэйтынг:"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, fuzzy, kde-format
 #| msgid "Download"
 msgid "Downloads"
 msgstr "Спампаваць"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt ""
@@ -616,7 +624,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "Спачатку паказваць тэчкі"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -624,14 +632,14 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr ""
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "Спачатку паказваць тэчкі"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, fuzzy, kde-format
 #| msgid "Most Downloads"
 msgctxt ""
@@ -639,42 +647,42 @@ msgctxt ""
 msgid "Show Most Downloaded First"
 msgstr "Больш спампоўванняў"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, fuzzy, kde-format
 #| msgid "&Replace..."
 msgid "Upload…"
 msgstr "&Замяніць..."
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr ""
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, fuzzy, kde-format
 #| msgid "&Go To..."
 msgid "Go to…"
 msgstr "&Ісці да..."
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, fuzzy, kde-format
 #| msgid "Search:"
 msgid "Search…"
 msgstr "Шукаць:"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, fuzzy, kde-format
 #| msgid "Character:"
 msgid "Category:"
 msgstr "Сімвал:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, fuzzy, kde-format
 #| msgid "Continue operation"
 msgid "Contribute your own…"
 msgstr "Працягнуць выкананне аперацыі"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, fuzzy, kde-format
 #| msgctxt "@note/rich"
 #| msgid "<i>Note</i>: %1"
@@ -683,7 +691,7 @@ msgctxt ""
 msgid "<i>(no title)</i>"
 msgstr "<i>Заўвага</i>: %1"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -691,20 +699,20 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, fuzzy, kde-format
 #| msgid "Pages"
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "Старонкі"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, fuzzy, kde-format
 #| msgid "Show Preview"
 msgctxt ""
@@ -713,7 +721,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr "Паказваць прагляд"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -721,16 +729,16 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, fuzzy, kde-format
 #| msgid "Download"
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
 msgstr "Спампаваць"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, fuzzy, kde-format
 #| msgctxt "@interface/rich"
 #| msgid "<i>%1</i>"
@@ -740,7 +748,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "<i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -748,7 +756,7 @@ msgctxt ""
 msgid "Working…"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, fuzzy, kde-format
 #| msgid "Update"
 msgctxt ""
@@ -757,7 +765,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "Абнавіць"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -768,7 +776,7 @@ msgid ""
 "bug report</a>."
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt "Label for the busy indicator showing an item is installing"
@@ -787,13 +795,13 @@ msgstr ""
 msgid "Please try again later."
 msgstr "Калі ласка, вызначце назву."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, fuzzy, kde-format
 #| msgid "None"
 msgid "None"
 msgstr "Няма"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, fuzzy, kde-format
 #| msgid "(%1/s)"
 msgctxt ""
@@ -801,14 +809,14 @@ msgctxt ""
 msgid "(%1/%2)"
 msgstr "(%1/с)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "Сцягнцуь новыя файлы"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, fuzzy, kde-format
 #| msgid "Show license information"
 msgctxt ""
@@ -816,21 +824,21 @@ msgctxt ""
 msgid "Updating information…"
 msgstr "Паказаць звесткі пра ліцэнзію"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, fuzzy, kde-format
 #| msgid "Store"
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "Захоўваць"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, fuzzy, kde-format
 #| msgid "Provider: %1"
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "Пастаўшчык: %1"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, fuzzy, kde-format
 #| msgid "Website:"
 msgctxt ""
@@ -839,7 +847,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "Web-старонка:"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, fuzzy, kde-format
 #| msgid "&Send Email"
 msgctxt ""
@@ -848,7 +856,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "&Даслаць ліст"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -856,10 +864,10 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -871,20 +879,20 @@ msgid ""
 "content added."
 msgstr ""
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, fuzzy, kde-format
 #| msgid "Loading Applet"
 msgid "Loading data"
 msgstr "Апрацоўванне аплета"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, fuzzy, kde-format
 #| msgid "Install"
 msgid "Installing"
 msgstr "Устанавіць"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -894,7 +902,7 @@ msgid ""
 "please contact the person in charge of your permissions."
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Back"
@@ -902,27 +910,27 @@ msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "Назад"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, fuzzy, kde-format
 #| msgid "Saturday"
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "Субота"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, fuzzy, kde-format
 #| msgid "Restart"
 msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "Працягнуць"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "New"
@@ -930,7 +938,7 @@ msgctxt "Knewstuff5"
 msgid "New"
 msgstr "Новы"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Home"
@@ -938,13 +946,13 @@ msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Home"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Up"
@@ -952,7 +960,7 @@ msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "Угору"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, fuzzy, kde-format
 #| msgctxt "dictionary variant"
 #| msgid "extended"
@@ -960,21 +968,21 @@ msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "пашыраны"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, fuzzy, kde-format
 #| msgid "Subscribe"
 msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "Ніжні індэкс"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, fuzzy, kde-format
 #| msgid "&Show All Entries"
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "Паказаць усе опцыі"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -1007,10 +1015,16 @@ msgstr ""
 #: widgets/action.cpp:28 widgets/button.cpp:70
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
-msgid "Download New Stuff..."
+msgctxt "@action"
+msgid "Download New Stuff…"
 msgstr "Сцягнцуь новыя файлы"
 
 #, fuzzy
+#~| msgid "Download New Stuff"
+#~ msgid "Download New Stuff..."
+#~ msgstr "Сцягнцуь новыя файлы"
+
+#, fuzzy
 #~| msgid "Install"
 #~ msgid "Initializing"
 #~ msgstr "Устанавіць"
diff -pruN 6.0.0-3/po/be@latin/knewstuff6.po 6.3.0-1/po/be@latin/knewstuff6.po
--- 6.0.0-3/po/be@latin/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/be@latin/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -7,7 +7,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2008-08-30 01:10+0300\n"
 "Last-Translator: Ihar Hrachyshka <ihar.hrachyshka@gmail.com>\n"
 "Language-Team: Belarusian Latin <i18n@mova.org>\n"
@@ -55,7 +55,7 @@ msgstr "Ničoha nie było zamieniena."
 msgid "You are now a fan."
 msgstr ""
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -123,7 +123,7 @@ msgstr "Fajły naładaŭ"
 msgid "Use"
 msgstr ""
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -131,17 +131,17 @@ msgid ""
 "This is a critical error and should be reported to the application author"
 msgstr ""
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr ""
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr ""
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr ""
@@ -287,7 +287,7 @@ msgid ""
 "the update"
 msgstr ""
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, fuzzy, kde-format
 #| msgid "Failed to load file '%1'"
 msgid ""
@@ -295,7 +295,7 @@ msgid ""
 "%2"
 msgstr "Nie ŭdałosia źmiaścić u pamiać fajł „%1”."
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, fuzzy, kde-format
 #| msgid "Pages"
 msgctxt ""
@@ -303,7 +303,7 @@ msgctxt ""
 msgid "All Categories"
 msgstr "Staronki"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, fuzzy, kde-format
 #| msgid "Unknown error"
 msgctxt ""
@@ -329,14 +329,14 @@ msgstr ""
 msgid "Download New %1…"
 msgstr "Ściahni novy %1"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, fuzzy, kde-format
 #| msgid "Download New %1"
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "Ściahni novy %1"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
 msgctxt ""
@@ -345,12 +345,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "Ściahni novyja cikavostki"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -359,12 +359,12 @@ msgid ""
 "this through the naming of the items."
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "Zainstaluj"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -372,7 +372,7 @@ msgctxt ""
 msgid "Installing %1 from %2"
 msgstr "Zainstaluj"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -380,10 +380,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -392,10 +392,10 @@ msgctxt ""
 msgid "Install"
 msgstr "Zainstaluj"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -403,24 +403,24 @@ msgctxt ""
 msgid "Install…"
 msgstr "Zainstaluj"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, fuzzy, kde-format
 #| msgid "Update"
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "Aktualizuj"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, fuzzy, kde-format
 #| msgid "Uninstall"
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "Adinstaluj"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -428,14 +428,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -446,12 +446,12 @@ msgid ""
 "to the KDE Community in a bug report</a>."
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, fuzzy, kde-format
 #| msgid "View Comments"
 msgctxt ""
@@ -460,19 +460,19 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "Pakažy kamentary"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, fuzzy, kde-format
 #| msgid "Rating: "
 msgid "Rating:"
 msgstr "Acenka: "
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, fuzzy, kde-format
 #| msgid "Homepage"
 msgid "Homepage:"
 msgstr "Chatniaja staronka"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -481,12 +481,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -494,79 +494,87 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr ""
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, fuzzy, kde-format
 #| msgid "File"
 msgid "Tiles"
 msgstr "Fajł"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "Ikony"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, fuzzy, kde-format
 #| msgid "No Preview"
 msgid "Preview"
 msgstr "Niama padhladu"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, kde-format
 msgid "Detailed Tiles View Mode"
 msgstr ""
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, fuzzy, kde-format
 #| msgid "Icons Only"
 msgid "Icons Only View Mode"
 msgstr "Tolki ikony"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, fuzzy, kde-format
 #| msgid "Preview URL:"
 msgid "Large Preview View Mode"
 msgstr "Adras padhladu:"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr ""
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, fuzzy, kde-format
 #| msgid "Install"
 msgid "Installed"
 msgstr "Zainstaluj"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, fuzzy, kde-format
 #| msgid "Update"
 msgid "Updateable"
 msgstr "Aktualizuj"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, fuzzy, kde-format
 #| msgid "Pages"
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "Staronki"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -574,31 +582,31 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Open Recent"
 msgid "Recent"
 msgstr "Adčyni niadaŭnaje"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr ""
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, fuzzy, kde-format
 #| msgid "Rating: "
 msgid "Rating"
 msgstr "Acenka: "
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, fuzzy, kde-format
 #| msgid "Download"
 msgid "Downloads"
 msgstr "Zabiary z servera"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt ""
@@ -607,7 +615,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "Spačatku pakazvaj katalohi"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -615,14 +623,14 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr ""
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "Spačatku pakazvaj katalohi"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, fuzzy, kde-format
 #| msgid "Most Downloads"
 msgctxt ""
@@ -630,42 +638,42 @@ msgctxt ""
 msgid "Show Most Downloaded First"
 msgstr "Najčaściej adbiranyja"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, fuzzy, kde-format
 #| msgid "&Replace..."
 msgid "Upload…"
 msgstr "&Zamiani..."
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr ""
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, fuzzy, kde-format
 #| msgid "&Go To..."
 msgid "Go to…"
 msgstr "&Pierajdzi..."
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, fuzzy, kde-format
 #| msgid "S&earch:"
 msgid "Search…"
 msgstr "&Šukaj:"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, fuzzy, kde-format
 #| msgid "Character:"
 msgid "Category:"
 msgstr "Znak:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, fuzzy, kde-format
 #| msgid "Continue operation"
 msgid "Contribute your own…"
 msgstr "Praciahvaj aperacyju"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, fuzzy, kde-format
 #| msgctxt "@note/rich"
 #| msgid "<i>Note</i>: %1"
@@ -674,7 +682,7 @@ msgctxt ""
 msgid "<i>(no title)</i>"
 msgstr "<i>Zaciem</i>: %1"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -682,20 +690,20 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, fuzzy, kde-format
 #| msgid "Pages"
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "Staronki"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -703,7 +711,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -711,16 +719,16 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, fuzzy, kde-format
 #| msgid "Download"
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
 msgstr "Zabiary z servera"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, fuzzy, kde-format
 #| msgctxt "@interface/rich"
 #| msgid "<i>%1</i>"
@@ -730,7 +738,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "<i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -738,7 +746,7 @@ msgctxt ""
 msgid "Working…"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, fuzzy, kde-format
 #| msgid "Update"
 msgctxt ""
@@ -747,7 +755,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "Aktualizuj"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -758,7 +766,7 @@ msgid ""
 "bug report</a>."
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt "Label for the busy indicator showing an item is installing"
@@ -777,14 +785,14 @@ msgstr ""
 msgid "Please try again later."
 msgstr "Upišy nazvu."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, fuzzy, kde-format
 #| msgctxt "No border line"
 #| msgid "None"
 msgid "None"
 msgstr "Niama"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, fuzzy, kde-format
 #| msgid "(%1/s)"
 msgctxt ""
@@ -792,14 +800,14 @@ msgctxt ""
 msgid "(%1/%2)"
 msgstr "(%1/s)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "Ściahni novyja cikavostki"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, fuzzy, kde-format
 #| msgid "Billing information:"
 msgctxt ""
@@ -807,21 +815,21 @@ msgctxt ""
 msgid "Updating information…"
 msgstr "Billingavyja źviestki:"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, fuzzy, kde-format
 #| msgid "&Store"
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "&Zachavaj"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, fuzzy, kde-format
 #| msgid "Provider: %1"
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "Pravajder: %1"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, fuzzy, kde-format
 #| msgid "&Open with '%1'"
 msgctxt ""
@@ -830,7 +838,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "&Adčyni ŭ „%1”"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, fuzzy, kde-format
 #| msgid "&Send Email"
 msgctxt ""
@@ -839,7 +847,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "&Vyšli e-maiłam"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -847,10 +855,10 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -862,20 +870,20 @@ msgid ""
 "content added."
 msgstr ""
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, fuzzy, kde-format
 #| msgid "Loading Applet"
 msgid "Loading data"
 msgstr "Źmiaščeńnie apleta ŭ pamiać"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, fuzzy, kde-format
 #| msgid "Install"
 msgid "Installing"
 msgstr "Zainstaluj"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -885,7 +893,7 @@ msgid ""
 "please contact the person in charge of your permissions."
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Back"
@@ -893,20 +901,20 @@ msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "Nazad"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, fuzzy, kde-format
 #| msgid "Saturday"
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "Subota"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, fuzzy, kde-format
 #| msgctxt "@action:button Restart find & replace"
 #| msgid "Restart"
@@ -914,7 +922,7 @@ msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "Paŭtary"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "New"
@@ -922,7 +930,7 @@ msgctxt "Knewstuff5"
 msgid "New"
 msgstr "Novy"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Home"
@@ -930,13 +938,13 @@ msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Home"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Up"
@@ -944,7 +952,7 @@ msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "Up"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, fuzzy, kde-format
 #| msgctxt "dictionary variant"
 #| msgid "extended"
@@ -952,21 +960,21 @@ msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "padoŭžany"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, fuzzy, kde-format
 #| msgid "Description"
 msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "Apisańnie"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, fuzzy, kde-format
 #| msgid "Pages"
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "Staronki"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -999,10 +1007,16 @@ msgstr ""
 #: widgets/action.cpp:28 widgets/button.cpp:70
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
-msgid "Download New Stuff..."
+msgctxt "@action"
+msgid "Download New Stuff…"
 msgstr "Ściahni novyja cikavostki"
 
 #, fuzzy
+#~| msgid "Download New Stuff"
+#~ msgid "Download New Stuff..."
+#~ msgstr "Ściahni novyja cikavostki"
+
+#, fuzzy
 #~| msgid "Install"
 #~ msgid "Initializing"
 #~ msgstr "Zainstaluj"
diff -pruN 6.0.0-3/po/bg/knewstuff6.po 6.3.0-1/po/bg/knewstuff6.po
--- 6.0.0-3/po/bg/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/bg/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -8,15 +8,15 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
-"PO-Revision-Date: 2024-02-03 15:56+0100\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
+"PO-Revision-Date: 2024-05-13 22:48+0200\n"
 "Last-Translator: Mincho Kondarev <mkondarev@yahoo.de>\n"
 "Language-Team: Bulgarian <kde-i18n-doc@kde.org>\n"
 "Language: bg\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Generator: Lokalize 23.08.4\n"
+"X-Generator: Lokalize 24.02.2\n"
 "Plural-Forms: nplurals=2; plural=n != 1;\n"
 
 #: attica/atticaprovider.cpp:165
@@ -57,7 +57,7 @@ msgstr "Гласът ви е приет.
 msgid "You are now a fan."
 msgstr "Вече сте почитател."
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -127,7 +127,7 @@ msgstr "Файлът с настройк
 msgid "Use"
 msgstr "Използване"
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -138,18 +138,18 @@ msgstr ""
 "%2\n"
 "Това е критична грешка и трябва да се докладва на автора на приложението"
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr "Зареждането на доставчици от файл: %1 е неуспешно"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr ""
 "Неуспешно зареждане на списък с доставчици на нови разширения от файл: %1"
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr "Грешка при зареждане на доставчика."
@@ -319,7 +319,7 @@ msgstr ""
 "Не успяхме да идентифицираме добра връзка за актуализиране на %1 и не можем "
 "да изпълним актуализацията"
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, kde-format
 msgid ""
 "Failed to adopt '%1'\n"
@@ -328,14 +328,14 @@ msgstr ""
 "Неуспешно приемане на \"%1\"\n"
 "%2"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, kde-format
 msgctxt ""
 "The first entry in the category selection list (also the default value)"
 msgid "All Categories"
 msgstr "Всички категории"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, kde-format
 msgctxt ""
 "The string passed back in the case the requested category is not known"
@@ -359,13 +359,13 @@ msgstr "Добавки"
 msgid "Download New %1…"
 msgstr "Изтегляне на нови %1…"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, kde-format
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "Изтегляне на нов %1"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, kde-format
 msgctxt ""
 "A placeholder title used in the dialog when there is no better title "
@@ -373,12 +373,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "Изтегляне на нови разширения"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr "Изберете вашата опция за инсталиране"
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -391,19 +391,19 @@ msgstr ""
 "опции, моля, свържете се с автора на този елемент и ги помолете да изяснят "
 "това чрез именуване на елементите."
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "Инсталиране"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, kde-format
 msgctxt ""
 "A passive notification shown when installation of an item is initiated"
 msgid "Installing %1 from %2"
 msgstr "Инсталиране на %1 от %2"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -411,10 +411,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr "%1 от %2"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, kde-format
 msgctxt ""
 "Request installation of this item, available when there is exactly one "
@@ -422,47 +422,47 @@ msgctxt ""
 msgid "Install"
 msgstr "Инсталиране"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, kde-format
 msgctxt ""
 "Show installation options, where there is more than one downloadable item"
 msgid "Install…"
 msgstr "Инсталиране…"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, kde-format
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "Актуализиране"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, kde-format
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "Деинсталиране"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
 "installed OR uninstalled"
 msgid "Currently working on the item %1 by %2. Please wait…"
-msgstr "В момента се обработва елементът %1 от %2. Моля изчакайте..."
+msgstr "В момента се обработва елементът %1 от %2. Моля изчакайте…"
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
-msgstr "В момента се актуализира елементът %1 от %2. Моля изчакайте..."
+msgstr "В момента се актуализира елементът %1 от %2. Моля изчакайте…"
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -476,12 +476,12 @@ msgstr ""
 "\"https: //bugs.kde.org/enter_bug.cgi?product=frameworks-knewstuff\">Моля, "
 "докладвайте за това на KDE общността в доклад за грешка </a>."
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr "Коментари и рецензии:"
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a new sub page with comments (comments "
@@ -489,17 +489,17 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "%1 рецензии и коментари"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, kde-format
 msgid "Rating:"
 msgstr "Оценка:"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, kde-format
 msgid "Homepage:"
 msgstr "Начална страница:"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -508,12 +508,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr "Отваряне на началната страница за %1"
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr "Как да направим дарение:"
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -521,74 +521,85 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr "Разберете как да дарите за този проект"
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+"Бъдете предпазливи, когато използвате създадени от потребителя съдържания, "
+"показани тук, тъй като те може да съдържат изпълним код, който не е тестван "
+"от KDE или от вашия дистрибутор за безопасност, стабилност или качество."
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
-"Наличното съдържание тук е качено от потребители като вас и не е прегледано "
-"от вашия дистрибутор за функционалност или стабилност."
+"Създаденото от потребителя съдържание, показано тук, не е тествано от KDE "
+"или от вашия дистрибутора за функционалност или качество."
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, kde-format
 msgid "Tiles"
 msgstr "Плочки"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "Икони"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, kde-format
 msgid "Preview"
 msgstr "Предварителен преглед"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, kde-format
 msgid "Detailed Tiles View Mode"
 msgstr "Режим на подробен преглед с плочки"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, kde-format
 msgid "Icons Only View Mode"
 msgstr "Режим на преглед само с икони"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, kde-format
 msgid "Large Preview View Mode"
 msgstr "Режим на предварителен преглед"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr "Всичко"
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "Инсталирани"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, kde-format
 msgid "Updateable"
 msgstr "С възможност за актуализиране"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, kde-format
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "Показване на всички записи"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr "Показване само на инсталирани записи"
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -596,27 +607,27 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr "Показване само на записи с възможност за актуализиране"
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, kde-format
 msgid "Recent"
 msgstr "Най-нови"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr "Азбучно"
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "Оценка"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, kde-format
 msgid "Downloads"
 msgstr "Изтегляния"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on when items were most "
@@ -624,7 +635,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "Първо най-новите"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -632,57 +643,57 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr "Сортиране по азбучен ред"
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, kde-format
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "Първо с най-висока оценка"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on number of downloads"
 msgid "Show Most Downloaded First"
 msgstr "Първо най-често изтегляни"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, kde-format
 msgid "Upload…"
 msgstr "Качване…"
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr "Научете се как да качвате нови разширения в този списък"
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, kde-format
 msgid "Go to…"
-msgstr "Отиване на..."
+msgstr "Отиване на…"
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, kde-format
 msgid "Search…"
-msgstr "Търсене..."
+msgstr "Търсене…"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "Категория:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, kde-format
 msgid "Contribute your own…"
 msgstr "Качете своя собствена…"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, kde-format
 msgctxt ""
 "Placeholder title for when a comment has no subject, but does have a rating"
 msgid "<i>(no title)</i>"
 msgstr "<i> (без заглавие) </i>"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -690,19 +701,19 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr "%1 <i> (автор) </i>"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr "Коментари и отзиви за %1"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, kde-format
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "Показване на всички коментари"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -710,7 +721,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr "Показване само на отзиви"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -718,15 +729,15 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr "Показване на отзиви и отговори"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, kde-format
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
 msgstr "%1 изтегляния"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, kde-format
 msgctxt ""
 "Subheading for the tile view, located immediately underneath the name of the "
@@ -734,23 +745,23 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "От <i> %1 </i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
 "uninstalled"
 msgid "Working…"
-msgstr "Обработване..."
+msgstr "Обработване…"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is in the process of being "
 "updated"
 msgid "Updating…"
-msgstr "Актуализиране..."
+msgstr "Актуализиране…"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -764,7 +775,7 @@ msgstr ""
 "cgi?product=frameworks-knownstuff\"> Моля, докладвайте това на общността на "
 "KDE в доклад за грешка </a>."
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, kde-format
 msgctxt "Label for the busy indicator showing an item is installing"
 msgid "Installing…"
@@ -781,44 +792,44 @@ msgstr "Възникна грешка"
 msgid "Please try again later."
 msgstr "Моля, опитайте отново по-късно."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, kde-format
 msgid "None"
 msgstr "Без"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, kde-format
 msgctxt ""
 "A text representation of the rating, shown as a fraction of the max value"
 msgid "(%1/%2)"
 msgstr "(%1/%2)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, kde-format
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "Качване на ново разширение: %1"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, kde-format
 msgctxt ""
 "A text shown beside a busy indicator suggesting that data is being fetched"
 msgid "Updating information…"
-msgstr "Обновяване на информацията..."
+msgstr "Обновяване на информацията…"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, kde-format
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "KDE магазин"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, kde-format
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "Доставчик"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, kde-format
 msgctxt ""
 "Text for an action which causes the specified website to be opened using the "
@@ -826,7 +837,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "Отваряне на Уебсайт: %1"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, kde-format
 msgctxt ""
 "Text for an action which will attempt to send an email using the user's "
@@ -834,7 +845,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "Изпращане на имейл до: %1"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -842,7 +853,7 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 "За да качите нови записи, или да добавите съдържание към съществуващ запис в "
 "KDE Store, моля отворете уебсайта и влезте. След като сте направили това, ще "
@@ -851,7 +862,7 @@ msgstr ""
 "отидете в системата за управление на продуктите, където можете да работите "
 "върху вашите продукти."
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -869,18 +880,18 @@ msgstr ""
 "алтернатива може да се наложи да се свържете директно с мениджърите на "
 "сайта, за да качите ново съдържание."
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "Зареждане на данни"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "Инсталиране"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -892,73 +903,73 @@ msgstr ""
 "Не сте упълномощени да получавате нови разширения. Ако смятате, че това е "
 "грешка,моля свържете се с лицето, отговарящо за вашите разрешения."
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "Назад"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr "Популярни"
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "Специални"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "Рестартиране"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "New"
 msgstr "Нови"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Домашна страница"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr "Рафт"
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "Нагоре"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "Препоръчани"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "Абонаменти"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "Всички записи"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -1004,5 +1015,6 @@ msgstr ""
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
 #, kde-format
-msgid "Download New Stuff..."
-msgstr "Изтегляне на нови неща..."
+msgctxt "@action"
+msgid "Download New Stuff…"
+msgstr "Изтегляне на нови разширения…"
diff -pruN 6.0.0-3/po/bn/knewstuff6.po 6.3.0-1/po/bn/knewstuff6.po
--- 6.0.0-3/po/bn/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/bn/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -10,7 +10,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2012-07-16 14:27+0530\n"
 "Last-Translator: Deepayan Sarkar <deepayan.sarkar@gmail.com>\n"
 "Language-Team: American English <kde-translation@bengalinux.org>\n"
@@ -65,7 +65,7 @@ msgstr "আপনার ভোট রে
 msgid "You are now a fan."
 msgstr "আপনি এখন একজন ফ্যান।"
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -136,7 +136,7 @@ msgstr "কনফিগারেশন 
 msgid "Use"
 msgstr ""
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -144,17 +144,17 @@ msgid ""
 "This is a critical error and should be reported to the application author"
 msgstr ""
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr ""
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr ""
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr ""
@@ -299,7 +299,7 @@ msgid ""
 "the update"
 msgstr ""
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, fuzzy, kde-format
 #| msgid "Failed to load file '%1'"
 msgid ""
@@ -307,7 +307,7 @@ msgid ""
 "%2"
 msgstr "'%1' ফাইল লোড করতে অক্ষম"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt ""
@@ -315,7 +315,7 @@ msgctxt ""
 msgid "All Categories"
 msgstr "সব গোত্র"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, fuzzy, kde-format
 #| msgid "Unknown error"
 msgctxt ""
@@ -341,14 +341,14 @@ msgstr ""
 msgid "Download New %1…"
 msgstr "নতুন %1 ডাউনলোড করুন"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, fuzzy, kde-format
 #| msgid "Download New %1"
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "নতুন %1 ডাউনলোড করুন"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
 msgctxt ""
@@ -357,12 +357,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "নতুন জিনিস ডাউনলোড করুন"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -371,12 +371,12 @@ msgid ""
 "this through the naming of the items."
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "ইনস্টল"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt ""
@@ -384,7 +384,7 @@ msgctxt ""
 msgid "Installing %1 from %2"
 msgstr "ইনস্টল করা হচ্ছে"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -392,10 +392,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -404,10 +404,10 @@ msgctxt ""
 msgid "Install"
 msgstr "ইনস্টল"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -415,24 +415,24 @@ msgctxt ""
 msgid "Install…"
 msgstr "ইনস্টল"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, fuzzy, kde-format
 #| msgid "Update"
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "আপডেট"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, fuzzy, kde-format
 #| msgid "Uninstall"
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "আন-ইনস্টল করো"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -440,14 +440,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -458,12 +458,12 @@ msgid ""
 "to the KDE Community in a bug report</a>."
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, fuzzy, kde-format
 #| msgid "View Comments"
 msgctxt ""
@@ -472,19 +472,19 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "মন্তব্য দেখুন"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, fuzzy, kde-format
 #| msgid "Rating: "
 msgid "Rating:"
 msgstr "রেটিং:"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, fuzzy, kde-format
 #| msgid "Homepage"
 msgid "Homepage:"
 msgstr "হোমপেজ"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -493,12 +493,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -506,79 +506,87 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr ""
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, fuzzy, kde-format
 #| msgctxt "@option:check Do filter on type - show only files"
 #| msgid "Files"
 msgid "Tiles"
 msgstr "ফাইল"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "আইকনসমূহ"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, fuzzy, kde-format
 #| msgid "No Preview"
 msgid "Preview"
 msgstr "প্রাকদর্শন নেই"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, fuzzy, kde-format
 msgid "Detailed Tiles View Mode"
 msgstr "বিস্তারিত বিবরণ"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, fuzzy, kde-format
 #| msgid "Icons view mode"
 msgid "Icons Only View Mode"
 msgstr "আইকন ভিউ মোড"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, fuzzy, kde-format
 #| msgid "Details view mode"
 msgid "Large Preview View Mode"
 msgstr "বিস্তারিত ভিউ মোড"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr ""
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "ইনস্টল করা"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, fuzzy, kde-format
 #| msgid "Update"
 msgid "Updateable"
 msgstr "আপডেট"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "সব গোত্র"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -586,28 +594,28 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, fuzzy, kde-format
 msgid "Recent"
 msgstr "&সম্প্রতি ব্যবহৃত"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr ""
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "রেটিং"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, fuzzy, kde-format
 #| msgid "Download"
 msgid "Downloads"
 msgstr "ডাউনলোড করো"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt ""
@@ -616,7 +624,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "ডিরেক্টরী আগে দেখাও"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -624,14 +632,14 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr ""
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "ডিরেক্টরী আগে দেখাও"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, fuzzy, kde-format
 #| msgid "Most downloads"
 msgctxt ""
@@ -639,41 +647,41 @@ msgctxt ""
 msgid "Show Most Downloaded First"
 msgstr "সর্বাধিক ডাউনলোড"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, fuzzy, kde-format
 #| msgid "Upload..."
 msgid "Upload…"
 msgstr "আপলোড..."
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr ""
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, fuzzy, kde-format
 #| msgid "&Go To..."
 msgid "Go to…"
 msgstr "...যা&ও"
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, fuzzy, kde-format
 #| msgid "Search:"
 msgid "Search…"
 msgstr "সন্ধান করো:"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "গোত্র:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, fuzzy, kde-format
 #| msgid "Continue operation"
 msgid "Contribute your own…"
 msgstr "কাজ চালিয়ে যাও"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, fuzzy, kde-format
 #| msgctxt "@note/rich"
 #| msgid "<i>Note</i>: %1"
@@ -682,7 +690,7 @@ msgctxt ""
 msgid "<i>(no title)</i>"
 msgstr "<i>নোট</i>: %1"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -690,20 +698,20 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "সব গোত্র"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -711,7 +719,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -719,8 +727,8 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, fuzzy, kde-format
 #| msgid "1 download"
 #| msgid_plural "%1 downloads"
@@ -728,8 +736,8 @@ msgctxt "The number of times the item ha
 msgid "%1 downloads"
 msgstr "একটি ডাউনলোড"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, fuzzy, kde-format
 #| msgctxt "Show the author of this item in a list"
 #| msgid "By <i>%1</i>"
@@ -739,7 +747,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "<i>%1</i>-র সৌজন্যে"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -747,7 +755,7 @@ msgctxt ""
 msgid "Working…"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, fuzzy, kde-format
 #| msgid "Updating"
 msgctxt ""
@@ -756,7 +764,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "আপডেট করা হচ্ছে"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -767,7 +775,7 @@ msgid ""
 "bug report</a>."
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt "Label for the busy indicator showing an item is installing"
@@ -786,14 +794,14 @@ msgstr ""
 msgid "Please try again later."
 msgstr "অনুগ্রহ করে একটি নাম লিখুন।"
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, fuzzy, kde-format
 #| msgctxt "No border line"
 #| msgid "None"
 msgid "None"
 msgstr "কিছু না"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, fuzzy, kde-format
 #| msgid "(%1/s)"
 msgctxt ""
@@ -801,14 +809,14 @@ msgctxt ""
 msgid "(%1/%2)"
 msgstr "(%1/সেঃ)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "নতুন জিনিস ডাউনলোড করুন"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, fuzzy, kde-format
 #| msgid "Billing information:"
 msgctxt ""
@@ -816,21 +824,21 @@ msgctxt ""
 msgid "Updating information…"
 msgstr "বিলিং তথ্য:"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, fuzzy, kde-format
 #| msgid "&Store"
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "&সঞ্চয় করো"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, fuzzy, kde-format
 #| msgid "Provider:"
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "সরবরাহকারী:"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, fuzzy, kde-format
 #| msgctxt "@label:button"
 #| msgid "&Open with %1"
@@ -840,7 +848,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "%1 দিয়ে খো&ল"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, fuzzy, kde-format
 #| msgid "&Send Email"
 msgctxt ""
@@ -849,7 +857,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "&ই-মেইল পাঠাও"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -857,10 +865,10 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -872,18 +880,18 @@ msgid ""
 "content added."
 msgstr ""
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "তথ্য লোড করা হচ্ছে"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "ইনস্টল করা হচ্ছে"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -893,7 +901,7 @@ msgid ""
 "please contact the person in charge of your permissions."
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Back"
@@ -901,20 +909,20 @@ msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "পিছিয়ে যাও"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, fuzzy, kde-format
 #| msgid "Saturday"
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "শনিবার"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, fuzzy, kde-format
 #| msgctxt "@action:button Restart find & replace"
 #| msgid "Restart"
@@ -922,7 +930,7 @@ msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "নতুন করে শুরু করো"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "New"
@@ -930,7 +938,7 @@ msgctxt "Knewstuff5"
 msgid "New"
 msgstr "নতুন"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Home"
@@ -938,13 +946,13 @@ msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Home"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Up"
@@ -952,7 +960,7 @@ msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "Up"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, fuzzy, kde-format
 #| msgctxt "dictionary variant"
 #| msgid "extended"
@@ -960,7 +968,7 @@ msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "বর্ধিত"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Subscript"
@@ -968,14 +976,14 @@ msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "Subscript"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "সব গোত্র"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -1006,9 +1014,14 @@ msgid ""
 msgstr ""
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
-#, kde-format
-msgid "Download New Stuff..."
-msgstr "নতুন জিনিস ডাউনলোড করুন..."
+#, fuzzy, kde-format
+#| msgid "Download New Stuff"
+msgctxt "@action"
+msgid "Download New Stuff…"
+msgstr "নতুন জিনিস ডাউনলোড করুন"
+
+#~ msgid "Download New Stuff..."
+#~ msgstr "নতুন জিনিস ডাউনলোড করুন..."
 
 #~ msgid "Initializing"
 #~ msgstr "চালু করা হচ্ছে"
diff -pruN 6.0.0-3/po/bn_IN/knewstuff6.po 6.3.0-1/po/bn_IN/knewstuff6.po
--- 6.0.0-3/po/bn_IN/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/bn_IN/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -9,7 +9,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2009-12-28 14:35+0530\n"
 "Last-Translator: Runa Bhattacharjee <runab@redhat.com>\n"
 "Language-Team: Bengali INDIA <anubad@lists.ankur.org.in>\n"
@@ -62,7 +62,7 @@ msgstr "কোনো টেক্সট
 msgid "You are now a fan."
 msgstr ""
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -130,7 +130,7 @@ msgstr "কনফিগারেশন 
 msgid "Use"
 msgstr ""
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -138,17 +138,17 @@ msgid ""
 "This is a critical error and should be reported to the application author"
 msgstr ""
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr "চিহ্নিত ফাইল: %1 থেকে উপলব্ধকারীদের তথ্য লোড করতে ব্যর্থ"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr ""
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr ""
@@ -294,7 +294,7 @@ msgid ""
 "the update"
 msgstr ""
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, fuzzy, kde-format
 #| msgid "Failed to load file '%1'"
 msgid ""
@@ -302,7 +302,7 @@ msgid ""
 "%2"
 msgstr "ফাইল '%1' লোড করতে ব্যর্থ"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt ""
@@ -310,7 +310,7 @@ msgctxt ""
 msgid "All Categories"
 msgstr "সকল শ্রেণী"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, fuzzy, kde-format
 #| msgid "Unknown error"
 msgctxt ""
@@ -336,14 +336,14 @@ msgstr ""
 msgid "Download New %1…"
 msgstr "নতুন জিনিস ডাউনলোড করুন..."
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, fuzzy, kde-format
 #| msgid "Download New Stuff..."
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "নতুন জিনিস ডাউনলোড করুন..."
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, fuzzy, kde-format
 #| msgid "Download New Stuff..."
 msgctxt ""
@@ -352,12 +352,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "নতুন জিনিস ডাউনলোড করুন..."
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -366,12 +366,12 @@ msgid ""
 "this through the naming of the items."
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "ইনস্টল করুন"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt ""
@@ -379,7 +379,7 @@ msgctxt ""
 msgid "Installing %1 from %2"
 msgstr "ইনস্টল করা হচ্ছে"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -387,10 +387,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -399,10 +399,10 @@ msgctxt ""
 msgid "Install"
 msgstr "ইনস্টল করুন"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -410,24 +410,24 @@ msgctxt ""
 msgid "Install…"
 msgstr "ইনস্টল করুন"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, fuzzy, kde-format
 #| msgid "Update"
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "আপডেট করুন"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, fuzzy, kde-format
 #| msgid "Uninstall"
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "আন-ইনস্টল করুন"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -435,14 +435,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -453,12 +453,12 @@ msgid ""
 "to the KDE Community in a bug report</a>."
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, fuzzy, kde-format
 #| msgid "View Comments"
 msgctxt ""
@@ -467,19 +467,19 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "মন্তব্য প্রদর্শন করা হবে"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, fuzzy, kde-format
 #| msgid "Rating: "
 msgid "Rating:"
 msgstr "গুরুত্বের মান:"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, fuzzy, kde-format
 #| msgid "Homepage"
 msgid "Homepage:"
 msgstr "হোম পেজ"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -488,12 +488,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -501,78 +501,86 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr ""
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, fuzzy, kde-format
 #| msgid "File"
 msgid "Tiles"
 msgstr "ফাইল"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "আইকন"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, fuzzy, kde-format
 #| msgid "Previews"
 msgid "Preview"
 msgstr "পূর্বদৃশ্য"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, kde-format
 msgid "Detailed Tiles View Mode"
 msgstr ""
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, fuzzy, kde-format
 #| msgid "Icons Only"
 msgid "Icons Only View Mode"
 msgstr "শুধুমাত্র আইকন"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, fuzzy, kde-format
 #| msgid "Preview Image:"
 msgid "Large Preview View Mode"
 msgstr "ছবির পূর্বদৃশ্য:"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr ""
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "ইনস্টল করা"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, fuzzy, kde-format
 #| msgid "Update"
 msgid "Updateable"
 msgstr "আপডেট করুন"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "সকল শ্রেণী"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -580,30 +588,30 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Open Recent"
 msgid "Recent"
 msgstr "সম্প্রতি ব্যবহৃত খুলুন"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr ""
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "গুরুত্বের মান"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, fuzzy, kde-format
 #| msgid "Download"
 msgid "Downloads"
 msgstr "ডাউনলোড করা হবে"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt ""
@@ -612,7 +620,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "প্রথমে ডিরেক্টরি প্রদর্শিত হবে"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -620,14 +628,14 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr ""
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "প্রথমে ডিরেক্টরি প্রদর্শিত হবে"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, fuzzy, kde-format
 #| msgid "Most Downloads"
 msgctxt ""
@@ -635,41 +643,41 @@ msgctxt ""
 msgid "Show Most Downloaded First"
 msgstr "সর্বাধিকবার ডাউনলোড করা হয়েছে"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, fuzzy, kde-format
 #| msgid "Upload..."
 msgid "Upload…"
 msgstr "আপলোড করুন..."
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr ""
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, fuzzy, kde-format
 #| msgid "&Go To..."
 msgid "Go to…"
 msgstr "চিহ্নিত অবস্থানে চলুন...(&G)"
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, fuzzy, kde-format
 #| msgid "Search:"
 msgid "Search…"
 msgstr "অনুসন্ধান:"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "শ্রেণী:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, fuzzy, kde-format
 #| msgid "Continue operation"
 msgid "Contribute your own…"
 msgstr "কর্মে এগিয়ে চলুন"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, fuzzy, kde-format
 #| msgctxt "@note/rich"
 #| msgid "<i>Note</i>: %1"
@@ -678,7 +686,7 @@ msgctxt ""
 msgid "<i>(no title)</i>"
 msgstr "<i>উল্লেখ্য</i>: %1"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -686,20 +694,20 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "সকল শ্রেণী"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -707,7 +715,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -715,16 +723,16 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, fuzzy, kde-format
 #| msgid "Download"
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
 msgstr "ডাউনলোড করা হবে"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, fuzzy, kde-format
 #| msgctxt "Show the author of this item in a list"
 #| msgid "By <i>%1</i>"
@@ -734,7 +742,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "<i>%1</i> দ্বারা"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -742,7 +750,7 @@ msgctxt ""
 msgid "Working…"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, fuzzy, kde-format
 #| msgid "Updating"
 msgctxt ""
@@ -751,7 +759,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "আপডেট করা হচ্ছে"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -762,7 +770,7 @@ msgid ""
 "bug report</a>."
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt "Label for the busy indicator showing an item is installing"
@@ -781,14 +789,14 @@ msgstr ""
 msgid "Please try again later."
 msgstr "অনুগ্রহ করে নাম নিখুন:"
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, fuzzy, kde-format
 #| msgctxt "No border line"
 #| msgid "None"
 msgid "None"
 msgstr "শূণ্য"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, fuzzy, kde-format
 #| msgid "(%1/s)"
 msgctxt ""
@@ -796,14 +804,14 @@ msgctxt ""
 msgid "(%1/%2)"
 msgstr "(%1/s)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, fuzzy, kde-format
 #| msgid "Download New Stuff..."
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "নতুন জিনিস ডাউনলোড করুন..."
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, fuzzy, kde-format
 #| msgid "Billing information:"
 msgctxt ""
@@ -811,21 +819,21 @@ msgctxt ""
 msgid "Updating information…"
 msgstr "বিল সংক্রান্ত তথ্য:"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, fuzzy, kde-format
 #| msgid "&Store"
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "সংরক্ষণ করা হবে (&S)"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, fuzzy, kde-format
 #| msgid "Provider:"
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "উপলব্ধকারী:"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, fuzzy, kde-format
 #| msgctxt "@label:button"
 #| msgid "&Open with %1"
@@ -835,7 +843,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "%1 সহযোগে খুলুন (&O)"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, fuzzy, kde-format
 #| msgid "&Send Email"
 msgctxt ""
@@ -844,7 +852,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "ই-মেইল করুন (&S)"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -852,10 +860,10 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -867,19 +875,19 @@ msgid ""
 "content added."
 msgstr ""
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, fuzzy, kde-format
 #| msgid "Loading Applet"
 msgid "Loading data"
 msgstr "অ্যাপ্লেট লোড করা হচ্ছে"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "ইনস্টল করা হচ্ছে"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -889,7 +897,7 @@ msgid ""
 "please contact the person in charge of your permissions."
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Back"
@@ -897,19 +905,19 @@ msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "পূর্ববর্তী"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, fuzzy, kde-format
 #| msgctxt "@action:button Restart find & replace"
 #| msgid "Restart"
@@ -917,7 +925,7 @@ msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "পুনরারম্ভ"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "New"
@@ -925,7 +933,7 @@ msgctxt "Knewstuff5"
 msgid "New"
 msgstr "নতুন"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Home"
@@ -933,13 +941,13 @@ msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Home"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Up"
@@ -947,7 +955,7 @@ msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "Up"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, fuzzy, kde-format
 #| msgctxt "dictionary variant"
 #| msgid "extended"
@@ -955,21 +963,21 @@ msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "প্রসারিত"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, fuzzy, kde-format
 #| msgid "Description"
 msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "বিবরণ"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "সকল শ্রেণী"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -1000,10 +1008,15 @@ msgid ""
 msgstr ""
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
-#, kde-format
-msgid "Download New Stuff..."
+#, fuzzy, kde-format
+#| msgid "Download New Stuff..."
+msgctxt "@action"
+msgid "Download New Stuff…"
 msgstr "নতুন জিনিস ডাউনলোড করুন..."
 
+#~ msgid "Download New Stuff..."
+#~ msgstr "নতুন জিনিস ডাউনলোড করুন..."
+
 #, fuzzy
 #~| msgid "Installing"
 #~ msgid "Initializing"
diff -pruN 6.0.0-3/po/br/knewstuff6.po 6.3.0-1/po/br/knewstuff6.po
--- 6.0.0-3/po/br/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/br/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -8,7 +8,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4-1.1\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2007-10-15 22:19+0200\n"
 "Last-Translator: Jañ-Mai Drapier <jan-mai.drapier@mail.dotcom.fr>\n"
 "Language-Team: Brezhoneg <Suav.Icb@wanadoo.fr>\n"
@@ -52,7 +52,7 @@ msgstr ""
 msgid "You are now a fan."
 msgstr ""
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -123,7 +123,7 @@ msgstr "Restroù kefluniadur"
 msgid "Use"
 msgstr "Dirollañ"
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -131,18 +131,18 @@ msgid ""
 "This is a critical error and should be reported to the application author"
 msgstr ""
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, fuzzy, kde-format
 #| msgid "Loading resource '%1' failed!"
 msgid "Loading of providers from file: %1 failed"
 msgstr "Sac'het eo kargañ an danvez '%1' !"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr ""
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, fuzzy, kde-format
 #| msgid "Error parsing providers list."
 msgid "Error initializing provider."
@@ -289,7 +289,7 @@ msgid ""
 "the update"
 msgstr ""
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, fuzzy, kde-format
 #| msgid "Failed to load file '%1'"
 msgid ""
@@ -297,7 +297,7 @@ msgid ""
 "%2"
 msgstr "N'hellan ket kargañ ar restr '%1'"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, fuzzy, kde-format
 #| msgid "Categories"
 msgctxt ""
@@ -305,7 +305,7 @@ msgctxt ""
 msgid "All Categories"
 msgstr "Rummoù"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, fuzzy, kde-format
 #| msgctxt "QFile"
 #| msgid "Unknown error"
@@ -332,14 +332,14 @@ msgstr ""
 msgid "Download New %1…"
 msgstr "Enkargañ"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, fuzzy, kde-format
 #| msgid "Download"
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "Enkargañ"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, fuzzy, kde-format
 #| msgid "Download"
 msgctxt ""
@@ -348,13 +348,13 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "Enkargañ"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, fuzzy, kde-format
 #| msgid "Resource Installation Error"
 msgid "Pick Your Installation Option"
 msgstr "Fazi en ur staliañ an danvez"
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -363,12 +363,12 @@ msgid ""
 "this through the naming of the items."
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "Staliañ"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -376,7 +376,7 @@ msgctxt ""
 msgid "Installing %1 from %2"
 msgstr "Staliañ"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -384,10 +384,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -396,10 +396,10 @@ msgctxt ""
 msgid "Install"
 msgstr "Staliañ"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -407,24 +407,24 @@ msgctxt ""
 msgid "Install…"
 msgstr "Staliañ"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, fuzzy, kde-format
 #| msgid "Update"
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "Bremañaat"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, fuzzy, kde-format
 #| msgid "Deinstall"
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "Distaliañ"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -432,14 +432,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -450,12 +450,12 @@ msgid ""
 "to the KDE Community in a bug report</a>."
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, fuzzy, kde-format
 #| msgid "Comments"
 msgctxt ""
@@ -464,19 +464,19 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "Askelennoù"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, fuzzy, kde-format
 #| msgid "Rating"
 msgid "Rating:"
 msgstr "Feur"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, fuzzy, kde-format
 #| msgid "Homepage"
 msgid "Homepage:"
 msgstr "Pajenn Er-Gêr"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -485,12 +485,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -498,79 +498,87 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr ""
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, fuzzy, kde-format
 #| msgid "&Tile"
 msgid "Tiles"
 msgstr "&Adrenkañ"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "Arlunioù"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, fuzzy, kde-format
 #| msgid "Preview"
 msgid "Preview"
 msgstr "Rakgwel"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, fuzzy, kde-format
 #| msgid "Detailed View"
 msgid "Detailed Tiles View Mode"
 msgstr "Gwell munut"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, fuzzy, kde-format
 #| msgid "Icon View"
 msgid "Icons Only View Mode"
 msgstr "Gwel Arlun"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, fuzzy, kde-format
 #| msgid "Detailed View"
 msgid "Large Preview View Mode"
 msgstr "Gwell munut"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr ""
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, fuzzy, kde-format
 #| msgid "Install"
 msgid "Installed"
 msgstr "Staliañ"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, fuzzy, kde-format
 #| msgid "Update"
 msgid "Updateable"
 msgstr "Bremañaat"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, fuzzy, kde-format
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "Diskouez pep tra dibaboù"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, fuzzy, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr "Diskouez pep tra dibaboù"
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, fuzzy, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -578,31 +586,31 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr "Diskouez pep tra dibaboù"
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, fuzzy, kde-format
 #| msgctxt "QAccel"
 #| msgid "Percent"
 msgid "Recent"
 msgstr "Dregantad"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr ""
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, fuzzy, kde-format
 #| msgid "Rating"
 msgid "Rating"
 msgstr "Feur"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, fuzzy, kde-format
 #| msgid "Download"
 msgid "Downloads"
 msgstr "Enkargañ"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, fuzzy, kde-format
 msgctxt ""
 "List option which will set the sort order to based on when items were most "
@@ -610,7 +618,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "&Diskennit"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -618,62 +626,62 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr ""
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, fuzzy, kde-format
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "&Diskennit"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, fuzzy, kde-format
 msgctxt ""
 "List option which will set the sort order to based on number of downloads"
 msgid "Show Most Downloaded First"
 msgstr "&Diskennit"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, fuzzy, kde-format
 #| msgid "&Upload"
 msgid "Upload…"
 msgstr "&Ezkargañ"
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr ""
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, fuzzy, kde-format
 #| msgid "&Go To..."
 msgid "Go to…"
 msgstr "&Mont da ..."
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, fuzzy, kde-format
 #| msgid "Search:"
 msgid "Search…"
 msgstr "Klask :"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, fuzzy, kde-format
 #| msgid "Categories"
 msgid "Category:"
 msgstr "Rummoù"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, fuzzy, kde-format
 #| msgid "Continue operation"
 msgid "Contribute your own…"
 msgstr "Kenderc'hel"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, kde-format
 msgctxt ""
 "Placeholder title for when a comment has no subject, but does have a rating"
 msgid "<i>(no title)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -681,20 +689,20 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, fuzzy, kde-format
 #| msgid "Categories"
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "Rummoù"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, fuzzy, kde-format
 #| msgid "Show Preview"
 msgctxt ""
@@ -703,7 +711,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr "Diskouez ar rakgwell"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -711,16 +719,16 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, fuzzy, kde-format
 #| msgid "Download"
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
 msgstr "Enkargañ"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, fuzzy, kde-format
 #| msgctxt "@interface/rich"
 #| msgid "<i>%1</i>"
@@ -730,7 +738,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "<i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -738,7 +746,7 @@ msgctxt ""
 msgid "Working…"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, fuzzy, kde-format
 #| msgid "Update"
 msgctxt ""
@@ -747,7 +755,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "Bremañaat"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -758,7 +766,7 @@ msgid ""
 "bug report</a>."
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt "Label for the busy indicator showing an item is installing"
@@ -779,13 +787,13 @@ msgstr "n'eus fazi ebet"
 msgid "Please try again later."
 msgstr "Roit un anv mar plij."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, fuzzy, kde-format
 #| msgid "None"
 msgid "None"
 msgstr "Ebet"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, fuzzy, kde-format
 #| msgid "(%1/s)"
 msgctxt ""
@@ -793,14 +801,14 @@ msgctxt ""
 msgid "(%1/%2)"
 msgstr "(%1/s)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, fuzzy, kde-format
 #| msgid "Download"
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "Enkargañ"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, fuzzy, kde-format
 #| msgid "Information"
 msgctxt ""
@@ -808,21 +816,21 @@ msgctxt ""
 msgid "Updating information…"
 msgstr "Titouroù"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, fuzzy, kde-format
 #| msgid "Store"
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "Enrollit"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, fuzzy, kde-format
 #| msgid "Provider: %1"
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "Pourchaser : %1"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, fuzzy, kde-format
 #| msgid "Website:"
 msgctxt ""
@@ -831,7 +839,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "Lec'hienn gwiad :"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, fuzzy, kde-format
 #| msgid "&Send Email"
 msgctxt ""
@@ -840,7 +848,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "&Kas ul lizher"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -848,10 +856,10 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -863,20 +871,20 @@ msgid ""
 "content added."
 msgstr ""
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, fuzzy, kde-format
 #| msgid "Loading Applet"
 msgid "Loading data"
 msgstr "Emaon o kargañ an arloadig"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, fuzzy, kde-format
 #| msgid "Install"
 msgid "Installing"
 msgstr "Staliañ"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -886,81 +894,81 @@ msgid ""
 "please contact the person in charge of your permissions."
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, fuzzy, kde-format
 #| msgid "Back"
 msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "War-gil"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, fuzzy, kde-format
 #| msgid "Saturday"
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "Sadorn"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, fuzzy, kde-format
 #| msgid "Restart"
 msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "Adloc'hañ"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, fuzzy, kde-format
 #| msgid "New"
 msgctxt "Knewstuff5"
 msgid "New"
 msgstr "Nevez"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, fuzzy, kde-format
 #| msgid "Home"
 msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Er-gêr"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, fuzzy, kde-format
 #| msgid "Up"
 msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "Uhel"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, fuzzy, kde-format
 #| msgid "Run &command"
 msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "Seveniñ ur goulev"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, fuzzy, kde-format
 #| msgid "Script"
 msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "Skrid"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, fuzzy, kde-format
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "Diskouez pep tra dibaboù"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -991,9 +999,11 @@ msgid ""
 msgstr ""
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
-#, kde-format
-msgid "Download New Stuff..."
-msgstr ""
+#, fuzzy, kde-format
+#| msgid "Download"
+msgctxt "@action"
+msgid "Download New Stuff…"
+msgstr "Enkargañ"
 
 #, fuzzy
 #~| msgid "Install"
diff -pruN 6.0.0-3/po/bs/knewstuff6.po 6.3.0-1/po/bs/knewstuff6.po
--- 6.0.0-3/po/bs/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/bs/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -12,7 +12,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2013-12-21 17:26+0000\n"
 "Last-Translator: Ademovic Saudin <sademovic1@etf.unsa.ba>\n"
 "Language-Team: bosanski <bs@li.org>\n"
@@ -69,7 +69,7 @@ msgstr "Vaš glas je ubilježen."
 msgid "You are now a fan."
 msgstr "Sada ste ljubitelj."
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -137,7 +137,7 @@ msgstr "Konfiguraciona datoteka %1 nije
 msgid "Use"
 msgstr ""
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -145,17 +145,17 @@ msgid ""
 "This is a critical error and should be reported to the application author"
 msgstr ""
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr "Učitavanje dobavljačâ̂ iz datoteke %1 nije uspjelo."
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr "Ne mogu da učitam dobavljače novih stvari iz datoteke %1."
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr "Greška u pripremanju dobavljača."
@@ -300,7 +300,7 @@ msgid ""
 "the update"
 msgstr ""
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, fuzzy, kde-format
 #| msgid "Failed to load file '%1'"
 msgid ""
@@ -309,7 +309,7 @@ msgid ""
 msgstr "Neuspjeh učitavanja datoteke %1"
 
 # >> @item:inlistbox
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt ""
@@ -317,7 +317,7 @@ msgctxt ""
 msgid "All Categories"
 msgstr "sve kategorije"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, fuzzy, kde-format
 #| msgid "Unknown error"
 msgctxt ""
@@ -343,14 +343,14 @@ msgstr ""
 msgid "Download New %1…"
 msgstr "Preuzmi novotarije..."
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, fuzzy, kde-format
 #| msgid "Download New Stuff..."
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "Preuzmi novotarije..."
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, fuzzy, kde-format
 #| msgid "Download New Stuff..."
 msgctxt ""
@@ -359,12 +359,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "Preuzmi novotarije..."
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -373,12 +373,12 @@ msgid ""
 "this through the naming of the items."
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "Instaliraj"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt ""
@@ -386,7 +386,7 @@ msgctxt ""
 msgid "Installing %1 from %2"
 msgstr "Instaliram"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -394,10 +394,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -406,10 +406,10 @@ msgctxt ""
 msgid "Install"
 msgstr "Instaliraj"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -417,24 +417,24 @@ msgctxt ""
 msgid "Install…"
 msgstr "Instaliraj"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, fuzzy, kde-format
 #| msgid "Update"
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "Ažuriraj"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, fuzzy, kde-format
 #| msgid "Uninstall"
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "Deinstaliraj"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -442,14 +442,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -460,12 +460,12 @@ msgid ""
 "to the KDE Community in a bug report</a>."
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, fuzzy, kde-format
 #| msgid "View Comments"
 msgctxt ""
@@ -474,19 +474,19 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "Prikaži komentare"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, fuzzy, kde-format
 #| msgid "Rating: "
 msgid "Rating:"
 msgstr "Ocjena: "
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, fuzzy, kde-format
 #| msgid "Homepage"
 msgid "Homepage:"
 msgstr "Početna stranica"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -495,12 +495,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -508,82 +508,90 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr ""
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, fuzzy, kde-format
 #| msgctxt "@option:check Do filter on type - show only files"
 #| msgid "Files"
 msgid "Tiles"
 msgstr "Datoteke"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "Ikone"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, fuzzy, kde-format
 #| msgid "Preview URL:"
 msgid "Preview"
 msgstr "URL za pregled:"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, fuzzy, kde-format
 #| msgid "Details view mode"
 msgid "Detailed Tiles View Mode"
 msgstr "Prikaz detalja"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, fuzzy, kde-format
 #| msgid "Icons view mode"
 msgid "Icons Only View Mode"
 msgstr "Prikaz ikona"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, fuzzy, kde-format
 #| msgid "Details view mode"
 msgid "Large Preview View Mode"
 msgstr "Prikaz detalja"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr ""
 
 # >> @option:radio Order by
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "instaliranom"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, fuzzy, kde-format
 #| msgid "Update"
 msgid "Updateable"
 msgstr "Ažuriraj"
 
 # >> @item:inlistbox
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "sve kategorije"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -591,31 +599,31 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Open Recent"
 msgid "Recent"
 msgstr "Otvori &skorašnje"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr ""
 
 # >> @option:radio Order by
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "ocjeni"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, fuzzy, kde-format
 #| msgid "Download"
 msgid "Downloads"
 msgstr "Preuzmi"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt ""
@@ -624,7 +632,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "Prikaži prvo direktorije"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -632,7 +640,7 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr ""
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt "List option which will set the sort order to based on user ratings"
@@ -640,7 +648,7 @@ msgid "Show Highest Rated First"
 msgstr "Prikaži prvo direktorije"
 
 # >> @option:radio Order by
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, fuzzy, kde-format
 #| msgid "Most downloads"
 msgctxt ""
@@ -648,41 +656,41 @@ msgctxt ""
 msgid "Show Most Downloaded First"
 msgstr "najviše preuzimanja"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, fuzzy, kde-format
 #| msgid "New Upload"
 msgid "Upload…"
 msgstr "Novo slanje"
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr ""
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, fuzzy, kde-format
 #| msgid "&Go To..."
 msgid "Go to…"
 msgstr "&Idi na..."
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, fuzzy, kde-format
 #| msgid "Search:"
 msgid "Search…"
 msgstr "Pretraži:"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "Kategorija:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, fuzzy, kde-format
 #| msgid "Continue operation"
 msgid "Contribute your own…"
 msgstr "Nastavi postupak"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, fuzzy, kde-format
 #| msgctxt "@note/rich"
 #| msgid "<i>Note</i>: %1"
@@ -691,7 +699,7 @@ msgctxt ""
 msgid "<i>(no title)</i>"
 msgstr "<i>Napomena</i>: %1"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -699,21 +707,21 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr ""
 
 # >> @item:inlistbox
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "sve kategorije"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -721,7 +729,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -729,8 +737,8 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, fuzzy, kde-format
 #| msgid "1 download"
 #| msgid_plural "%1 downloads"
@@ -738,8 +746,8 @@ msgctxt "The number of times the item ha
 msgid "%1 downloads"
 msgstr "%1 preuzimanje"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, fuzzy, kde-format
 #| msgctxt "Show the author of this item in a list"
 #| msgid "By <i>%1</i>"
@@ -749,7 +757,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "Po <i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -757,7 +765,7 @@ msgctxt ""
 msgid "Working…"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, fuzzy, kde-format
 #| msgid "Updating"
 msgctxt ""
@@ -766,7 +774,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "Ažuriram"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -777,7 +785,7 @@ msgid ""
 "bug report</a>."
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt "Label for the busy indicator showing an item is installing"
@@ -796,14 +804,14 @@ msgstr ""
 msgid "Please try again later."
 msgstr "Unesite ime."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, fuzzy, kde-format
 #| msgctxt "No border line"
 #| msgid "None"
 msgid "None"
 msgstr "nijedna"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, fuzzy, kde-format
 #| msgid "(%1/s)"
 msgctxt ""
@@ -811,14 +819,14 @@ msgctxt ""
 msgid "(%1/%2)"
 msgstr "(%1/s)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, fuzzy, kde-format
 #| msgid "Download New Stuff..."
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "Preuzmi novotarije..."
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, fuzzy, kde-format
 #| msgid "Billing information:"
 msgctxt ""
@@ -826,21 +834,21 @@ msgctxt ""
 msgid "Updating information…"
 msgstr "Podaci o naplati:"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, fuzzy, kde-format
 #| msgid "&Store"
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "&Skladišti"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, fuzzy, kde-format
 #| msgid "Provider:"
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "Dobavljač:"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, fuzzy, kde-format
 #| msgctxt "@label:button"
 #| msgid "&Open with %1"
@@ -850,7 +858,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "&Otvori pomoću %1"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, fuzzy, kde-format
 #| msgid "&Send Email"
 msgctxt ""
@@ -859,7 +867,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "Pošalji &e‑poštu"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -867,10 +875,10 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -882,18 +890,18 @@ msgid ""
 "content added."
 msgstr ""
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "Učitavam podatke"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "Instaliram"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -903,7 +911,7 @@ msgid ""
 "please contact the person in charge of your permissions."
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Back"
@@ -911,19 +919,19 @@ msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "Nazad"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, fuzzy, kde-format
 #| msgctxt "@action:button Restart find & replace"
 #| msgid "Restart"
@@ -931,7 +939,7 @@ msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "Ponovi"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "New"
@@ -939,7 +947,7 @@ msgctxt "Knewstuff5"
 msgid "New"
 msgstr "Novo"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Home"
@@ -947,13 +955,13 @@ msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Home"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Up"
@@ -961,7 +969,7 @@ msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "Gore"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, fuzzy, kde-format
 #| msgctxt "dictionary variant"
 #| msgid "extended"
@@ -969,7 +977,7 @@ msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "prošireni"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Subscript"
@@ -978,14 +986,14 @@ msgid "Subscriptions"
 msgstr "Indeks"
 
 # >> @item:inlistbox
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "sve kategorije"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -1016,10 +1024,15 @@ msgid ""
 msgstr ""
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
-#, kde-format
-msgid "Download New Stuff..."
+#, fuzzy, kde-format
+#| msgid "Download New Stuff..."
+msgctxt "@action"
+msgid "Download New Stuff…"
 msgstr "Preuzmi novotarije..."
 
+#~ msgid "Download New Stuff..."
+#~ msgstr "Preuzmi novotarije..."
+
 #~ msgid "Initializing"
 #~ msgstr "Pripremam"
 
diff -pruN 6.0.0-3/po/ca/knewstuff6.po 6.3.0-1/po/ca/knewstuff6.po
--- 6.0.0-3/po/ca/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/ca/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -14,8 +14,8 @@ msgid ""
 msgstr ""
 "Project-Id-Version: knewstuff\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
-"PO-Revision-Date: 2024-01-19 11:24+0100\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
+"PO-Revision-Date: 2024-05-08 16:10+0200\n"
 "Last-Translator: Josep M. Ferrer <txemaq@gmail.com>\n"
 "Language-Team: Catalan <kde-i18n-ca@kde.org>\n"
 "Language: ca\n"
@@ -64,7 +64,7 @@ msgstr "El vostre vot s'ha enregistrat."
 msgid "You are now a fan."
 msgstr "Ara sou un fan."
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -135,7 +135,7 @@ msgstr "El fitxer de configuració no é
 msgid "Use"
 msgstr "Usa"
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -146,17 +146,17 @@ msgstr ""
 "%2\n"
 "Aquest és un error crític i s'hauria d'informar a l'autor de l'aplicació"
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr "Ha fallat la càrrega de proveïdors des del fitxer: %1"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr "No s'ha pogut carregar cap proveïdor de novetats des del fitxer: %1"
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr "Error en inicialitzar el proveïdor."
@@ -328,7 +328,7 @@ msgstr ""
 "S'ha fallat en identificar un bon enllaç per a actualitzar %1 i no es pot "
 "realitzar l'actualització"
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, kde-format
 msgid ""
 "Failed to adopt '%1'\n"
@@ -337,14 +337,14 @@ msgstr ""
 "Ha fallat en adoptar «%1»\n"
 "%2"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, kde-format
 msgctxt ""
 "The first entry in the category selection list (also the default value)"
 msgid "All Categories"
 msgstr "Totes les categories"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, kde-format
 msgctxt ""
 "The string passed back in the case the requested category is not known"
@@ -368,13 +368,13 @@ msgstr "novetats"
 msgid "Download New %1…"
 msgstr "Baixa %1…"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, kde-format
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "Baixa %1"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, kde-format
 msgctxt ""
 "A placeholder title used in the dialog when there is no better title "
@@ -382,12 +382,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "Baixa les novetats"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr "Trieu l'opció d'instal·lació"
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -400,19 +400,19 @@ msgstr ""
 "opcions disponibles, contacteu amb els autors d'aquest element i demaneu que "
 "ho aclareixin reanomenant els elements."
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "Instal·la"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, kde-format
 msgctxt ""
 "A passive notification shown when installation of an item is initiated"
 msgid "Installing %1 from %2"
 msgstr "S'està instal·lant %1 des de %2"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -420,10 +420,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr "%1 per %2"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, kde-format
 msgctxt ""
 "Request installation of this item, available when there is exactly one "
@@ -431,32 +431,32 @@ msgctxt ""
 msgid "Install"
 msgstr "Instal·la"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, kde-format
 msgctxt ""
 "Show installation options, where there is more than one downloadable item"
 msgid "Install…"
 msgstr "Instal·la…"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, kde-format
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "Actualitza"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, kde-format
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "Desinstal·la"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -464,14 +464,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr "Actualment, s'està treballant sobre l'element %1 per a %2. Espereu…"
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr "Actualment, s'està actualitzant l'element %1 per a %2. Espereu…"
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -485,12 +485,12 @@ msgstr ""
 "\"https://bugs.kde.org/enter_bug.cgi?product=frameworks-knewstuff\">Informeu-"
 "ho a la comunitat KDE amb un informe d'error</a>."
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr "Comentaris i ressenyes:"
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a new sub page with comments (comments "
@@ -498,17 +498,17 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "%1 ressenyes i comentaris"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, kde-format
 msgid "Rating:"
 msgstr "Puntuació:"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, kde-format
 msgid "Homepage:"
 msgstr "Pàgina web:"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -517,12 +517,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr "Obre la pàgina web de %1"
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr "Com fer un donatiu:"
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -530,74 +530,85 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr "Trobeu com fer una donació al projecte"
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+"Aneu amb compte en accedir al contingut creat per l'usuari que es mostra "
+"aquí, ja que pot contenir codi executable del qual no s'ha provat la "
+"seguretat, l'estabilitat o la qualitat per KDE o el vostre distribuïdor"
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
-"El contingut disponible aquí ha estat carregat per usuaris com vosaltres i "
-"no ha estat revisat pel vostre distribuïdor de funcionalitat o estabilitat."
+"El contingut creat per l'usuari que es mostra aquí no s'ha provat la "
+"funcionalitat o la qualitat per KDE ni el vostre distribuïdor."
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, kde-format
 msgid "Tiles"
 msgstr "Mosaics"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "Icones"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, kde-format
 msgid "Preview"
 msgstr "Vista prèvia"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, kde-format
 msgid "Detailed Tiles View Mode"
 msgstr "Mode de vista de mosaic en detall"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, kde-format
 msgid "Icons Only View Mode"
 msgstr "Mode de vista només icones"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, kde-format
 msgid "Large Preview View Mode"
 msgstr "Mode de vista prèvia gran"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr "Tot"
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "Instal·lat"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, kde-format
 msgid "Updateable"
 msgstr "Actualitzable"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, kde-format
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "Mostra totes les entrades"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr "Mostra només les entrades instal·lades"
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -605,27 +616,27 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr "Mostra només les entrades actualitzables"
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, kde-format
 msgid "Recent"
 msgstr "Recents"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr "Alfabèticament"
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "Puntuació"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, kde-format
 msgid "Downloads"
 msgstr "Baixades"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on when items were most "
@@ -633,7 +644,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "Primer mostra la més recent"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -641,59 +652,59 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr "Ordena alfabèticament per nom"
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, kde-format
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "Primer mostra la que té millor puntuació"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on number of downloads"
 msgid "Show Most Downloaded First"
 msgstr "Primer mostra la més baixada"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, kde-format
 msgid "Upload…"
 msgstr "Puja…"
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr ""
 "Apreneu com afegir les vostres pròpies coses noves i calentes a aquesta "
 "llista"
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, kde-format
 msgid "Go to…"
 msgstr "Ves a…"
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, kde-format
 msgid "Search…"
 msgstr "Cerca…"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "Categoria:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, kde-format
 msgid "Contribute your own…"
 msgstr "Col·laboreu-hi amb…"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, kde-format
 msgctxt ""
 "Placeholder title for when a comment has no subject, but does have a rating"
 msgid "<i>(no title)</i>"
 msgstr "<i>(sense títol)</i>"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -701,19 +712,19 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr "%1 <i>(autor)</i>"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr "Comentaris i ressenyes de %1"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, kde-format
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "Mostra tots els comentaris"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -721,7 +732,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr "Mostra només les ressenyes"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -729,15 +740,15 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr "Mostra les ressenyes i les respostes"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, kde-format
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
 msgstr "%1 baixades"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, kde-format
 msgctxt ""
 "Subheading for the tile view, located immediately underneath the name of the "
@@ -745,7 +756,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "Per <i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -753,7 +764,7 @@ msgctxt ""
 msgid "Working…"
 msgstr "Està treballant…"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is in the process of being "
@@ -761,7 +772,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "S'està actualitzant…"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -775,7 +786,7 @@ msgstr ""
 "product=frameworks-knewstuff\">Informeu-ho a la comunitat KDE amb un informe "
 "d'error</a>."
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, kde-format
 msgctxt "Label for the busy indicator showing an item is installing"
 msgid "Installing…"
@@ -792,44 +803,44 @@ msgstr "S'ha produït un error"
 msgid "Please try again later."
 msgstr "Torneu-ho a intentar més tard."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, kde-format
 msgid "None"
 msgstr "Sense"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, kde-format
 msgctxt ""
 "A text representation of the rating, shown as a fraction of the max value"
 msgid "(%1/%2)"
 msgstr "(%1/%2)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, kde-format
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "Puja les novetats: %1"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, kde-format
 msgctxt ""
 "A text shown beside a busy indicator suggesting that data is being fetched"
 msgid "Updating information…"
 msgstr "S'està actualitzant la informació…"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, kde-format
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "KDE Store"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, kde-format
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "El vostre proveïdor"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, kde-format
 msgctxt ""
 "Text for an action which causes the specified website to be opened using the "
@@ -837,7 +848,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "Obre el lloc web: %1"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, kde-format
 msgctxt ""
 "Text for an action which will attempt to send an email using the user's "
@@ -845,7 +856,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "Envia un correu a: %1"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -853,7 +864,7 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 "Per a carregar entrades noves o per a afegir contingut a una entrada "
 "existent a la KDE Store, obriu el lloc web i accediu-hi. Una vegada fet "
@@ -861,7 +872,7 @@ msgstr ""
 "clic a la vostra icona d'usuari. Feu clic en aquesta entrada per a anar al "
 "sistema de gestió de productes, on podreu treballar en els vostres productes."
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -880,18 +891,18 @@ msgstr ""
 "directament amb els gerents del lloc per a aconseguir afegir un contingut "
 "nou."
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "S'estan carregant les dades"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "S'està instal·lant"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -903,73 +914,73 @@ msgstr ""
 "No esteu autoritzat a usar Obtén les novetats candents. Si penseu que és un "
 "error, contacteu amb la persona al càrrec dels vostres permisos."
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "Enrere"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr "Populars"
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "Destacats"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "Reinicia"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "New"
 msgstr "Nous"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Inici"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr "Prestatge"
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "Amunt"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "Recomanats"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "Subscripcions"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "Totes les entrades"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -1017,8 +1028,12 @@ msgstr ""
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
 #, kde-format
-msgid "Download New Stuff..."
-msgstr "Baixa les novetats..."
+msgctxt "@action"
+msgid "Download New Stuff…"
+msgstr "Baixa les novetats…"
+
+#~ msgid "Download New Stuff..."
+#~ msgstr "Baixa les novetats..."
 
 #~ msgctxt ""
 #~ "A message which is shown when the user attempts to display a specific "
diff -pruN 6.0.0-3/po/ca@valencia/knewstuff6.po 6.3.0-1/po/ca@valencia/knewstuff6.po
--- 6.0.0-3/po/ca@valencia/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/ca@valencia/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -14,8 +14,8 @@ msgid ""
 msgstr ""
 "Project-Id-Version: knewstuff\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
-"PO-Revision-Date: 2024-01-19 11:24+0100\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
+"PO-Revision-Date: 2024-05-08 16:10+0200\n"
 "Last-Translator: Josep M. Ferrer <txemaq@gmail.com>\n"
 "Language-Team: Catalan <kde-i18n-ca@kde.org>\n"
 "Language: ca@valencia\n"
@@ -64,7 +64,7 @@ msgstr "El vostre vot s'ha enregistrat."
 msgid "You are now a fan."
 msgstr "Ara sou un fan."
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -137,7 +137,7 @@ msgstr "El fitxer de configuració no é
 msgid "Use"
 msgstr "Utilitza"
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -148,17 +148,17 @@ msgstr ""
 "%2\n"
 "Este és un error crític i s'hauria d'informar a l'autor de l'aplicació"
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr "Ha fallat la càrrega de proveïdors des del fitxer: %1"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr "No s'ha pogut carregar cap proveïdor de novetats des del fitxer: %1"
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr "S'ha produït un error en restablir el proveïdor."
@@ -330,7 +330,7 @@ msgstr ""
 "S'ha fallat en identificar un bon enllaç per a actualitzar %1 i no es pot "
 "realitzar l'actualització"
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, kde-format
 msgid ""
 "Failed to adopt '%1'\n"
@@ -339,14 +339,14 @@ msgstr ""
 "No s'ha pogut adoptar «%1»\n"
 "%2"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, kde-format
 msgctxt ""
 "The first entry in the category selection list (also the default value)"
 msgid "All Categories"
 msgstr "Totes les categories"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, kde-format
 msgctxt ""
 "The string passed back in the case the requested category is not known"
@@ -370,13 +370,13 @@ msgstr "novetats"
 msgid "Download New %1…"
 msgstr "Baixa %1…"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, kde-format
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "Baixa %1"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, kde-format
 msgctxt ""
 "A placeholder title used in the dialog when there is no better title "
@@ -384,12 +384,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "Baixa les novetats"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr "Seleccioneu l'opció d'instal·lació"
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -402,19 +402,19 @@ msgstr ""
 "opcions disponibles, contacteu amb els autors d'este element i demaneu que "
 "ho aclarisquen canviant de nom els elements."
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "Instal·la"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, kde-format
 msgctxt ""
 "A passive notification shown when installation of an item is initiated"
 msgid "Installing %1 from %2"
 msgstr "S'està instal·lant %1 des de %2"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -422,10 +422,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr "%1 per %2"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, kde-format
 msgctxt ""
 "Request installation of this item, available when there is exactly one "
@@ -433,32 +433,32 @@ msgctxt ""
 msgid "Install"
 msgstr "Instal·la"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, kde-format
 msgctxt ""
 "Show installation options, where there is more than one downloadable item"
 msgid "Install…"
 msgstr "Instal·la…"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, kde-format
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "Actualitza"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, kde-format
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "Desinstal·la"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -466,14 +466,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr "Actualment, s'està treballant sobre l'element %1 per a %2. Espereu…"
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr "Actualment, s'està actualitzant l'element %1 per a %2. Espereu…"
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -487,12 +487,12 @@ msgstr ""
 "\"https://bugs.kde.org/enter_bug.cgi?product=frameworks-knewstuff\">Informeu-"
 "ne a la comunitat KDE amb un informe d'error</a>."
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr "Comentaris i ressenyes:"
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a new sub page with comments (comments "
@@ -500,17 +500,17 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "%1 ressenyes i comentaris"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, kde-format
 msgid "Rating:"
 msgstr "Puntuació:"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, kde-format
 msgid "Homepage:"
 msgstr "Pàgina web:"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -519,12 +519,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr "Obri la pàgina web de %1"
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr "Com fer un donatiu:"
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -532,74 +532,85 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr "Trobeu com fer una donació al projecte"
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+"Aneu amb compte en accedir al contingut creat per l'usuari que es mostra "
+"ací, ja que pot contindre codi executable del qual no s'ha provat la "
+"seguretat, l'estabilitat o la qualitat per KDE o el vostre distribuïdor"
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
-"El contingut disponible ací ha sigut carregat per usuaris com vosaltres i no "
-"ha sigut revisat pel vostre distribuïdor de funcionalitat o estabilitat."
+"El contingut creat per l'usuari que es mostra ací no s'ha provat la "
+"funcionalitat o la qualitat per KDE ni el vostre distribuïdor."
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, kde-format
 msgid "Tiles"
 msgstr "Mosaics"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "Icones"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, kde-format
 msgid "Preview"
 msgstr "Vista prèvia"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, kde-format
 msgid "Detailed Tiles View Mode"
 msgstr "Mode de vista de mosaic en detall"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, kde-format
 msgid "Icons Only View Mode"
 msgstr "Mode de vista només icones"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, kde-format
 msgid "Large Preview View Mode"
 msgstr "Mode de vista prèvia gran"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr "Tot"
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "Instal·lat"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, kde-format
 msgid "Updateable"
 msgstr "Actualitzable"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, kde-format
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "Mostra totes les entrades"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr "Mostra només les entrades instal·lades"
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -607,27 +618,27 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr "Mostra només les entrades actualitzables"
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, kde-format
 msgid "Recent"
 msgstr "Recents"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr "Alfabèticament"
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "Puntuació"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, kde-format
 msgid "Downloads"
 msgstr "Baixades"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on when items were most "
@@ -635,7 +646,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "Primer mostra la més recent"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -643,58 +654,58 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr "Ordena alfabèticament per nom"
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, kde-format
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "Primer mostra la que té millor puntuació"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on number of downloads"
 msgid "Show Most Downloaded First"
 msgstr "Primer mostra la més baixada"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, kde-format
 msgid "Upload…"
 msgstr "Puja…"
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr ""
 "Apreneu com afegir les vostres pròpies coses noves i calentes a esta llista"
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, kde-format
 msgid "Go to…"
 msgstr "Ves fins a…"
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, kde-format
 msgid "Search…"
 msgstr "Busca…"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "Categoria:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, kde-format
 msgid "Contribute your own…"
 msgstr "Col·laboreu-hi amb…"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, kde-format
 msgctxt ""
 "Placeholder title for when a comment has no subject, but does have a rating"
 msgid "<i>(no title)</i>"
 msgstr "<i>(sense títol)</i>"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -702,19 +713,19 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr "%1 <i>(autor)</i>"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr "Comentaris i ressenyes de %1"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, kde-format
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "Mostra tots els comentaris"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -722,7 +733,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr "Mostra només les ressenyes"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -730,15 +741,15 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr "Mostra les ressenyes i les respostes"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, kde-format
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
 msgstr "%1 baixades"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, kde-format
 msgctxt ""
 "Subheading for the tile view, located immediately underneath the name of the "
@@ -746,7 +757,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "Per <i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -754,7 +765,7 @@ msgctxt ""
 msgid "Working…"
 msgstr "Està treballant…"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is in the process of being "
@@ -762,7 +773,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "S'està actualitzant…"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -776,7 +787,7 @@ msgstr ""
 "product=frameworks-knewstuff\">Informeu-ne a la comunitat KDE amb un informe "
 "d'error</a>."
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, kde-format
 msgctxt "Label for the busy indicator showing an item is installing"
 msgid "Installing…"
@@ -793,44 +804,44 @@ msgstr "S'ha produït un error"
 msgid "Please try again later."
 msgstr "Torneu-ho a intentar més tard."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, kde-format
 msgid "None"
 msgstr "Sense"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, kde-format
 msgctxt ""
 "A text representation of the rating, shown as a fraction of the max value"
 msgid "(%1/%2)"
 msgstr "(%1/%2)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, kde-format
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "Puja les novetats: %1"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, kde-format
 msgctxt ""
 "A text shown beside a busy indicator suggesting that data is being fetched"
 msgid "Updating information…"
 msgstr "S'està actualitzant la informació…"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, kde-format
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "KDE Store"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, kde-format
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "El vostre proveïdor"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, kde-format
 msgctxt ""
 "Text for an action which causes the specified website to be opened using the "
@@ -838,7 +849,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "Obri el lloc web: %1"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, kde-format
 msgctxt ""
 "Text for an action which will attempt to send an email using the user's "
@@ -846,7 +857,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "Envia un correu a: %1"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -854,7 +865,7 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 "Per a carregar entrades noves o per a afegir contingut a una entrada "
 "existent en la KDE Store, obriu el lloc web i accediu-hi. Una vegada fet "
@@ -863,7 +874,7 @@ msgstr ""
 "al sistema de gestió de productes, on podreu treballar en els vostres "
 "productes."
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -882,18 +893,18 @@ msgstr ""
 "directament amb els gerents del lloc per a aconseguir afegir un contingut "
 "nou."
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "S'estan carregant les dades"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "S'està instal·lant"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -905,73 +916,73 @@ msgstr ""
 "No esteu autoritzat a utilitzar Obtín les novetats candents. Si penseu que "
 "és un error, contacteu amb la persona al càrrec dels vostres permisos."
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "Arrere"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr "Populars"
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "Destacats"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "Reinicia"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "New"
 msgstr "Nous"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Inici"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr "Prestatge"
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "Amunt"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "Recomanats"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "Subscripcions"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "Totes les entrades"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -1019,5 +1030,6 @@ msgstr ""
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
 #, kde-format
-msgid "Download New Stuff..."
-msgstr "Baixa les novetats..."
+msgctxt "@action"
+msgid "Download New Stuff…"
+msgstr "Baixa les novetats…"
diff -pruN 6.0.0-3/po/crh/knewstuff6.po 6.3.0-1/po/crh/knewstuff6.po
--- 6.0.0-3/po/crh/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/crh/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -7,7 +7,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2009-02-12 23:29-0600\n"
 "Last-Translator: Reşat SABIQ <tilde.birlik@gmail.com>\n"
 "Language-Team: Qırımtatarca (Qırım Türkçesi)\n"
@@ -53,7 +53,7 @@ msgstr "İç bir metin deñiştirilmedi.
 msgid "You are now a fan."
 msgstr ""
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -121,7 +121,7 @@ msgstr "Ayarlama dosyeleri"
 msgid "Use"
 msgstr ""
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -129,17 +129,17 @@ msgid ""
 "This is a critical error and should be reported to the application author"
 msgstr ""
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr ""
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr ""
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr ""
@@ -285,7 +285,7 @@ msgid ""
 "the update"
 msgstr ""
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, fuzzy, kde-format
 #| msgid "Failed to load file '%1'"
 msgid ""
@@ -293,7 +293,7 @@ msgid ""
 "%2"
 msgstr "'%1' dosyesiniñ yüklenüvi oñmadı"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, fuzzy, kde-format
 #| msgid "Pages"
 msgctxt ""
@@ -301,7 +301,7 @@ msgctxt ""
 msgid "All Categories"
 msgstr "Saife"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, fuzzy, kde-format
 #| msgid "Unknown error"
 msgctxt ""
@@ -327,14 +327,14 @@ msgstr ""
 msgid "Download New %1…"
 msgstr "Yañı %1 Endir"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, fuzzy, kde-format
 #| msgid "Download New %1"
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "Yañı %1 Endir"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
 msgctxt ""
@@ -343,12 +343,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "Yañı Şeylerni Endir"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -357,12 +357,12 @@ msgid ""
 "this through the naming of the items."
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "Qur"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -370,7 +370,7 @@ msgctxt ""
 msgid "Installing %1 from %2"
 msgstr "Qur"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -378,10 +378,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -390,10 +390,10 @@ msgctxt ""
 msgid "Install"
 msgstr "Qur"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -401,24 +401,24 @@ msgctxt ""
 msgid "Install…"
 msgstr "Qur"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, fuzzy, kde-format
 #| msgid "Update"
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "Yañart"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, fuzzy, kde-format
 #| msgid "Uninstall"
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "Ğayrı Qur"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -426,14 +426,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -444,12 +444,12 @@ msgid ""
 "to the KDE Community in a bug report</a>."
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, fuzzy, kde-format
 #| msgid "View Comments"
 msgctxt ""
@@ -458,20 +458,20 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "Şerhlerni Köster"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, fuzzy, kde-format
 #| msgid "Rating: "
 msgid "Rating:"
 msgstr "Derecelendirme:"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Home"
 msgid "Homepage:"
 msgstr "Ev"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -480,12 +480,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -493,79 +493,87 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr ""
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, fuzzy, kde-format
 #| msgid "File"
 msgid "Tiles"
 msgstr "Dosye"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "İşaretçikler"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, fuzzy, kde-format
 #| msgid "No Preview"
 msgid "Preview"
 msgstr "Ög-baquv Yoq"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, kde-format
 msgid "Detailed Tiles View Mode"
 msgstr ""
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, fuzzy, kde-format
 #| msgid "Icons Only"
 msgid "Icons Only View Mode"
 msgstr "Faqat İşaretçikler"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, fuzzy, kde-format
 #| msgid "Preview URL:"
 msgid "Large Preview View Mode"
 msgstr "Ög-baquv URL:"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr ""
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, fuzzy, kde-format
 #| msgid "Install"
 msgid "Installed"
 msgstr "Qur"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, fuzzy, kde-format
 #| msgid "Update"
 msgid "Updateable"
 msgstr "Yañart"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, fuzzy, kde-format
 #| msgid "Pages"
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "Saife"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -573,31 +581,31 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Open Recent"
 msgid "Recent"
 msgstr "Deminkini Aç"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr ""
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, fuzzy, kde-format
 #| msgid "Rating: "
 msgid "Rating"
 msgstr "Derecelendirme:"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, fuzzy, kde-format
 #| msgid "Download"
 msgid "Downloads"
 msgstr "Endir"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt ""
@@ -606,7 +614,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "Fihristlerni aldın köster"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -614,14 +622,14 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr ""
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "Fihristlerni aldın köster"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, fuzzy, kde-format
 #| msgid "Most Downloads"
 msgctxt ""
@@ -629,42 +637,42 @@ msgctxt ""
 msgid "Show Most Downloaded First"
 msgstr "Eñ Çoq Endirilgen"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, fuzzy, kde-format
 #| msgid "&Replace..."
 msgid "Upload…"
 msgstr "&Deñiştir..."
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr ""
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, fuzzy, kde-format
 #| msgid "&Go To..."
 msgid "Go to…"
 msgstr "&Bar..."
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, fuzzy, kde-format
 #| msgid "S&earch:"
 msgid "Search…"
 msgstr "&Qıdır"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, fuzzy, kde-format
 #| msgid "Character:"
 msgid "Category:"
 msgstr "Remiz:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, fuzzy, kde-format
 #| msgid "Continue operation"
 msgid "Contribute your own…"
 msgstr "Ameliyatnı devam et"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, fuzzy, kde-format
 #| msgctxt "@note/rich"
 #| msgid "<i>Note</i>: %1"
@@ -673,7 +681,7 @@ msgctxt ""
 msgid "<i>(no title)</i>"
 msgstr "<i>Not</i>: %1"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -681,20 +689,20 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, fuzzy, kde-format
 #| msgid "Pages"
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "Saife"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -702,7 +710,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -710,16 +718,16 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, fuzzy, kde-format
 #| msgid "Download"
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
 msgstr "Endir"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, fuzzy, kde-format
 #| msgctxt "@interface/rich"
 #| msgid "<i>%1</i>"
@@ -729,7 +737,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "<i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -737,7 +745,7 @@ msgctxt ""
 msgid "Working…"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, fuzzy, kde-format
 #| msgid "Update"
 msgctxt ""
@@ -746,7 +754,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "Yañart"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -757,7 +765,7 @@ msgid ""
 "bug report</a>."
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt "Label for the busy indicator showing an item is installing"
@@ -776,14 +784,14 @@ msgstr ""
 msgid "Please try again later."
 msgstr "Lütfen bir isim qoyuñız."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, fuzzy, kde-format
 #| msgctxt "No border line"
 #| msgid "None"
 msgid "None"
 msgstr "İç biri"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, fuzzy, kde-format
 #| msgid "(%1/s)"
 msgctxt ""
@@ -791,14 +799,14 @@ msgctxt ""
 msgid "(%1/%2)"
 msgstr "(%1/s)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "Yañı Şeylerni Endir"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, fuzzy, kde-format
 #| msgid "Billing Information:"
 msgctxt ""
@@ -806,21 +814,21 @@ msgctxt ""
 msgid "Updating information…"
 msgstr "Faturalama Malümatı:"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, fuzzy, kde-format
 #| msgid "Store"
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "Saqla"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, fuzzy, kde-format
 #| msgid "Provider: %1"
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "Teminatçı: %1"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, fuzzy, kde-format
 #| msgid "&Open with '%1'"
 msgctxt ""
@@ -829,7 +837,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "'%1' ile &Aç"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, fuzzy, kde-format
 #| msgid "&Send Email"
 msgctxt ""
@@ -838,7 +846,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "E-poçta &Yiber"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -846,10 +854,10 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -861,20 +869,20 @@ msgid ""
 "content added."
 msgstr ""
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, fuzzy, kde-format
 #| msgid "Loading Applet"
 msgid "Loading data"
 msgstr "Aplet Yüklene"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, fuzzy, kde-format
 #| msgid "Install"
 msgid "Installing"
 msgstr "Qur"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -884,7 +892,7 @@ msgid ""
 "please contact the person in charge of your permissions."
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Back"
@@ -892,20 +900,20 @@ msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "Keri"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, fuzzy, kde-format
 #| msgid "Saturday"
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "Cumaertesi"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, fuzzy, kde-format
 #| msgctxt "@action:button Restart find & replace"
 #| msgid "Restart"
@@ -913,7 +921,7 @@ msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "Kene başlat"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "New"
@@ -921,7 +929,7 @@ msgctxt "Knewstuff5"
 msgid "New"
 msgstr "Yañı"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Home"
@@ -929,13 +937,13 @@ msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Ev"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Up"
@@ -943,7 +951,7 @@ msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "Yuqarı"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, fuzzy, kde-format
 #| msgctxt "dictionary variant"
 #| msgid "extended"
@@ -951,7 +959,7 @@ msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "uzatılğan"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Subscript"
@@ -959,14 +967,14 @@ msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "Alt-remizler"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, fuzzy, kde-format
 #| msgid "Pages"
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "Saife"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -999,10 +1007,16 @@ msgstr ""
 #: widgets/action.cpp:28 widgets/button.cpp:70
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
-msgid "Download New Stuff..."
+msgctxt "@action"
+msgid "Download New Stuff…"
 msgstr "Yañı Şeylerni Endir"
 
 #, fuzzy
+#~| msgid "Download New Stuff"
+#~ msgid "Download New Stuff..."
+#~ msgstr "Yañı Şeylerni Endir"
+
+#, fuzzy
 #~| msgid "Install"
 #~ msgid "Initializing"
 #~ msgstr "Qur"
diff -pruN 6.0.0-3/po/cs/knewstuff6.po 6.3.0-1/po/cs/knewstuff6.po
--- 6.0.0-3/po/cs/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/cs/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -3,22 +3,22 @@
 # Lukáš Tinkl <lukas@kde.org>, 2010, 2011, 2012.
 # Vít Pelčák <vit@pelcak.org>, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020.
 # Tomáš Chvátal <tomas.chvatal@gmail.com>, 2012, 2013.
-# Vit Pelcak <vit@pelcak.org>, 2021, 2022, 2023.
+# SPDX-FileCopyrightText: 2021, 2022, 2023, 2024 Vit Pelcak <vit@pelcak.org>
 #
 msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
-"PO-Revision-Date: 2023-06-05 11:47+0200\n"
-"Last-Translator: Vit Pelcak <vit@pelcak.org>\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
+"PO-Revision-Date: 2024-05-29 11:22+0200\n"
+"Last-Translator: Vit Pelcak <vpelcak@suse.cz>\n"
 "Language-Team: Czech <kde-i18n-doc@kde.org>\n"
 "Language: cs\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;\n"
-"X-Generator: Lokalize 23.04.1\n"
+"X-Generator: Lokalize 24.02.2\n"
 "X-Language: cs_CZ\n"
 "X-Source-Language: en_US\n"
 
@@ -60,7 +60,7 @@ msgstr "Váš hlas byl zaznamenán."
 msgid "You are now a fan."
 msgstr "Nyní jste fanoušek."
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -125,7 +125,7 @@ msgstr "Konfigurační soubor je neplatn
 msgid "Use"
 msgstr "Použít"
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -133,17 +133,17 @@ msgid ""
 "This is a critical error and should be reported to the application author"
 msgstr ""
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr "Načítání poskytovatelů ze souboru %1 selhalo"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr "Nelze získat poskytovatele obsahu ze souboru: %1"
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr "Chyba během inicializace poskytovatele."
@@ -283,21 +283,21 @@ msgid ""
 "the update"
 msgstr ""
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, kde-format
 msgid ""
 "Failed to adopt '%1'\n"
 "%2"
 msgstr ""
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, kde-format
 msgctxt ""
 "The first entry in the category selection list (also the default value)"
 msgid "All Categories"
 msgstr "Všechny kategorie"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, kde-format
 msgctxt ""
 "The string passed back in the case the requested category is not known"
@@ -321,13 +321,13 @@ msgstr ""
 msgid "Download New %1…"
 msgstr "Stáhnout nové %1…"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, kde-format
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "Stáhnout nový %1"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, kde-format
 msgctxt ""
 "A placeholder title used in the dialog when there is no better title "
@@ -335,12 +335,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "Stáhnout nový obsah"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr "Zvolte si možnost instalace"
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -349,19 +349,19 @@ msgid ""
 "this through the naming of the items."
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "Instalovat"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, kde-format
 msgctxt ""
 "A passive notification shown when installation of an item is initiated"
 msgid "Installing %1 from %2"
 msgstr "Instaluje se %1 z %2"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -369,10 +369,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr "%1 od %2"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, kde-format
 msgctxt ""
 "Request installation of this item, available when there is exactly one "
@@ -380,32 +380,32 @@ msgctxt ""
 msgid "Install"
 msgstr "Instalovat"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, kde-format
 msgctxt ""
 "Show installation options, where there is more than one downloadable item"
 msgid "Install…"
 msgstr "Instalovat…"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, kde-format
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "Aktualizovat"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, kde-format
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "Odinstalovat"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -413,14 +413,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr "Aktuálně pracuji na položce %1 z %2. Prosím, počkejte…"
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr "Aktuálně aktualizuji %1 z %2. Prosím, počkejte…"
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -431,12 +431,12 @@ msgid ""
 "to the KDE Community in a bug report</a>."
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr "Komentáře a kontrola:"
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a new sub page with comments (comments "
@@ -444,17 +444,17 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "%1 Hodnocení a komentáře"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, kde-format
 msgid "Rating:"
 msgstr "Hodnocení:"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, kde-format
 msgid "Homepage:"
 msgstr "Domácí stránka:"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -463,12 +463,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr "Otevřít domovskou stránku pro %1"
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr "Jak přispět:"
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -476,74 +476,82 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr "Jak přispět na tento projekt"
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
-"Zde dostupný obsah byl odeslán uživateli jako jste vy a nebyl zkontrolován "
-"tvůrcem vaší distribuce zda je správně funkční a stabilní."
+"Obsah vytvořený uživateli nebyl testován KDE ani tvůrcem vaší distribuce zda "
+"je správně funkční a stabilní."
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, kde-format
 msgid "Tiles"
 msgstr "Dlaždice"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "Ikony"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, kde-format
 msgid "Preview"
 msgstr "Náhled"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, kde-format
 msgid "Detailed Tiles View Mode"
 msgstr "Režim podrobného dlaždicového zobrazení"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, kde-format
 msgid "Icons Only View Mode"
 msgstr "Režim zobrazení pouze s ikonami"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, kde-format
 msgid "Large Preview View Mode"
 msgstr "Režim zobrazení velkého náhledu"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr "Vše"
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "Nainstalováno"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, kde-format
 msgid "Updateable"
 msgstr "Aktualizovatelné"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, kde-format
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "Zobrazit všechny položky"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr "Zobrazit pouze nainstalované položky"
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -551,27 +559,27 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr "Zobrazit pouze aktualizovatelné položky"
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, kde-format
 msgid "Recent"
 msgstr "Nedávné"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr "Podle abecedy"
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "Hodnocení"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, kde-format
 msgid "Downloads"
 msgstr "Stahování"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on when items were most "
@@ -579,7 +587,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "Nejdříve zobrazit nejnovější"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -587,57 +595,57 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr "Seřadit abecedně podle jména"
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, kde-format
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "Nejdříve zobrazit nejlépe hodnocené"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on number of downloads"
 msgid "Show Most Downloaded First"
 msgstr "Nejdříve zobrazit nejvíce stahované"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, kde-format
 msgid "Upload…"
 msgstr "Odeslat…"
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr ""
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, kde-format
 msgid "Go to…"
 msgstr "Přejít na…"
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, kde-format
 msgid "Search…"
 msgstr "Hledat…"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "Kategorie:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, kde-format
 msgid "Contribute your own…"
 msgstr "Přispět vlastní…"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, kde-format
 msgctxt ""
 "Placeholder title for when a comment has no subject, but does have a rating"
 msgid "<i>(no title)</i>"
 msgstr "<li>(bez názvu)</li>"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -645,19 +653,19 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr "%1 <i>(autor)</i>"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr "Komentáře a kontrola pro %1"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, kde-format
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "Zobrazit všechny komentáře"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -665,7 +673,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr "Zobrazit pouze náhledy"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -673,15 +681,15 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr "Zobrazit náhledy a odpovědi"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, kde-format
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
 msgstr "%1 stažení"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, kde-format
 msgctxt ""
 "Subheading for the tile view, located immediately underneath the name of the "
@@ -689,7 +697,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "Od <i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -697,7 +705,7 @@ msgctxt ""
 msgid "Working…"
 msgstr "Pracuje…"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is in the process of being "
@@ -705,7 +713,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "Aktualizuji…"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -716,7 +724,7 @@ msgid ""
 "bug report</a>."
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, kde-format
 msgctxt "Label for the busy indicator showing an item is installing"
 msgid "Installing…"
@@ -734,44 +742,44 @@ msgid "Please try again later."
 msgstr "Prosím, zkuste znovu později."
 
 # žádné parametry funkce v inspektoru funkcí
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, kde-format
 msgid "None"
 msgstr "Nic"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, kde-format
 msgctxt ""
 "A text representation of the rating, shown as a fraction of the max value"
 msgid "(%1/%2)"
 msgstr "(%1/%2)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, kde-format
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "Odeslat nový obsah: %1"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, kde-format
 msgctxt ""
 "A text shown beside a busy indicator suggesting that data is being fetched"
 msgid "Updating information…"
 msgstr "Aktualizuji informace…"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, kde-format
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "Obchod KDE"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, kde-format
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "Váš poskytovatel"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, kde-format
 msgctxt ""
 "Text for an action which causes the specified website to be opened using the "
@@ -779,7 +787,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "Otevřít webovou stránku: %1"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, kde-format
 msgctxt ""
 "Text for an action which will attempt to send an email using the user's "
@@ -787,7 +795,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "Odeslat e-mail na: %1"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -795,10 +803,10 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -810,18 +818,18 @@ msgid ""
 "content added."
 msgstr ""
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "Načítají se data"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "Instaluje se"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -831,73 +839,73 @@ msgid ""
 "please contact the person in charge of your permissions."
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "Zpět"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr "Populární"
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "Restartovat"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "New"
 msgstr "Nový"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Domů"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "Nahoru"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "Doporučeno"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "Přihlášení"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "Všechny položky"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -929,5 +937,6 @@ msgstr ""
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
 #, kde-format
-msgid "Download New Stuff..."
-msgstr "Stáhnout nový obsah..."
+msgctxt "@action"
+msgid "Download New Stuff…"
+msgstr "Stáhnout nový obsah…"
diff -pruN 6.0.0-3/po/csb/knewstuff6.po 6.3.0-1/po/csb/knewstuff6.po
--- 6.0.0-3/po/csb/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/csb/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -7,7 +7,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2009-12-04 22:09+0100\n"
 "Last-Translator: Mark Kwidzińśczi <mark@linuxcsb.org>\n"
 "Language-Team: Kaszëbsczi <i18n-csb@linuxcsb.org>\n"
@@ -54,7 +54,7 @@ msgstr "Niżóden tekst nie òstôł zam
 msgid "You are now a fan."
 msgstr ""
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -122,7 +122,7 @@ msgstr "Kònfigùracjowé lopczi"
 msgid "Use"
 msgstr ""
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -130,17 +130,17 @@ msgid ""
 "This is a critical error and should be reported to the application author"
 msgstr ""
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr ""
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr ""
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr ""
@@ -286,7 +286,7 @@ msgid ""
 "the update"
 msgstr ""
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, fuzzy, kde-format
 #| msgid "Failed to load file '%1'"
 msgid ""
@@ -294,7 +294,7 @@ msgid ""
 "%2"
 msgstr "Ni jidze wladowac lopka '%1'"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt ""
@@ -302,7 +302,7 @@ msgctxt ""
 msgid "All Categories"
 msgstr "Wszëtczé kategòrëje"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, fuzzy, kde-format
 #| msgid "Unknown error"
 msgctxt ""
@@ -328,14 +328,14 @@ msgstr ""
 msgid "Download New %1…"
 msgstr "Zladëjë nowé %1"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, fuzzy, kde-format
 #| msgid "Download New %1"
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "Zladëjë nowé %1"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
 msgctxt ""
@@ -344,12 +344,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "Zladëjë nowé paczétë"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -358,12 +358,12 @@ msgid ""
 "this through the naming of the items."
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "Instalëjë"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt ""
@@ -371,7 +371,7 @@ msgctxt ""
 msgid "Installing %1 from %2"
 msgstr "Instalëjë"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -379,10 +379,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -391,10 +391,10 @@ msgctxt ""
 msgid "Install"
 msgstr "Instalëjë"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -402,24 +402,24 @@ msgctxt ""
 msgid "Install…"
 msgstr "Instalëjë"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, fuzzy, kde-format
 #| msgid "Update"
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "Aktualizëjë"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, fuzzy, kde-format
 #| msgid "Uninstall"
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "Òdinstalëjë"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -427,14 +427,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -445,12 +445,12 @@ msgid ""
 "to the KDE Community in a bug report</a>."
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, fuzzy, kde-format
 #| msgid "View Comments"
 msgctxt ""
@@ -459,19 +459,19 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "Wëskrzëni dopòwiescë"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, fuzzy, kde-format
 #| msgid "Rating: "
 msgid "Rating:"
 msgstr "Taksa: "
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, fuzzy, kde-format
 #| msgid "Homepage"
 msgid "Homepage:"
 msgstr "Domôcô starna WWW"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -480,12 +480,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -493,78 +493,86 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr ""
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, fuzzy, kde-format
 #| msgid "File"
 msgid "Tiles"
 msgstr "Lopk"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "Ikònë"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, fuzzy, kde-format
 #| msgid "Previews"
 msgid "Preview"
 msgstr "Pòdzérczi"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, kde-format
 msgid "Detailed Tiles View Mode"
 msgstr ""
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, fuzzy, kde-format
 #| msgid "Icons Only"
 msgid "Icons Only View Mode"
 msgstr "Blós ikonë"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, fuzzy, kde-format
 #| msgid "Preview Image:"
 msgid "Large Preview View Mode"
 msgstr "Pòdzerk òbrôzka:"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr ""
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "Instalacëjô"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, fuzzy, kde-format
 #| msgid "Update"
 msgid "Updateable"
 msgstr "Aktualizëjë"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "Wszëtczé kategòrëje"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -572,30 +580,30 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Open Recent"
 msgid "Recent"
 msgstr "Òtemkni wczasniészi"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr ""
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "Òbtaksowanié"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, fuzzy, kde-format
 #| msgid "Download"
 msgid "Downloads"
 msgstr "Ladëjë"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt ""
@@ -604,7 +612,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "Pòkôżë wprzód katalodżi"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -612,14 +620,14 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr ""
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "Pòkôżë wprzód katalodżi"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, fuzzy, kde-format
 #| msgid "Most Downloads"
 msgctxt ""
@@ -627,41 +635,41 @@ msgctxt ""
 msgid "Show Most Downloaded First"
 msgstr "Nôczãsci zladowóné"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, fuzzy, kde-format
 #| msgid "Upload..."
 msgid "Upload…"
 msgstr "Wladënk..."
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr ""
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, fuzzy, kde-format
 #| msgid "&Go To..."
 msgid "Go to…"
 msgstr "&Biéj do..."
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, fuzzy, kde-format
 #| msgid "Search:"
 msgid "Search…"
 msgstr "Szëkba:"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "Kategòrëjô:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, fuzzy, kde-format
 #| msgid "Continue operation"
 msgid "Contribute your own…"
 msgstr "Biéj dali z òperacëją"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, fuzzy, kde-format
 #| msgctxt "@note/rich"
 #| msgid "<i>Note</i>: %1"
@@ -670,7 +678,7 @@ msgctxt ""
 msgid "<i>(no title)</i>"
 msgstr "<i>Nadczidka</i>: %1"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -678,20 +686,20 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "Wszëtczé kategòrëje"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -699,7 +707,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -707,16 +715,16 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, fuzzy, kde-format
 #| msgid "Download"
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
 msgstr "Ladëjë"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, fuzzy, kde-format
 #| msgctxt "Show the author of this item in a list"
 #| msgid "By <i>%1</i>"
@@ -726,7 +734,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "przez <i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -734,7 +742,7 @@ msgctxt ""
 msgid "Working…"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, fuzzy, kde-format
 #| msgid "Updating"
 msgctxt ""
@@ -743,7 +751,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "Aktualizëjë"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -754,7 +762,7 @@ msgid ""
 "bug report</a>."
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt "Label for the busy indicator showing an item is installing"
@@ -773,14 +781,14 @@ msgstr ""
 msgid "Please try again later."
 msgstr "Proszã pòdac miono."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, fuzzy, kde-format
 #| msgctxt "No border line"
 #| msgid "None"
 msgid "None"
 msgstr "Felëjë"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, fuzzy, kde-format
 #| msgid "(%1/s)"
 msgctxt ""
@@ -788,14 +796,14 @@ msgctxt ""
 msgid "(%1/%2)"
 msgstr "(%1/s)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "Zladëjë nowé paczétë"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, fuzzy, kde-format
 #| msgid "Billing information:"
 msgctxt ""
@@ -803,21 +811,21 @@ msgctxt ""
 msgid "Updating information…"
 msgstr "Rechùnkòwô wëdowiédza:"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, fuzzy, kde-format
 #| msgid "&Store"
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "&Trzëmôj"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, fuzzy, kde-format
 #| msgid "Provider:"
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "Dowòznik:"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, fuzzy, kde-format
 #| msgid "&Open with '%1'"
 msgctxt ""
@@ -826,7 +834,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "Òtemkni &w '%1'"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, fuzzy, kde-format
 #| msgid "&Send Email"
 msgctxt ""
@@ -835,7 +843,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "Wëslë &e-mail"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -843,10 +851,10 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -858,19 +866,19 @@ msgid ""
 "content added."
 msgstr ""
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, fuzzy, kde-format
 #| msgid "Loading Applet"
 msgid "Loading data"
 msgstr "Ladowanié apletu"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "Instalëjë"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -880,7 +888,7 @@ msgid ""
 "please contact the person in charge of your permissions."
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Back"
@@ -888,20 +896,20 @@ msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "Nazôd"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, fuzzy, kde-format
 #| msgid "Saturday"
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "sobòta"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, fuzzy, kde-format
 #| msgctxt "@action:button Restart find & replace"
 #| msgid "Restart"
@@ -909,7 +917,7 @@ msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "Zrëszë znowa"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "New"
@@ -917,7 +925,7 @@ msgctxt "Knewstuff5"
 msgid "New"
 msgstr "Nowi"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Home"
@@ -925,13 +933,13 @@ msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Home"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Up"
@@ -939,7 +947,7 @@ msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "W górã"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, fuzzy, kde-format
 #| msgctxt "dictionary variant"
 #| msgid "extended"
@@ -947,7 +955,7 @@ msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "rozszérzoné"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Subscript"
@@ -955,14 +963,14 @@ msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "Subskribùjë"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "Wszëtczé kategòrëje"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -993,9 +1001,14 @@ msgid ""
 msgstr ""
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
-#, kde-format
-msgid "Download New Stuff..."
-msgstr "Zladëjë nowé paczétë..."
+#, fuzzy, kde-format
+#| msgid "Download New Stuff"
+msgctxt "@action"
+msgid "Download New Stuff…"
+msgstr "Zladëjë nowé paczétë"
+
+#~ msgid "Download New Stuff..."
+#~ msgstr "Zladëjë nowé paczétë..."
 
 #, fuzzy
 #~| msgid "Installing"
diff -pruN 6.0.0-3/po/cy/knewstuff6.po 6.3.0-1/po/cy/knewstuff6.po
--- 6.0.0-3/po/cy/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/cy/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -18,7 +18,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2005-01-28 17:54+0000\n"
 "Last-Translator: Kevin Donnelly <kevin@dotmon.com>\n"
 "Language-Team: Cymraeg\n"
@@ -65,7 +65,7 @@ msgstr "Ni amnewidwyd testun. "
 msgid "You are now a fan."
 msgstr ""
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -133,7 +133,7 @@ msgstr "Ffurfwedd"
 msgid "Use"
 msgstr "Dat-gysgodi"
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -141,18 +141,18 @@ msgid ""
 "This is a critical error and should be reported to the application author"
 msgstr ""
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, fuzzy, kde-format
 #| msgid "Loading resource '%1' failed!"
 msgid "Loading of providers from file: %1 failed"
 msgstr "Methodd llwytho adnodd '%1'!"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr ""
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, fuzzy, kde-format
 #| msgid "Error parsing providers list."
 msgid "Error initializing provider."
@@ -300,14 +300,14 @@ msgid ""
 "the update"
 msgstr ""
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, fuzzy, kde-format
 msgid ""
 "Failed to adopt '%1'\n"
 "%2"
 msgstr "Methu llwytho adnodd '%1'"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, fuzzy, kde-format
 #| msgid "Categories"
 msgctxt ""
@@ -315,7 +315,7 @@ msgctxt ""
 msgid "All Categories"
 msgstr "Categoriau"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, fuzzy, kde-format
 #| msgctxt "QFile"
 #| msgid "Unknown error"
@@ -342,14 +342,14 @@ msgstr ""
 msgid "Download New %1…"
 msgstr "Lawrlwytho %1 Newydd"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, fuzzy, kde-format
 #| msgid "Download New %1"
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "Lawrlwytho %1 Newydd"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
 msgctxt ""
@@ -358,12 +358,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "Lawrlwytho y Diweddaraf"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, fuzzy, kde-format
 msgid "Pick Your Installation Option"
 msgstr "Dewis Adnoddau"
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -372,12 +372,12 @@ msgid ""
 "this through the naming of the items."
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "Arsefydlu"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -385,7 +385,7 @@ msgctxt ""
 msgid "Installing %1 from %2"
 msgstr "Arsefydlu"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -393,10 +393,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -405,10 +405,10 @@ msgctxt ""
 msgid "Install"
 msgstr "Arsefydlu"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -416,24 +416,24 @@ msgctxt ""
 msgid "Install…"
 msgstr "Arsefydlu"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, fuzzy, kde-format
 #| msgid "Update"
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "Diweddaru"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "Arsefydlu"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -441,14 +441,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -459,12 +459,12 @@ msgid ""
 "to the KDE Community in a bug report</a>."
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, fuzzy, kde-format
 #| msgid "Comment"
 msgctxt ""
@@ -473,19 +473,19 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "Esboniad"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, fuzzy, kde-format
 #| msgid "Rating"
 msgid "Rating:"
 msgstr "Poblogrwydd"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, fuzzy, kde-format
 #| msgid "Homepage"
 msgid "Homepage:"
 msgstr "Tudalen gartref"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -494,12 +494,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -507,73 +507,81 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr ""
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, fuzzy, kde-format
 #| msgid "&Tile"
 msgid "Tiles"
 msgstr "&Teilio"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "Eiconau"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, fuzzy, kde-format
 #| msgid "Preview URL:"
 msgid "Preview"
 msgstr "URL Rhagolwg:"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, fuzzy, kde-format
 #| msgid "Details"
 msgid "Detailed Tiles View Mode"
 msgstr " Manylion"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, fuzzy, kde-format
 #| msgid "Icon Size"
 msgid "Icons Only View Mode"
 msgstr "Maint Eicon"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, fuzzy, kde-format
 #| msgid "Details"
 msgid "Large Preview View Mode"
 msgstr " Manylion"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr ""
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, fuzzy, kde-format
 #| msgid "Install"
 msgid "Installed"
 msgstr "Arsefydlu"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, fuzzy, kde-format
 #| msgid "Update"
 msgid "Updateable"
 msgstr "Diweddaru"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, fuzzy, kde-format
 #| msgid "Show all options"
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "Dangos y dewisiadau i gyd"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, fuzzy, kde-format
 #| msgid "Show all options"
 msgctxt ""
@@ -581,7 +589,7 @@ msgctxt ""
 msgid "Show Only Installed Entries"
 msgstr "Dangos y dewisiadau i gyd"
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, fuzzy, kde-format
 #| msgid "Show all options"
 msgctxt ""
@@ -590,31 +598,31 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr "Dangos y dewisiadau i gyd"
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, fuzzy, kde-format
 #| msgctxt "QAccel"
 #| msgid "Percent"
 msgid "Recent"
 msgstr "Canran-nod"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr ""
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, fuzzy, kde-format
 #| msgid "Rating"
 msgid "Rating"
 msgstr "Poblogrwydd"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, fuzzy, kde-format
 #| msgid "Download"
 msgid "Downloads"
 msgstr "Lawrlwytho"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, fuzzy, kde-format
 #| msgid "Most Downloads"
 msgctxt ""
@@ -623,7 +631,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "Lawrlwythir yn Amlaf"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -631,14 +639,14 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr ""
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, fuzzy, kde-format
 #| msgid "Highest Rated"
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "Ystyriedir y Gorau"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, fuzzy, kde-format
 #| msgid "Most Downloads"
 msgctxt ""
@@ -646,49 +654,49 @@ msgctxt ""
 msgid "Show Most Downloaded First"
 msgstr "Lawrlwythir yn Amlaf"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, fuzzy, kde-format
 #| msgid "&Upload"
 msgid "Upload…"
 msgstr "&Lanlwytho"
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr ""
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, fuzzy, kde-format
 #| msgid "&Go To..."
 msgid "Go to…"
 msgstr "&Mynd i.."
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, fuzzy, kde-format
 #| msgid "S&earch:"
 msgid "Search…"
 msgstr "C&hwilio"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, fuzzy, kde-format
 #| msgid "Categories"
 msgid "Category:"
 msgstr "Categoriau"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, fuzzy, kde-format
 #| msgid "Continue operation"
 msgid "Contribute your own…"
 msgstr "Ewch ymlaen a'r gweithrediad"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, kde-format
 msgctxt ""
 "Placeholder title for when a comment has no subject, but does have a rating"
 msgid "<i>(no title)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -696,20 +704,20 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, fuzzy, kde-format
 #| msgid "Categories"
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "Categoriau"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -717,7 +725,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -725,16 +733,16 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, fuzzy, kde-format
 #| msgid "Download"
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
 msgstr "Lawrlwytho"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, fuzzy, kde-format
 #| msgid "<b>Error</b>: %1: %2"
 msgctxt ""
@@ -743,7 +751,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "<b>Gwall</b>: %1: %2"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -751,7 +759,7 @@ msgctxt ""
 msgid "Working…"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, fuzzy, kde-format
 #| msgid "Update"
 msgctxt ""
@@ -760,7 +768,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "Diweddaru"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -771,7 +779,7 @@ msgid ""
 "bug report</a>."
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt "Label for the busy indicator showing an item is installing"
@@ -792,13 +800,13 @@ msgstr "ni ddigwyddodd gwall"
 msgid "Please try again later."
 msgstr "Rhowch enw, os gwelwch yn dda."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, fuzzy, kde-format
 #| msgid "None"
 msgid "None"
 msgstr "Dim"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, fuzzy, kde-format
 #| msgid "(%1/s)"
 msgctxt ""
@@ -806,14 +814,14 @@ msgctxt ""
 msgid "(%1/%2)"
 msgstr "(%1/s)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "Lawrlwytho y Diweddaraf"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, fuzzy, kde-format
 #| msgid "Information"
 msgctxt ""
@@ -821,20 +829,20 @@ msgctxt ""
 msgid "Updating information…"
 msgstr "Gwybodaeth"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, fuzzy, kde-format
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "Stryd"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, fuzzy, kde-format
 #| msgid "Hide %1"
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "Cuddio %1"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, fuzzy, kde-format
 #| msgid "&Open with '%1'"
 msgctxt ""
@@ -843,7 +851,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "A&gor efo '%1'"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, fuzzy, kde-format
 #| msgid "&Send Email"
 msgctxt ""
@@ -852,7 +860,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "Anfon E&bost"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -860,10 +868,10 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -875,20 +883,20 @@ msgid ""
 "content added."
 msgstr ""
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, fuzzy, kde-format
 #| msgid "Loading Applet"
 msgid "Loading data"
 msgstr "Llwytho rhaglennig"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, fuzzy, kde-format
 #| msgid "Install"
 msgid "Installing"
 msgstr "Arsefydlu"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -898,41 +906,41 @@ msgid ""
 "please contact the person in charge of your permissions."
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, fuzzy, kde-format
 #| msgid "Back"
 msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "Yn ôl"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, fuzzy, kde-format
 #| msgid "Saturday"
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "Dydd Sadwrn"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, fuzzy, kde-format
 #| msgid "Restart"
 msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "Ail-gychwyn"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, fuzzy, kde-format
 #| msgid "New"
 msgctxt "Knewstuff5"
 msgid "New"
 msgstr "Newydd"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, fuzzy, kde-format
 #| msgctxt "Opposite to End"
 #| msgid "Home"
@@ -940,39 +948,39 @@ msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Cartref"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, fuzzy, kde-format
 #| msgid "Up"
 msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "I fyny"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, fuzzy, kde-format
 msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "Ysgr&if"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, fuzzy, kde-format
 #| msgid "Show all options"
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "Dangos y dewisiadau i gyd"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -1005,10 +1013,16 @@ msgstr ""
 #: widgets/action.cpp:28 widgets/button.cpp:70
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
-msgid "Download New Stuff..."
+msgctxt "@action"
+msgid "Download New Stuff…"
 msgstr "Lawrlwytho y Diweddaraf"
 
 #, fuzzy
+#~| msgid "Download New Stuff"
+#~ msgid "Download New Stuff..."
+#~ msgstr "Lawrlwytho y Diweddaraf"
+
+#, fuzzy
 #~| msgid "Install"
 #~ msgid "Initializing"
 #~ msgstr "Arsefydlu"
diff -pruN 6.0.0-3/po/da/knewstuff6.po 6.3.0-1/po/da/knewstuff6.po
--- 6.0.0-3/po/da/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/da/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -8,7 +8,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2021-09-09 21:26+0200\n"
 "Last-Translator: Martin Schlander <mschlander@opensuse.org>\n"
 "Language-Team: Danish <kde-i18n-doc@kde.org>\n"
@@ -57,7 +57,7 @@ msgstr "Din stemme blev afgivet."
 msgid "You are now a fan."
 msgstr "Du er nu fan."
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -126,7 +126,7 @@ msgstr "Konfigurationsfilen er ugyldig:
 msgid "Use"
 msgstr "Brug"
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, fuzzy, kde-format
 #| msgid ""
 #| "Could not initialise the installation handler for %1\n"
@@ -139,17 +139,17 @@ msgstr ""
 "Kunne ikke initialisere installationshåndteringen for %1\n"
 "Dette er en kritisk fejl og bør rapporteres til programmets ophavsmand"
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr "Indlæsning af udbydere fra filen %1 mislykkedes"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr "Kunne ikke indlæse Hent smarte nye ting-udbydere fra filen: %1"
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr "Fejl under initialisering af udbyder."
@@ -320,7 +320,7 @@ msgstr ""
 "Vi kunne ikke identificere et godt link til opdatering af %1, og kan derfor "
 "ikke udføre opdateringen."
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, kde-format
 msgid ""
 "Failed to adopt '%1'\n"
@@ -329,14 +329,14 @@ msgstr ""
 "Kunne ikke tilegne \"%1\"\n"
 "%2"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, kde-format
 msgctxt ""
 "The first entry in the category selection list (also the default value)"
 msgid "All Categories"
 msgstr "Alle kategorier"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, kde-format
 msgctxt ""
 "The string passed back in the case the requested category is not known"
@@ -367,13 +367,13 @@ msgstr "Ting og sager"
 msgid "Download New %1…"
 msgstr "Download ny %1"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, kde-format
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "Download ny %1"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, kde-format
 msgctxt ""
 "A placeholder title used in the dialog when there is no better title "
@@ -381,12 +381,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "Download nye ting"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr "Dit installationsvalg"
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -399,19 +399,19 @@ msgstr ""
 "tilgængelige valgmuligheder, så kontakt ophavsmanden til dette element og "
 "bed dem om at gøre dette klarere igennem navngivningen af elementerne."
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "Installér"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, kde-format
 msgctxt ""
 "A passive notification shown when installation of an item is initiated"
 msgid "Installing %1 from %2"
 msgstr "Installerer %1 fra %2"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -419,10 +419,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr "%1 af %2"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, kde-format
 msgctxt ""
 "Request installation of this item, available when there is exactly one "
@@ -430,10 +430,10 @@ msgctxt ""
 msgid "Install"
 msgstr "Installér"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -441,22 +441,22 @@ msgctxt ""
 msgid "Install…"
 msgstr "Installér"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, kde-format
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "Opdatér"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, kde-format
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "Afinstallér"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, fuzzy, kde-format
 #| msgctxt ""
 #| "Status message to be shown when the entry is in the process of being "
@@ -468,7 +468,7 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr "Arbejder i øjeblikket på elementet %1 af %2. Vent venligst..."
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, fuzzy, kde-format
 #| msgctxt ""
 #| "Status message to be shown when the entry is in the process of being "
@@ -479,7 +479,7 @@ msgctxt ""
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr "Opdaterer nu elementet %1 af %2. Vent venligst..."
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -493,12 +493,12 @@ msgstr ""
 "\"https://bugs.kde.org/enter_bug.cgi?product=frameworks-knewstuff"
 "\">Rapportér venligst dette til KDE-fællesskabet i en fejlrapport</a>."
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr "Kommentarer og anmeldelser:"
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a new sub page with comments (comments "
@@ -506,17 +506,17 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "%1 anmeldelser og kommentarer"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, kde-format
 msgid "Rating:"
 msgstr "Vurdering:"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, kde-format
 msgid "Homepage:"
 msgstr "Hjemmeside:"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -525,12 +525,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr "Åbn hjemmesiden for %1"
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr "Hvordan man donerer:"
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -538,72 +538,80 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr "Find ud af hvordan man donerer til dette projekt"
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, kde-format
 msgid "Tiles"
 msgstr "Felter"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "Ikoner"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, kde-format
 msgid "Preview"
 msgstr "Forhåndsvisning"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, kde-format
 msgid "Detailed Tiles View Mode"
 msgstr "Detaljeret visningstilstand med felter"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, kde-format
 msgid "Icons Only View Mode"
 msgstr "Visningstilstand kun med ikoner"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, kde-format
 msgid "Large Preview View Mode"
 msgstr "Visningstilstand med stor forhåndsvisning"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr "Alt"
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "Installeret"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, kde-format
 msgid "Updateable"
 msgstr "Kan opdateres"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, kde-format
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "Vis alle indgange"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr "Vis kun installerede indgange"
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -611,27 +619,27 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr "Vis kun indgange som kan opdateres"
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, kde-format
 msgid "Recent"
 msgstr "Nylige"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr "Alfabetisk"
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "Vurdering"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, kde-format
 msgid "Downloads"
 msgstr "Downloads"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on when items were most "
@@ -639,7 +647,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "Vis mest nylige først"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -647,61 +655,61 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr "Sortér alfabetisk efter navn"
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, kde-format
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "Vis højest vurderede først"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on number of downloads"
 msgid "Show Most Downloaded First"
 msgstr "Vis flest downloads først"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, fuzzy, kde-format
 #| msgid "Upload..."
 msgid "Upload…"
 msgstr "Upload..."
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr "Lær hvordan du kan tilføje dine egne smarte ting til denne liste"
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, fuzzy, kde-format
 #| msgid "Go to..."
 msgid "Go to…"
 msgstr "Gå til..."
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, fuzzy, kde-format
 #| msgid "Search:"
 msgid "Search…"
 msgstr "Søg:"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "Kategori:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, fuzzy, kde-format
 #| msgid "Contribute your own..."
 msgid "Contribute your own…"
 msgstr "Bidrag med din egen..."
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, kde-format
 msgctxt ""
 "Placeholder title for when a comment has no subject, but does have a rating"
 msgid "<i>(no title)</i>"
 msgstr "<i>(ingen titel)</i>"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -709,19 +717,19 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr "%1 <i>(ophavsmand)</i>"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr "Kommentarer og anmeldelser til %1"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, kde-format
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "Vis alle kommentarer"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -729,7 +737,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr "Vis kun anmeldelser"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -737,15 +745,15 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr "Vis anmeldelser og svar"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, kde-format
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
 msgstr "%1 downloads"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, kde-format
 msgctxt ""
 "Subheading for the tile view, located immediately underneath the name of the "
@@ -753,7 +761,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "Af <i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, fuzzy, kde-format
 #| msgctxt ""
 #| "Label for the busy indicator showing an item is being installed OR "
@@ -765,7 +773,7 @@ msgctxt ""
 msgid "Working…"
 msgstr "Arbejder..."
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, fuzzy, kde-format
 #| msgid "Updating"
 msgctxt ""
@@ -774,7 +782,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "Opdaterer"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -788,7 +796,7 @@ msgstr ""
 "product=frameworks-knewstuff\">Rapportér venligst dette til KDE-fællesskabet "
 "i en fejlrapport</a>."
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt "Label for the busy indicator showing an item is installing"
@@ -807,19 +815,19 @@ msgstr "Der opstod en fejl"
 msgid "Please try again later."
 msgstr "Put venligst et navn ind."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, kde-format
 msgid "None"
 msgstr "Ingen"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, kde-format
 msgctxt ""
 "A text representation of the rating, shown as a fraction of the max value"
 msgid "(%1/%2)"
 msgstr "(%1/%2)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, fuzzy, kde-format
 #| msgctxt "@knewstuff5"
 #| msgid "Upload New Stuff: %1"
@@ -827,7 +835,7 @@ msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "Opdatér nye ting: %1"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, fuzzy, kde-format
 #| msgctxt ""
 #| "A text shown beside a busy indicator suggesting that data is being fetched"
@@ -837,19 +845,19 @@ msgctxt ""
 msgid "Updating information…"
 msgstr "Opdaterer information..."
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, kde-format
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "KDE-butik"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, kde-format
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "Din udbyder"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, kde-format
 msgctxt ""
 "Text for an action which causes the specified website to be opened using the "
@@ -857,7 +865,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "Åbn webside: %1"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, kde-format
 msgctxt ""
 "Text for an action which will attempt to send an email using the user's "
@@ -865,15 +873,22 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "Send e-mail til: %1"
 
-#: qtquick/qml/UploadPage.qml:154
-#, kde-format
+#: qtquick/qml/UploadPage.qml:159
+#, fuzzy, kde-format
+#| msgctxt "A description of how to upload content to a generic provider"
+#| msgid ""
+#| "To upload new entries, or to add content to an existing entry on the KDE "
+#| "Store, please open the website and log in. Once you have done this, you "
+#| "will be able to find the My Products entry in the menu which pops up when "
+#| "you click your user icon. Click on this entry to go to the product "
+#| "management system, where you can work on your products ."
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
 "To upload new entries, or to add content to an existing entry on the KDE "
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 "For at uploade nye indgange, eller føje indhold til en eksisterende indgang "
 "på KDE-butikken, så åbn websiden og log ind. Når du har gjort det, vil du "
@@ -881,7 +896,7 @@ msgstr ""
 "på dit brugerikon. Klik på denne indgang for at gå til "
 "produkthåndteringssystemet, hvor du kan arbejde på dine produkter."
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -899,18 +914,18 @@ msgstr ""
 "skulle kontakte websidens administratorer direkte for at få nyt indhold "
 "tilføjet."
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "Indlæser data"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "Installerer"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -922,73 +937,73 @@ msgstr ""
 "Du har ikke rettigheder til Get Hot New Stuff. Hvis du mener dette er en "
 "fejl, så kontakt venligst den person der er ansvarlig for dine rettigheder."
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "Tilbage"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr "Populære"
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "På plakaten"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "Genstart"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "New"
 msgstr "Ny"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Hjem"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr "Reol"
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "Op"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "Anbefalet"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "Abonnementer"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "Alle indgange"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -1045,9 +1060,17 @@ msgstr ""
 " Et eksempel på sådan en fil er kns://peruse.knsrc/api.kde-look.org/1316714"
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
-#, kde-format
-msgid "Download New Stuff..."
-msgstr "Download nye ting..."
+#, fuzzy, kde-format
+#| msgctxt ""
+#| "A placeholder title used in the dialog when there is no better title "
+#| "available"
+#| msgid "Download New Stuff"
+msgctxt "@action"
+msgid "Download New Stuff…"
+msgstr "Download nye ting"
+
+#~ msgid "Download New Stuff..."
+#~ msgstr "Download nye ting..."
 
 #~ msgctxt ""
 #~ "A message which is shown when the user attempts to display a specific "
diff -pruN 6.0.0-3/po/de/knewstuff6.po 6.3.0-1/po/de/knewstuff6.po
--- 6.0.0-3/po/de/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/de/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -1,3 +1,4 @@
+# SPDX-FileCopyrightText: 2010, 2024 Johannes Obermayr <johannesobermayr@gmx.de>
 # Thomas Diehl <thd@kde.org>, 2002, 2003, 2004, 2005.
 # Stefan Winter <swinter@kde.org>, 2004.
 # Thomas Fischer <thomas.fischer@t-fischer.net>, 2004.
@@ -6,7 +7,6 @@
 # Thomas Reitelbach <tr@erdfunkstelle.de>, 2005, 2006, 2007, 2008, 2009.
 # Burkhard Lück <lueck@hube-lueck.de>, 2006, 2007, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020, 2021.
 # Frederik Schwarzer <schwarzer@kde.org>, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2016, 2020, 2023.
-# Johannes Obermayr <johannesobermayr@gmx.de>, 2010.
 # Panagiotis Papadopoulos <pano_90@gmx.net>, 2010.
 # Rolf Eike Beer <kde@opensource.sf-tec.de>, 2012.
 # Jannick Kuhr <opensource@kuhr.org>, 2023.
@@ -14,16 +14,16 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
-"PO-Revision-Date: 2023-03-21 19:57+0100\n"
-"Last-Translator: Frederik Schwarzer <schwarzer@kde.org>\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
+"PO-Revision-Date: 2024-04-28 20:25+0200\n"
+"Last-Translator: Johannes Obermayr <johannesobermayr@gmx.de>\n"
 "Language-Team: German <kde-i18n-de@kde.org>\n"
 "Language: de\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=2; plural=(n != 1);\n"
-"X-Generator: Lokalize 22.12.3\n"
+"X-Generator: Lokalize 24.02.2\n"
 
 #: attica/atticaprovider.cpp:165
 #, kde-format
@@ -63,7 +63,7 @@ msgstr "Ihre Bewertung wurde aufgenommen
 msgid "You are now a fan."
 msgstr "Sind sind nun ein Fan."
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -137,7 +137,7 @@ msgstr "Einrichtungsdatei ist ungültig:
 msgid "Use"
 msgstr "Verwenden"
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -145,17 +145,17 @@ msgid ""
 "This is a critical error and should be reported to the application author"
 msgstr ""
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr "Laden von Anbietern aus der Datei „%1“ fehlgeschlagen"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr "Aus der Datei können keine Anbieter geladen werden: %1"
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr "Fehler beim Initialisieren des Anbieters."
@@ -297,7 +297,7 @@ msgid ""
 "the update"
 msgstr ""
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, fuzzy, kde-format
 #| msgid "Failed to load file '%1'"
 msgid ""
@@ -305,14 +305,14 @@ msgid ""
 "%2"
 msgstr "Die Datei „%1“ kann nicht geladen werden"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, kde-format
 msgctxt ""
 "The first entry in the category selection list (also the default value)"
 msgid "All Categories"
 msgstr "Alle Kategorien"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, kde-format
 msgctxt ""
 "The string passed back in the case the requested category is not known"
@@ -339,13 +339,13 @@ msgstr ""
 msgid "Download New %1…"
 msgstr "Neue %1 herunterladen"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, kde-format
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "Neue %1 herunterladen"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, kde-format
 msgctxt ""
 "A placeholder title used in the dialog when there is no better title "
@@ -353,12 +353,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "Erweiterungen herunterladen"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -367,19 +367,19 @@ msgid ""
 "this through the naming of the items."
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "Installieren"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, kde-format
 msgctxt ""
 "A passive notification shown when installation of an item is initiated"
 msgid "Installing %1 from %2"
 msgstr "%1 von %2 wird installiert"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -387,10 +387,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr "%1 von %2"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, kde-format
 msgctxt ""
 "Request installation of this item, available when there is exactly one "
@@ -398,33 +398,32 @@ msgctxt ""
 msgid "Install"
 msgstr "Installieren"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
-#, fuzzy, kde-format
-#| msgid "Install"
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
+#, kde-format
 msgctxt ""
 "Show installation options, where there is more than one downloadable item"
 msgid "Install…"
-msgstr "Installieren"
+msgstr "Installieren …"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, kde-format
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "Aktualisieren"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, kde-format
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "Deinstallieren"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -432,14 +431,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -450,12 +449,12 @@ msgid ""
 "to the KDE Community in a bug report</a>."
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr "Kommentare und Bewertungen:"
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a new sub page with comments (comments "
@@ -463,17 +462,17 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "%1 Bewertungen und Kommentare"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, kde-format
 msgid "Rating:"
 msgstr "Bewertung:"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, kde-format
 msgid "Homepage:"
 msgstr "Homepage:"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -482,12 +481,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr "Webseite für %1 öffnen"
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr "Möglichkeiten zum Spenden:"
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -495,72 +494,80 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr ""
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, kde-format
 msgid "Tiles"
 msgstr "Kacheln"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "Symbole"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, kde-format
 msgid "Preview"
 msgstr "Vorschau"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, kde-format
 msgid "Detailed Tiles View Mode"
 msgstr "Detailierte Kachelansicht"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, kde-format
 msgid "Icons Only View Mode"
 msgstr "Symbolansicht"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, kde-format
 msgid "Large Preview View Mode"
 msgstr "Große Vorschauansicht"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr "Alles"
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "Installiert"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, kde-format
 msgid "Updateable"
 msgstr "Aktualisierbar"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, kde-format
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "Alle Einträge anzeigen"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr "Nur installierte Einträge anzeigen"
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -568,27 +575,27 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr "Nur aktualisierbare Einträge anzeigen"
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, kde-format
 msgid "Recent"
 msgstr "Zuletzt verwendet"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr "Alphabetisch"
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "Bewertung"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, kde-format
 msgid "Downloads"
 msgstr "Downloads"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on when items were most "
@@ -596,7 +603,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "Aktuellste zuerst anzeigen"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -604,61 +611,58 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr "Alphabetisch nach Namen sortieren"
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, kde-format
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "Mit höchster Bewertung zuerst anzeigen"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on number of downloads"
 msgid "Show Most Downloaded First"
 msgstr "Am meistern heruntergeladene zuerst anzeigen"
 
-#: qtquick/qml/Page.qml:337
-#, fuzzy, kde-format
-#| msgid "Upload..."
+#: qtquick/qml/Page.qml:358
+#, kde-format
 msgid "Upload…"
-msgstr "Hochladen ..."
+msgstr "Hochladen …"
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr ""
 
-#: qtquick/qml/Page.qml:348
-#, fuzzy, kde-format
-#| msgid "Go to..."
+#: qtquick/qml/Page.qml:369
+#, kde-format
 msgid "Go to…"
-msgstr "Gehe zu ..."
+msgstr "Gehe zu …"
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
-#, fuzzy, kde-format
-#| msgid "Search:"
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
+#, kde-format
 msgid "Search…"
-msgstr "Suchen:"
+msgstr "Suchen …"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "Kategorie:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, fuzzy, kde-format
 #| msgid "Continue operation"
 msgid "Contribute your own…"
 msgstr "Vorgang fortsetzen"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, kde-format
 msgctxt ""
 "Placeholder title for when a comment has no subject, but does have a rating"
 msgid "<i>(no title)</i>"
 msgstr "<i>Kein Titel</i>"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -666,19 +670,19 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr "%1 <i>(Autor)</i>"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr "Kommentare und Bewertungen für %1"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, kde-format
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "Alle Kommentare anzeigen"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -686,7 +690,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr "Nur Bewertungen anzeigen"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -694,15 +698,15 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr "Bewertungen und Antworten anzeigen"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, kde-format
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
 msgstr "%1x heruntergeladen"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, kde-format
 msgctxt ""
 "Subheading for the tile view, located immediately underneath the name of the "
@@ -710,7 +714,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "Von <i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, fuzzy, kde-format
 #| msgctxt ""
 #| "Label for the busy indicator showing an item is being installed OR "
@@ -722,16 +726,15 @@ msgctxt ""
 msgid "Working…"
 msgstr "In Arbeit ..."
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
-#, fuzzy, kde-format
-#| msgid "Updating"
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is in the process of being "
 "updated"
 msgid "Updating…"
-msgstr "Wird aktualisiert"
+msgstr "Wird aktualisiert …"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -742,12 +745,11 @@ msgid ""
 "bug report</a>."
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
-#, fuzzy, kde-format
-#| msgid "Installing"
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
+#, kde-format
 msgctxt "Label for the busy indicator showing an item is installing"
 msgid "Installing…"
-msgstr "Wird installiert"
+msgstr "Wird installiert …"
 
 #: qtquick/qml/private/ErrorDisplayer.qml:15
 #, kde-format
@@ -760,19 +762,19 @@ msgstr "Es ist ein Fehler aufgetreten"
 msgid "Please try again later."
 msgstr "Bitte versuchen Sie es später erneut."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, kde-format
 msgid "None"
 msgstr "Keine"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, kde-format
 msgctxt ""
 "A text representation of the rating, shown as a fraction of the max value"
 msgid "(%1/%2)"
 msgstr "(%1/%2)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, fuzzy, kde-format
 #| msgctxt ""
 #| "A placeholder title used in the dialog when there is no better title "
@@ -782,7 +784,7 @@ msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "Erweiterungen herunterladen"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, fuzzy, kde-format
 #| msgctxt ""
 #| "A text shown beside a busy indicator suggesting that data is being fetched"
@@ -792,19 +794,19 @@ msgctxt ""
 msgid "Updating information…"
 msgstr "Informationen werden aktualisiert ..."
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, kde-format
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "KDE Store"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, kde-format
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "Ihr Anbieter"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, kde-format
 msgctxt ""
 "Text for an action which causes the specified website to be opened using the "
@@ -812,7 +814,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "Webseite öffnen: %1"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, kde-format
 msgctxt ""
 "Text for an action which will attempt to send an email using the user's "
@@ -820,7 +822,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "E-Mail senden an: %1"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -828,10 +830,10 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -843,18 +845,18 @@ msgid ""
 "content added."
 msgstr ""
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "Daten werden geladen"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "Wird installiert"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -864,49 +866,49 @@ msgid ""
 "please contact the person in charge of your permissions."
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "Zurück"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr "Beliebt"
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "Empfohlen"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "Neu starten"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "New"
 msgstr "Neu"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Startseite"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Up"
@@ -914,25 +916,25 @@ msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "Pfeil hoch"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "Empfohlen"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "Abonnements"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "Alle Einträge"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -963,9 +965,17 @@ msgid ""
 msgstr ""
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
-#, kde-format
-msgid "Download New Stuff..."
-msgstr "Erweiterungen herunterladen ..."
+#, fuzzy, kde-format
+#| msgctxt ""
+#| "A placeholder title used in the dialog when there is no better title "
+#| "available"
+#| msgid "Download New Stuff"
+msgctxt "@action"
+msgid "Download New Stuff…"
+msgstr "Erweiterungen herunterladen"
+
+#~ msgid "Download New Stuff..."
+#~ msgstr "Erweiterungen herunterladen ..."
 
 #~ msgctxt ""
 #~ "A message which is shown when the user attempts to display a specific "
diff -pruN 6.0.0-3/po/el/knewstuff6.po 6.3.0-1/po/el/knewstuff6.po
--- 6.0.0-3/po/el/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/el/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -20,7 +20,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2016-12-08 10:14+0200\n"
 "Last-Translator: Dimitris Kardarakos <dimkard@gmail.com>\n"
 "Language-Team: Greek <kde-i18n-el@kde.org>\n"
@@ -69,7 +69,7 @@ msgstr "Η ψήφος σας καταγ
 msgid "You are now a fan."
 msgstr "Είστε τώρα ένας υποστηρικτής."
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -139,7 +139,7 @@ msgstr "Το αρχείο διαμόρφ
 msgid "Use"
 msgstr ""
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -147,17 +147,17 @@ msgid ""
 "This is a critical error and should be reported to the application author"
 msgstr ""
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr "Αποτυχία φόρτωσης του παρόχων από το αρχείο: %1"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr "Αδύνατη η φόρτωση λήψης παρόχων νέων χρήσιμων υλικών από το αρχείο: %1"
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr "Σφάλμα κατά την αρχικοποίηση του παρόχου."
@@ -303,7 +303,7 @@ msgid ""
 "the update"
 msgstr ""
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, fuzzy, kde-format
 #| msgid "Failed to load file '%1'"
 msgid ""
@@ -311,7 +311,7 @@ msgid ""
 "%2"
 msgstr "Αποτυχία φόρτωσης του αρχείου '%1'"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt ""
@@ -319,7 +319,7 @@ msgctxt ""
 msgid "All Categories"
 msgstr "Όλες οι κατηγορίες"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, fuzzy, kde-format
 #| msgid "Unknown error"
 msgctxt ""
@@ -345,14 +345,14 @@ msgstr ""
 msgid "Download New %1…"
 msgstr "Λήψη νέου %1"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, fuzzy, kde-format
 #| msgid "Download New %1"
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "Λήψη νέου %1"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
 msgctxt ""
@@ -361,12 +361,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "Λήψη νέου υλικού"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -375,12 +375,12 @@ msgid ""
 "this through the naming of the items."
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "Εγκατάσταση"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt ""
@@ -388,7 +388,7 @@ msgctxt ""
 msgid "Installing %1 from %2"
 msgstr "Εγκατάσταση"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -396,10 +396,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -408,10 +408,10 @@ msgctxt ""
 msgid "Install"
 msgstr "Εγκατάσταση"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -419,22 +419,22 @@ msgctxt ""
 msgid "Install…"
 msgstr "Εγκατάσταση"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, kde-format
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "Ενημέρωση"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, kde-format
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "Απεγκατάσταση"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -442,14 +442,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -460,12 +460,12 @@ msgid ""
 "to the KDE Community in a bug report</a>."
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, fuzzy, kde-format
 #| msgid "View Comments"
 msgctxt ""
@@ -474,19 +474,19 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "Προβολή σχολίων"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, fuzzy, kde-format
 #| msgid "Rating: "
 msgid "Rating:"
 msgstr "Αξιολόγηση: "
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, fuzzy, kde-format
 #| msgid "Homepage"
 msgid "Homepage:"
 msgstr "Αρχική σελίδα"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -495,12 +495,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -508,73 +508,81 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr ""
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, fuzzy, kde-format
 #| msgctxt "@option:check Do filter on type - show only files"
 #| msgid "Files"
 msgid "Tiles"
 msgstr "Αρχεία"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "Εικονίδια"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, fuzzy, kde-format
 #| msgid "Previews"
 msgid "Preview"
 msgstr "Προεπισκοπήσεις"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, fuzzy, kde-format
 #| msgid "Detailed View"
 msgid "Detailed Tiles View Mode"
 msgstr "Λεπτομερής προβολή"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, fuzzy, kde-format
 #| msgid "Icons view mode"
 msgid "Icons Only View Mode"
 msgstr "Λειτουργία προβολής εικονιδίων"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, fuzzy, kde-format
 #| msgid "Details view mode"
 msgid "Large Preview View Mode"
 msgstr "Λειτουργία λεπτομερής προβολής"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr ""
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "Εγκατεστημένο"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, fuzzy, kde-format
 #| msgid "Update"
 msgid "Updateable"
 msgstr "Ενημέρωση"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, fuzzy, kde-format
 #| msgid "&Show All Entries"
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "&Εμφάνιση όλων των επιλογών"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, fuzzy, kde-format
 #| msgid "&Show All Entries"
 msgctxt ""
@@ -582,7 +590,7 @@ msgctxt ""
 msgid "Show Only Installed Entries"
 msgstr "&Εμφάνιση όλων των επιλογών"
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, fuzzy, kde-format
 #| msgid "&Show All Entries"
 msgctxt ""
@@ -591,29 +599,29 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr "&Εμφάνιση όλων των επιλογών"
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, fuzzy, kde-format
 #| msgid "Open &Recent"
 msgid "Recent"
 msgstr "Άνοιγμα πρόσ&φατου"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr ""
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "Αξιολόγηση"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, fuzzy, kde-format
 #| msgid "Download"
 msgid "Downloads"
 msgstr "Να γίνει λήψη"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt ""
@@ -622,7 +630,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "Εμφάνιση πρώτα των καταλόγων"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -630,14 +638,14 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr ""
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "Εμφάνιση πρώτα των καταλόγων"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, fuzzy, kde-format
 #| msgid "Most downloads"
 msgctxt ""
@@ -645,41 +653,41 @@ msgctxt ""
 msgid "Show Most Downloaded First"
 msgstr "Περισσότερες λήψεις"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, fuzzy, kde-format
 #| msgid "Upload..."
 msgid "Upload…"
 msgstr "Αποστολή..."
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr ""
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, fuzzy, kde-format
 #| msgid "&Go To..."
 msgid "Go to…"
 msgstr "&Μετάβαση σε..."
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, fuzzy, kde-format
 #| msgid "Search:"
 msgid "Search…"
 msgstr "Αναζήτηση:"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "Κατηγορία:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, fuzzy, kde-format
 #| msgid "Continue operation"
 msgid "Contribute your own…"
 msgstr "Συνέχεια της λειτουργίας"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, fuzzy, kde-format
 #| msgctxt "@note/rich"
 #| msgid "<i>Note</i>: %1"
@@ -688,7 +696,7 @@ msgctxt ""
 msgid "<i>(no title)</i>"
 msgstr "<i>Σημείωση</i>: %1"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -696,20 +704,20 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "Όλες οι κατηγορίες"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, fuzzy, kde-format
 #| msgid "Show Preview"
 msgctxt ""
@@ -718,7 +726,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr "Εμφάνιση προεπισκόπησης"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -726,8 +734,8 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, fuzzy, kde-format
 #| msgid "1 download"
 #| msgid_plural "%1 downloads"
@@ -735,8 +743,8 @@ msgctxt "The number of times the item ha
 msgid "%1 downloads"
 msgstr "1 λήψη"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, fuzzy, kde-format
 #| msgctxt "Show the author of this item in a list"
 #| msgid "By <i>%1</i>"
@@ -746,7 +754,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "Από <i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -754,7 +762,7 @@ msgctxt ""
 msgid "Working…"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, fuzzy, kde-format
 #| msgid "Updating"
 msgctxt ""
@@ -763,7 +771,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "Ενημέρωση"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -774,7 +782,7 @@ msgid ""
 "bug report</a>."
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt "Label for the busy indicator showing an item is installing"
@@ -793,14 +801,14 @@ msgstr ""
 msgid "Please try again later."
 msgstr "Παρακαλώ εισάγετε ένα όνομα."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, fuzzy, kde-format
 #| msgctxt "No border line"
 #| msgid "None"
 msgid "None"
 msgstr "Καμία"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, fuzzy, kde-format
 #| msgid "(%1/s)"
 msgctxt ""
@@ -808,14 +816,14 @@ msgctxt ""
 msgid "(%1/%2)"
 msgstr "(%1/s)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "Λήψη νέου υλικού"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, fuzzy, kde-format
 #| msgid "Billing information:"
 msgctxt ""
@@ -823,21 +831,21 @@ msgctxt ""
 msgid "Updating information…"
 msgstr "Πληροφορίες χρέωσης:"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, fuzzy, kde-format
 #| msgid "&Store"
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "&Αποθήκευση"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, fuzzy, kde-format
 #| msgid "Provider:"
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "Πάροχος:"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, fuzzy, kde-format
 #| msgctxt "@label:button"
 #| msgid "&Open with %1"
@@ -847,7 +855,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "Ά&νοιγμα με %1"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, fuzzy, kde-format
 #| msgid "&Send Email"
 msgctxt ""
@@ -856,7 +864,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "&Αποστολή ηλ. αλληλογραφίας"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -864,10 +872,10 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -879,18 +887,18 @@ msgid ""
 "content added."
 msgstr ""
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "Φόρτωση δεδομένων"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "Εγκατάσταση"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -900,7 +908,7 @@ msgid ""
 "please contact the person in charge of your permissions."
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Back"
@@ -908,20 +916,20 @@ msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "Πίσω"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, fuzzy, kde-format
 #| msgid "Saturday"
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "Σάββατο"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, fuzzy, kde-format
 #| msgctxt "@action:button Restart find & replace"
 #| msgid "Restart"
@@ -929,7 +937,7 @@ msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "Επανεκκίνηση"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "New"
@@ -937,7 +945,7 @@ msgctxt "Knewstuff5"
 msgid "New"
 msgstr "Νέο"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Home"
@@ -945,13 +953,13 @@ msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Home"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Up"
@@ -959,7 +967,7 @@ msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "Πάνω"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, fuzzy, kde-format
 #| msgctxt "dictionary variant"
 #| msgid "extended"
@@ -967,7 +975,7 @@ msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "εκτεταμένη"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Subscript"
@@ -975,14 +983,14 @@ msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "Δείκτης"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, fuzzy, kde-format
 #| msgid "&Show All Entries"
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "&Εμφάνιση όλων των επιλογών"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -1013,9 +1021,14 @@ msgid ""
 msgstr ""
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
-#, kde-format
-msgid "Download New Stuff..."
-msgstr "Λήψη νέου υλικού..."
+#, fuzzy, kde-format
+#| msgid "Download New Stuff"
+msgctxt "@action"
+msgid "Download New Stuff…"
+msgstr "Λήψη νέου υλικού"
+
+#~ msgid "Download New Stuff..."
+#~ msgstr "Λήψη νέου υλικού..."
 
 #~ msgid "Initializing"
 #~ msgstr "Αρχικοποίηση"
diff -pruN 6.0.0-3/po/en_GB/knewstuff6.po 6.3.0-1/po/en_GB/knewstuff6.po
--- 6.0.0-3/po/en_GB/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/en_GB/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -2,13 +2,13 @@
 # Malcolm Hunter <malcolm.hunter@gmx.co.uk>, 2002,2003,2004, 2005, 2006, 2007, 2008, 2009.
 # Jonathan Riddell <kde-en-gb@jriddell.org>, 2003.
 # Andrew Coles <andrew_coles@yahoo.co.uk>, 2004, 2005, 2009, 2010.
-# Steve Allewell <steve.allewell@gmail.com>, 2014, 2015, 2016, 2017, 2018, 2019, 2020, 2021, 2022, 2023.
+# SPDX-FileCopyrightText: 2014, 2015, 2016, 2017, 2018, 2019, 2020, 2021, 2022, 2023, 2024 Steve Allewell <steve.allewell@gmail.com>
 msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
-"PO-Revision-Date: 2023-06-17 12:07+0100\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
+"PO-Revision-Date: 2024-05-20 19:31+0100\n"
 "Last-Translator: Steve Allewell <steve.allewell@gmail.com>\n"
 "Language-Team: British English\n"
 "Language: en_GB\n"
@@ -16,7 +16,7 @@ msgstr ""
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=2; plural=n != 1;\n"
-"X-Generator: Lokalize 23.03.70\n"
+"X-Generator: Lokalize 24.02.2\n"
 
 #: attica/atticaprovider.cpp:165
 #, kde-format
@@ -57,7 +57,7 @@ msgstr "Your vote was recorded."
 msgid "You are now a fan."
 msgstr "You are now a fan."
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -127,7 +127,7 @@ msgstr "Configuration file is invalid: \
 msgid "Use"
 msgstr "Use"
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -138,17 +138,17 @@ msgstr ""
 "%2\n"
 "This is a critical error and should be reported to the application author"
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr "Loading of providers from file: %1 failed"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr "Could not load get hot new stuff providers from file: %1"
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr "Error initialising provider."
@@ -318,7 +318,7 @@ msgstr ""
 "We failed to identify a good link for updating %1, and are unable to perform "
 "the update"
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, kde-format
 msgid ""
 "Failed to adopt '%1'\n"
@@ -327,14 +327,14 @@ msgstr ""
 "Failed to adopt '%1'\n"
 "%2"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, kde-format
 msgctxt ""
 "The first entry in the category selection list (also the default value)"
 msgid "All Categories"
 msgstr "All Categories"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, kde-format
 msgctxt ""
 "The string passed back in the case the requested category is not known"
@@ -358,13 +358,13 @@ msgstr "Stuff"
 msgid "Download New %1…"
 msgstr "Download New %1…"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, kde-format
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "Download New %1"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, kde-format
 msgctxt ""
 "A placeholder title used in the dialog when there is no better title "
@@ -372,12 +372,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "Download New Stuff"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr "Pick Your Installation Option"
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -390,19 +390,19 @@ msgstr ""
 "options, please contact the author of this item and ask that they clarify "
 "this through the naming of the items."
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "Install"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, kde-format
 msgctxt ""
 "A passive notification shown when installation of an item is initiated"
 msgid "Installing %1 from %2"
 msgstr "Installing %1 from %2"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -410,10 +410,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr "%1 by %2"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, kde-format
 msgctxt ""
 "Request installation of this item, available when there is exactly one "
@@ -421,32 +421,32 @@ msgctxt ""
 msgid "Install"
 msgstr "Install"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, kde-format
 msgctxt ""
 "Show installation options, where there is more than one downloadable item"
 msgid "Install…"
 msgstr "Install…"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, kde-format
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "Update"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, kde-format
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "Uninstall"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -454,14 +454,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr "Currently working on the item %1 by %2. Please wait…"
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr "Currently updating the item %1 by %2. Please wait…"
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -475,12 +475,12 @@ msgstr ""
 "bugs.kde.org/enter_bug.cgi?product=frameworks-knewstuff\">Please report this "
 "to the KDE Community in a bug report</a>."
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr "Comments and Reviews:"
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a new sub page with comments (comments "
@@ -488,17 +488,17 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "%1 Reviews and Comments"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, kde-format
 msgid "Rating:"
 msgstr "Rating:"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, kde-format
 msgid "Homepage:"
 msgstr "Homepage:"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -507,12 +507,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr "Open the homepage for %1"
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr "How To Donate:"
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -520,74 +520,85 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr "Find out how to donate to this project"
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, kde-format
 msgid "Tiles"
 msgstr "Tiles"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "Icons"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, kde-format
 msgid "Preview"
 msgstr "Preview"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, kde-format
 msgid "Detailed Tiles View Mode"
 msgstr "Detailed Tiles View Mode"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, kde-format
 msgid "Icons Only View Mode"
 msgstr "Icons Only View Mode"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, kde-format
 msgid "Large Preview View Mode"
 msgstr "Large Preview View Mode"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr "Everything"
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "Installed"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, kde-format
 msgid "Updateable"
 msgstr "Updatable"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, kde-format
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "Show All Entries"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr "Show Only Installed Entries"
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -595,27 +606,27 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr "Show Only Updatable Entries"
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, kde-format
 msgid "Recent"
 msgstr "Recent"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr "Alphabetical"
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "Rating"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, kde-format
 msgid "Downloads"
 msgstr "Downloads"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on when items were most "
@@ -623,7 +634,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "Show Most Recent First"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -631,57 +642,57 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr "Sort Alphabetically By Name"
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, kde-format
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "Show Highest Rated First"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on number of downloads"
 msgid "Show Most Downloaded First"
 msgstr "Show Most Downloaded First"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, kde-format
 msgid "Upload…"
 msgstr "Upload…"
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr "Learn how to add your own hot new stuff to this list"
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, kde-format
 msgid "Go to…"
 msgstr "Go to…"
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, kde-format
 msgid "Search…"
 msgstr "Search…"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "Category:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, kde-format
 msgid "Contribute your own…"
 msgstr "Contribute your own…"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, kde-format
 msgctxt ""
 "Placeholder title for when a comment has no subject, but does have a rating"
 msgid "<i>(no title)</i>"
 msgstr "<i>(no title)</i>"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -689,19 +700,19 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr "%1 <i>(author)</i>"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr "Comments and Reviews for %1"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, kde-format
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "Show All Comments"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -709,7 +720,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr "Show Reviews Only"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -717,15 +728,15 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr "Show Reviews and Replies"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, kde-format
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
 msgstr "%1 downloads"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, kde-format
 msgctxt ""
 "Subheading for the tile view, located immediately underneath the name of the "
@@ -733,7 +744,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "By <i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -741,7 +752,7 @@ msgctxt ""
 msgid "Working…"
 msgstr "Working…"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is in the process of being "
@@ -749,7 +760,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "Updating…"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -763,7 +774,7 @@ msgstr ""
 "product=frameworks-knewstuff\">Please report this to the KDE Community in a "
 "bug report</a>."
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, kde-format
 msgctxt "Label for the busy indicator showing an item is installing"
 msgid "Installing…"
@@ -780,44 +791,44 @@ msgstr "An Error Occurred"
 msgid "Please try again later."
 msgstr "Please try again later."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, kde-format
 msgid "None"
 msgstr "None"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, kde-format
 msgctxt ""
 "A text representation of the rating, shown as a fraction of the max value"
 msgid "(%1/%2)"
 msgstr "(%1/%2)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, kde-format
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "Upload New Stuff: %1"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, kde-format
 msgctxt ""
 "A text shown beside a busy indicator suggesting that data is being fetched"
 msgid "Updating information…"
 msgstr "Updating information…"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, kde-format
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "KDE Store"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, kde-format
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "Your Provider"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, kde-format
 msgctxt ""
 "Text for an action which causes the specified website to be opened using the "
@@ -825,7 +836,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "Open Website: %1"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, kde-format
 msgctxt ""
 "Text for an action which will attempt to send an email using the user's "
@@ -833,7 +844,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "Send Email To: %1"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -841,15 +852,15 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 "To upload new entries, or to add content to an existing entry on the KDE "
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -867,18 +878,18 @@ msgstr ""
 "might be required to contact the managers of the site directly to get new "
 "content added."
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "Loading data"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "Installing"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -890,73 +901,73 @@ msgstr ""
 "You are not authorised to Get Hot New Stuff. If you think this is in error, "
 "please contact the person in charge of your permissions."
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "Back"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr "Popular"
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "Featured"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "Restart"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "New"
 msgstr "New"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Home"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr "Shelf"
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "Up"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "Recommended"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "Subscriptions"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "All Entries"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -974,19 +985,7 @@ msgstr ""
 "installed into the systemwide knsrc file location"
 
 #: tools/knewstuff-dialog/main.cpp:33
-#, fuzzy, kde-format
-#| msgid ""
-#| "A kns url to show information from. The format for a kns url is kns://"
-#| "knsrcfile/providerid/entryid\n"
-#| "'knsrcfile'\n"
-#| "is the name of a knsrc file as might be passed directly through this "
-#| "tool's knsrcfile argument\n"
-#| "'providerid'\n"
-#| "is the hostname of the provider the entry should exist on\n"
-#| "'entryid'\n"
-#| "is the unique ID of an entry found in the provider specified by the knsrc "
-#| "file.\n"
-#| " An example of such a url is kns://peruse.knsrc/api.kde-look.org/1316714"
+#, kde-format
 msgid ""
 "A kns url to show information from. The format for a kns url is kns://"
 "knsrcfile/providerid/entryid\n"
@@ -1000,7 +999,7 @@ msgid ""
 "file.\n"
 " An example of such a url is kns://sddmtheme.knsrc/api.kde-look.org/2059021"
 msgstr ""
-"A kns URL to show information from. The format for a kns URL is kns://"
+"A kns url to show information from. The format for a kns url is kns://"
 "knsrcfile/providerid/entryid\n"
 "'knsrcfile'\n"
 "is the name of a knsrc file as might be passed directly through this tool's "
@@ -1010,12 +1009,16 @@ msgstr ""
 "'entryid'\n"
 "is the unique ID of an entry found in the provider specified by the knsrc "
 "file.\n"
-" An example of such a URL is kns://peruse.knsrc/api.kde-look.org/1316714"
+" An example of such a url is kns://sddmtheme.knsrc/api.kde-look.org/2059021"
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
 #, kde-format
-msgid "Download New Stuff..."
-msgstr "Download New Stuff..."
+msgctxt "@action"
+msgid "Download New Stuff…"
+msgstr "Download New Stuff…"
+
+#~ msgid "Download New Stuff..."
+#~ msgstr "Download New Stuff..."
 
 #~ msgctxt ""
 #~ "A message which is shown when the user attempts to display a specific "
diff -pruN 6.0.0-3/po/eo/knewstuff6.po 6.3.0-1/po/eo/knewstuff6.po
--- 6.0.0-3/po/eo/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/eo/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -4,7 +4,7 @@
 # Wolfram Diestel <wolfram@steloj.de>, 1998.
 # Heiko Evermann <heiko@evermann.de>, 2002, 2003.
 # Matthias Peick <matthias@peick.de>, 2004, 2005.
-# Oliver Kellogg <okellogg@users.sourceforge.net>,2007.
+# Oliver Kellogg <olivermkellogg@gmail.com>,2007.
 # Cindy McKee <cfmckee@gmail.com>, 2007, 2008.
 # Axel Rousseau <axel@esperanto-jeunes.org>, 2009.
 # Michael Moroni <michael.moroni@mailoo.org>, 2012.
@@ -15,9 +15,9 @@ msgid ""
 msgstr ""
 "Project-Id-Version: knewstuff\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
-"PO-Revision-Date: 2024-01-20 15:45+0100\n"
-"Last-Translator: Oliver Kellogg <okellogg@users.sourceforge.net>\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
+"PO-Revision-Date: 2024-05-09 22:01+0100\n"
+"Last-Translator: Oliver Kellogg <olivermkellogg@gmail.com>\n"
 "Language-Team: Esperanto <kde-i18n-eo@kde.org>\n"
 "Language: eo\n"
 "MIME-Version: 1.0\n"
@@ -64,7 +64,7 @@ msgstr "Via marko estis registrita."
 msgid "You are now a fan."
 msgstr "Vi nun estas ŝatanto."
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -131,7 +131,7 @@ msgstr "Agorddosiero nevalidas: \"%1\""
 msgid "Use"
 msgstr "Uzi"
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -143,17 +143,17 @@ msgstr ""
 "Ĉi tio estas kritika eraro kaj devus esti raportita al la aŭtoro de la "
 "aplikaĵo."
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr "Ŝargado de provizantoj el dosiero: %1 fiaskis"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr "Ne eblis ŝargi akiri varmajn novajn provizantojn de dosiero: %1"
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr "Eraro dum pravalorizado de provizanto."
@@ -324,7 +324,7 @@ msgstr ""
 "Ni malsukcesis identigi bonan ligilon por ĝisdatigi %1, kaj ne kapablas "
 "plenumi la ĝisdatigon"
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, kde-format
 msgid ""
 "Failed to adopt '%1'\n"
@@ -333,14 +333,14 @@ msgstr ""
 "Malsukcesis adopti '%1'\n"
 "%2"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, kde-format
 msgctxt ""
 "The first entry in the category selection list (also the default value)"
 msgid "All Categories"
 msgstr "Ĉiuj kategorioj"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, kde-format
 msgctxt ""
 "The string passed back in the case the requested category is not known"
@@ -364,13 +364,13 @@ msgstr "Aĵon"
 msgid "Download New %1…"
 msgstr "Elŝuti Novan %1…"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, kde-format
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "Elŝuti Novan %1"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, kde-format
 msgctxt ""
 "A placeholder title used in the dialog when there is no better title "
@@ -378,12 +378,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "Elŝuti tre novajn aĵojn"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr "Elekti Vian Instal-Opcion"
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -396,19 +396,19 @@ msgstr ""
 "kontakti la aŭtoron de ĉi tiu aĵo kaj petu, ke ili klarigu tion per la "
 "nomado de la eroj."
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "Instali"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, kde-format
 msgctxt ""
 "A passive notification shown when installation of an item is initiated"
 msgid "Installing %1 from %2"
 msgstr "Instalante %1 de %2"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -416,10 +416,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr "%1 per %2"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, kde-format
 msgctxt ""
 "Request installation of this item, available when there is exactly one "
@@ -427,32 +427,32 @@ msgctxt ""
 msgid "Install"
 msgstr "Instali"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, kde-format
 msgctxt ""
 "Show installation options, where there is more than one downloadable item"
 msgid "Install…"
 msgstr "Instali…"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, kde-format
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "Ĝisdatigi"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, kde-format
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "Malinstali"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -460,14 +460,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr "Aktuale laboras pri la ero %1 de %2. Bonvolu atendi…"
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr "Aktuale ĝisdatiganta la eron %1 de %2. Bonvolu atendi…"
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -481,12 +481,12 @@ msgstr ""
 "bugs.kde.org/enter_bug.cgi?product=frameworks-knewstuff\">Bonvolu raporti "
 "tion al la KDE-Komunumo en raporto pri eraro</a>."
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr "Komentoj kaj Recenzoj:"
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a new sub page with comments (comments "
@@ -494,17 +494,17 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "%1 Recenzoj kaj Komentoj"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, kde-format
 msgid "Rating:"
 msgstr "Pritakso:"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, kde-format
 msgid "Homepage:"
 msgstr "Hejmpaĝo:"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -513,12 +513,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr "Malfermi la hejmpaĝon por %1"
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr "Kiel Donaci:"
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -526,74 +526,85 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr "Ekscii kiel donaci al ĉi tiu projekto"
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+"Atentu kiam vi aliras uzantkreitan enhavon montritan ĉi tie, ĉar ĝi eble "
+"enhavas plenumeblan kodon, kiu ne estis provita de KDE aŭ via distribuisto "
+"pri sekureco, stabileco aŭ kvalito"
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
-"La enhavo disponebla ĉi tie estis alŝutita de uzantoj kiel vi, kaj ne estis "
-"reviziita de via distribuisto por funkcieco aŭ stabileco."
+"Uzant-kreita enhavo montrata ĉi tie ne estis reviziita de via distribuisto "
+"pri funkcieco aŭ stabileco."
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, kde-format
 msgid "Tiles"
 msgstr "Kaheloj"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "Piktogramoj"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, kde-format
 msgid "Preview"
 msgstr "Antaŭrigardo"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, kde-format
 msgid "Detailed Tiles View Mode"
 msgstr "Vidreĝimo de Detalaj Kaheloj"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, kde-format
 msgid "Icons Only View Mode"
 msgstr "Nur-Piktograma Vidreĝimo"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, kde-format
 msgid "Large Preview View Mode"
 msgstr "Grand-Antaŭrigarda Vidreĝimo"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr "Ĉio"
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "Instalitaj"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, kde-format
 msgid "Updateable"
 msgstr "Ĝisdatigebla"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, kde-format
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "Montri ĉiujn enskribojn"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr "Montri Nur Instalitajn Enskribojn"
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -601,27 +612,27 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr "Montri Nur Ĝisdatigeblajn Enskribojn"
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, kde-format
 msgid "Recent"
 msgstr "Lastatempa"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr "Alfabeta"
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "Pritakso"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, kde-format
 msgid "Downloads"
 msgstr "Elŝutoj"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on when items were most "
@@ -629,7 +640,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "Montri Plej Lasttempajn Unue"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -637,57 +648,57 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr "Ordigi Alfabete Laŭ Nomo"
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, kde-format
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "Montri Plej Altnivelajn Unue"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on number of downloads"
 msgid "Show Most Downloaded First"
 msgstr "Montru Plej Elŝutitajn Unue"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, kde-format
 msgid "Upload…"
 msgstr "Alŝuti…"
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr "Lernu kiel aldoni viajn proprajn novajn aĵojn al ĉi tiu listo"
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, kde-format
 msgid "Go to…"
 msgstr "Iri al…"
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, kde-format
 msgid "Search…"
 msgstr "Serĉi…"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "Kategorio:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, kde-format
 msgid "Contribute your own…"
 msgstr "Kontribui vian propran…"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, kde-format
 msgctxt ""
 "Placeholder title for when a comment has no subject, but does have a rating"
 msgid "<i>(no title)</i>"
 msgstr "<i>(sen titolo)</i>"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -695,19 +706,19 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr "%1 <i>(aŭtoro)</i>"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr "Komentoj kaj Recenzoj por %1"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, kde-format
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "Montri Ĉiujn Komentojn"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -715,7 +726,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr "Montri Nur Recenzojn"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -723,15 +734,15 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr "Montri Recenzojn kaj Respondojn"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, kde-format
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
 msgstr "%1 elŝutoj"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, kde-format
 msgctxt ""
 "Subheading for the tile view, located immediately underneath the name of the "
@@ -739,7 +750,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "De <i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -747,7 +758,7 @@ msgctxt ""
 msgid "Working…"
 msgstr "Laborante…"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is in the process of being "
@@ -755,7 +766,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "Ĝisdatiganta…"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -769,7 +780,7 @@ msgstr ""
 "product=frameworks-knewstuff\">Bonvolu raporti tion al la KDE-Komunumo en "
 "raporto pri eraro</a>."
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, kde-format
 msgctxt "Label for the busy indicator showing an item is installing"
 msgid "Installing…"
@@ -786,44 +797,44 @@ msgstr "Eraro okazis"
 msgid "Please try again later."
 msgstr "Bonvolu reprovi poste."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, kde-format
 msgid "None"
 msgstr "Neniu"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, kde-format
 msgctxt ""
 "A text representation of the rating, shown as a fraction of the max value"
 msgid "(%1/%2)"
 msgstr "(%1/%2)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, kde-format
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "Alŝuti Novajn Aĵojn: %1"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, kde-format
 msgctxt ""
 "A text shown beside a busy indicator suggesting that data is being fetched"
 msgid "Updating information…"
 msgstr "Ĝisdatigante informojn…"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, kde-format
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "KDE-vendejo"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, kde-format
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "Via Provizanto"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, kde-format
 msgctxt ""
 "Text for an action which causes the specified website to be opened using the "
@@ -831,7 +842,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "Malfermi Retejon: %1"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, kde-format
 msgctxt ""
 "Text for an action which will attempt to send an email using the user's "
@@ -839,7 +850,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "Sendi Retpoŝton Al: %1"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -847,7 +858,7 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 "Por alŝuti novajn enskribojn, aŭ aldoni enhavon al ekzistanta enskribo en la "
 "KDE-Butiko, bonvolu malfermi la retejon kaj ensaluti. Post kiam vi faris "
@@ -855,7 +866,7 @@ msgstr ""
 "kiam vi alklaku vian uzantan ikonon. Alklaku ĉi tiun eniron por iri al la "
 "produkta administra sistemo, kie vi povas labori pri viaj produktoj."
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -873,18 +884,18 @@ msgstr ""
 "devos kontakti la administrantojn de la retejo rekte por aldoni novan "
 "enhavon."
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "Ŝarganta datumojn"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "Instalanta"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -896,73 +907,73 @@ msgstr ""
 "Vi ne estas rajtigita akiri Varmajn Novaĵojn. Se vi pensas, ke tio estas "
 "erara, bonvolu kontakti la respondeculon pri viaj permesoj."
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "Malantaŭen"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr "Populara"
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "Prezentita"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "Restarigi"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "New"
 msgstr "Nova"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Hejmen"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr "Breto"
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "Supren"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "Rekomendita"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "Abonoj"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "Ĉiuj Enskriboj"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -1008,5 +1019,6 @@ msgstr ""
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
 #, kde-format
-msgid "Download New Stuff..."
-msgstr "Elŝuti tre novajn aĵojn..."
+msgctxt "@action"
+msgid "Download New Stuff…"
+msgstr "Elŝuti Novajn Aĵojn…"
diff -pruN 6.0.0-3/po/es/knewstuff6.po 6.3.0-1/po/es/knewstuff6.po
--- 6.0.0-3/po/es/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/es/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -14,8 +14,8 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
-"PO-Revision-Date: 2024-01-20 02:19+0100\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
+"PO-Revision-Date: 2024-05-08 12:41+0200\n"
 "Last-Translator: Eloy Cuadra <ecuadra@eloihr.net>\n"
 "Language-Team: Spanish <kde-l10n-es@kde.org>\n"
 "Language: es\n"
@@ -23,7 +23,7 @@ msgstr ""
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 "First-Translator: Boris Wesslowski <Boris@Wesslowski.com>\n"
-"X-Generator: Lokalize 23.08.4\n"
+"X-Generator: Lokalize 24.02.2\n"
 "Plural-Forms: nplurals=2; plural=n != 1;\n"
 
 #: attica/atticaprovider.cpp:165
@@ -64,7 +64,7 @@ msgstr "Su voto ha sido registrado."
 msgid "You are now a fan."
 msgstr "Ahora se ha convertido en fan."
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -134,7 +134,7 @@ msgstr "Archivo de configuración no vá
 msgid "Use"
 msgstr "Usar"
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -146,18 +146,18 @@ msgstr ""
 "%2\n"
 "Se trata de un error crítico que se debe notificar al autor de la aplicación."
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr "Ha fallado la carga de proveedores desde el archivo %1"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr ""
 "No se pueden cargar los proveedores para las novedades desde el archivo: %1"
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr "Error al inicializar el proveedor."
@@ -329,7 +329,7 @@ msgstr ""
 "Hemos fallado al identificar un buen enlace para actualizar %1, por lo que "
 "no se puede realizar la actualización."
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, kde-format
 msgid ""
 "Failed to adopt '%1'\n"
@@ -338,14 +338,14 @@ msgstr ""
 "La adopción de «%1» ha fallado\n"
 "%2"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, kde-format
 msgctxt ""
 "The first entry in the category selection list (also the default value)"
 msgid "All Categories"
 msgstr "Todas las categorías"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, kde-format
 msgctxt ""
 "The string passed back in the case the requested category is not known"
@@ -369,13 +369,13 @@ msgstr "novedades"
 msgid "Download New %1…"
 msgstr "Descargar novedades: %1..."
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, kde-format
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "Descargar novedades: %1"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, kde-format
 msgctxt ""
 "A placeholder title used in the dialog when there is no better title "
@@ -383,12 +383,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "Descargar novedades"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr "Escoja la opción de instalación"
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -401,19 +401,19 @@ msgstr ""
 "el autor del elemento y pídale que se lo aclare cambiando el nombre de dicho "
 "elemento."
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "Instalar"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, kde-format
 msgctxt ""
 "A passive notification shown when installation of an item is initiated"
 msgid "Installing %1 from %2"
 msgstr "Instalando %1 desde %2"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -421,10 +421,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr "%1, por %2"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, kde-format
 msgctxt ""
 "Request installation of this item, available when there is exactly one "
@@ -432,32 +432,32 @@ msgctxt ""
 msgid "Install"
 msgstr "Instalar"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, kde-format
 msgctxt ""
 "Show installation options, where there is more than one downloadable item"
 msgid "Install…"
 msgstr "Instalar..."
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, kde-format
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "Actualizar"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, kde-format
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "Desinstalar"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -465,14 +465,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr "Se está trabajando en el elemento %1 creado por %2. Espere..."
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr "Actualizando el elemento %1 creado por %2. Espere..."
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -486,12 +486,12 @@ msgstr ""
 "href=\"https://bugs.kde.org/enter_bug.cgi?product=frameworks-knewstuff"
 "\">Comuníquelo a la comunidad de KDE mediante un informe de error</a>."
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr "Comentarios y reseñas:"
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a new sub page with comments (comments "
@@ -499,17 +499,17 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "%1 reseñas y comentarios"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, kde-format
 msgid "Rating:"
 msgstr "Puntuación:"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, kde-format
 msgid "Homepage:"
 msgstr "Página web:"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -518,12 +518,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr "Abrir la página web de %1"
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr "Cómo hacer un donativo:"
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -531,74 +531,86 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr "Descubra cómo hacer un donativo a este proyecto"
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+"Tenga precaución cuando acceda al contenido creado por usuarios que se "
+"muestra aquí, ya que puede contener código ejecutable cuya seguridad, "
+"estabilidad o calidad no hayan sido comprobadas por KDE o por su "
+"distribuidor."
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
-"El contenido aquí disponible ha sido enviado por usuarios como usted, por lo "
-"que su su distribuidor no ha comprobado su funcionalidad ni su estabilidad."
+"La funcionalidad y la calidad del contenido creado por usuarios que se "
+"muestra aquí no han sido comprobadas por KDE o por su distribuidor."
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, kde-format
 msgid "Tiles"
 msgstr "Mosaico"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "Iconos"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, kde-format
 msgid "Preview"
 msgstr "Vista previa"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, kde-format
 msgid "Detailed Tiles View Mode"
 msgstr "Modo de vista en mosaico detallada"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, kde-format
 msgid "Icons Only View Mode"
 msgstr "Modo de vista de solo iconos"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, kde-format
 msgid "Large Preview View Mode"
 msgstr "Modo de vista previa grande"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr "Todo"
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "Instalado"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, kde-format
 msgid "Updateable"
 msgstr "Actualizable"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, kde-format
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "Mostrar todas las entradas"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr "Mostrar solo las entradas instaladas"
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -606,27 +618,27 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr "Mostrar solo las entradas actualizables"
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, kde-format
 msgid "Recent"
 msgstr "Recientes"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr "Alfabéticamente"
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "Puntuación"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, kde-format
 msgid "Downloads"
 msgstr "Descargas"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on when items were most "
@@ -634,7 +646,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "Mostrar primero las más recientes"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -642,57 +654,57 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr "Ordenar alfabéticamente por nombre"
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, kde-format
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "Mostrar primero las más puntuadas"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on number of downloads"
 msgid "Show Most Downloaded First"
 msgstr "Mostrar primero las más descargadas"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, kde-format
 msgid "Upload…"
 msgstr "Enviar..."
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr "Aprenda a añadir sus propias novedades interesantes a esta lista"
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, kde-format
 msgid "Go to…"
 msgstr "Ir a..."
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, kde-format
 msgid "Search…"
 msgstr "Buscar..."
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "Categoría:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, kde-format
 msgid "Contribute your own…"
 msgstr "Contribuir con el suyo..."
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, kde-format
 msgctxt ""
 "Placeholder title for when a comment has no subject, but does have a rating"
 msgid "<i>(no title)</i>"
 msgstr "<i>(sin título)</i>"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -700,19 +712,19 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr "%1 <i>(autor)</i>"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr "Comentarios y reseñas para %1"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, kde-format
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "Mostrar todos los comentarios"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -720,7 +732,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr "Mostrar solo las reseñas"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -728,15 +740,15 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr "Mostrar las reseñas y las respuestas"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, kde-format
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
 msgstr "%1 descargas"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, kde-format
 msgctxt ""
 "Subheading for the tile view, located immediately underneath the name of the "
@@ -744,7 +756,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "Por <i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -752,7 +764,7 @@ msgctxt ""
 msgid "Working…"
 msgstr "Trabajando..."
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is in the process of being "
@@ -760,7 +772,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "Actualizando..."
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -774,7 +786,7 @@ msgstr ""
 "cgi?product=frameworks-knewstuff\">Comuníquelo a la comunidad de KDE "
 "mediante un informe de error</a>."
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, kde-format
 msgctxt "Label for the busy indicator showing an item is installing"
 msgid "Installing…"
@@ -791,44 +803,44 @@ msgstr "Ha ocurrido un error"
 msgid "Please try again later."
 msgstr "Vuelva a intentarlo más tarde."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, kde-format
 msgid "None"
 msgstr "Ninguno"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, kde-format
 msgctxt ""
 "A text representation of the rating, shown as a fraction of the max value"
 msgid "(%1/%2)"
 msgstr "(%1/%2)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, kde-format
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "Enviar novedades: %1"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, kde-format
 msgctxt ""
 "A text shown beside a busy indicator suggesting that data is being fetched"
 msgid "Updating information…"
 msgstr "Actualizando información..."
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, kde-format
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "KDE Store"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, kde-format
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "Su proveedor"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, kde-format
 msgctxt ""
 "Text for an action which causes the specified website to be opened using the "
@@ -836,7 +848,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "Abrir sitio web: %1"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, kde-format
 msgctxt ""
 "Text for an action which will attempt to send an email using the user's "
@@ -844,7 +856,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "Enviar correo electrónico a: %1"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -852,7 +864,7 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 "Para enviar nuevas entradas o añadir contenido a una entrada existente en la "
 "KDE Store, vaya al sitio web e inicie sesión. Tras ello, encontrará la "
@@ -860,7 +872,7 @@ msgstr ""
 "usuario. Use dicha entrada para ir al sistema de gestión de productos, donde "
 "podrá trabajar con sus productos."
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -878,18 +890,18 @@ msgstr ""
 "alternativa, es posible que deba ponerse en contacto directamente con los "
 "administradores del sitio para añadir contenido nuevo."
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "Cargando datos"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "Instalando"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -901,73 +913,73 @@ msgstr ""
 "No tiene autorización para descargar novedades. Si cree que se trata de un "
 "error, contacte con la persona encargada de asignarle permisos."
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "Volver"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr "Popular"
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "Destacado"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "Reiniciar"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "New"
 msgstr "Nuevo"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Inicio"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr "Estantería"
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "Arriba"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "Recomendado"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "Suscripciones"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "Todas las entradas"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -1013,9 +1025,13 @@ msgstr ""
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
 #, kde-format
-msgid "Download New Stuff..."
+msgctxt "@action"
+msgid "Download New Stuff…"
 msgstr "Descargar novedades..."
 
+#~ msgid "Download New Stuff..."
+#~ msgstr "Descargar novedades..."
+
 #~ msgctxt ""
 #~ "A message which is shown when the user attempts to display a specific "
 #~ "entry from a specific provider, but that entry isn't found"
diff -pruN 6.0.0-3/po/et/knewstuff6.po 6.3.0-1/po/et/knewstuff6.po
--- 6.0.0-3/po/et/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/et/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -10,7 +10,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2020-10-07 21:04+0200\n"
 "Last-Translator: Mihkel Tõnnov <mihhkel@gmail.com>\n"
 "Language-Team: Estonian <>\n"
@@ -59,7 +59,7 @@ msgstr "Sinu hääl salvestati."
 msgid "You are now a fan."
 msgstr "Oled nüüd fänn."
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -129,7 +129,7 @@ msgstr "Seadistustefail on vigane: \"%1\
 msgid "Use"
 msgstr "Kasuta"
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, fuzzy, kde-format
 #| msgid ""
 #| "Could not initialise the installation handler for %1\n"
@@ -142,17 +142,17 @@ msgstr ""
 "%1 paigalduskäitleja initsialiseerimine nurjus.\n"
 "See on kriitiline tõrge ja sellest tuleks teatada rakenduse autorile"
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr "Pakkujate laadimine failist %1 nurjus"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr "Uue kuuma kraami pakkujate laadimine failist nurjus: %1"
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr "Viga pakkuja initsialiseerimisel."
@@ -318,7 +318,7 @@ msgid ""
 "the update"
 msgstr ""
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, fuzzy, kde-format
 #| msgid "Failed to load file '%1'"
 msgid ""
@@ -326,14 +326,14 @@ msgid ""
 "%2"
 msgstr "Faili '%1' laadimine nurjus"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, kde-format
 msgctxt ""
 "The first entry in the category selection list (also the default value)"
 msgid "All Categories"
 msgstr "Kõik kategooriad"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, kde-format
 msgctxt ""
 "The string passed back in the case the requested category is not known"
@@ -364,13 +364,13 @@ msgstr "kraami"
 msgid "Download New %1…"
 msgstr "Uue kraami tõmbamine: %1"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, kde-format
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "Uue kraami tõmbamine: %1"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, kde-format
 msgctxt ""
 "A placeholder title used in the dialog when there is no better title "
@@ -378,12 +378,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "Uue kraami tõmbamine"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr "Paigaldamisvaliku valimine"
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -396,19 +396,19 @@ msgstr ""
 "valida, võta palun ühendust elemendi loojaga ja palu seda täpsemalt "
 "selgitada."
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "Paigalda"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, kde-format
 msgctxt ""
 "A passive notification shown when installation of an item is initiated"
 msgid "Installing %1 from %2"
 msgstr "%1 paigaldamine asukohast %2"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -416,10 +416,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr "%1, autor: %2"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, kde-format
 msgctxt ""
 "Request installation of this item, available when there is exactly one "
@@ -427,10 +427,10 @@ msgctxt ""
 msgid "Install"
 msgstr "Paigalda"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -438,22 +438,22 @@ msgctxt ""
 msgid "Install…"
 msgstr "Paigalda"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, kde-format
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "Uuenda"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, kde-format
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "Eemalda"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, fuzzy, kde-format
 #| msgctxt ""
 #| "Status message to be shown when the entry is in the process of being "
@@ -465,7 +465,7 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr "Praegu uuendatakse komponenti %1, mille autor on %2. Palun oota ..."
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, fuzzy, kde-format
 #| msgctxt ""
 #| "Status message to be shown when the entry is in the process of being "
@@ -476,7 +476,7 @@ msgctxt ""
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr "Praegu uuendatakse komponenti %1, mille autor on %2. Palun oota ..."
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -490,12 +490,12 @@ msgstr ""
 "org/enter_bug.cgi?product=frameworks-knewstuff\">Palun anna sellest KDE "
 "kogukonnale teada veateatega</a>."
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr "Kommentaarid ja ülevaated:"
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a new sub page with comments (comments "
@@ -503,17 +503,17 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "%1 arvustused ja kommentaarid"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, kde-format
 msgid "Rating:"
 msgstr "Hinnang:"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, kde-format
 msgid "Homepage:"
 msgstr "Kodulehekülg:"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -522,12 +522,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr "Ava %1 kodulehekülg"
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr "Kuidas annetust teha:"
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -535,61 +535,69 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr "Selgitamine, kuidas projektile annetus teha"
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, fuzzy, kde-format
 #| msgid "&Tile"
 msgid "Tiles"
 msgstr "&Paanidena"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "Ikoonid"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, fuzzy, kde-format
 #| msgid "Previews"
 msgid "Preview"
 msgstr "Eelvaatlused"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, fuzzy, kde-format
 #| msgid "Detailed Tree View"
 msgid "Detailed Tiles View Mode"
 msgstr "Detailne puuvaade"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, fuzzy, kde-format
 #| msgid "Icons view mode"
 msgid "Icons Only View Mode"
 msgstr "Ikoonivaate režiim"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, fuzzy, kde-format
 #| msgid "Preview view mode"
 msgid "Large Preview View Mode"
 msgstr "Eelvaatluse režiim"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, fuzzy, kde-format
 #| msgctxt "List option which will set the filter to show everything"
 #| msgid "Everything"
 msgid "Everything"
 msgstr "Kõik"
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "Paigaldatud"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, fuzzy, kde-format
 #| msgctxt ""
 #| "List option which will set the filter so only installed items with "
@@ -598,14 +606,14 @@ msgstr "Paigaldatud"
 msgid "Updateable"
 msgstr "Ainult uuendatavad"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, fuzzy, kde-format
 #| msgid "&Show All Entries"
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "&Näita kõiki kirjeid"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, fuzzy, kde-format
 #| msgid "&Show All Entries"
 msgctxt ""
@@ -613,7 +621,7 @@ msgctxt ""
 msgid "Show Only Installed Entries"
 msgstr "&Näita kõiki kirjeid"
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, fuzzy, kde-format
 #| msgid "&Show All Entries"
 msgctxt ""
@@ -622,14 +630,14 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr "&Näita kõiki kirjeid"
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, fuzzy, kde-format
 #| msgctxt "QAccel"
 #| msgid "Percent"
 msgid "Recent"
 msgstr "Protsent"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, fuzzy, kde-format
 #| msgctxt ""
 #| "List option which will set the sort order to be alphabetical based on the "
@@ -638,18 +646,18 @@ msgstr "Protsent"
 msgid "Alphabetical"
 msgstr "Sorteerimine tähestiku järgi"
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "Hinnang"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, fuzzy, kde-format
 #| msgid "Download"
 msgid "Downloads"
 msgstr "Laadi alla"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, fuzzy, kde-format
 #| msgctxt ""
 #| "List option which will set the sort order to based on when items were "
@@ -661,7 +669,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "Uusimate näitamine esimesena"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, fuzzy, kde-format
 #| msgctxt ""
 #| "List option which will set the sort order to be alphabetical based on the "
@@ -673,7 +681,7 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr "Sorteerimine tähestiku järgi"
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, fuzzy, kde-format
 #| msgctxt "List option which will set the sort order to based on user ratings"
 #| msgid "Show highest rated first"
@@ -681,7 +689,7 @@ msgctxt "List option which will set the
 msgid "Show Highest Rated First"
 msgstr "Kõige hinnatumate näitamine esimesena"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, fuzzy, kde-format
 #| msgctxt ""
 #| "List option which will set the sort order to based on number of downloads"
@@ -691,48 +699,48 @@ msgctxt ""
 msgid "Show Most Downloaded First"
 msgstr "Kõige enam alla laaditute näitamine esimesena"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, fuzzy, kde-format
 #| msgid "Upload..."
 msgid "Upload…"
 msgstr "Üleslaadimine..."
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr ""
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, fuzzy, kde-format
 #| msgid "&Go To..."
 msgid "Go to…"
 msgstr "&Mine..."
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, fuzzy, kde-format
 #| msgid "Search:"
 msgid "Search…"
 msgstr "Otsing:"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "Kategooria:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, fuzzy, kde-format
 #| msgid "Continue operation"
 msgid "Contribute your own…"
 msgstr "Jätka tegevust"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, kde-format
 msgctxt ""
 "Placeholder title for when a comment has no subject, but does have a rating"
 msgid "<i>(no title)</i>"
 msgstr "<i>(nimetus puudub)</i>"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -740,19 +748,19 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr "%1 <i>(autor)</i>"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr "%1 kommentaarid ja ülevaated"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, kde-format
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "Kõigi kommentaaride näitamine"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -760,7 +768,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr "Ainult arvustuste näitamine"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -768,15 +776,15 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr "Arvustuste ja vastuste näitamine"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, kde-format
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
 msgstr "%1 allalaadimist"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, kde-format
 msgctxt ""
 "Subheading for the tile view, located immediately underneath the name of the "
@@ -784,7 +792,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "Autor: <i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -792,7 +800,7 @@ msgctxt ""
 msgid "Working…"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, fuzzy, kde-format
 #| msgid "Updating"
 msgctxt ""
@@ -801,7 +809,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "Uuendamine"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -815,7 +823,7 @@ msgstr ""
 "product=frameworks-knewstuff\">Palun anna sellest KDE kogukonnale teada "
 "veateatega</a>."
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt "Label for the busy indicator showing an item is installing"
@@ -834,12 +842,12 @@ msgstr "Tekkis tõrge"
 msgid "Please try again later."
 msgstr "Palun sisesta nimi."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, kde-format
 msgid "None"
 msgstr "Puudub"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, fuzzy, kde-format
 #| msgid "(%1/s)"
 msgctxt ""
@@ -847,7 +855,7 @@ msgctxt ""
 msgid "(%1/%2)"
 msgstr "(%1/s)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, fuzzy, kde-format
 #| msgctxt ""
 #| "A placeholder title used in the dialog when there is no better title "
@@ -857,7 +865,7 @@ msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "Uue kraami tõmbamine"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, fuzzy, kde-format
 #| msgid "Billing information:"
 msgctxt ""
@@ -865,21 +873,21 @@ msgctxt ""
 msgid "Updating information…"
 msgstr "Arvestusinfo:"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, fuzzy, kde-format
 #| msgid "&Store"
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "&Salvesta"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, fuzzy, kde-format
 #| msgid "Provider:"
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "Pakkuja:"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, fuzzy, kde-format
 #| msgid ""
 #| "\n"
@@ -896,7 +904,7 @@ msgstr ""
 "Veebilehekülg:\n"
 "%1"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, fuzzy, kde-format
 #| msgid "&Send Email"
 msgctxt ""
@@ -905,7 +913,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "&Saada kiri"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -913,10 +921,10 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -928,18 +936,18 @@ msgid ""
 "content added."
 msgstr ""
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "Andmete laadimine"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "Paigaldamine"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -951,7 +959,7 @@ msgstr ""
 "Sul puuduvad õigused hankida uut kuuma kraami. Kui arvad, et see ei peaks "
 "nii olema, võta ühendust isikuga, kes sinu õigustega tegeleb."
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Back"
@@ -959,20 +967,20 @@ msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "Tagasi"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, fuzzy, kde-format
 #| msgid "Saturday"
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "laupäev"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, fuzzy, kde-format
 #| msgctxt "@action:button Restart find & replace"
 #| msgid "Restart"
@@ -980,7 +988,7 @@ msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "Jätka"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "New"
@@ -988,7 +996,7 @@ msgctxt "Knewstuff5"
 msgid "New"
 msgstr "Uus"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Home"
@@ -996,13 +1004,13 @@ msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Home"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Up"
@@ -1010,7 +1018,7 @@ msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "Nool üles"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, fuzzy, kde-format
 #| msgctxt "dictionary variant"
 #| msgid "extended"
@@ -1018,7 +1026,7 @@ msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "laiendatud"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Subscript"
@@ -1026,14 +1034,14 @@ msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "Alakiri"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, fuzzy, kde-format
 #| msgid "&Show All Entries"
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "&Näita kõiki kirjeid"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -1064,9 +1072,17 @@ msgid ""
 msgstr ""
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
-#, kde-format
-msgid "Download New Stuff..."
-msgstr "Laadi alla uut kraami..."
+#, fuzzy, kde-format
+#| msgctxt ""
+#| "A placeholder title used in the dialog when there is no better title "
+#| "available"
+#| msgid "Download New Stuff"
+msgctxt "@action"
+msgid "Download New Stuff…"
+msgstr "Uue kraami tõmbamine"
+
+#~ msgid "Download New Stuff..."
+#~ msgstr "Laadi alla uut kraami..."
 
 #~ msgid "Initializing"
 #~ msgstr "Initsialiseerimine"
diff -pruN 6.0.0-3/po/eu/knewstuff6.po 6.3.0-1/po/eu/knewstuff6.po
--- 6.0.0-3/po/eu/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/eu/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -12,15 +12,15 @@ msgid ""
 msgstr ""
 "Project-Id-Version: knewstuff\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
-"PO-Revision-Date: 2024-01-19 19:12+0100\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
+"PO-Revision-Date: 2024-05-12 16:36+0200\n"
 "Last-Translator: Iñigo Salvador Azurmendi <xalba@ni.eus>\n"
 "Language-Team: Basque <kde-i18n-eu@kde.org>\n"
 "Language: eu\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Generator: Lokalize 23.08.4\n"
+"X-Generator: Lokalize 24.02.2\n"
 "Plural-Forms: nplurals=2; plural=(n != 1);\n"
 
 #: attica/atticaprovider.cpp:165
@@ -61,7 +61,7 @@ msgstr "Zure bozka erregistratu da."
 msgid "You are now a fan."
 msgstr "Orain fan bat zara."
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -130,7 +130,7 @@ msgstr "Konfiguratzeko fitxategia baliog
 msgid "Use"
 msgstr "Erabili"
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -141,17 +141,17 @@ msgstr ""
 "%2\n"
 "Hau errore larria da eta aplikazio egileari jakinarazi beharko litzaioke"
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr "Fitxategiko hornitzaileak kargatzen: %1 huts egin du"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr "Ezin dira zamatu berrikuntza hornitzaileak fitxategitik: %1"
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr "Errorea hornitzailea hasieratzen."
@@ -323,7 +323,7 @@ msgstr ""
 "Ez dugu %1 eguneratzeko esteka onik identifikatzerik izan, eta ezin dugu "
 "eguneratu"
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, kde-format
 msgid ""
 "Failed to adopt '%1'\n"
@@ -332,14 +332,14 @@ msgstr ""
 "«%1»  bereganatzea huts egin du\n"
 "%2"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, kde-format
 msgctxt ""
 "The first entry in the category selection list (also the default value)"
 msgid "All Categories"
 msgstr "Kategoria guztiak"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, kde-format
 msgctxt ""
 "The string passed back in the case the requested category is not known"
@@ -363,13 +363,13 @@ msgstr "Berrikuntzak"
 msgid "Download New %1…"
 msgstr "Zama-jaitsi %1 berria..."
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, kde-format
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "Zama-jaitsi %1 berria"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, kde-format
 msgctxt ""
 "A placeholder title used in the dialog when there is no better title "
@@ -377,12 +377,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "Zama-jaitsi gauza berriak"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr "Hautatu instalatzeko zure aukera"
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -395,19 +395,19 @@ msgstr ""
 "badago, jar zaitez harremanean elementu honen egileekin eta eska iezaiezu "
 "elementuen izendapenaren bidez hau argitu dezatela."
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "Instalatu"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, kde-format
 msgctxt ""
 "A passive notification shown when installation of an item is initiated"
 msgid "Installing %1 from %2"
 msgstr "%1, %2-(e)tik instalatzea"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -415,10 +415,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr "%2-(r)en %1"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, kde-format
 msgctxt ""
 "Request installation of this item, available when there is exactly one "
@@ -426,32 +426,32 @@ msgctxt ""
 msgid "Install"
 msgstr "Instalatu"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, kde-format
 msgctxt ""
 "Show installation options, where there is more than one downloadable item"
 msgid "Install…"
 msgstr "Instalatu..."
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, kde-format
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "Eguneratu"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, kde-format
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "Desinstalatu"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -459,14 +459,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr "Une honetan %2(r)en %1 elementua lantzen. Itxaron mesedez..."
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr "Une honetan %2(r)en %1 elementua eguneratzen. Itxaron mesedez..."
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -480,12 +480,12 @@ msgstr ""
 "\"https://bugs.kde.org/enter_bug.cgi?product=frameworks-knewstuff\">Mesedez, "
 "jakinarazi KDE Komunitateari akats txosten baten bidez</a>."
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr "Iruzkinak eta berrikuspenak:"
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a new sub page with comments (comments "
@@ -493,17 +493,17 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "%1 berrikuspen eta iruzkin"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, kde-format
 msgid "Rating:"
 msgstr "Balorazioa:"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, kde-format
 msgid "Homepage:"
 msgstr "Orri nagusia:"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -512,12 +512,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr "Ireki %1(r)en orri nagusia"
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr "Dohaintza nola egin:"
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -525,75 +525,85 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr "Jakin proiektu honi dohaintza nola egin"
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+"Kontuz ibili hemen erakusten den erabiltzaileek sortutako edukira sartzean; "
+"izan ere, baliteke KDEk edo zure banatzaileak haren segurtasuna, "
+"egonkortasuna edo kalitatea aztertu ez duten kode exekutagarria izatea"
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
-"Hemen erabilgarri dagoen edukia zure gisako erabiltzaileek zama-igo dute, "
-"eta zure banatzaileak ez du bere funtzionaltasun edo egonkortasun "
-"berrikuspenik egin."
+"Hemen erakusten den erabiltzaileek sortutako edukiaren funtzionaltasuna edo "
+"kalitatea ez du KDEk ez eta zure banatzaileak aztertu."
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, kde-format
 msgid "Tiles"
 msgstr "Lauzak"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "Ikonoak"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, kde-format
 msgid "Preview"
 msgstr "Aurreikusi"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, kde-format
 msgid "Detailed Tiles View Mode"
 msgstr "Xehetasun lauza ikuspegi modua"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, kde-format
 msgid "Icons Only View Mode"
 msgstr "Ikono soileko ikuspegi modua"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, kde-format
 msgid "Large Preview View Mode"
 msgstr "Aurreikuspegi handiko ikuspegi modua"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr "Dena"
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "Instalatuta"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, kde-format
 msgid "Updateable"
 msgstr "Eguneragarria"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, kde-format
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "Erakutsi kategoria guztiak"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr "Erakutsi instalatutako sarrerak bakarrik"
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -601,27 +611,27 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr "Erakutsi sarrera eguneragarriak bakarrik"
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, kde-format
 msgid "Recent"
 msgstr "Azken aldikoa"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr "Alfabetikoki"
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "Puntuazioa"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, kde-format
 msgid "Downloads"
 msgstr "Zama-jaisteak"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on when items were most "
@@ -629,7 +639,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "Erakutsi berrienak lehenengo"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -637,57 +647,57 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr "Sailkatu alfabetikoki izenaren arabera"
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, kde-format
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "Erakutsi balorazio handienekoak lehenengo"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on number of downloads"
 msgid "Show Most Downloaded First"
 msgstr "Erakutsi gehien zama-jaitsitakoak lehenengo"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, kde-format
 msgid "Upload…"
 msgstr "Zama-igo..."
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr "Ikasi zeure berrikuntza propioak zerrenda honetara gehitzen"
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, kde-format
 msgid "Go to…"
 msgstr "Joan hona..."
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, kde-format
 msgid "Search…"
 msgstr "Bilatu..."
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "Saila:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, kde-format
 msgid "Contribute your own…"
 msgstr "Zure ekarpena..."
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, kde-format
 msgctxt ""
 "Placeholder title for when a comment has no subject, but does have a rating"
 msgid "<i>(no title)</i>"
 msgstr "<i>(titulurik gabe)</i>"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -695,19 +705,19 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr "%1 <i>(egilea)</i>"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr "%1-(e)n gaineko iruzkinak eta berrikuspenak"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, kde-format
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "Erakutsi iruzkin guztiak"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -715,7 +725,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr "Erakutsi soilik berrikuspenak"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -723,15 +733,15 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr "Erakutsi berrikuspenak eta erantzunak"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, kde-format
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
 msgstr "%1 zama-jaiste"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, kde-format
 msgctxt ""
 "Subheading for the tile view, located immediately underneath the name of the "
@@ -739,7 +749,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "<i>%1</i>-(e)k egina"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -747,7 +757,7 @@ msgctxt ""
 msgid "Working…"
 msgstr "Lanean..."
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is in the process of being "
@@ -755,7 +765,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "Eguneratzen..."
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -769,7 +779,7 @@ msgstr ""
 "cgi?product=frameworks-knewstuff\">Eman honen berri KDE Komunitateari akats-"
 "txosten baten bidez</a>."
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, kde-format
 msgctxt "Label for the busy indicator showing an item is installing"
 msgid "Installing…"
@@ -786,44 +796,44 @@ msgstr "Errore bat gertatu da"
 msgid "Please try again later."
 msgstr "Mesedez, saiatu berriz beranduago."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, kde-format
 msgid "None"
 msgstr "Bat ere ez"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, kde-format
 msgctxt ""
 "A text representation of the rating, shown as a fraction of the max value"
 msgid "(%1/%2)"
 msgstr "(%1/%2)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, kde-format
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "Zama-igo gauza berriak: %1"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, kde-format
 msgctxt ""
 "A text shown beside a busy indicator suggesting that data is being fetched"
 msgid "Updating information…"
 msgstr "Informazioa eguneratzen..."
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, kde-format
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "KDE biltegia"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, kde-format
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "Zure hornitzailea"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, kde-format
 msgctxt ""
 "Text for an action which causes the specified website to be opened using the "
@@ -831,7 +841,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "Ireki webgunea: %1"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, kde-format
 msgctxt ""
 "Text for an action which will attempt to send an email using the user's "
@@ -839,7 +849,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "Bidali e-posta honi: %1"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -847,7 +857,7 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 "Sarrera berriak zama-igotzeko, edo KDE biltegian dagoen sarrera bati edukia "
 "gehitzeko, mesedez, ireki webgunea eta saio-hasi. Hori egin duzunean, zure "
@@ -855,7 +865,7 @@ msgstr ""
 "sarrera ikusi ahal izango duzu. Egin klik sarrera horri produktuak "
 "kudeatzeko sistemara joateko, non zure produktuetan lan egin dezakezun."
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -873,18 +883,18 @@ msgstr ""
 "dituzun. Bestela, baliteke, eduki berria gehitzeko, zuzenean guneko "
 "administratzaileekin harremanetan jarri behar izatea."
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "Datuak kargatzen"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "Instalatzen"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -896,73 +906,73 @@ msgstr ""
 "Ez duzu berrikuntzak eskuratzeko baimenik. Hau errore bat dela uste baduzu, "
 "jar zaitez harremanean zure baimenen ardura duen pertsonarekin."
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "Atzera"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr "Preziatua"
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "Nabarmendua"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "Berrabiarazi"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "New"
 msgstr "Berria"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Hasiera"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr "Apalategia"
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "Gora"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "Gomendatua"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "Harpidetzak"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "Sarrera guztiak"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -1008,8 +1018,12 @@ msgstr ""
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
 #, kde-format
-msgid "Download New Stuff..."
-msgstr "Zama-jaitsi gauza berriak..."
+msgctxt "@action"
+msgid "Download New Stuff…"
+msgstr "Gauza berriak zama-jaitsi..."
+
+#~ msgid "Download New Stuff..."
+#~ msgstr "Zama-jaitsi gauza berriak..."
 
 #~ msgctxt ""
 #~ "A message which is shown when the user attempts to display a specific "
diff -pruN 6.0.0-3/po/fa/knewstuff6.po 6.3.0-1/po/fa/knewstuff6.po
--- 6.0.0-3/po/fa/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/fa/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -10,7 +10,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2012-06-28 16:40+0430\n"
 "Last-Translator: Mohammad Reza Mirdamadi <mohi@linuxshop.ir>\n"
 "Language-Team: Farsi (Persian) <kde-i18n-fa@kde.org>\n"
@@ -66,7 +66,7 @@ msgstr "رای شما موفقیت آم
 msgid "You are now a fan."
 msgstr "حالا شما یک هوادار هستید."
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -136,7 +136,7 @@ msgstr "پرونده‌های پیکرب
 msgid "Use"
 msgstr ""
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -144,17 +144,17 @@ msgid ""
 "This is a critical error and should be reported to the application author"
 msgstr ""
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr ""
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr "نتوانست فراهم کنندگان چیزهای تازه و داغ را بار کند از پرونده: %1"
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr ""
@@ -301,7 +301,7 @@ msgid ""
 "the update"
 msgstr ""
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, fuzzy, kde-format
 #| msgid "Failed to load file '%1'"
 msgid ""
@@ -309,7 +309,7 @@ msgid ""
 "%2"
 msgstr "خرابی در بارگذاری پرونده »%1«"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt ""
@@ -317,7 +317,7 @@ msgctxt ""
 msgid "All Categories"
 msgstr "همه دسته‌ها"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, fuzzy, kde-format
 #| msgid "Unknown error"
 msgctxt ""
@@ -343,14 +343,14 @@ msgstr ""
 msgid "Download New %1…"
 msgstr "بارگیری جدید %1"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, fuzzy, kde-format
 #| msgid "Download New %1"
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "بارگیری جدید %1"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
 msgctxt ""
@@ -359,12 +359,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "بارگیری new stuff"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -373,12 +373,12 @@ msgid ""
 "this through the naming of the items."
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "نصب"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt ""
@@ -386,7 +386,7 @@ msgctxt ""
 msgid "Installing %1 from %2"
 msgstr "در حال نصب"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -394,10 +394,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -406,10 +406,10 @@ msgctxt ""
 msgid "Install"
 msgstr "نصب"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -418,10 +418,10 @@ msgid "Install…"
 msgstr "نصب"
 
 # Update
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, fuzzy, kde-format
 #| msgid "Update"
 msgctxt "Request updating of this item"
@@ -429,14 +429,14 @@ msgid "Update"
 msgstr "به‌روزرسانی"
 
 # Uninstall
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, fuzzy, kde-format
 #| msgid "Uninstall"
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "عزل"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -444,14 +444,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -462,12 +462,12 @@ msgid ""
 "to the KDE Community in a bug report</a>."
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, fuzzy, kde-format
 #| msgid "View Comments"
 msgctxt ""
@@ -476,19 +476,19 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "نظرات را ببینید"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, fuzzy, kde-format
 #| msgid "Rating: "
 msgid "Rating:"
 msgstr "رتبه‌بندی:"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, fuzzy, kde-format
 #| msgid "Homepage"
 msgid "Homepage:"
 msgstr "صفحه آغازه"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -497,12 +497,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -510,74 +510,82 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr ""
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, fuzzy, kde-format
 #| msgctxt "@option:check Do filter on type - show only files"
 #| msgid "Files"
 msgid "Tiles"
 msgstr "پرونده‌ها"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "شمایلها"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, fuzzy, kde-format
 #| msgid "No Preview"
 msgid "Preview"
 msgstr "بدون پیش‌نمایش"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, fuzzy, kde-format
 #| msgid "Detailed View"
 msgid "Detailed Tiles View Mode"
 msgstr "نمای جزئیات"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, fuzzy, kde-format
 #| msgid "Icons view mode"
 msgid "Icons Only View Mode"
 msgstr "حالت نمای شمایل"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, fuzzy, kde-format
 #| msgid "Details view mode"
 msgid "Large Preview View Mode"
 msgstr "حالت نمایش جزییات"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr ""
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "نصب‌شده"
 
 # Update
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, fuzzy, kde-format
 #| msgid "Update"
 msgid "Updateable"
 msgstr "به‌روزرسانی"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, fuzzy, kde-format
 #| msgid "&Show All Entries"
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "&نمایش همه مدخلها‌"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, fuzzy, kde-format
 #| msgid "&Show All Entries"
 msgctxt ""
@@ -585,7 +593,7 @@ msgctxt ""
 msgid "Show Only Installed Entries"
 msgstr "&نمایش همه مدخلها‌"
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, fuzzy, kde-format
 #| msgid "&Show All Entries"
 msgctxt ""
@@ -594,29 +602,29 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr "&نمایش همه مدخلها‌"
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, fuzzy, kde-format
 #| msgid "Open &Recent"
 msgid "Recent"
 msgstr "باز کردن &اخیر‌"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr ""
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "درجه‌بندی"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, fuzzy, kde-format
 #| msgid "Download"
 msgid "Downloads"
 msgstr "بارگیری"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt ""
@@ -625,7 +633,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "ابتدا نمایش فهرستهای راهنما"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -633,14 +641,14 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr ""
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "ابتدا نمایش فهرستهای راهنما"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, fuzzy, kde-format
 #| msgid "Most downloads"
 msgctxt ""
@@ -648,41 +656,41 @@ msgctxt ""
 msgid "Show Most Downloaded First"
 msgstr "بیشترین بارگیریها"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, fuzzy, kde-format
 #| msgid "Upload..."
 msgid "Upload…"
 msgstr "بارگذاری..."
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr ""
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, fuzzy, kde-format
 #| msgid "&Go To..."
 msgid "Go to…"
 msgstr "&برو به...‌"
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, fuzzy, kde-format
 #| msgid "Search:"
 msgid "Search…"
 msgstr "جستجو:"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "دسته:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, fuzzy, kde-format
 #| msgid "Continue operation"
 msgid "Contribute your own…"
 msgstr "ادامه عملیات"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, fuzzy, kde-format
 #| msgctxt "@note/rich"
 #| msgid "<i>Note</i>: %1"
@@ -691,7 +699,7 @@ msgctxt ""
 msgid "<i>(no title)</i>"
 msgstr "<i>نکته</i>: %1"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -699,20 +707,20 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "همه دسته‌ها"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, fuzzy, kde-format
 #| msgid "Show Preview"
 msgctxt ""
@@ -721,7 +729,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr "نمایش پیش‌نمایش"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -729,8 +737,8 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, fuzzy, kde-format
 #| msgid "Download"
 msgctxt "The number of times the item has been downloaded"
@@ -738,8 +746,8 @@ msgid "%1 downloads"
 msgstr "بارگیری‌ها:"
 
 # <i>%1</i>
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, fuzzy, kde-format
 #| msgctxt "Show the author of this item in a list"
 #| msgid "By <i>%1</i>"
@@ -749,7 +757,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "از <i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -758,7 +766,7 @@ msgid "Working…"
 msgstr ""
 
 # Update
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, fuzzy, kde-format
 #| msgid "Updating"
 msgctxt ""
@@ -767,7 +775,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "به‌روزرسانی"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -778,7 +786,7 @@ msgid ""
 "bug report</a>."
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt "Label for the busy indicator showing an item is installing"
@@ -797,14 +805,14 @@ msgstr ""
 msgid "Please try again later."
 msgstr "لطفاً، یک نام پیشنهاد کنید."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, fuzzy, kde-format
 #| msgctxt "No border line"
 #| msgid "None"
 msgid "None"
 msgstr "هیچ"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, fuzzy, kde-format
 #| msgid "(%1/s)"
 msgctxt ""
@@ -812,14 +820,14 @@ msgctxt ""
 msgid "(%1/%2)"
 msgstr ")%1/ثانیه("
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "بارگیری new stuff"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, fuzzy, kde-format
 #| msgid "Billing information:"
 msgctxt ""
@@ -827,21 +835,21 @@ msgctxt ""
 msgid "Updating information…"
 msgstr "اطلاعات صورت‌حساب:"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, fuzzy, kde-format
 #| msgid "&Store"
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "ذخیره"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, fuzzy, kde-format
 #| msgid "Provider:"
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "فراهم‌کننده:"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, fuzzy, kde-format
 #| msgid ""
 #| "\n"
@@ -854,7 +862,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "وبگاه:"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, fuzzy, kde-format
 #| msgid "&Send Email"
 msgctxt ""
@@ -863,7 +871,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "&ارسال رایانامه‌"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -871,10 +879,10 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -886,19 +894,19 @@ msgid ""
 "content added."
 msgstr ""
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, fuzzy, kde-format
 #| msgid "Loading Applet"
 msgid "Loading data"
 msgstr "بارگذاری برنامک"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "در حال نصب"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -908,7 +916,7 @@ msgid ""
 "please contact the person in charge of your permissions."
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Back"
@@ -916,20 +924,20 @@ msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "پس"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, fuzzy, kde-format
 #| msgid "Saturday"
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "شنبه"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, fuzzy, kde-format
 #| msgctxt "@action:button Restart find & replace"
 #| msgid "Restart"
@@ -937,7 +945,7 @@ msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "بازآغازی"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "New"
@@ -945,7 +953,7 @@ msgctxt "Knewstuff5"
 msgid "New"
 msgstr "جدید"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Home"
@@ -953,14 +961,14 @@ msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "آغازه"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr ""
 
 # Up
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Up"
@@ -968,7 +976,7 @@ msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "بالا"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, fuzzy, kde-format
 #| msgctxt "dictionary variant"
 #| msgid "extended"
@@ -976,7 +984,7 @@ msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "بسط‌یافته"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Subscript"
@@ -984,14 +992,14 @@ msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "عضوشدن"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, fuzzy, kde-format
 #| msgid "&Show All Entries"
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "&نمایش همه مدخلها‌"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -1022,9 +1030,14 @@ msgid ""
 msgstr ""
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
-#, kde-format
-msgid "Download New Stuff..."
-msgstr "بارگیری چیزهای جدید..."
+#, fuzzy, kde-format
+#| msgid "Download New Stuff"
+msgctxt "@action"
+msgid "Download New Stuff…"
+msgstr "بارگیری new stuff"
+
+#~ msgid "Download New Stuff..."
+#~ msgstr "بارگیری چیزهای جدید..."
 
 #, fuzzy
 #~| msgid "Installing"
diff -pruN 6.0.0-3/po/fi/knewstuff6.po 6.3.0-1/po/fi/knewstuff6.po
--- 6.0.0-3/po/fi/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/fi/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -25,7 +25,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2024-02-14 18:46+0200\n"
 "Last-Translator: Tommi Nieminen <translator@legisign.org>\n"
 "Language-Team: Finnish <kde-i18n-doc@kde.org>\n"
@@ -75,7 +75,7 @@ msgstr "Äänesi rekisteröitiin."
 msgid "You are now a fan."
 msgstr "Sinut on merkitty faniksi."
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -143,7 +143,7 @@ msgstr "Asetustiedosto on virheellinen:
 msgid "Use"
 msgstr "Käytä"
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -154,17 +154,17 @@ msgstr ""
 "%2\n"
 "Tämä on vakava virhe, josta tulisi ilmoittaa sovelluksen kehittäjälle"
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr "Tarjoajien lataus tiedostosta %1 epäonnistui"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr "Hae verkosta -tarjoajia ei voitu ladata tiedostosta: %1"
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr "Virhe alustettaessa tarjoajaa."
@@ -333,7 +333,7 @@ msgstr ""
 "Kelvollista kohteen %1 päivityslinkkiä ei löytynyt eikä päivitystä voida "
 "tehdä"
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, kde-format
 msgid ""
 "Failed to adopt '%1'\n"
@@ -342,14 +342,14 @@ msgstr ""
 "Käyttöönotto epäonnistui: ”%1”\n"
 "%2"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, kde-format
 msgctxt ""
 "The first entry in the category selection list (also the default value)"
 msgid "All Categories"
 msgstr "Kaikki luokat"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, kde-format
 msgctxt ""
 "The string passed back in the case the requested category is not known"
@@ -375,13 +375,13 @@ msgid "Download New %1…"
 msgstr "Lataa uusia – %1…"
 
 # *** HUOM! Tarkoitettu väliaikaiseksi, kunnes %1 saataisiin muotoiltua järkeväksi tai koko jono muuttuisi. ”Lataa uusi – Väriteemat” on aavistuksen (vaikkei paljon) parempi kuin ”Lataa uusi Väriteemat”.
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, kde-format
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "Lataa uusia – %1"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, kde-format
 msgctxt ""
 "A placeholder title used in the dialog when there is no better title "
@@ -389,12 +389,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "Lataa uutuuksia…"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr "Valitse asennusvalintasi"
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -408,19 +408,19 @@ msgstr ""
 "ladattavien kohteiden luettelosta. Jos valinta on epäselvä, ota yhteyttä "
 "tämän kohdan tekijään ja pyydä häntä selventämään kohteiden nimiä."
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "Asenna"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, kde-format
 msgctxt ""
 "A passive notification shown when installation of an item is initiated"
 msgid "Installing %1 from %2"
 msgstr "Asennetaan %1 lähteestä %2"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -428,10 +428,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr "%1/%2"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, kde-format
 msgctxt ""
 "Request installation of this item, available when there is exactly one "
@@ -439,32 +439,32 @@ msgctxt ""
 msgid "Install"
 msgstr "Asenna"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, kde-format
 msgctxt ""
 "Show installation options, where there is more than one downloadable item"
 msgid "Install…"
 msgstr "Asenna…"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, kde-format
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "Päivitä"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, kde-format
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "Poista asennus"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -472,14 +472,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr "Käsitellään kohdetta %1/%2. Odota…"
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr "Päivitetään kohdetta %1/%2. Odota…"
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -493,12 +493,12 @@ msgstr ""
 "enter_bug.cgi?product=frameworks-knewstuff\">Ilmoita tästä KDE-yhteisölle "
 "vikailmoituksella</a>."
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr "Kommentit ja arvostelut:"
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a new sub page with comments (comments "
@@ -506,17 +506,17 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "%1 arvostelua ja kommenttia"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, kde-format
 msgid "Rating:"
 msgstr "Arvostelu:"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, kde-format
 msgid "Homepage:"
 msgstr "Kotisivu:"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -525,12 +525,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr "Avaa sivusto – %1"
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr "Lahjoittaminen:"
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -538,75 +538,86 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr "Miten lahjoittaa projektille"
 
-#: qtquick/qml/Page.qml:141
-#, kde-format
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
+#, fuzzy, kde-format
+#| msgid ""
+#| "The content available here has been uploaded by users like you, and has "
+#| "not been reviewed by your distributor for functionality or stability."
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 "Tässä saatavilla olevan sisällön tarjoavat kaltaisesti käyttäjät, eikä "
 "jakelusi ole tarkistanut sen toimivuutta tai vakautta."
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, kde-format
 msgid "Tiles"
 msgstr "Ruudukko"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "Kuvakkeet"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, kde-format
 msgid "Preview"
 msgstr "Esikatselu"
 
 # Ruudukko-sanavalinta tulee Facebookin vastaavanoloisesta näkymästä
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, kde-format
 msgid "Detailed Tiles View Mode"
 msgstr "Yksityiskohtainen ruudukkonäkymä"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, kde-format
 msgid "Icons Only View Mode"
 msgstr "Vain kuvakkeet -näkymä"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, kde-format
 msgid "Large Preview View Mode"
 msgstr "Suuri esikatselunäkymä"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr "Kaikki"
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "Asennetut"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, kde-format
 msgid "Updateable"
 msgstr "Päivitettävissä"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, kde-format
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "Näytä kaikki kohteet"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr "Näytä vain asennetut kohteet"
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -614,27 +625,27 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr "Näytä vain päivitettävissä olevat kohteet"
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, kde-format
 msgid "Recent"
 msgstr "Uusimmat"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr "Aakkosjärjestys"
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "Arvostelu"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, kde-format
 msgid "Downloads"
 msgstr "Lataukset"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on when items were most "
@@ -642,7 +653,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "Näytä ensin uusimmat"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -650,57 +661,57 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr "Aakkosta nimen mukaan"
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, kde-format
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "Näytä ensin parhaiksi arvioidut"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on number of downloads"
 msgid "Show Most Downloaded First"
 msgstr "Näytä ensin ladatuimmat"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, kde-format
 msgid "Upload…"
 msgstr "Lähetä…"
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr "Lisätietoa siitä, miten lisätä luetteloon omia uutuuksiasi"
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, kde-format
 msgid "Go to…"
 msgstr "Siirry…"
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, kde-format
 msgid "Search…"
 msgstr "Etsi…"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "Luokka:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, kde-format
 msgid "Contribute your own…"
 msgstr "Lahjoita omasi…"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, kde-format
 msgctxt ""
 "Placeholder title for when a comment has no subject, but does have a rating"
 msgid "<i>(no title)</i>"
 msgstr "<i>(ei otsikkoa)</i>"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -708,19 +719,19 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr "%1 <i>(tekijä)</i>"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr "%1 – kommentit ja arvostelut"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, kde-format
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "Näytä kaikki kommentit"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -728,7 +739,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr "Näytä vain arvostelut"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -736,15 +747,15 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr "Näytä arvostelut vastauksineen"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, kde-format
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
 msgstr "%1 latausta"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, kde-format
 msgctxt ""
 "Subheading for the tile view, located immediately underneath the name of the "
@@ -752,7 +763,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "Tekijältä <i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -760,7 +771,7 @@ msgctxt ""
 msgid "Working…"
 msgstr "Käsitellään…"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is in the process of being "
@@ -768,7 +779,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "Päivitetään…"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -781,7 +792,7 @@ msgstr ""
 "Virheellinen tai tuntematon tila. <a href=\"https://bugs.kde.org/enter_bug."
 "cgi?product=frameworks-knewstuff\">Tee tästä KDE-yhteisölle vikailmoitus</a>."
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, kde-format
 msgctxt "Label for the busy indicator showing an item is installing"
 msgid "Installing…"
@@ -798,44 +809,44 @@ msgstr "Sattui virhe"
 msgid "Please try again later."
 msgstr "Yritä myöhemmin uudestaan."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, kde-format
 msgid "None"
 msgstr "Ei mitään"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, kde-format
 msgctxt ""
 "A text representation of the rating, shown as a fraction of the max value"
 msgid "(%1/%2)"
 msgstr "(%1/%2)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, kde-format
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "Lähetä uutuuksia: %1"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, kde-format
 msgctxt ""
 "A text shown beside a busy indicator suggesting that data is being fetched"
 msgid "Updating information…"
 msgstr "Päivitetään tietoja…"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, kde-format
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "KDE Store"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, kde-format
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "Tarjoaja"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, kde-format
 msgctxt ""
 "Text for an action which causes the specified website to be opened using the "
@@ -843,7 +854,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "Avaa sivusto: %1"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, kde-format
 msgctxt ""
 "Text for an action which will attempt to send an email using the user's "
@@ -851,22 +862,29 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "Lähetä sähköpostia: %1"
 
-#: qtquick/qml/UploadPage.qml:154
-#, kde-format
+#: qtquick/qml/UploadPage.qml:159
+#, fuzzy, kde-format
+#| msgctxt "A description of how to upload content to a generic provider"
+#| msgid ""
+#| "To upload new entries, or to add content to an existing entry on the KDE "
+#| "Store, please open the website and log in. Once you have done this, you "
+#| "will be able to find the My Products entry in the menu which pops up when "
+#| "you click your user icon. Click on this entry to go to the product "
+#| "management system, where you can work on your products ."
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
 "To upload new entries, or to add content to an existing entry on the KDE "
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 "Lisätäksesi uusia kohteita tai sisältöä olemassa olevaan KDE Storen "
 "kohteeseen kirjaudu ensin sivustolle. Napsautettuasi tämän jälkeen "
 "käyttäjäkuvaketta löydät valikosta Tuotteeni-kohdan. Siitä pääset "
 "tuotehallintajärjestelmään, jolla hallitset tuotteitasi."
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -883,18 +901,18 @@ msgstr ""
 "tuotehallintajärjestelmään, joka antaa lisäohjeita. Vaihtoehtoisesti "
 "sisällön lisäämiseksi on otettava suoraan yhteyttä sivuston ylläpitäjiin."
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "Ladataan tietoja"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "Asennetaan"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -906,73 +924,73 @@ msgstr ""
 "Sinulla ei ole oikeuksia hakea uutuuksia. Jos pidät tätä virheenä, ota "
 "yhteys käyttöoikeuksista vastaavaan."
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "Takaisin"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr "Suositut"
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "Esitellyt"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "Käynnistä uudelleen"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "New"
 msgstr "Uudet"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Koti"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr "Hylly"
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "Ylemmäs"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "Suositellut"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "Tilaukset"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "Kaikki kohteet"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -1017,10 +1035,18 @@ msgstr ""
 "Esimerkki osoitteesta: kns://sddmteema.knsrc/api.kde-look.org/2059021"
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
-#, kde-format
-msgid "Download New Stuff..."
+#, fuzzy, kde-format
+#| msgctxt ""
+#| "A placeholder title used in the dialog when there is no better title "
+#| "available"
+#| msgid "Download New Stuff"
+msgctxt "@action"
+msgid "Download New Stuff…"
 msgstr "Lataa uutuuksia…"
 
+#~ msgid "Download New Stuff..."
+#~ msgstr "Lataa uutuuksia…"
+
 #~ msgctxt ""
 #~ "A message which is shown when the user attempts to display a specific "
 #~ "entry from a specific provider, but that entry isn't found"
diff -pruN 6.0.0-3/po/fr/knewstuff6.po 6.3.0-1/po/fr/knewstuff6.po
--- 6.0.0-3/po/fr/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/fr/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -24,16 +24,16 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
-"PO-Revision-Date: 2024-01-23 10:25+0100\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
+"PO-Revision-Date: 2024-05-08 18:09+0200\n"
 "Last-Translator: Xavier Besnard <xavier.besnard@kde.org>\n"
-"Language-Team: French <kde-francophone@kde.org>\n"
+"Language-Team: French <French <kde-francophone@kde.org>>\n"
 "Language: fr\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=2; plural=(n > 1);\n"
-"X-Generator: Lokalize 23.08.4\n"
+"X-Generator: Lokalize 23.08.5\n"
 "X-Environment: kde\n"
 "X-Accelerator-Marker: &\n"
 "X-Text-Markup: kde4\n"
@@ -76,7 +76,7 @@ msgstr "Votre vote a été enregistré."
 msgid "You are now a fan."
 msgstr "Vous êtes maintenant un fan."
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -150,7 +150,7 @@ msgstr "Le fichier de configuration n'es
 msgid "Use"
 msgstr "Utiliser"
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -161,19 +161,19 @@ msgstr ""
 "%2Ceci est une erreur critique. Elle devrait être signalée à l'auteur de "
 "l'application."
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr "Chargement des fournisseurs à partir du fichier : %1 a échoué"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr ""
 "Il est impossible de charger les fournisseurs de nouveautés à partir d'un "
 "fichier : %1"
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr "Problème lors de l'initialisation du fournisseur."
@@ -350,7 +350,7 @@ msgstr ""
 "Impossible d'identifier un lien correct pour mettre à jour %1 et de réaliser "
 "la mise à jour."
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, kde-format
 msgid ""
 "Failed to adopt '%1'\n"
@@ -359,14 +359,14 @@ msgstr ""
 "Impossible d'adopter « %1 »\n"
 "%2"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, kde-format
 msgctxt ""
 "The first entry in the category selection list (also the default value)"
 msgid "All Categories"
 msgstr "Toutes les catégories"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, kde-format
 msgctxt ""
 "The string passed back in the case the requested category is not known"
@@ -390,13 +390,13 @@ msgstr "Nouveauté"
 msgid "Download New %1…"
 msgstr "Télécharger un nouveau %1"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, kde-format
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "Télécharger un nouveau %1"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, kde-format
 msgctxt ""
 "A placeholder title used in the dialog when there is no better title "
@@ -404,12 +404,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "Télécharger les nouveautés..."
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr "Choisissez votre option d'installation"
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -422,19 +422,19 @@ msgstr ""
 "option choisir parmi les options disponibles, contactez l'auteur de cet "
 "élément et demandez-lui de clarifier l'appellation des éléments."
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "Installer"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, kde-format
 msgctxt ""
 "A passive notification shown when installation of an item is initiated"
 msgid "Installing %1 from %2"
 msgstr "Installation de %1 depuis %2"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -442,10 +442,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr "%1 par %2"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, kde-format
 msgctxt ""
 "Request installation of this item, available when there is exactly one "
@@ -453,32 +453,32 @@ msgctxt ""
 msgid "Install"
 msgstr "Installer"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, kde-format
 msgctxt ""
 "Show installation options, where there is more than one downloadable item"
 msgid "Install…"
 msgstr "Installer..."
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, kde-format
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "Mettre à jour"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, kde-format
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "Désinstaller"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -486,14 +486,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr "Traitement en cours de l'élément %1 parmi %2. Veuillez patienter..."
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr "Mise à jour de l'élément %1 parmi %2 en cours. Veuillez patienter…"
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -507,12 +507,12 @@ msgstr ""
 "kde.org/enter_bug.cgi?product=frameworks-knewstuff\">Veuillez le signaler à "
 "la communauté KDE dans un rapport de bogue</a>."
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr "Commentaires et avis :"
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a new sub page with comments (comments "
@@ -520,17 +520,17 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "%1 avis et commentaires"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, kde-format
 msgid "Rating:"
 msgstr "Note :"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, kde-format
 msgid "Homepage:"
 msgstr "Page d'accueil :"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -539,12 +539,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr "Ouvrir la page d'accueil de %1"
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr "Comment faire un don :"
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -552,75 +552,85 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr "Découvrez comment faire un don pour ce projet"
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+"Soyez prudent lorsque vous accédez au contenu créé par l'utilisateur, car il "
+"peut contenir du code exécutable n'ayant pas été testé par KDE ou par votre "
+"distributeur concernant la sécurité, la stabilité ou la qualité."
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
-"Le contenu disponible ici a été téléchargé par des utilisateurs comme vous. "
-"Il n'a pas été vérifié par votre distributeur quant à sa fonctionnalité ou "
-"sa stabilité."
+"Le contenu créé par un utilisateur ici n'a pas été testé par KDE ou votre "
+"fournisseur de distribution concernant ses fonctionnalités ou sa qualité."
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, kde-format
 msgid "Tiles"
 msgstr "Tuiles"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "Icônes"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, kde-format
 msgid "Preview"
 msgstr "Aperçu"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, kde-format
 msgid "Detailed Tiles View Mode"
 msgstr "Mode d'affichage détaillé en tuiles"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, kde-format
 msgid "Icons Only View Mode"
 msgstr "Mode d'affichage uniquement avec icônes"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, kde-format
 msgid "Large Preview View Mode"
 msgstr "Mode d'affichage par aperçus larges"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr "Tout"
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "Installés"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, kde-format
 msgid "Updateable"
 msgstr "Pouvant être mis à jour"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, kde-format
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "Afficher tous les entrées"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr "Afficher uniquement les entrées installées"
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -628,27 +638,27 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr "Afficher uniquement les entrées pouvant être mises à jour"
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, kde-format
 msgid "Recent"
 msgstr "Récent"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr "Alphabétique"
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "Note"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, kde-format
 msgid "Downloads"
 msgstr "Téléchargements"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on when items were most "
@@ -656,7 +666,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "Afficher les plus récents en premier"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -664,57 +674,57 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr "Trier les noms par ordre alphabétique"
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, kde-format
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "Afficher les mieux notés en premier"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on number of downloads"
 msgid "Show Most Downloaded First"
 msgstr "Afficher les plus téléchargés en premier"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, kde-format
 msgid "Upload…"
 msgstr "Envoyer…"
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr "Apprendre à ajouter sa propre nouveauté à cette liste"
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, kde-format
 msgid "Go to…"
 msgstr "Aller à..."
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, kde-format
 msgid "Search…"
 msgstr "Rechercher..."
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "Catégorie :"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, kde-format
 msgid "Contribute your own…"
 msgstr "Contribuer personnellement..."
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, kde-format
 msgctxt ""
 "Placeholder title for when a comment has no subject, but does have a rating"
 msgid "<i>(no title)</i>"
 msgstr "<i>(sans titre)</i>"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -722,19 +732,19 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr "%1 <i>(auteur)</i>"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr "Commentaires et avis sur %1"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, kde-format
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "Afficher tous les commentaires"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -742,7 +752,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr "Afficher uniquement les avis"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -750,15 +760,15 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr "Afficher les avis et les réponses"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, kde-format
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
 msgstr "%1 téléchargements"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, kde-format
 msgctxt ""
 "Subheading for the tile view, located immediately underneath the name of the "
@@ -766,7 +776,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "Par <i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -774,7 +784,7 @@ msgctxt ""
 msgid "Working…"
 msgstr "Traitement en cours..."
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is in the process of being "
@@ -782,7 +792,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "Mise à jour en cours..."
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -796,7 +806,7 @@ msgstr ""
 "product=frameworks-knewstuff\">Veuillez le signaler à la communauté KDE dans "
 "un rapport de bogue</a>."
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, kde-format
 msgctxt "Label for the busy indicator showing an item is installing"
 msgid "Installing…"
@@ -813,44 +823,44 @@ msgstr "Une erreur est survenue"
 msgid "Please try again later."
 msgstr "Veuillez ré-essayer plus tard."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, kde-format
 msgid "None"
 msgstr "Aucun"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, kde-format
 msgctxt ""
 "A text representation of the rating, shown as a fraction of the max value"
 msgid "(%1/%2)"
 msgstr "(%1 / %2)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, kde-format
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "Envoyer une nouveauté : %1"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, kde-format
 msgctxt ""
 "A text shown beside a busy indicator suggesting that data is being fetched"
 msgid "Updating information…"
 msgstr "Mise à jour d'informations en cours…"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, kde-format
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "Boutique KDE"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, kde-format
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "Votre fournisseur :"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, kde-format
 msgctxt ""
 "Text for an action which causes the specified website to be opened using the "
@@ -858,7 +868,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "Ouvrir le site Internet : %1"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, kde-format
 msgctxt ""
 "Text for an action which will attempt to send an email using the user's "
@@ -866,7 +876,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "Envoyer un courrier électronique à : %1"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -874,7 +884,7 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 "Pour envoyer de nouvelles entrées ou pour ajouter du contenu à une entrée "
 "existante sur la boutique KDE, veuillez ouvrir le site Internet et vous "
@@ -883,7 +893,7 @@ msgstr ""
 "utilisateur. Cliquez sur cette entrée pour accéder au système de gestion des "
 "produits, où vous pouvez travailler sur vos produits."
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -902,18 +912,18 @@ msgstr ""
 "deviez contacter directement les gestionnaires du site pour faire ajouter du "
 "nouveau contenu."
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "Chargement des données"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "Installation"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -926,73 +936,73 @@ msgstr ""
 "nouveautés »). Si vous pensez qu'il s'agit d'une erreur, veuillez contacter "
 "la personne responsable de vos permissions."
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "Retour"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr "Populaire"
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "Présenté"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "Redémarrer"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "New"
 msgstr "Nouveau"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Accueil"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr "Étagère"
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "Haut"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "Recommandé"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "Abonnements"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "Tous les entrées"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -1040,9 +1050,13 @@ msgstr ""
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
 #, kde-format
-msgid "Download New Stuff..."
+msgctxt "@action"
+msgid "Download New Stuff…"
 msgstr "Télécharger les nouveautés..."
 
+#~ msgid "Download New Stuff..."
+#~ msgstr "Télécharger les nouveautés..."
+
 #~ msgctxt ""
 #~ "A message which is shown when the user attempts to display a specific "
 #~ "entry from a specific provider, but that entry isn't found"
diff -pruN 6.0.0-3/po/fy/knewstuff6.po 6.3.0-1/po/fy/knewstuff6.po
--- 6.0.0-3/po/fy/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/fy/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -15,7 +15,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2010-07-22 09:48+0100\n"
 "Last-Translator: Berend Ytsma <berendy@gmail.com>\n"
 "Language-Team: nl <kde-i18n-doc@lists.kde.org>\n"
@@ -60,7 +60,7 @@ msgstr "Jo stim is notearre."
 msgid "You are now a fan."
 msgstr "Jo binne no in fan."
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -128,7 +128,7 @@ msgstr "Konfiguraasjetriem net jildich:
 msgid "Use"
 msgstr ""
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -136,17 +136,17 @@ msgid ""
 "This is a critical error and should be reported to the application author"
 msgstr ""
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr ""
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr ""
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr "Flater by it tarieden fan ferskaffer."
@@ -291,7 +291,7 @@ msgid ""
 "the update"
 msgstr ""
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, fuzzy, kde-format
 #| msgid "Failed to load file '%1'"
 msgid ""
@@ -299,7 +299,7 @@ msgid ""
 "%2"
 msgstr "It mislearre om triem '%1' te laden"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt ""
@@ -307,7 +307,7 @@ msgctxt ""
 msgid "All Categories"
 msgstr "Alles kategoryen"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, fuzzy, kde-format
 #| msgid "Unknown error"
 msgctxt ""
@@ -333,14 +333,14 @@ msgstr ""
 msgid "Download New %1…"
 msgstr "Nije %1 oerhelje"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, fuzzy, kde-format
 #| msgid "Download New %1"
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "Nije %1 oerhelje"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, fuzzy, kde-format
 #| msgid "Download New Stuff..."
 msgctxt ""
@@ -349,12 +349,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "Nij guod ynlade..."
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -363,12 +363,12 @@ msgid ""
 "this through the naming of the items."
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "Ynstallearje"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt ""
@@ -376,7 +376,7 @@ msgctxt ""
 msgid "Installing %1 from %2"
 msgstr "Ynstallaasje is geande"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -384,10 +384,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -396,10 +396,10 @@ msgctxt ""
 msgid "Install"
 msgstr "Ynstallearje"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -407,24 +407,24 @@ msgctxt ""
 msgid "Install…"
 msgstr "Ynstallearje"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, fuzzy, kde-format
 #| msgid "Update"
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "Bywurkje"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, fuzzy, kde-format
 #| msgid "Uninstall"
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "Unt-ynstallearje"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -432,14 +432,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -450,12 +450,12 @@ msgid ""
 "to the KDE Community in a bug report</a>."
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, fuzzy, kde-format
 #| msgid "View Comments"
 msgctxt ""
@@ -464,19 +464,19 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "Kommentaar besjen"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, fuzzy, kde-format
 #| msgid "Rating: "
 msgid "Rating:"
 msgstr "Wurdearring:"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, fuzzy, kde-format
 #| msgid "Homepage"
 msgid "Homepage:"
 msgstr "Thússide"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -485,12 +485,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -498,78 +498,86 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr ""
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, fuzzy, kde-format
 #| msgid "File"
 msgid "Tiles"
 msgstr "Triem"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "Byldkaikes"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, kde-format
 msgid "Preview"
 msgstr "Foarbylden"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, fuzzy, kde-format
 #| msgid "Details view mode"
 msgid "Detailed Tiles View Mode"
 msgstr "Details werjeftemodus"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, fuzzy, kde-format
 #| msgid "Icons view mode"
 msgid "Icons Only View Mode"
 msgstr "Byldkaike werjeftemodus"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, fuzzy, kde-format
 #| msgid "Details view mode"
 msgid "Large Preview View Mode"
 msgstr "Details werjeftemodus"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr ""
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "Ynstallearre"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, fuzzy, kde-format
 #| msgid "Update"
 msgid "Updateable"
 msgstr "Bywurkje"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "Alles kategoryen"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -577,30 +585,30 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Open Recent"
 msgid "Recent"
 msgstr "Resinte iepene"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr ""
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "Wurdearring"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, fuzzy, kde-format
 #| msgid "Download"
 msgid "Downloads"
 msgstr "Ynlade"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt ""
@@ -609,7 +617,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "Lit triemtafels earst sjen"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -617,14 +625,14 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr ""
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "Lit triemtafels earst sjen"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, fuzzy, kde-format
 #| msgid "Most downloads"
 msgctxt ""
@@ -632,41 +640,41 @@ msgctxt ""
 msgid "Show Most Downloaded First"
 msgstr "Measte ynladen"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, fuzzy, kde-format
 #| msgid "Upload..."
 msgid "Upload…"
 msgstr "Opladen..."
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr ""
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, fuzzy, kde-format
 #| msgid "&Go To..."
 msgid "Go to…"
 msgstr "&Gean nei..."
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, fuzzy, kde-format
 #| msgid "Search:"
 msgid "Search…"
 msgstr "Sykje:"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "Kategory:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, fuzzy, kde-format
 #| msgid "Continue operation"
 msgid "Contribute your own…"
 msgstr "Operaasje trochsette"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, fuzzy, kde-format
 #| msgctxt "@note/rich"
 #| msgid "<i>Note</i>: %1"
@@ -675,7 +683,7 @@ msgctxt ""
 msgid "<i>(no title)</i>"
 msgstr "<i>Notysje</i>: %1"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -683,20 +691,20 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "Alles kategoryen"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -704,7 +712,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -712,8 +720,8 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, fuzzy, kde-format
 #| msgid "1 download"
 #| msgid_plural "%1 downloads"
@@ -721,8 +729,8 @@ msgctxt "The number of times the item ha
 msgid "%1 downloads"
 msgstr "1 ynlaad"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, fuzzy, kde-format
 #| msgctxt "Show the author of this item in a list"
 #| msgid "By <i>%1</i>"
@@ -732,7 +740,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "Troch <i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -740,7 +748,7 @@ msgctxt ""
 msgid "Working…"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, fuzzy, kde-format
 #| msgid "Updating"
 msgctxt ""
@@ -749,7 +757,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "Fernijen is geande"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -760,7 +768,7 @@ msgid ""
 "bug report</a>."
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt "Label for the busy indicator showing an item is installing"
@@ -779,14 +787,14 @@ msgstr ""
 msgid "Please try again later."
 msgstr "Graach namme ynfiere."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, fuzzy, kde-format
 #| msgctxt "No border line"
 #| msgid "None"
 msgid "None"
 msgstr "Gjint"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, fuzzy, kde-format
 #| msgid "(%1/s)"
 msgctxt ""
@@ -794,14 +802,14 @@ msgctxt ""
 msgid "(%1/%2)"
 msgstr "(%1/s)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, fuzzy, kde-format
 #| msgid "Download New Stuff..."
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "Nij guod ynlade..."
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, fuzzy, kde-format
 #| msgid "Billing information:"
 msgctxt ""
@@ -809,21 +817,21 @@ msgctxt ""
 msgid "Updating information…"
 msgstr "Rekkening ynformaasje:"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, fuzzy, kde-format
 #| msgid "&Store"
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "&Bewarje"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, fuzzy, kde-format
 #| msgid "Provider:"
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "Ferskaffer:"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, fuzzy, kde-format
 #| msgctxt "@label:button"
 #| msgid "&Open with %1"
@@ -833,7 +841,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "&Iepenje mei %1"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, fuzzy, kde-format
 #| msgid "&Send Email"
 msgctxt ""
@@ -842,7 +850,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "&Stjoer E-post"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -850,10 +858,10 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -865,18 +873,18 @@ msgid ""
 "content added."
 msgstr ""
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "Gegevens wurde laden"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "Ynstallaasje is geande"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -886,7 +894,7 @@ msgid ""
 "please contact the person in charge of your permissions."
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Back"
@@ -894,20 +902,20 @@ msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "Tebek"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, fuzzy, kde-format
 #| msgid "Saturday"
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "sneon"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, fuzzy, kde-format
 #| msgctxt "@action:button Restart find & replace"
 #| msgid "Restart"
@@ -915,7 +923,7 @@ msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "Op'e nij starte"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "New"
@@ -923,7 +931,7 @@ msgctxt "Knewstuff5"
 msgid "New"
 msgstr "Nij"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Home"
@@ -931,13 +939,13 @@ msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Home"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Up"
@@ -945,7 +953,7 @@ msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "Up"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, fuzzy, kde-format
 #| msgctxt "dictionary variant"
 #| msgid "extended"
@@ -953,7 +961,7 @@ msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "Utwreid"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Subscript"
@@ -961,14 +969,14 @@ msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "Underskriuwen"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "Alles kategoryen"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -999,10 +1007,15 @@ msgid ""
 msgstr ""
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
-#, kde-format
-msgid "Download New Stuff..."
+#, fuzzy, kde-format
+#| msgid "Download New Stuff..."
+msgctxt "@action"
+msgid "Download New Stuff…"
 msgstr "Nij guod ynlade..."
 
+#~ msgid "Download New Stuff..."
+#~ msgstr "Nij guod ynlade..."
+
 #~ msgid "Initializing"
 #~ msgstr "Tariede"
 
diff -pruN 6.0.0-3/po/ga/knewstuff6.po 6.3.0-1/po/ga/knewstuff6.po
--- 6.0.0-3/po/ga/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/ga/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -8,7 +8,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2004-12-14 09:11-0600\n"
 "Last-Translator: Kevin Scannell <kscanne@gmail.com>\n"
 "Language-Team: Irish <gaeilge-gnulinux@lists.sourceforge.net>\n"
@@ -59,7 +59,7 @@ msgstr "Taifeadadh do vóta."
 msgid "You are now a fan."
 msgstr "Tá tú i do leantóir anois."
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -129,7 +129,7 @@ msgstr "Comhad cumraíochta neamhbhailí
 msgid "Use"
 msgstr "Díscáthaigh"
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -137,17 +137,17 @@ msgid ""
 "This is a critical error and should be reported to the application author"
 msgstr ""
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr "Soláthraithe á luchtú ó chomhad: %1 teipthe"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr "Níorbh fhéidir Soláthraithe Stuif Nuaí a luchtú ó chomhad: %1"
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr "Earráid agus an soláthraí á thúsú."
@@ -292,7 +292,7 @@ msgid ""
 "the update"
 msgstr ""
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, fuzzy, kde-format
 #| msgid "Failed to load file '%1'"
 msgid ""
@@ -300,7 +300,7 @@ msgid ""
 "%2"
 msgstr "Níorbh fhéidir comhad '%1' a luchtú"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt ""
@@ -308,7 +308,7 @@ msgctxt ""
 msgid "All Categories"
 msgstr "Gach Catagóir"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, fuzzy, kde-format
 #| msgid "Unknown error"
 msgctxt ""
@@ -334,14 +334,14 @@ msgstr ""
 msgid "Download New %1…"
 msgstr "Íosluchtaigh %1 Nua"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, fuzzy, kde-format
 #| msgid "Download New %1"
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "Íosluchtaigh %1 Nua"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, fuzzy, kde-format
 #| msgid "Download New Stuff..."
 msgctxt ""
@@ -350,13 +350,13 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "Íosluchtaigh Stuif Nua..."
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, fuzzy, kde-format
 #| msgid "Resource Installation Error"
 msgid "Pick Your Installation Option"
 msgstr "Earráid Shuiteála Acmhainní"
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -365,12 +365,12 @@ msgid ""
 "this through the naming of the items."
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "Suiteáil"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt ""
@@ -378,7 +378,7 @@ msgctxt ""
 msgid "Installing %1 from %2"
 msgstr "Á Shuiteáil"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -386,10 +386,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -398,10 +398,10 @@ msgctxt ""
 msgid "Install"
 msgstr "Suiteáil"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -409,24 +409,24 @@ msgctxt ""
 msgid "Install…"
 msgstr "Suiteáil"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, fuzzy, kde-format
 #| msgid "Update"
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "Nuashonraigh"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, fuzzy, kde-format
 #| msgid "Uninstall"
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "Díshuiteáil"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -434,14 +434,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -452,12 +452,12 @@ msgid ""
 "to the KDE Community in a bug report</a>."
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, fuzzy, kde-format
 #| msgid "View Comments"
 msgctxt ""
@@ -466,19 +466,19 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "Amharc ar Nótaí"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, fuzzy, kde-format
 #| msgid "Rating: "
 msgid "Rating:"
 msgstr "Rátáil:"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, fuzzy, kde-format
 #| msgid "Homepage"
 msgid "Homepage:"
 msgstr "Leathanach Baile"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -487,12 +487,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -500,72 +500,80 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr ""
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, fuzzy, kde-format
 #| msgid "&Tile"
 msgid "Tiles"
 msgstr "&Tíl"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "Deilbhíní"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, fuzzy, kde-format
 #| msgid "No Preview"
 msgid "Preview"
 msgstr "Gan Réamhamharc"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, fuzzy, kde-format
 #| msgid "Detailed Tree View"
 msgid "Detailed Tiles View Mode"
 msgstr "Amharc Mionsonraithe Crainn"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, fuzzy, kde-format
 #| msgid "Icons view mode"
 msgid "Icons Only View Mode"
 msgstr "Amharc le Deilbhíní"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, fuzzy, kde-format
 #| msgid "Details view mode"
 msgid "Large Preview View Mode"
 msgstr "Amharc Mionsonraithe"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr ""
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "Suiteáilte"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, fuzzy, kde-format
 #| msgid "Update"
 msgid "Updateable"
 msgstr "Nuashonraigh"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, fuzzy, kde-format
 #| msgid "&Show All Entries"
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "&Taispeáin Gach Iontráil"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, fuzzy, kde-format
 #| msgid "&Show All Entries"
 msgctxt ""
@@ -573,7 +581,7 @@ msgctxt ""
 msgid "Show Only Installed Entries"
 msgstr "&Taispeáin Gach Iontráil"
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, fuzzy, kde-format
 #| msgid "&Show All Entries"
 msgctxt ""
@@ -582,30 +590,30 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr "&Taispeáin Gach Iontráil"
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, fuzzy, kde-format
 #| msgctxt "QAccel"
 #| msgid "Percent"
 msgid "Recent"
 msgstr "Comhartha Céatadáin"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr ""
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "Rátáil"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, fuzzy, kde-format
 #| msgid "Download"
 msgid "Downloads"
 msgstr "Íosluchtaigh"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt ""
@@ -614,7 +622,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "Taispeáin comhadlanna ag an mbarr"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -622,14 +630,14 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr ""
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "Taispeáin comhadlanna ag an mbarr"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, fuzzy, kde-format
 #| msgid "Most downloads"
 msgctxt ""
@@ -637,41 +645,41 @@ msgctxt ""
 msgid "Show Most Downloaded First"
 msgstr "An líon is mó íosluchtuithe"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, fuzzy, kde-format
 #| msgid "Upload..."
 msgid "Upload…"
 msgstr "Uasluchtaigh..."
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr ""
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, fuzzy, kde-format
 #| msgid "&Go To..."
 msgid "Go to…"
 msgstr "&Téigh go..."
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, fuzzy, kde-format
 #| msgid "Search:"
 msgid "Search…"
 msgstr "Cuardaigh:"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "Catagóir:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, fuzzy, kde-format
 #| msgid "Continue operation"
 msgid "Contribute your own…"
 msgstr "Lean leis an oibríocht"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, fuzzy, kde-format
 #| msgctxt "@note/rich"
 #| msgid "<i>Note</i>: %1"
@@ -680,7 +688,7 @@ msgctxt ""
 msgid "<i>(no title)</i>"
 msgstr "<i>Nóta</i>: %1"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -688,20 +696,20 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "Gach Catagóir"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, fuzzy, kde-format
 #| msgid "Show Preview"
 msgctxt ""
@@ -710,7 +718,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr "Taispeáin Réamhamharc"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -718,8 +726,8 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, fuzzy, kde-format
 #| msgid "1 download"
 #| msgid_plural "%1 downloads"
@@ -727,8 +735,8 @@ msgctxt "The number of times the item ha
 msgid "%1 downloads"
 msgstr "1 íosluchtú"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, fuzzy, kde-format
 #| msgctxt "Show the author of this item in a list"
 #| msgid "By <i>%1</i>"
@@ -738,7 +746,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "Le <i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -746,7 +754,7 @@ msgctxt ""
 msgid "Working…"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, fuzzy, kde-format
 #| msgid "Updating"
 msgctxt ""
@@ -755,7 +763,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "Á Nuashonrú"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -766,7 +774,7 @@ msgid ""
 "bug report</a>."
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt "Label for the busy indicator showing an item is installing"
@@ -787,14 +795,14 @@ msgstr "ní raibh aon earráid"
 msgid "Please try again later."
 msgstr "Iontráil ainm, le do thoil."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, fuzzy, kde-format
 #| msgctxt "No border line"
 #| msgid "None"
 msgid "None"
 msgstr "Gan Imlíne"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, fuzzy, kde-format
 #| msgid "(%1/s)"
 msgctxt ""
@@ -802,14 +810,14 @@ msgctxt ""
 msgid "(%1/%2)"
 msgstr "(%1/s)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, fuzzy, kde-format
 #| msgid "Download New Stuff..."
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "Íosluchtaigh Stuif Nua..."
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, fuzzy, kde-format
 #| msgid "Billing information:"
 msgctxt ""
@@ -817,21 +825,21 @@ msgctxt ""
 msgid "Updating information…"
 msgstr "Faisnéis bhilleála:"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, fuzzy, kde-format
 #| msgid "&Store"
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "&Stóráil"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, fuzzy, kde-format
 #| msgid "Provider:"
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "Soláthraí:"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, fuzzy, kde-format
 #| msgid ""
 #| "\n"
@@ -848,7 +856,7 @@ msgstr ""
 "Suíomh Gréasáin:\n"
 "%1"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, fuzzy, kde-format
 #| msgid "&Send Email"
 msgctxt ""
@@ -857,7 +865,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "&Seol Ríomhphost"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -865,10 +873,10 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -880,18 +888,18 @@ msgid ""
 "content added."
 msgstr ""
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "Sonraí á luchtú"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "Á Shuiteáil"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -901,7 +909,7 @@ msgid ""
 "please contact the person in charge of your permissions."
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Back"
@@ -909,20 +917,20 @@ msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "Siar"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, fuzzy, kde-format
 #| msgid "Saturday"
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "Satharn"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, fuzzy, kde-format
 #| msgctxt "@action:button Restart find & replace"
 #| msgid "Restart"
@@ -930,7 +938,7 @@ msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "Atosaigh"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "New"
@@ -938,7 +946,7 @@ msgctxt "Knewstuff5"
 msgid "New"
 msgstr "Nua"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Home"
@@ -946,13 +954,13 @@ msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Home"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Up"
@@ -960,7 +968,7 @@ msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "Up"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, fuzzy, kde-format
 #| msgctxt "dictionary variant"
 #| msgid "extended"
@@ -968,7 +976,7 @@ msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "breisithe"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Subscript"
@@ -976,14 +984,14 @@ msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "Foscript"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, fuzzy, kde-format
 #| msgid "&Show All Entries"
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "&Taispeáin Gach Iontráil"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -1014,10 +1022,15 @@ msgid ""
 msgstr ""
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
-#, kde-format
-msgid "Download New Stuff..."
+#, fuzzy, kde-format
+#| msgid "Download New Stuff..."
+msgctxt "@action"
+msgid "Download New Stuff…"
 msgstr "Íosluchtaigh Stuif Nua..."
 
+#~ msgid "Download New Stuff..."
+#~ msgstr "Íosluchtaigh Stuif Nua..."
+
 #~ msgid "Initializing"
 #~ msgstr "Á Thúsú"
 
diff -pruN 6.0.0-3/po/gd/knewstuff6.po 6.3.0-1/po/gd/knewstuff6.po
--- 6.0.0-3/po/gd/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/gd/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -6,7 +6,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: \n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2015-11-04 15:13+0000\n"
 "Last-Translator: Michael Bauer <fios@akerbeltz.org>\n"
 "Language-Team: Fòram na Gàidhlig\n"
@@ -58,7 +58,7 @@ msgstr "Chaidh a' bhòt agad a chlàradh
 msgid "You are now a fan."
 msgstr "Tha thu 'ga leantainn a-nis."
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -127,7 +127,7 @@ msgstr "Chan eil am faidhle rèiteachaid
 msgid "Use"
 msgstr ""
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -135,19 +135,19 @@ msgid ""
 "This is a critical error and should be reported to the application author"
 msgstr ""
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr "Dh'fhàillig le luchdadh nan solaraichean on fhaidhle: %1"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr ""
 "Cha b' urrainn dhuinn solaraichean deagh-stuith ùir a luchdadh on fhaidhle: "
 "%1"
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr "Mearachd le tòiseachadh an t-solaraiche."
@@ -291,14 +291,14 @@ msgid ""
 "the update"
 msgstr ""
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, kde-format
 msgid ""
 "Failed to adopt '%1'\n"
 "%2"
 msgstr ""
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt ""
@@ -306,7 +306,7 @@ msgctxt ""
 msgid "All Categories"
 msgstr "A h-uile roinn-seòrsa"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, fuzzy, kde-format
 #| msgid "Category:"
 msgctxt ""
@@ -332,14 +332,14 @@ msgstr ""
 msgid "Download New %1…"
 msgstr "Luchdaich a-nuas stuth ùr..."
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, fuzzy, kde-format
 #| msgid "Download New Stuff..."
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "Luchdaich a-nuas stuth ùr..."
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, fuzzy, kde-format
 #| msgid "Download New Stuff..."
 msgctxt ""
@@ -348,12 +348,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "Luchdaich a-nuas stuth ùr..."
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -362,12 +362,12 @@ msgid ""
 "this through the naming of the items."
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "Stàlaich"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt ""
@@ -375,7 +375,7 @@ msgctxt ""
 msgid "Installing %1 from %2"
 msgstr "'Ga stàladh"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -383,10 +383,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -395,10 +395,10 @@ msgctxt ""
 msgid "Install"
 msgstr "Stàlaich"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -406,24 +406,24 @@ msgctxt ""
 msgid "Install…"
 msgstr "Stàlaich"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, fuzzy, kde-format
 #| msgid "Update"
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "Ùraich"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, fuzzy, kde-format
 #| msgid "Uninstall"
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "Dì-stàlaich"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -431,14 +431,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -449,12 +449,12 @@ msgid ""
 "to the KDE Community in a bug report</a>."
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a new sub page with comments (comments "
@@ -462,20 +462,20 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, fuzzy, kde-format
 #| msgid "Rating"
 msgid "Rating:"
 msgstr "Rangachadh"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, fuzzy, kde-format
 #| msgctxt "A link to the description of this Get Hot New Stuff item"
 #| msgid "Homepage"
 msgid "Homepage:"
 msgstr "Duilleag-dhachaigh"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -484,12 +484,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -497,78 +497,86 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr ""
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, kde-format
 msgid "Tiles"
 msgstr ""
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr ""
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, fuzzy, kde-format
 #| msgid "Preview Images"
 msgid "Preview"
 msgstr "Dealbhan ro-sheallaidh"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, fuzzy, kde-format
 #| msgid "Details view mode"
 msgid "Detailed Tiles View Mode"
 msgstr "Modh sealladh an fhiosrachaidh"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, fuzzy, kde-format
 #| msgid "Icons view mode"
 msgid "Icons Only View Mode"
 msgstr "Modh sealladh nan ìomhaigheagan"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, fuzzy, kde-format
 #| msgid "Details view mode"
 msgid "Large Preview View Mode"
 msgstr "Modh sealladh an fhiosrachaidh"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr ""
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "Air a stàladh"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, fuzzy, kde-format
 #| msgid "Update"
 msgid "Updateable"
 msgstr "Ùraich"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "A h-uile roinn-seòrsa"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -576,29 +584,29 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, kde-format
 msgid "Recent"
 msgstr ""
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr ""
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "Rangachadh"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, fuzzy, kde-format
 #| msgid "1 download"
 #| msgid_plural "%1 downloads"
 msgid "Downloads"
 msgstr "%1 luchdadh a-nuas"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, fuzzy, kde-format
 #| msgid "Most downloads"
 msgctxt ""
@@ -607,7 +615,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "Air a luchdadh a-nuas as trice"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -615,14 +623,14 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr ""
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, fuzzy, kde-format
 #| msgid "Most downloads"
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "Air a luchdadh a-nuas as trice"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, fuzzy, kde-format
 #| msgid "Most downloads"
 msgctxt ""
@@ -630,46 +638,46 @@ msgctxt ""
 msgid "Show Most Downloaded First"
 msgstr "Air a luchdadh a-nuas as trice"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, fuzzy, kde-format
 #| msgid "New Upload"
 msgid "Upload…"
 msgstr "Luchdadh suas ùr"
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr ""
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, kde-format
 msgid "Go to…"
 msgstr ""
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, fuzzy, kde-format
 #| msgid "Search:"
 msgid "Search…"
 msgstr "Lorg:"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "Roinn-seòrsa:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, kde-format
 msgid "Contribute your own…"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, kde-format
 msgctxt ""
 "Placeholder title for when a comment has no subject, but does have a rating"
 msgid "<i>(no title)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -677,20 +685,20 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "A h-uile roinn-seòrsa"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -698,7 +706,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -706,8 +714,8 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, fuzzy, kde-format
 #| msgid "1 download"
 #| msgid_plural "%1 downloads"
@@ -715,8 +723,8 @@ msgctxt "The number of times the item ha
 msgid "%1 downloads"
 msgstr "%1 luchdadh a-nuas"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, fuzzy, kde-format
 #| msgctxt "Show the author of this item in a list"
 #| msgid "By <i>%1</i>"
@@ -726,7 +734,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "Le <i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -734,7 +742,7 @@ msgctxt ""
 msgid "Working…"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, fuzzy, kde-format
 #| msgid "Updating"
 msgctxt ""
@@ -743,7 +751,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "'Ga ùrachadh"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -754,7 +762,7 @@ msgid ""
 "bug report</a>."
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt "Label for the busy indicator showing an item is installing"
@@ -772,26 +780,26 @@ msgstr ""
 msgid "Please try again later."
 msgstr ""
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, kde-format
 msgid "None"
 msgstr ""
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, kde-format
 msgctxt ""
 "A text representation of the rating, shown as a fraction of the max value"
 msgid "(%1/%2)"
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, fuzzy, kde-format
 #| msgid "Download New Stuff..."
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "Luchdaich a-nuas stuth ùr..."
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, fuzzy, kde-format
 #| msgid "Fetching provider information..."
 msgctxt ""
@@ -799,20 +807,20 @@ msgctxt ""
 msgid "Updating information…"
 msgstr "A' faighinn fiosrachadh an t-solaraiche..."
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, kde-format
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, fuzzy, kde-format
 #| msgid "Provider:"
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "Solaraiche:"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, kde-format
 msgctxt ""
 "Text for an action which causes the specified website to be opened using the "
@@ -820,7 +828,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, kde-format
 msgctxt ""
 "Text for an action which will attempt to send an email using the user's "
@@ -828,7 +836,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -836,10 +844,10 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -851,18 +859,18 @@ msgid ""
 "content added."
 msgstr ""
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "A' luchdadh dàta"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "'Ga stàladh"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -872,38 +880,38 @@ msgid ""
 "please contact the person in charge of your permissions."
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Back"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, fuzzy, kde-format
 #| msgid "Newest"
 msgctxt "Knewstuff5"
 msgid "New"
 msgstr "As ùire"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, fuzzy, kde-format
 #| msgctxt "A link to the description of this Get Hot New Stuff item"
 #| msgid "Homepage"
@@ -911,39 +919,39 @@ msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Duilleag-dhachaigh"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Up"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, fuzzy, kde-format
 #| msgid "Description:"
 msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "Tuairisgeul:"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "A h-uile roinn-seòrsa"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -974,10 +982,15 @@ msgid ""
 msgstr ""
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
-#, kde-format
-msgid "Download New Stuff..."
+#, fuzzy, kde-format
+#| msgid "Download New Stuff..."
+msgctxt "@action"
+msgid "Download New Stuff…"
 msgstr "Luchdaich a-nuas stuth ùr..."
 
+#~ msgid "Download New Stuff..."
+#~ msgstr "Luchdaich a-nuas stuth ùr..."
+
 #~ msgid "Initializing"
 #~ msgstr "'Ga thòiseachadh"
 
diff -pruN 6.0.0-3/po/gl/knewstuff6.po 6.3.0-1/po/gl/knewstuff6.po
--- 6.0.0-3/po/gl/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/gl/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -15,8 +15,8 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
-"PO-Revision-Date: 2024-01-22 18:51+0100\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
+"PO-Revision-Date: 2024-05-09 19:21+0200\n"
 "Last-Translator: Adrián Chaves (Gallaecio) <adrian@chaves.io>\n"
 "Language-Team: Proxecto Trasno (proxecto@trasno.gal)\n"
 "Language: gl\n"
@@ -24,7 +24,7 @@ msgstr ""
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=2; plural=n != 1;\n"
-"X-Generator: Lokalize 23.08.4\n"
+"X-Generator: Lokalize 24.02.2\n"
 
 #: attica/atticaprovider.cpp:165
 #, kde-format
@@ -64,7 +64,7 @@ msgstr "Rexistrouse o seu voto."
 msgid "You are now a fan."
 msgstr "Agora é o seu fan."
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -135,7 +135,7 @@ msgstr "O ficheiro de configuración é
 msgid "Use"
 msgstr "Usar"
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -147,17 +147,17 @@ msgstr ""
 "Trátase dun erro crítico e defería informal del ao equipo desenvolvedor da "
 "aplicación."
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr "Carga dos fornecedores desde o ficheiro: %1 fallou"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr "Non foi posíbel obter fornecedores de novidades do ficheiro: %1"
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr "Produciuse un erro ao inicializar o fornecedor."
@@ -330,7 +330,7 @@ msgstr ""
 "Non foi posíbel identificar unha ligazón axeitada para actualizar %1, e non "
 "é posíbel realizar a actualización."
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, kde-format
 msgid ""
 "Failed to adopt '%1'\n"
@@ -339,14 +339,14 @@ msgstr ""
 "Non foi posíbel adoptar «%1».\n"
 "%2"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, kde-format
 msgctxt ""
 "The first entry in the category selection list (also the default value)"
 msgid "All Categories"
 msgstr "Todas as categorías"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, kde-format
 msgctxt ""
 "The string passed back in the case the requested category is not known"
@@ -370,13 +370,13 @@ msgstr "cousas"
 msgid "Download New %1…"
 msgstr "Descargar %1…"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, kde-format
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "Descargar %1"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, kde-format
 msgctxt ""
 "A placeholder title used in the dialog when there is no better title "
@@ -384,12 +384,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "Descargar cousas"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr "Escolla a súa opción de instalación"
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -402,19 +402,19 @@ msgstr ""
 "contacte co autor do elemento e pídalle que clarifique o nome dos elementos "
 "para que quede máis claro."
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "Instalar"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, kde-format
 msgctxt ""
 "A passive notification shown when installation of an item is initiated"
 msgid "Installing %1 from %2"
 msgstr "Instalando %1 de %2"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -422,10 +422,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr "%1 de %2"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, kde-format
 msgctxt ""
 "Request installation of this item, available when there is exactly one "
@@ -433,32 +433,32 @@ msgctxt ""
 msgid "Install"
 msgstr "Instalar"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, kde-format
 msgctxt ""
 "Show installation options, where there is more than one downloadable item"
 msgid "Install…"
 msgstr "Instalar…"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, kde-format
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "Actualizar"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, kde-format
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "Desinstalar"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -466,14 +466,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr "Traballando no elemento %1 de %2. Agarde…"
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr "Actualizando o elemento %1 de %2. Agarde…"
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -487,12 +487,12 @@ msgstr ""
 "bugs.kde.org/enter_bug.cgi?product=frameworks-knewstuff\">Informe disto á "
 "comunidade KDE mediante un informe de fallo</a>."
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr "Comentarios e recensións:"
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a new sub page with comments (comments "
@@ -500,17 +500,17 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "%1 recensións e comentarios"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, kde-format
 msgid "Rating:"
 msgstr "Cualificación:"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, kde-format
 msgid "Homepage:"
 msgstr "Páxina web:"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -519,12 +519,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr "Abrir a páxina principal de %1"
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr "Como doar:"
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -532,74 +532,85 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr "Descubra como doar a este proxecto"
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+"Teña coidado ao acceder a este contido creado por persoas usuarias. Pode "
+"conter código executábel, e nin KDE nin o seu distribuidor comprobaron a súa "
+"seguridade, estabilidade ou calidade."
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
-"Este contido subírono persoas coma vostede, e a súa funcionalidade e "
-"estabilidade non as revisou o equipo da súa distribución."
+"Nin KDE nin o seu distribuidor comprobaron a funcionalidade ou calidade "
+"deste contido creado por persoas usuarias."
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, kde-format
 msgid "Tiles"
 msgstr "Teselas"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "Iconas"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, kde-format
 msgid "Preview"
 msgstr "Vista previa"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, kde-format
 msgid "Detailed Tiles View Mode"
 msgstr "Modo detallado de vista de teselas"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, kde-format
 msgid "Icons Only View Mode"
 msgstr "Modo de vista de só iconas"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, kde-format
 msgid "Large Preview View Mode"
 msgstr "Modo de vista de vista previa grande"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr "Todo"
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "Instalado"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, kde-format
 msgid "Updateable"
 msgstr "Actualizábel"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, kde-format
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "Amosar todas as entradas"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr "Amosar só as entradas instaladas"
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -607,27 +618,27 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr "Amosar só as entradas actualizábeis"
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, kde-format
 msgid "Recent"
 msgstr "Recentes"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr "Alfabeticamente"
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "Cualificación"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, kde-format
 msgid "Downloads"
 msgstr "Descargas"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on when items were most "
@@ -635,7 +646,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "Amosar primeiro o máis recente"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -643,57 +654,57 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr "Ordenar alfabeticamente por nome"
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, kde-format
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "Amosar primeiro o de mellor cualificación"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on number of downloads"
 msgid "Show Most Downloaded First"
 msgstr "Amosar primeiro o máis descargado"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, kde-format
 msgid "Upload…"
 msgstr "Enviar…"
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr "Aprenda a engadir as súas cousas á lista"
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, kde-format
 msgid "Go to…"
 msgstr "Ir a…"
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, kde-format
 msgid "Search…"
 msgstr "Buscar…"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "Categoría:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, kde-format
 msgid "Contribute your own…"
 msgstr "Contribuír o seu…"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, kde-format
 msgctxt ""
 "Placeholder title for when a comment has no subject, but does have a rating"
 msgid "<i>(no title)</i>"
 msgstr "<i>(sen título)</i>"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -701,19 +712,19 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr "%1 <i>(autor)</i>"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr "Comentarios e recensións de %1"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, kde-format
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "Amosar todos os comentarios"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -721,7 +732,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr "Amosar só as recensións"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -729,15 +740,15 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr "Amosar as recensións e as respostas"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, kde-format
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
 msgstr "%1 descargas"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, kde-format
 msgctxt ""
 "Subheading for the tile view, located immediately underneath the name of the "
@@ -745,7 +756,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "Por <i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -753,7 +764,7 @@ msgctxt ""
 msgid "Working…"
 msgstr "Traballando…"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is in the process of being "
@@ -761,7 +772,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "Actualizando…"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -775,7 +786,7 @@ msgstr ""
 "cgi?product=frameworks-knewstuff\">Informe disto á comunidade KDE mediante "
 "un informe de fallo</a>."
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, kde-format
 msgctxt "Label for the busy indicator showing an item is installing"
 msgid "Installing…"
@@ -792,44 +803,44 @@ msgstr "Produciuse un erro"
 msgid "Please try again later."
 msgstr "Inténteo de novo máis tarde."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, kde-format
 msgid "None"
 msgstr "Ningún"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, kde-format
 msgctxt ""
 "A text representation of the rating, shown as a fraction of the max value"
 msgid "(%1/%2)"
 msgstr "(%1/%2)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, kde-format
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "Enviar cousas: %1"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, kde-format
 msgctxt ""
 "A text shown beside a busy indicator suggesting that data is being fetched"
 msgid "Updating information…"
 msgstr "Actualizando a información…"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, kde-format
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "Tenda de KDE"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, kde-format
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "Fornecedor"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, kde-format
 msgctxt ""
 "Text for an action which causes the specified website to be opened using the "
@@ -837,7 +848,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "Ir ao sitio web: %1"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, kde-format
 msgctxt ""
 "Text for an action which will attempt to send an email using the user's "
@@ -845,7 +856,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "Contactar: %1"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -853,7 +864,7 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 "Para enviar novas entradas ou para engadir contido a unha entrada existente "
 "da tenda de KDE abra o sitio web e identifíquese. Despois poderá atopar a "
@@ -861,7 +872,7 @@ msgstr ""
 "persoa usuaria. Prema esa entrada para ir ao sistema de xestión de produtos, "
 "desde onde pode traballar nos seus."
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -879,18 +890,18 @@ msgstr ""
 "que se lle esixa contactar directamente coas persoas que xestionan o sitio "
 "para que engadan o seu contido."
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "Estanse a cargar os datos"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "Instalando"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -902,73 +913,73 @@ msgstr ""
 "Non ten autorización para usar Get Hot New Stuff. Se pensa que se trata dun "
 "erro, contacte coa persoa responsábel dos seus permisos."
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "Atrás"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr "Popular"
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "Promoción"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "Reiniciar"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "New"
 msgstr "Nova"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Inicio"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr "Estante"
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "Subir"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "Recomendación"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "Subscricións"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "Todas as entradas"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -1014,9 +1025,13 @@ msgstr ""
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
 #, kde-format
-msgid "Download New Stuff..."
+msgctxt "@action"
+msgid "Download New Stuff…"
 msgstr "Descargar novidades…"
 
+#~ msgid "Download New Stuff..."
+#~ msgstr "Descargar novidades…"
+
 #~ msgctxt ""
 #~ "A message which is shown when the user attempts to display a specific "
 #~ "entry from a specific provider, but that entry isn't found"
diff -pruN 6.0.0-3/po/gu/knewstuff6.po 6.3.0-1/po/gu/knewstuff6.po
--- 6.0.0-3/po/gu/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/gu/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -7,7 +7,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2009-11-22 00:01+0530\n"
 "Last-Translator: Kartik Mistry <kartik.mistry@gmail.com>\n"
 "Language-Team: Gujarati <team@utkarsh.org>\n"
@@ -53,7 +53,7 @@ msgstr "તમારો મત સફળ
 msgid "You are now a fan."
 msgstr "તમે હવે ચાહક છો."
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -121,7 +121,7 @@ msgstr "રુપરેખાંકન 
 msgid "Use"
 msgstr ""
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -129,17 +129,17 @@ msgid ""
 "This is a critical error and should be reported to the application author"
 msgstr ""
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr ""
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr ""
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr ""
@@ -285,7 +285,7 @@ msgid ""
 "the update"
 msgstr ""
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, fuzzy, kde-format
 #| msgid "Failed to load file '%1'"
 msgid ""
@@ -293,7 +293,7 @@ msgid ""
 "%2"
 msgstr "ફાઈલ '%1' લાવવામાં નિષ્ફળતા"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt ""
@@ -301,7 +301,7 @@ msgctxt ""
 msgid "All Categories"
 msgstr "બધાં વર્ગો"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, fuzzy, kde-format
 #| msgid "Unknown error"
 msgctxt ""
@@ -327,14 +327,14 @@ msgstr ""
 msgid "Download New %1…"
 msgstr "નવું %1 ડાઉનલોડ કરો"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, fuzzy, kde-format
 #| msgid "Download New %1"
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "નવું %1 ડાઉનલોડ કરો"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
 msgctxt ""
@@ -343,12 +343,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "નવી વસ્તુ ડાઉનલોડ કરો"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -357,12 +357,12 @@ msgid ""
 "this through the naming of the items."
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "સ્થાપન"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt ""
@@ -370,7 +370,7 @@ msgctxt ""
 msgid "Installing %1 from %2"
 msgstr "સ્થાપન કરે છે"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -378,10 +378,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -390,10 +390,10 @@ msgctxt ""
 msgid "Install"
 msgstr "સ્થાપન"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -401,24 +401,24 @@ msgctxt ""
 msgid "Install…"
 msgstr "સ્થાપન"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, fuzzy, kde-format
 #| msgid "Update"
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "સુધારો"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, fuzzy, kde-format
 #| msgid "Uninstall"
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "અસ્થાપન"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -426,14 +426,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -444,12 +444,12 @@ msgid ""
 "to the KDE Community in a bug report</a>."
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, fuzzy, kde-format
 #| msgid "View Comments"
 msgctxt ""
@@ -458,19 +458,19 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "ટિપ્પણીઓ જુઓ"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, fuzzy, kde-format
 #| msgid "Rating: "
 msgid "Rating:"
 msgstr "યોગ્યતા: "
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, fuzzy, kde-format
 #| msgid "Homepage"
 msgid "Homepage:"
 msgstr "ઘર પાનું"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -479,12 +479,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -492,79 +492,87 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr ""
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, fuzzy, kde-format
 #| msgctxt "@option:check Do filter on type - show only files"
 #| msgid "Files"
 msgid "Tiles"
 msgstr "ફાઇલ્સ"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "ચિહ્નો"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, fuzzy, kde-format
 #| msgid "Previews"
 msgid "Preview"
 msgstr "પૂર્વદર્શનો"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, kde-format
 msgid "Detailed Tiles View Mode"
 msgstr ""
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, fuzzy, kde-format
 #| msgid "Icons Only"
 msgid "Icons Only View Mode"
 msgstr "ફકત ચિહ્નો"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, fuzzy, kde-format
 #| msgid "Preview Images"
 msgid "Large Preview View Mode"
 msgstr "પૂર્વદર્શન ચિત્રો"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr ""
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "સ્થાપિત"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, fuzzy, kde-format
 #| msgid "Update"
 msgid "Updateable"
 msgstr "સુધારો"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "બધાં વર્ગો"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -572,30 +580,30 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Open Recent"
 msgid "Recent"
 msgstr "તાજેતરનું ખોલો"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr ""
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "યોગ્યતા"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, fuzzy, kde-format
 #| msgid "Download"
 msgid "Downloads"
 msgstr "ડાઉનલોડ"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt ""
@@ -604,7 +612,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "ડિરેક્ટરીઓ પ્રથમ બતાવો"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -612,14 +620,14 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr ""
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "ડિરેક્ટરીઓ પ્રથમ બતાવો"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, fuzzy, kde-format
 #| msgid "Most downloads"
 msgctxt ""
@@ -627,41 +635,41 @@ msgctxt ""
 msgid "Show Most Downloaded First"
 msgstr "સૌથી વધુ ડાઉનલોડ"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, fuzzy, kde-format
 #| msgid "Upload..."
 msgid "Upload…"
 msgstr "અપલોડ..."
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr ""
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, fuzzy, kde-format
 #| msgid "&Go To..."
 msgid "Go to…"
 msgstr "પ્રતિ જાઓ. (&G).."
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, fuzzy, kde-format
 #| msgid "Search:"
 msgid "Search…"
 msgstr "શોધો:"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "વર્ગ:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, fuzzy, kde-format
 #| msgid "Continue operation"
 msgid "Contribute your own…"
 msgstr "પ્રક્રિયા ચાલુ રાખો"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, fuzzy, kde-format
 #| msgctxt "@note/rich"
 #| msgid "<i>Note</i>: %1"
@@ -670,7 +678,7 @@ msgctxt ""
 msgid "<i>(no title)</i>"
 msgstr "<i>નોંધ</i>: %1"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -678,20 +686,20 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "બધાં વર્ગો"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -699,7 +707,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -707,16 +715,16 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, fuzzy, kde-format
 #| msgid "Download"
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
 msgstr "ડાઉનલોડ"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, fuzzy, kde-format
 #| msgctxt "Show the author of this item in a list"
 #| msgid "By <i>%1</i>"
@@ -726,7 +734,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "<i>%1</i> વડે"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -734,7 +742,7 @@ msgctxt ""
 msgid "Working…"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, fuzzy, kde-format
 #| msgid "Updating"
 msgctxt ""
@@ -743,7 +751,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "સુધારે છે"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -754,7 +762,7 @@ msgid ""
 "bug report</a>."
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt "Label for the busy indicator showing an item is installing"
@@ -773,14 +781,14 @@ msgstr ""
 msgid "Please try again later."
 msgstr "મહેરબાની કરીને અહીં નામ મૂકો."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, fuzzy, kde-format
 #| msgctxt "No border line"
 #| msgid "None"
 msgid "None"
 msgstr "કંઇ નહી"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, fuzzy, kde-format
 #| msgid "(%1/s)"
 msgctxt ""
@@ -788,14 +796,14 @@ msgctxt ""
 msgid "(%1/%2)"
 msgstr "(%1/s)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "નવી વસ્તુ ડાઉનલોડ કરો"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, fuzzy, kde-format
 #| msgid "Billing information:"
 msgctxt ""
@@ -803,21 +811,21 @@ msgctxt ""
 msgid "Updating information…"
 msgstr "બીલ અંગેની માહિતી:"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, fuzzy, kde-format
 #| msgid "&Store"
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "સંગ્રહો (&S)"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, fuzzy, kde-format
 #| msgid "Provider:"
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "પૂરૂં પાડનાર:"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, fuzzy, kde-format
 #| msgctxt "@label:button"
 #| msgid "&Open with %1"
@@ -827,7 +835,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "'%1' ની સાથે ખોલો (&O)"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, fuzzy, kde-format
 #| msgid "&Send Email"
 msgctxt ""
@@ -836,7 +844,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "ઈમેલ મોકલો (&S)"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -844,10 +852,10 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -859,19 +867,19 @@ msgid ""
 "content added."
 msgstr ""
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, fuzzy, kde-format
 #| msgid "Loading Applet"
 msgid "Loading data"
 msgstr "એપ્લેટ લાવે છે"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "સ્થાપન કરે છે"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -881,7 +889,7 @@ msgid ""
 "please contact the person in charge of your permissions."
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Back"
@@ -889,20 +897,20 @@ msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "પાછળ"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, fuzzy, kde-format
 #| msgid "Saturday"
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "શનિવાર"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, fuzzy, kde-format
 #| msgctxt "@action:button Restart find & replace"
 #| msgid "Restart"
@@ -910,7 +918,7 @@ msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "ફરી શરુ કરો"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "New"
@@ -918,7 +926,7 @@ msgctxt "Knewstuff5"
 msgid "New"
 msgstr "નવું"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Home"
@@ -926,13 +934,13 @@ msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "હોમ"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Up"
@@ -940,7 +948,7 @@ msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "અપ"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, fuzzy, kde-format
 #| msgctxt "dictionary variant"
 #| msgid "extended"
@@ -948,7 +956,7 @@ msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "વિસ્તૃત"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Subscript"
@@ -956,14 +964,14 @@ msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "સબસ્ક્રિપ્ટ"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "બધાં વર્ગો"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -994,9 +1002,14 @@ msgid ""
 msgstr ""
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
-#, kde-format
-msgid "Download New Stuff..."
-msgstr "નવી વસ્તુ ડાઉનલોડ કરો..."
+#, fuzzy, kde-format
+#| msgid "Download New Stuff"
+msgctxt "@action"
+msgid "Download New Stuff…"
+msgstr "નવી વસ્તુ ડાઉનલોડ કરો"
+
+#~ msgid "Download New Stuff..."
+#~ msgstr "નવી વસ્તુ ડાઉનલોડ કરો..."
 
 #, fuzzy
 #~| msgid "Installing"
diff -pruN 6.0.0-3/po/ha/knewstuff6.po 6.3.0-1/po/ha/knewstuff6.po
--- 6.0.0-3/po/ha/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/ha/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -7,7 +7,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2009-03-17 11:22+0100\n"
 "Last-Translator: Adriaan de Groot <groot@kde.org>\n"
 "Language-Team: Hausa <kde-i18n-doc@lists.kde.org>\n"
@@ -51,7 +51,7 @@ msgstr ""
 msgid "You are now a fan."
 msgstr ""
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -115,7 +115,7 @@ msgstr ""
 msgid "Use"
 msgstr ""
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -123,17 +123,17 @@ msgid ""
 "This is a critical error and should be reported to the application author"
 msgstr ""
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr ""
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr ""
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr ""
@@ -273,21 +273,21 @@ msgid ""
 "the update"
 msgstr ""
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, kde-format
 msgid ""
 "Failed to adopt '%1'\n"
 "%2"
 msgstr ""
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, kde-format
 msgctxt ""
 "The first entry in the category selection list (also the default value)"
 msgid "All Categories"
 msgstr ""
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, kde-format
 msgctxt ""
 "The string passed back in the case the requested category is not known"
@@ -311,13 +311,13 @@ msgstr ""
 msgid "Download New %1…"
 msgstr ""
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, kde-format
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr ""
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, kde-format
 msgctxt ""
 "A placeholder title used in the dialog when there is no better title "
@@ -325,12 +325,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -339,19 +339,19 @@ msgid ""
 "this through the naming of the items."
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, kde-format
 msgctxt ""
 "A passive notification shown when installation of an item is initiated"
 msgid "Installing %1 from %2"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -359,10 +359,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, kde-format
 msgctxt ""
 "Request installation of this item, available when there is exactly one "
@@ -370,32 +370,32 @@ msgctxt ""
 msgid "Install"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, kde-format
 msgctxt ""
 "Show installation options, where there is more than one downloadable item"
 msgid "Install…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, kde-format
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, kde-format
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -403,14 +403,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -421,12 +421,12 @@ msgid ""
 "to the KDE Community in a bug report</a>."
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a new sub page with comments (comments "
@@ -434,17 +434,17 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, kde-format
 msgid "Rating:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, kde-format
 msgid "Homepage:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -453,12 +453,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -466,72 +466,80 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr ""
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, kde-format
 msgid "Tiles"
 msgstr ""
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr ""
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, kde-format
 msgid "Preview"
 msgstr ""
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, kde-format
 msgid "Detailed Tiles View Mode"
 msgstr ""
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, kde-format
 msgid "Icons Only View Mode"
 msgstr ""
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, kde-format
 msgid "Large Preview View Mode"
 msgstr ""
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr ""
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr ""
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, kde-format
 msgid "Updateable"
 msgstr ""
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, kde-format
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -539,27 +547,27 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, kde-format
 msgid "Recent"
 msgstr ""
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr ""
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr ""
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, kde-format
 msgid "Downloads"
 msgstr ""
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on when items were most "
@@ -567,7 +575,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr ""
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -575,57 +583,57 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr ""
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, kde-format
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr ""
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on number of downloads"
 msgid "Show Most Downloaded First"
 msgstr ""
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, kde-format
 msgid "Upload…"
 msgstr ""
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr ""
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, kde-format
 msgid "Go to…"
 msgstr ""
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, kde-format
 msgid "Search…"
 msgstr ""
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr ""
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, kde-format
 msgid "Contribute your own…"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, kde-format
 msgctxt ""
 "Placeholder title for when a comment has no subject, but does have a rating"
 msgid "<i>(no title)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -633,19 +641,19 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, kde-format
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -653,7 +661,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -661,15 +669,15 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, kde-format
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, kde-format
 msgctxt ""
 "Subheading for the tile view, located immediately underneath the name of the "
@@ -677,7 +685,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -685,7 +693,7 @@ msgctxt ""
 msgid "Working…"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is in the process of being "
@@ -693,7 +701,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -704,7 +712,7 @@ msgid ""
 "bug report</a>."
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, kde-format
 msgctxt "Label for the busy indicator showing an item is installing"
 msgid "Installing…"
@@ -721,44 +729,44 @@ msgstr ""
 msgid "Please try again later."
 msgstr ""
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, kde-format
 msgid "None"
 msgstr ""
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, kde-format
 msgctxt ""
 "A text representation of the rating, shown as a fraction of the max value"
 msgid "(%1/%2)"
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, kde-format
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, kde-format
 msgctxt ""
 "A text shown beside a busy indicator suggesting that data is being fetched"
 msgid "Updating information…"
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, kde-format
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, kde-format
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, kde-format
 msgctxt ""
 "Text for an action which causes the specified website to be opened using the "
@@ -766,7 +774,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, kde-format
 msgctxt ""
 "Text for an action which will attempt to send an email using the user's "
@@ -774,7 +782,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -782,10 +790,10 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -797,18 +805,18 @@ msgid ""
 "content added."
 msgstr ""
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr ""
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr ""
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -818,75 +826,75 @@ msgid ""
 "please contact the person in charge of your permissions."
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Back"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, fuzzy, kde-format
 #| msgid "Start"
 msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "Tada"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "New"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Home"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Up"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, fuzzy, kde-format
 #| msgid "Question"
 msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "Tambaya"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -918,7 +926,8 @@ msgstr ""
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
 #, kde-format
-msgid "Download New Stuff..."
+msgctxt "@action"
+msgid "Download New Stuff…"
 msgstr ""
 
 #, fuzzy
diff -pruN 6.0.0-3/po/he/knewstuff6.po 6.3.0-1/po/he/knewstuff6.po
--- 6.0.0-3/po/he/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/he/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -22,8 +22,8 @@ msgid ""
 msgstr ""
 "Project-Id-Version: knewstuff5\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
-"PO-Revision-Date: 2024-01-19 08:31+0200\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
+"PO-Revision-Date: 2024-05-08 09:09+0300\n"
 "Last-Translator: Yaron Shahrabani <sh.yaron@gmail.com>\n"
 "Language-Team: צוות התרגום של KDE ישראל\n"
 "Language: he\n"
@@ -32,7 +32,7 @@ msgstr ""
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=4; plural=(n == 1) ? 0 : ((n == 2) ? 1 : ((n > 10 && "
 "n % 10 == 0) ? 2 : 3));\n"
-"X-Generator: Lokalize 23.08.4\n"
+"X-Generator: Lokalize 23.08.5\n"
 
 #: attica/atticaprovider.cpp:165
 #, kde-format
@@ -72,7 +72,7 @@ msgstr "הצבעתך נקלטה בהצל
 msgid "You are now a fan."
 msgstr "נשמרת בין האוהדים."
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -138,7 +138,7 @@ msgstr "קובץ תצורה שגוי: 
 msgid "Use"
 msgstr "שימוש"
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -149,17 +149,17 @@ msgstr ""
 "%2\n"
 "זו שגיאה מהותית ויש לדווח עליה ליוצרי היישום"
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr "טעינת הספקים מהקובץ: %1 נכשלה"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr "אי אפשר לטעון ספקים של דברים חדשים לוהטים מהקובץ: %1"
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr "שגיאה באתחול הספק."
@@ -323,7 +323,7 @@ msgid ""
 "the update"
 msgstr "לא הצלחנו לזהות קישור טוב לעדכון %1, ולא הצלחנו לבצע את העדכון"
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, kde-format
 msgid ""
 "Failed to adopt '%1'\n"
@@ -332,14 +332,14 @@ msgstr ""
 "אימוץ ‚%1’ נכשל\n"
 "%2"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, kde-format
 msgctxt ""
 "The first entry in the category selection list (also the default value)"
 msgid "All Categories"
 msgstr "כל הקטגוריות"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, kde-format
 msgctxt ""
 "The string passed back in the case the requested category is not known"
@@ -363,13 +363,13 @@ msgstr "דברים"
 msgid "Download New %1…"
 msgstr "הורדת %1 חדש…"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, kde-format
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "הורדת %1 חדש"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, kde-format
 msgctxt ""
 "A placeholder title used in the dialog when there is no better title "
@@ -377,12 +377,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "הורדת דברים חדשים"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr "בחירת אפשרות ההתקנה שלך"
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -390,23 +390,23 @@ msgid ""
 "options, please contact the author of this item and ask that they clarify "
 "this through the naming of the items."
 msgstr ""
-"נא לבחור את האפשרות שברצונך להתקין מרשימת הפריטים שניתן להוריד להלן. אם לא "
-"ברור לך מה צריך לבחור מהאפשרויות הזמינות, נא ליצור קשר עם מי שיצר את הפריט "
-"הזה ולשאול אם יוכלו להסביר מה הרקע לפי שמות הפריטים."
+"נא לבחור את האפשרות להתקנה מרשימת הפריטים שניתן להוריד להלן. אם לא ברור לך "
+"מה צריך לבחור מהאפשרויות הזמינות, נא ליצור קשר עם מי שיצר את הפריט הזה "
+"ולשאול אם יוכלו להסביר מה הרקע לפי שמות הפריטים."
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "התקנה"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, kde-format
 msgctxt ""
 "A passive notification shown when installation of an item is initiated"
 msgid "Installing %1 from %2"
 msgstr "%1 מותקן מתוך %2"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -414,10 +414,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr "%1 מאת %2"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, kde-format
 msgctxt ""
 "Request installation of this item, available when there is exactly one "
@@ -425,32 +425,32 @@ msgctxt ""
 msgid "Install"
 msgstr "התקנה"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, kde-format
 msgctxt ""
 "Show installation options, where there is more than one downloadable item"
 msgid "Install…"
 msgstr "התקנה…"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, kde-format
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "עדכון"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, kde-format
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "הסרה"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -458,14 +458,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr "מתבצעת עבודה על הפריט %1 מאת %2. נא להמתין…"
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr "הפריט %1 מאת %2 מתעדכן כרגע. נא להמתין…"
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -479,12 +479,12 @@ msgstr ""
 "enter_bug.cgi?product=frameworks-knewstuff\">נא לדווח על זה לקהילת KDE דרך "
 "דוח תקלה</a>."
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr "תגובות וביקורות:"
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a new sub page with comments (comments "
@@ -492,17 +492,17 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "%1 ביקורות ותגובות"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, kde-format
 msgid "Rating:"
 msgstr "דירוג:"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, kde-format
 msgid "Homepage:"
 msgstr "אתר בית:"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -511,12 +511,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr "פתיחת אתר הבית של %1"
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr "איך לתרום:"
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -524,74 +524,85 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr "מידע על איך לתרום למיזם הזה"
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+"להשתמש באזהרה בעת גישה לתוכן שנוצר על ידי משתמשים שמופיע כאן, כיוון שהוא "
+"יכול להכיל קוד שאפשר להריץ שלא נבדק על ידי KDE או על ידי מהנדסי ההפצה שלך "
+"מבחינת בטיחות, יציבות או איכות"
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
-"התוכן שזמין כאן הועלה על ידי משתמשים כמוך ולא עבר סקירה על ידי עורכי ההפצה "
-"שלך לבחינת היכולות או היציבות."
+"תוכן שמופיע כאן ונוצר על ידי המשתמשים לא נבדק על ידי KDE או על ידי מהנדסי "
+"ההפצה שלך מבחינת תקינות או איכות."
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, kde-format
 msgid "Tiles"
 msgstr "אריחים"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "סמלים"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, kde-format
 msgid "Preview"
 msgstr "תצוגה מקדימה"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, kde-format
 msgid "Detailed Tiles View Mode"
 msgstr "מצב תצוגת אריחים מפורטים"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, kde-format
 msgid "Icons Only View Mode"
 msgstr "מצב תצוגת סמלים בלבד"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, kde-format
 msgid "Large Preview View Mode"
 msgstr "מצב תצוגה מקדימה גדולה"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr "הכול"
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "הותקן"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, kde-format
 msgid "Updateable"
 msgstr "זמין לעדכון"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, kde-format
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "הצגת כל הרשומות"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr "להציג רשומות מותקנות בלבד"
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -599,27 +610,27 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr "להציג רשומות שניתן לעדכן בלבד"
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, kde-format
 msgid "Recent"
 msgstr "אחרונים"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr "לפי אלפבית"
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "דירוג"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, kde-format
 msgid "Downloads"
 msgstr "הורדות"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on when items were most "
@@ -627,7 +638,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "הצגת העדכניים ביותר בהתחלה"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -635,57 +646,57 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr "מיון אלפביתי לפי שם"
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, kde-format
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "הצגת המדורגים ביותר בהתחלה"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on number of downloads"
 msgid "Show Most Downloaded First"
 msgstr "הצגת אלו שהורדו הכי הרבה בהתחלה"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, kde-format
 msgid "Upload…"
 msgstr "העלאה…"
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr "הסבר על הוספת הדברים החמים החדשים שלך לרשימה הזאת"
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, kde-format
 msgid "Go to…"
 msgstr "מעבר אל…"
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, kde-format
 msgid "Search…"
 msgstr "חיפוש…"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "קטגוריה:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, kde-format
 msgid "Contribute your own…"
 msgstr "תרומת דברים משלך…"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, kde-format
 msgctxt ""
 "Placeholder title for when a comment has no subject, but does have a rating"
 msgid "<i>(no title)</i>"
 msgstr "<i>(אין כותרת)</i>"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -693,19 +704,19 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr "%1 <i>(יוצר)</i>"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr "תגובות וביקורות של %1"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, kde-format
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "הצגת כל התגובות"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -713,7 +724,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr "הצגת ביקורות בלבד"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -721,15 +732,15 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr "הצגת ביקורות ותגובות"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, kde-format
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
 msgstr "%1 הורדות"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, kde-format
 msgctxt ""
 "Subheading for the tile view, located immediately underneath the name of the "
@@ -737,7 +748,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "מאת <i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -745,7 +756,7 @@ msgctxt ""
 msgid "Working…"
 msgstr "נא להמתין…"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is in the process of being "
@@ -753,7 +764,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "מתבצע עדכון…"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -767,7 +778,7 @@ msgstr ""
 "product=frameworks-knewstuff\">נא לדווח על זה לקהילת KDE דרך דיוח על תקלה</"
 "a>."
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, kde-format
 msgctxt "Label for the busy indicator showing an item is installing"
 msgid "Installing…"
@@ -784,44 +795,44 @@ msgstr "אירעה שגיאה"
 msgid "Please try again later."
 msgstr "נא לנסות שוב."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, kde-format
 msgid "None"
 msgstr "אין"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, kde-format
 msgctxt ""
 "A text representation of the rating, shown as a fraction of the max value"
 msgid "(%1/%2)"
 msgstr "(%1/%2)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, kde-format
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "העלאת דברים חדשים: %1"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, kde-format
 msgctxt ""
 "A text shown beside a busy indicator suggesting that data is being fetched"
 msgid "Updating information…"
 msgstr "המידע מעודכן…"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, kde-format
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "חנות KDE"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, kde-format
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "הספק שלך"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, kde-format
 msgctxt ""
 "Text for an action which causes the specified website to be opened using the "
@@ -829,7 +840,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "פתיחת אתר: %1"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, kde-format
 msgctxt ""
 "Text for an action which will attempt to send an email using the user's "
@@ -837,7 +848,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "שליחת דוא״ל אל: %1"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -845,14 +856,14 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 "כדי להעלות רשומות חדשות או כדי להוסיף תוכן לרשומה קיימת בחנות KDE, נא לפתוח "
-"את האתר ולהיכנס. לאחר שביצעת את הפעולה הזאת, יתאפשר לך למצוא את רשומת "
-"המוצרים שלי בתפריט שתקפוץ בלחיצה על סמל המשתמש שלך. יש ללחוץ על הרשומה הזאת "
-"כדי לעבור למערכת ניהול המוצרים, בה ניתן לעבוד על המוצרים שלך."
+"את האתר ולהיכנס. לאחר ביצוע הפעולה הזאת, אפשר למצוא את רשומת המוצרים שלי "
+"בתפריט שיקפוץ בלחיצה על סמל המשתמש שלך. יש ללחוץ על הרשומה הזאת כדי לעבור "
+"למערכת ניהול המוצרים, בה ניתן לעבוד על המוצרים שלך."
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -868,18 +879,18 @@ msgstr ""
 "המוצר, בה צריך לעקוב אחר ההוראות כיצד להוסיף. לחלופין, יכול להיות שצריך "
 "ליצור קשר עם מנהלי האתר ישירות כדי להוסיף תוכן חדש."
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "מידע נטען"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "מתבצעת התקנה"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -891,73 +902,73 @@ msgstr ""
 "אסור לך להוריד דברים חדשים לוהטים. אם לדעתך זאת טעות, נא ליצור קשר עם אלו "
 "שאחראים על ההרשאות שלך."
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "חזרה"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr "נפוצים"
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "מומלצי העורך"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "הפעלה מחדש"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "New"
 msgstr "חדש"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "אתר הבית"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr "מדף"
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "למעלה"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "מומלצים"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "מינויים"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "כל הרשומות"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -970,8 +981,8 @@ msgid ""
 "with a dialog which lets you switch between all the config files installed "
 "into the systemwide knsrc file location"
 msgstr ""
-"קובץ ה־KNSRC שברצונך להציג. אם לא מועבר כלום, תופיע חלונית שתאפשר לך לבחור "
-"מבין כל קובצי ההגדרות שמותקנים במקום קובצי ה־knsrc הכלל מערכתי"
+"קובץ ה־KNSRC להצגה. אם לא מועבר כלום, תופיע חלונית שתאפשר לך לבחור מבין כל "
+"קובצי ההגדרות שמותקנים במקום קובצי ה־knsrc הכלל מערכתי"
 
 #: tools/knewstuff-dialog/main.cpp:33
 #, kde-format
@@ -1000,8 +1011,12 @@ msgstr ""
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
 #, kde-format
-msgid "Download New Stuff..."
-msgstr "דברים חדשים מגיעים…"
+msgctxt "@action"
+msgid "Download New Stuff…"
+msgstr "הורדת דברים חדשים…"
+
+#~ msgid "Download New Stuff..."
+#~ msgstr "דברים חדשים מגיעים…"
 
 #~ msgctxt ""
 #~ "A message which is shown when the user attempts to display a specific "
diff -pruN 6.0.0-3/po/hi/knewstuff6.po 6.3.0-1/po/hi/knewstuff6.po
--- 6.0.0-3/po/hi/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/hi/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -10,7 +10,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2022-02-26 11:47+0530\n"
 "Last-Translator: Raghavendra Kamath <raghu@raghukamath.com>\n"
 "Language-Team: Hindi <kde-l10n-hi@kde.org>\n"
@@ -60,7 +60,7 @@ msgstr "आपका मतदान द
 msgid "You are now a fan."
 msgstr "आप चहेते बन गए"
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -128,7 +128,7 @@ msgstr "कॉन्फ़िगरे
 msgid "Use"
 msgstr ""
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -136,17 +136,17 @@ msgid ""
 "This is a critical error and should be reported to the application author"
 msgstr ""
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr ""
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr ""
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr ""
@@ -291,7 +291,7 @@ msgid ""
 "the update"
 msgstr ""
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, fuzzy, kde-format
 #| msgid "Failed to load file '%1'"
 msgid ""
@@ -299,7 +299,7 @@ msgid ""
 "%2"
 msgstr "फ़ाइल '%1' लोड करने में असफल"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt ""
@@ -307,7 +307,7 @@ msgctxt ""
 msgid "All Categories"
 msgstr "सभी वर्ग"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, fuzzy, kde-format
 #| msgid "Unknown error"
 msgctxt ""
@@ -333,14 +333,14 @@ msgstr ""
 msgid "Download New %1…"
 msgstr "ताज़ा सामग्री डाउनलोड करें"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, fuzzy, kde-format
 #| msgid "Download New Stuff..."
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "ताज़ा सामग्री डाउनलोड करें"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, fuzzy, kde-format
 #| msgid "Download New Stuff..."
 msgctxt ""
@@ -349,12 +349,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "ताज़ा सामग्री डाउनलोड करें"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -363,12 +363,12 @@ msgid ""
 "this through the naming of the items."
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "संस्थापित करें"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt ""
@@ -376,7 +376,7 @@ msgctxt ""
 msgid "Installing %1 from %2"
 msgstr "संस्थापित हो रहा"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -384,10 +384,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -396,10 +396,10 @@ msgctxt ""
 msgid "Install"
 msgstr "संस्थापित करें"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -407,24 +407,24 @@ msgctxt ""
 msgid "Install…"
 msgstr "संस्थापित करें"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, fuzzy, kde-format
 #| msgid "Update"
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "अद्यतन"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, fuzzy, kde-format
 #| msgid "Uninstall"
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "अनइंस्टाल"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -432,14 +432,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -450,12 +450,12 @@ msgid ""
 "to the KDE Community in a bug report</a>."
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, fuzzy, kde-format
 #| msgid "View Comments"
 msgctxt ""
@@ -464,20 +464,20 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "टिप्पणियाँ देखें"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, fuzzy, kde-format
 #| msgid "Rating: "
 msgid "Rating:"
 msgstr "रेटिंग:"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, fuzzy, kde-format
 #| msgctxt "A link to the description of this Get Hot New Stuff item"
 #| msgid "Homepage"
 msgid "Homepage:"
 msgstr "मुख पृष्ठ"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -486,12 +486,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -499,80 +499,88 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr ""
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, fuzzy, kde-format
 #| msgctxt "@option:check Do filter on type - show only files"
 #| msgid "Files"
 msgid "Tiles"
 msgstr "फ़ाइल "
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "प्रतीक"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, fuzzy, kde-format
 #| msgid "Preview URL:"
 msgid "Preview"
 msgstr "पूर्वावलोकन यूआरएल:"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, fuzzy, kde-format
 #| msgid "Details view mode"
 msgid "Detailed Tiles View Mode"
 msgstr "विवरण दृश्य मोड"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, fuzzy, kde-format
 #| msgid "Icons view mode"
 msgid "Icons Only View Mode"
 msgstr "प्रतीक दृश्य मोड"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, fuzzy, kde-format
 #| msgid "Details view mode"
 msgid "Large Preview View Mode"
 msgstr "विवरण दृश्य मोड"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr ""
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "स्थापित"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, fuzzy, kde-format
 #| msgid "Update"
 msgid "Updateable"
 msgstr "अद्यतन"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "सभी वर्ग"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -580,30 +588,30 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Open Recent"
 msgid "Recent"
 msgstr "हालिया खोलें"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr ""
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "रेटिंग"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, fuzzy, kde-format
 #| msgid "Download"
 msgid "Downloads"
 msgstr "डाउनलोड"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt ""
@@ -612,7 +620,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "पहले डिरेक्ट्री दिखाएँ"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -620,14 +628,14 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr ""
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "पहले डिरेक्ट्री दिखाएँ"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, fuzzy, kde-format
 #| msgid "Most downloads"
 msgctxt ""
@@ -635,41 +643,41 @@ msgctxt ""
 msgid "Show Most Downloaded First"
 msgstr "अधिकतम डाउनलोड्स"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, fuzzy, kde-format
 #| msgid "New Upload"
 msgid "Upload…"
 msgstr "नया अपलोड"
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr ""
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, fuzzy, kde-format
 #| msgid "&Go To..."
 msgid "Go to…"
 msgstr "यहाँ जाएं... (&G)"
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, fuzzy, kde-format
 #| msgid "Search:"
 msgid "Search…"
 msgstr "ढूंढें:"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "श्रेणी:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, fuzzy, kde-format
 #| msgid "Continue operation"
 msgid "Contribute your own…"
 msgstr "ऑपरेशन जारी रखें"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, fuzzy, kde-format
 #| msgctxt "@note/rich"
 #| msgid "<i>Note</i>: %1"
@@ -678,7 +686,7 @@ msgctxt ""
 msgid "<i>(no title)</i>"
 msgstr "<i>टीप</i>: %1"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -686,20 +694,20 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "सभी वर्ग"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -707,7 +715,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -715,8 +723,8 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, fuzzy, kde-format
 #| msgid "1 download"
 #| msgid_plural "%1 downloads"
@@ -724,8 +732,8 @@ msgctxt "The number of times the item ha
 msgid "%1 downloads"
 msgstr "१ डाउनलोड"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, fuzzy, kde-format
 #| msgctxt "Show the author of this item in a list"
 #| msgid "By <i>%1</i>"
@@ -735,7 +743,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "<i>%1</i>से"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -743,7 +751,7 @@ msgctxt ""
 msgid "Working…"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, fuzzy, kde-format
 #| msgid "Updating"
 msgctxt ""
@@ -752,7 +760,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "अद्यतन हो रहा"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -763,7 +771,7 @@ msgid ""
 "bug report</a>."
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt "Label for the busy indicator showing an item is installing"
@@ -782,14 +790,14 @@ msgstr ""
 msgid "Please try again later."
 msgstr "कृपया नाम भरें"
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, fuzzy, kde-format
 #| msgctxt "No border line"
 #| msgid "None"
 msgid "None"
 msgstr "कुछ नहीं"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, fuzzy, kde-format
 #| msgid "(%1/s)"
 msgctxt ""
@@ -797,14 +805,14 @@ msgctxt ""
 msgid "(%1/%2)"
 msgstr "(%1/s)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, fuzzy, kde-format
 #| msgid "Download New Stuff..."
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "ताज़ा सामग्री डाउनलोड करें"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, fuzzy, kde-format
 #| msgid "Billing information:"
 msgctxt ""
@@ -812,21 +820,21 @@ msgctxt ""
 msgid "Updating information…"
 msgstr "बिलिंग जानकारी"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, fuzzy, kde-format
 #| msgid "&Store"
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "भंडारित करें (&S)"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, fuzzy, kde-format
 #| msgid "Provider:"
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "प्रदाता:"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, fuzzy, kde-format
 #| msgctxt "@label:button"
 #| msgid "&Open with %1"
@@ -836,7 +844,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "%1 के साथ खोलें (&O)"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, fuzzy, kde-format
 #| msgid "&Send Email"
 msgctxt ""
@@ -845,7 +853,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "ईमेल भेजें (&S)"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -853,10 +861,10 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -868,18 +876,18 @@ msgid ""
 "content added."
 msgstr ""
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "डॉटा लोड किया जा रहा है"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "संस्थापित हो रहा"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -889,7 +897,7 @@ msgid ""
 "please contact the person in charge of your permissions."
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Back"
@@ -897,19 +905,19 @@ msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "पीछे"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, fuzzy, kde-format
 #| msgctxt "@action:button Restart find & replace"
 #| msgid "Restart"
@@ -917,7 +925,7 @@ msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "पुनः प्रारंभ करें"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "New"
@@ -925,7 +933,7 @@ msgctxt "Knewstuff5"
 msgid "New"
 msgstr "नया"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Home"
@@ -933,13 +941,13 @@ msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "घर"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Up"
@@ -947,7 +955,7 @@ msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "ऊपर"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, fuzzy, kde-format
 #| msgctxt "dictionary variant"
 #| msgid "extended"
@@ -955,7 +963,7 @@ msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "विस्तारित"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Subscript"
@@ -963,14 +971,14 @@ msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "लघुपाठ"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "सभी वर्ग"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -1001,10 +1009,15 @@ msgid ""
 msgstr ""
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
-#, kde-format
-msgid "Download New Stuff..."
+#, fuzzy, kde-format
+#| msgid "Download New Stuff..."
+msgctxt "@action"
+msgid "Download New Stuff…"
 msgstr "ताज़ा सामग्री डाउनलोड करें"
 
+#~ msgid "Download New Stuff..."
+#~ msgstr "ताज़ा सामग्री डाउनलोड करें"
+
 #~ msgid "Initializing"
 #~ msgstr "संस्थापित हो रहा"
 
diff -pruN 6.0.0-3/po/hne/knewstuff6.po 6.3.0-1/po/hne/knewstuff6.po
--- 6.0.0-3/po/hne/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/hne/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -8,7 +8,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2009-02-10 20:44+0530\n"
 "Last-Translator: Ravishankar Shrivastava <raviratlami@aol.in>\n"
 "Language-Team: Hindi <kde-i18n-doc@lists.kde.org>\n"
@@ -54,7 +54,7 @@ msgstr "कोई पाठ बदले
 msgid "You are now a fan."
 msgstr ""
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -122,7 +122,7 @@ msgstr "कान्फिगरेस
 msgid "Use"
 msgstr ""
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -130,17 +130,17 @@ msgid ""
 "This is a critical error and should be reported to the application author"
 msgstr ""
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr ""
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr ""
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr ""
@@ -287,7 +287,7 @@ msgid ""
 "the update"
 msgstr ""
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, fuzzy, kde-format
 #| msgid "Failed to load file '%1'"
 msgid ""
@@ -295,7 +295,7 @@ msgid ""
 "%2"
 msgstr "फाइल '%1' लोड करे मं फेल"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, fuzzy, kde-format
 #| msgid "Pages"
 msgctxt ""
@@ -303,7 +303,7 @@ msgctxt ""
 msgid "All Categories"
 msgstr "पेज"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, fuzzy, kde-format
 #| msgid "Unknown error"
 msgctxt ""
@@ -329,14 +329,14 @@ msgstr ""
 msgid "Download New %1…"
 msgstr "नवा %1 डाउनलोड करव"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, fuzzy, kde-format
 #| msgid "Download New %1"
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "नवा %1 डाउनलोड करव"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
 msgctxt ""
@@ -345,12 +345,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "ताजा सामान डाउनलोड करव"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -359,12 +359,12 @@ msgid ""
 "this through the naming of the items."
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "इनस्टाल करव"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -372,7 +372,7 @@ msgctxt ""
 msgid "Installing %1 from %2"
 msgstr "इनस्टाल करव"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -380,10 +380,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -392,10 +392,10 @@ msgctxt ""
 msgid "Install"
 msgstr "इनस्टाल करव"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -403,24 +403,24 @@ msgctxt ""
 msgid "Install…"
 msgstr "इनस्टाल करव"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, fuzzy, kde-format
 #| msgid "Update"
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "अपडेट"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, fuzzy, kde-format
 #| msgid "Uninstall"
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "अनइंस्टाल"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -428,14 +428,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -446,12 +446,12 @@ msgid ""
 "to the KDE Community in a bug report</a>."
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, fuzzy, kde-format
 #| msgid "View Comments"
 msgctxt ""
@@ -460,19 +460,19 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "टिप्पनी मन ल देखव"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, fuzzy, kde-format
 #| msgid "Rating: "
 msgid "Rating:"
 msgstr "रेटिंग:"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, fuzzy, kde-format
 #| msgid "Homepage"
 msgid "Homepage:"
 msgstr "मुख पेज"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -481,12 +481,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -494,73 +494,81 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr ""
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, fuzzy, kde-format
 #| msgid "File"
 msgid "Tiles"
 msgstr "फाइल"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "चिनहा"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, fuzzy, kde-format
 #| msgid "No Preview"
 msgid "Preview"
 msgstr "प्रिव्यू नइ"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, fuzzy, kde-format
 #| msgid "Detailed View"
 msgid "Detailed Tiles View Mode"
 msgstr "विस्तृत दृस्य"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, fuzzy, kde-format
 #| msgid "Icons Only"
 msgid "Icons Only View Mode"
 msgstr "सिरिफ चिनहा"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, fuzzy, kde-format
 #| msgid "Detailed View"
 msgid "Large Preview View Mode"
 msgstr "विस्तृत दृस्य"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr ""
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, fuzzy, kde-format
 #| msgid "Install"
 msgid "Installed"
 msgstr "इनस्टाल करव"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, fuzzy, kde-format
 #| msgid "Update"
 msgid "Updateable"
 msgstr "अपडेट"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, fuzzy, kde-format
 #| msgid "&Show All Entries"
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "सब्बो प्रविस्टि देखाव (&S)"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, fuzzy, kde-format
 #| msgid "&Show All Entries"
 msgctxt ""
@@ -568,7 +576,7 @@ msgctxt ""
 msgid "Show Only Installed Entries"
 msgstr "सब्बो प्रविस्टि देखाव (&S)"
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, fuzzy, kde-format
 #| msgid "&Show All Entries"
 msgctxt ""
@@ -577,30 +585,30 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr "सब्बो प्रविस्टि देखाव (&S)"
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, fuzzy, kde-format
 #| msgid "Open &Recent"
 msgid "Recent"
 msgstr "अभी हाल के वाले ल खोलव  (&R)"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr ""
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, fuzzy, kde-format
 #| msgid "Rating: "
 msgid "Rating"
 msgstr "रेटिंग:"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, fuzzy, kde-format
 #| msgid "Download"
 msgid "Downloads"
 msgstr "डाउनलोड"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt ""
@@ -609,7 +617,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "पहिली डिरेक्टरी देखाव"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -617,14 +625,14 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr ""
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "पहिली डिरेक्टरी देखाव"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, fuzzy, kde-format
 #| msgid "Most Downloads"
 msgctxt ""
@@ -632,42 +640,42 @@ msgctxt ""
 msgid "Show Most Downloaded First"
 msgstr "सबसे अधिक डाउनलोड"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, fuzzy, kde-format
 #| msgid "&Replace..."
 msgid "Upload…"
 msgstr "बदलव...(&R)"
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr ""
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, fuzzy, kde-format
 #| msgid "&Go To..."
 msgid "Go to…"
 msgstr "इहां जाव... (&G)"
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, fuzzy, kde-format
 #| msgid "S&earch:"
 msgid "Search…"
 msgstr "खोजव: (&e)"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, fuzzy, kde-format
 #| msgid "Character:"
 msgid "Category:"
 msgstr "अक्छर:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, fuzzy, kde-format
 #| msgid "Continue operation"
 msgid "Contribute your own…"
 msgstr "आपरेसन जारी रखव"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, fuzzy, kde-format
 #| msgctxt "@note/rich"
 #| msgid "<i>Note</i>: %1"
@@ -676,7 +684,7 @@ msgctxt ""
 msgid "<i>(no title)</i>"
 msgstr "<i>टीप</i>: %1"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -684,20 +692,20 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, fuzzy, kde-format
 #| msgid "Pages"
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "पेज"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, fuzzy, kde-format
 #| msgid "Show Preview"
 msgctxt ""
@@ -706,7 +714,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr "प्रिव्यू देखाव"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -714,16 +722,16 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, fuzzy, kde-format
 #| msgid "Download"
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
 msgstr "डाउनलोड"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, fuzzy, kde-format
 #| msgctxt "@interface/rich"
 #| msgid "<i>%1</i>"
@@ -733,7 +741,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "<i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -741,7 +749,7 @@ msgctxt ""
 msgid "Working…"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, fuzzy, kde-format
 #| msgid "Update"
 msgctxt ""
@@ -750,7 +758,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "अपडेट"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -761,7 +769,7 @@ msgid ""
 "bug report</a>."
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt "Label for the busy indicator showing an item is installing"
@@ -780,14 +788,14 @@ msgstr ""
 msgid "Please try again later."
 msgstr "किरपा करके, नाम भरव."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, fuzzy, kde-format
 #| msgctxt "No border line"
 #| msgid "None"
 msgid "None"
 msgstr "कुछ नइ"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, fuzzy, kde-format
 #| msgid "(%1/s)"
 msgctxt ""
@@ -795,14 +803,14 @@ msgctxt ""
 msgid "(%1/%2)"
 msgstr "(%1/s)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "ताजा सामान डाउनलोड करव"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, fuzzy, kde-format
 #| msgid "Billing Information:"
 msgctxt ""
@@ -810,20 +818,20 @@ msgctxt ""
 msgid "Updating information…"
 msgstr "बिलिंग जानकारी"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, fuzzy, kde-format
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "भंडारित करव"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, fuzzy, kde-format
 #| msgid "Provider: %1"
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "प्रदाता: %1"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, fuzzy, kde-format
 #| msgid "&Open with '%1'"
 msgctxt ""
@@ -832,7 +840,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr " '%1' एखर साथ खोलव (&O)"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, fuzzy, kde-format
 #| msgid "&Send Email"
 msgctxt ""
@@ -841,7 +849,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "ईमेल भेजव (&S)"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -849,10 +857,10 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -864,20 +872,20 @@ msgid ""
 "content added."
 msgstr ""
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, fuzzy, kde-format
 #| msgid "Loading Applet"
 msgid "Loading data"
 msgstr "ऐपलेट लोड करत हे"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, fuzzy, kde-format
 #| msgid "Install"
 msgid "Installing"
 msgstr "इनस्टाल करव"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -887,33 +895,33 @@ msgid ""
 "please contact the person in charge of your permissions."
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, fuzzy, kde-format
 #| msgid "Back"
 msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "पीछू"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, fuzzy, kde-format
 #| msgid "Saturday"
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "सनिवार"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, fuzzy, kde-format
 msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "फिर से  चालू करव"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "New"
@@ -921,7 +929,7 @@ msgctxt "Knewstuff5"
 msgid "New"
 msgstr "नवा"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Home"
@@ -929,13 +937,13 @@ msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "घर"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Up"
@@ -943,7 +951,7 @@ msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "ऊपर"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, fuzzy, kde-format
 #| msgctxt "dictionary variant"
 #| msgid "extended"
@@ -951,7 +959,7 @@ msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "विस्तारित"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Subscript"
@@ -959,14 +967,14 @@ msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "सब्स्क्रिप्ट"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, fuzzy, kde-format
 #| msgid "&Show All Entries"
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "सब्बो प्रविस्टि देखाव (&S)"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -999,10 +1007,16 @@ msgstr ""
 #: widgets/action.cpp:28 widgets/button.cpp:70
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
-msgid "Download New Stuff..."
+msgctxt "@action"
+msgid "Download New Stuff…"
 msgstr "ताजा सामान डाउनलोड करव"
 
 #, fuzzy
+#~| msgid "Download New Stuff"
+#~ msgid "Download New Stuff..."
+#~ msgstr "ताजा सामान डाउनलोड करव"
+
+#, fuzzy
 #~| msgid "Install"
 #~ msgid "Initializing"
 #~ msgstr "इनस्टाल करव"
diff -pruN 6.0.0-3/po/hr/knewstuff6.po 6.3.0-1/po/hr/knewstuff6.po
--- 6.0.0-3/po/hr/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/hr/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -11,7 +11,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2011-07-22 16:08+0200\n"
 "Last-Translator: Marko Dimjašević <marko@dimjasevic.net>\n"
 "Language-Team: Croatian <kde-croatia-list@lists.sourceforge.net>\n"
@@ -73,7 +73,7 @@ msgstr "Vaš glas je zabilježen."
 msgid "You are now a fan."
 msgstr "Sad ste obožavatelj/ica."
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -143,7 +143,7 @@ msgstr "Konfiguracijska datoteka je neis
 msgid "Use"
 msgstr ""
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -151,17 +151,17 @@ msgid ""
 "This is a critical error and should be reported to the application author"
 msgstr ""
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr "Učitavanje pružatelja usluge iz datoteke: %1 nije uspjelo"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr "Nije moguće učitati pružatelje Nabavi nove sadržaje iz datoteke: %1"
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr "Pogreška pri inicijalizaciji pružatelja."
@@ -305,7 +305,7 @@ msgid ""
 "the update"
 msgstr ""
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, fuzzy, kde-format
 #| msgid "Failed to load file '%1'"
 msgid ""
@@ -313,7 +313,7 @@ msgid ""
 "%2"
 msgstr "Neuspjelo učitavanje datoteke '%1'"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt ""
@@ -321,7 +321,7 @@ msgctxt ""
 msgid "All Categories"
 msgstr "Sve kategorije"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, fuzzy, kde-format
 #| msgid "Unknown error"
 msgctxt ""
@@ -347,14 +347,14 @@ msgstr ""
 msgid "Download New %1…"
 msgstr "Preuzmite nove sadržaje…"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, fuzzy, kde-format
 #| msgid "Download New Stuff..."
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "Preuzmite nove sadržaje…"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, fuzzy, kde-format
 #| msgid "Download New Stuff..."
 msgctxt ""
@@ -363,12 +363,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "Preuzmite nove sadržaje…"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -377,12 +377,12 @@ msgid ""
 "this through the naming of the items."
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "Instaliraj"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt ""
@@ -390,7 +390,7 @@ msgctxt ""
 msgid "Installing %1 from %2"
 msgstr "Instaliranje"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -398,10 +398,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -410,10 +410,10 @@ msgctxt ""
 msgid "Install"
 msgstr "Instaliraj"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -421,24 +421,24 @@ msgctxt ""
 msgid "Install…"
 msgstr "Instaliraj"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, fuzzy, kde-format
 #| msgid "Update"
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "Ažuriraj"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, fuzzy, kde-format
 #| msgid "Uninstall"
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "Odinstaliraj"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -446,14 +446,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -464,12 +464,12 @@ msgid ""
 "to the KDE Community in a bug report</a>."
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, fuzzy, kde-format
 #| msgid "View Comments"
 msgctxt ""
@@ -478,19 +478,19 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "Pregledaj komentare"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, fuzzy, kde-format
 #| msgid "Rating: "
 msgid "Rating:"
 msgstr "Ocjena:"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, fuzzy, kde-format
 #| msgid "Homepage"
 msgid "Homepage:"
 msgstr "Osobna stranica"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -499,12 +499,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -512,80 +512,88 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr ""
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, fuzzy, kde-format
 #| msgctxt "@option:check Do filter on type - show only files"
 #| msgid "Files"
 msgid "Tiles"
 msgstr "sDatoteke"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "Ikone"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, fuzzy, kde-format
 #| msgid "Preview URL:"
 msgid "Preview"
 msgstr "Pregled URL-a:"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, fuzzy, kde-format
 #| msgid "Details view mode"
 msgid "Detailed Tiles View Mode"
 msgstr "Način detaljnog prikaza"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, fuzzy, kde-format
 #| msgid "Icons view mode"
 msgid "Icons Only View Mode"
 msgstr "Način prikaza s ikonama"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, fuzzy, kde-format
 #| msgid "Details view mode"
 msgid "Large Preview View Mode"
 msgstr "Način detaljnog prikaza"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr ""
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "Instalirano"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, fuzzy, kde-format
 #| msgid "Update"
 msgid "Updateable"
 msgstr "Ažuriraj"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "Sve kategorije"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -593,30 +601,30 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Open Recent"
 msgid "Recent"
 msgstr "Otvori &nedavno"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr ""
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "Ocjena"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, fuzzy, kde-format
 #| msgid "Download"
 msgid "Downloads"
 msgstr "Preuzmi"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt ""
@@ -625,7 +633,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "Prvo prikaži direktorije"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -633,14 +641,14 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr ""
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "Prvo prikaži direktorije"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, fuzzy, kde-format
 #| msgid "Most downloads"
 msgctxt ""
@@ -648,41 +656,41 @@ msgctxt ""
 msgid "Show Most Downloaded First"
 msgstr "Najviše preuzimanja"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, fuzzy, kde-format
 #| msgid "New Upload"
 msgid "Upload…"
 msgstr "Novo slanje"
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr ""
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, fuzzy, kde-format
 #| msgid "&Go To..."
 msgid "Go to…"
 msgstr "&Idi na…"
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, fuzzy, kde-format
 #| msgid "Search:"
 msgid "Search…"
 msgstr "Pretraga:"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "Kategorija:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, fuzzy, kde-format
 #| msgid "Continue operation"
 msgid "Contribute your own…"
 msgstr "Nastavi operaciju"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, fuzzy, kde-format
 #| msgctxt "@note/rich"
 #| msgid "<i>Note</i>: %1"
@@ -691,7 +699,7 @@ msgctxt ""
 msgid "<i>(no title)</i>"
 msgstr "<i>Napomena</i>: %1"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -699,20 +707,20 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "Sve kategorije"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -720,7 +728,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -728,8 +736,8 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, fuzzy, kde-format
 #| msgid "1 download"
 #| msgid_plural "%1 downloads"
@@ -737,8 +745,8 @@ msgctxt "The number of times the item ha
 msgid "%1 downloads"
 msgstr "%1 preuzimanje"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, fuzzy, kde-format
 #| msgctxt "Show the author of this item in a list"
 #| msgid "By <i>%1</i>"
@@ -748,7 +756,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "Od <i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -756,7 +764,7 @@ msgctxt ""
 msgid "Working…"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, fuzzy, kde-format
 #| msgid "Updating"
 msgctxt ""
@@ -765,7 +773,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "Ažuriranje"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -776,7 +784,7 @@ msgid ""
 "bug report</a>."
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt "Label for the busy indicator showing an item is installing"
@@ -795,14 +803,14 @@ msgstr ""
 msgid "Please try again later."
 msgstr "Unesite ime."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, fuzzy, kde-format
 #| msgctxt "No border line"
 #| msgid "None"
 msgid "None"
 msgstr "Bez"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, fuzzy, kde-format
 #| msgid "(%1/s)"
 msgctxt ""
@@ -810,14 +818,14 @@ msgctxt ""
 msgid "(%1/%2)"
 msgstr "(%1/s)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, fuzzy, kde-format
 #| msgid "Download New Stuff..."
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "Preuzmite nove sadržaje…"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, fuzzy, kde-format
 #| msgid "Billing information:"
 msgctxt ""
@@ -825,21 +833,21 @@ msgctxt ""
 msgid "Updating information…"
 msgstr "Podaci o plaćanju:"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, fuzzy, kde-format
 #| msgid "&Store"
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "&Pohrani"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, fuzzy, kde-format
 #| msgid "Provider:"
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "Pružatelj usluge:"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, fuzzy, kde-format
 #| msgctxt "@label:button"
 #| msgid "&Open with %1"
@@ -849,7 +857,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "&Otvori s %1|/|&Otvori s $[ins %1]"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, fuzzy, kde-format
 #| msgid "&Send Email"
 msgctxt ""
@@ -858,7 +866,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "%Pošalji e-poštu"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -866,10 +874,10 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -881,18 +889,18 @@ msgid ""
 "content added."
 msgstr ""
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "Učitavam podatke"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "Instaliranje"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -902,7 +910,7 @@ msgid ""
 "please contact the person in charge of your permissions."
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Back"
@@ -910,19 +918,19 @@ msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "Nazad"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, fuzzy, kde-format
 #| msgctxt "@action:button Restart find & replace"
 #| msgid "Restart"
@@ -930,7 +938,7 @@ msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "Ponovi"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "New"
@@ -938,7 +946,7 @@ msgctxt "Knewstuff5"
 msgid "New"
 msgstr "Novo"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Home"
@@ -946,13 +954,13 @@ msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Kućni telefon"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Up"
@@ -960,7 +968,7 @@ msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "Gore"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, fuzzy, kde-format
 #| msgctxt "dictionary variant"
 #| msgid "extended"
@@ -968,7 +976,7 @@ msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "prošireni"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Subscript"
@@ -976,14 +984,14 @@ msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "&Indeks"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "Sve kategorije"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -1014,10 +1022,15 @@ msgid ""
 msgstr ""
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
-#, kde-format
-msgid "Download New Stuff..."
+#, fuzzy, kde-format
+#| msgid "Download New Stuff..."
+msgctxt "@action"
+msgid "Download New Stuff…"
 msgstr "Preuzmite nove sadržaje…"
 
+#~ msgid "Download New Stuff..."
+#~ msgstr "Preuzmite nove sadržaje…"
+
 #~ msgid "Initializing"
 #~ msgstr "Inicijaliziram"
 
diff -pruN 6.0.0-3/po/hsb/knewstuff6.po 6.3.0-1/po/hsb/knewstuff6.po
--- 6.0.0-3/po/hsb/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/hsb/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -10,7 +10,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2008-12-19 22:49+0100\n"
 "Last-Translator: Eduard Werner <edi.werner@gmx.de>\n"
 "Language-Team: en_US <kde-i18n-doc@lists.kde.org>\n"
@@ -56,7 +56,7 @@ msgstr "Žadyn tekst njebu narunany."
 msgid "You are now a fan."
 msgstr ""
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -124,7 +124,7 @@ msgstr "Konfiguraciske dataje"
 msgid "Use"
 msgstr ""
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -132,17 +132,17 @@ msgid ""
 "This is a critical error and should be reported to the application author"
 msgstr ""
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr ""
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr ""
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr ""
@@ -288,7 +288,7 @@ msgid ""
 "the update"
 msgstr ""
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, fuzzy, kde-format
 #| msgid "Failed to load file '%1'"
 msgid ""
@@ -296,7 +296,7 @@ msgid ""
 "%2"
 msgstr "Njemóžu dataju '%1' začitać"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, fuzzy, kde-format
 #| msgid "Pages"
 msgctxt ""
@@ -304,7 +304,7 @@ msgctxt ""
 msgid "All Categories"
 msgstr "Strony"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, fuzzy, kde-format
 #| msgid "Unknown error"
 msgctxt ""
@@ -330,14 +330,14 @@ msgstr ""
 msgid "Download New %1…"
 msgstr "Sćahnyć nowe %1"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, fuzzy, kde-format
 #| msgid "Download New %1"
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "Sćahnyć nowe %1"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
 msgctxt ""
@@ -346,12 +346,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "Nowe wěcy wobstarać"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -360,12 +360,12 @@ msgid ""
 "this through the naming of the items."
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "Instalować"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -373,7 +373,7 @@ msgctxt ""
 msgid "Installing %1 from %2"
 msgstr "Instalować"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -381,10 +381,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -393,10 +393,10 @@ msgctxt ""
 msgid "Install"
 msgstr "Instalować"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -404,24 +404,24 @@ msgctxt ""
 msgid "Install…"
 msgstr "Instalować"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, fuzzy, kde-format
 #| msgid "Update"
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "Aktualizowanje"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, fuzzy, kde-format
 #| msgid "Uninstall"
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "Deinstalować"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -429,14 +429,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -447,12 +447,12 @@ msgid ""
 "to the KDE Community in a bug report</a>."
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, fuzzy, kde-format
 #| msgid "View Comments"
 msgctxt ""
@@ -461,19 +461,19 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "Komentary wobhladać"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, fuzzy, kde-format
 #| msgid "Rating: "
 msgid "Rating:"
 msgstr "Hódnoćenje:"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, fuzzy, kde-format
 #| msgid "Homepage"
 msgid "Homepage:"
 msgstr "Domjaca strona"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -482,12 +482,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -495,79 +495,87 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr ""
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, fuzzy, kde-format
 #| msgid "File"
 msgid "Tiles"
 msgstr "Dataja"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "piktogramy"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, fuzzy, kde-format
 #| msgid "No Preview"
 msgid "Preview"
 msgstr "Žana přehladka"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, kde-format
 msgid "Detailed Tiles View Mode"
 msgstr ""
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, fuzzy, kde-format
 #| msgid "Icons Only"
 msgid "Icons Only View Mode"
 msgstr "Jenož piktogramy"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, fuzzy, kde-format
 #| msgid "Preview URL:"
 msgid "Large Preview View Mode"
 msgstr "Přehladka URL:"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr ""
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, fuzzy, kde-format
 #| msgid "Install"
 msgid "Installed"
 msgstr "Instalować"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, fuzzy, kde-format
 #| msgid "Update"
 msgid "Updateable"
 msgstr "Aktualizowanje"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, fuzzy, kde-format
 #| msgid "Pages"
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "Strony"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -575,31 +583,31 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Open Recent"
 msgid "Recent"
 msgstr "Njedawno wočinjene wočinić"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr ""
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, fuzzy, kde-format
 #| msgid "Rating: "
 msgid "Rating"
 msgstr "Hódnoćenje:"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, fuzzy, kde-format
 #| msgid "Download"
 msgid "Downloads"
 msgstr "Sćahnyć"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt ""
@@ -608,7 +616,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "Najprjedy zapiski pokazać"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -616,14 +624,14 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr ""
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "Najprjedy zapiski pokazać"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, fuzzy, kde-format
 #| msgid "Most Downloads"
 msgctxt ""
@@ -631,42 +639,42 @@ msgctxt ""
 msgid "Show Most Downloaded First"
 msgstr "Najhusćišo sćehnjene"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, fuzzy, kde-format
 #| msgid "&Replace..."
 msgid "Upload…"
 msgstr "&Narunać"
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr ""
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, fuzzy, kde-format
 #| msgid "&Go To..."
 msgid "Go to…"
 msgstr "&Dźi na ..."
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, fuzzy, kde-format
 #| msgid "S&earch:"
 msgid "Search…"
 msgstr "P&ytać:"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, fuzzy, kde-format
 #| msgid "Character:"
 msgid "Category:"
 msgstr "Pismik:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, fuzzy, kde-format
 #| msgid "Continue operation"
 msgid "Contribute your own…"
 msgstr "Z akciju pokročować"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, fuzzy, kde-format
 #| msgctxt "@note/rich"
 #| msgid "<i>Note</i>: %1"
@@ -675,7 +683,7 @@ msgctxt ""
 msgid "<i>(no title)</i>"
 msgstr "<i>Přispomnjenje</i>: %1"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -683,20 +691,20 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, fuzzy, kde-format
 #| msgid "Pages"
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "Strony"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -704,7 +712,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -712,16 +720,16 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, fuzzy, kde-format
 #| msgid "Download"
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
 msgstr "Sćahnyć"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, fuzzy, kde-format
 #| msgctxt "@interface/rich"
 #| msgid "<i>%1</i>"
@@ -731,7 +739,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "<i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -739,7 +747,7 @@ msgctxt ""
 msgid "Working…"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, fuzzy, kde-format
 #| msgid "Update"
 msgctxt ""
@@ -748,7 +756,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "Aktualizowanje"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -759,7 +767,7 @@ msgid ""
 "bug report</a>."
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt "Label for the busy indicator showing an item is installing"
@@ -778,14 +786,14 @@ msgstr ""
 msgid "Please try again later."
 msgstr "Prošu zapodajće mjeno."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, fuzzy, kde-format
 #| msgctxt "No border line"
 #| msgid "None"
 msgid "None"
 msgstr "Žane"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, fuzzy, kde-format
 #| msgid "(%1/s)"
 msgctxt ""
@@ -793,14 +801,14 @@ msgctxt ""
 msgid "(%1/%2)"
 msgstr "(%1/s)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "Nowe wěcy wobstarać"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, fuzzy, kde-format
 #| msgid "Billing Information:"
 msgctxt ""
@@ -808,21 +816,21 @@ msgctxt ""
 msgid "Updating information…"
 msgstr "Informacija za zličbowanje:"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, fuzzy, kde-format
 #| msgid "Store"
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "Składować"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, fuzzy, kde-format
 #| msgid "Provider: %1"
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "Prowider: %1"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, fuzzy, kde-format
 #| msgid "&Open with '%1'"
 msgctxt ""
@@ -831,7 +839,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "&Z '%1' wočinić?"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, fuzzy, kde-format
 #| msgid "&Send Email"
 msgctxt ""
@@ -840,7 +848,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "&Mailku pósłać"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -848,10 +856,10 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -863,20 +871,20 @@ msgid ""
 "content added."
 msgstr ""
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, fuzzy, kde-format
 #| msgid "Loading Applet"
 msgid "Loading data"
 msgstr "Začitam miniprogram"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, fuzzy, kde-format
 #| msgid "Install"
 msgid "Installing"
 msgstr "Instalować"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -886,7 +894,7 @@ msgid ""
 "please contact the person in charge of your permissions."
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Back"
@@ -894,27 +902,27 @@ msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "Wróćo"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, fuzzy, kde-format
 #| msgid "Saturday"
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "Sobota"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, fuzzy, kde-format
 #| msgid "Restart"
 msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "Znowa startować"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "New"
@@ -922,7 +930,7 @@ msgctxt "Knewstuff5"
 msgid "New"
 msgstr "Nowe"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Home"
@@ -930,13 +938,13 @@ msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Pos1"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Up"
@@ -944,7 +952,7 @@ msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "Horje"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, fuzzy, kde-format
 #| msgctxt "dictionary variant"
 #| msgid "extended"
@@ -952,7 +960,7 @@ msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "rošěrjene"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Subscript"
@@ -960,14 +968,14 @@ msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "subskript"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, fuzzy, kde-format
 #| msgid "Pages"
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "Strony"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -1000,10 +1008,16 @@ msgstr ""
 #: widgets/action.cpp:28 widgets/button.cpp:70
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
-msgid "Download New Stuff..."
+msgctxt "@action"
+msgid "Download New Stuff…"
 msgstr "Nowe wěcy wobstarać"
 
 #, fuzzy
+#~| msgid "Download New Stuff"
+#~ msgid "Download New Stuff..."
+#~ msgstr "Nowe wěcy wobstarać"
+
+#, fuzzy
 #~| msgid "Install"
 #~ msgid "Initializing"
 #~ msgstr "Instalować"
diff -pruN 6.0.0-3/po/hu/knewstuff6.po 6.3.0-1/po/hu/knewstuff6.po
--- 6.0.0-3/po/hu/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/hu/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -6,7 +6,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: KDE 4.4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2024-01-08 10:40+0100\n"
 "Last-Translator: Kristof Kiszel <ulysses@fsf.hu>\n"
 "Language-Team: Hungarian <kde-l10n-hu@kde.org>\n"
@@ -55,7 +55,7 @@ msgstr "Rögzítettük a szavazatát."
 msgid "You are now a fan."
 msgstr "Ön most már rajongó."
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -123,7 +123,7 @@ msgstr "Érvénytelen beállítófájl:
 msgid "Use"
 msgstr "Használat"
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -134,19 +134,19 @@ msgstr ""
 "%2\n"
 "Ez egy kritikus hiba, jelentse az alkalmazás szerzőjének"
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr "Nem sikerült betölteni a szolgáltatólistát. Fájl: %1."
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr ""
 "Nem sikerült betölteni az új kiegészítők szolgáltatólistáját ebből a "
 "fájlból: %1"
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr "Hiba a szolgáltató inicializálásakor."
@@ -316,7 +316,7 @@ msgstr ""
 "Nem sikerült azonosítani a megfelelő hivatkozást a(z) %1 frissítéséhez, nem "
 "lehet végrehajtani a frissítést"
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, kde-format
 msgid ""
 "Failed to adopt '%1'\n"
@@ -325,14 +325,14 @@ msgstr ""
 "„%1” elfogadása sikertelen\n"
 "%2"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, kde-format
 msgctxt ""
 "The first entry in the category selection list (also the default value)"
 msgid "All Categories"
 msgstr "Minden kategória"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, kde-format
 msgctxt ""
 "The string passed back in the case the requested category is not known"
@@ -356,13 +356,13 @@ msgstr "dolgok"
 msgid "Download New %1…"
 msgstr "Új %1 letöltése…"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, kde-format
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "Új %1 letöltése"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, kde-format
 msgctxt ""
 "A placeholder title used in the dialog when there is no better title "
@@ -370,12 +370,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "Új cuccok letöltése"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr "Válasszon telepítési opciót"
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -387,19 +387,19 @@ msgstr ""
 "Ha bizonytalan abban, melyiket kellene választania, lépjen kapcsolatba az "
 "elem szerzőjével, aki segít tisztázni az elemek elnevezését."
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "Telepítés"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, kde-format
 msgctxt ""
 "A passive notification shown when installation of an item is initiated"
 msgid "Installing %1 from %2"
 msgstr "%1 telepítése innen: %2"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -407,10 +407,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr "%1, szerző: %2"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, kde-format
 msgctxt ""
 "Request installation of this item, available when there is exactly one "
@@ -418,32 +418,32 @@ msgctxt ""
 msgid "Install"
 msgstr "Telepítés"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, kde-format
 msgctxt ""
 "Show installation options, where there is more than one downloadable item"
 msgid "Install…"
 msgstr "Telepítés…"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, kde-format
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "Frissítés"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, kde-format
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "Eltávolítás"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -451,14 +451,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr "A(z) %1 (szerző: %2) elem feldolgozása folyamatban. Kis türelmet…"
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr "A(z) %1 (szerző: %2) elem frissítése folyamatban. Kis türelmet…"
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -472,12 +472,12 @@ msgstr ""
 "\"https://bugs.kde.org/enter_bug.cgi?product=frameworks-knewstuff\">Jelentse "
 "ezt a hibát a KDE Communitynek</a>."
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr "Megjegyzések és értékelések:"
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a new sub page with comments (comments "
@@ -485,17 +485,17 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "%1 értékelés és megjegyzés"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, kde-format
 msgid "Rating:"
 msgstr "Értékelés:"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, kde-format
 msgid "Homepage:"
 msgstr "Honlap:"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -504,12 +504,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr "A(z) %1 honlapjának megnyitása"
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr "Hogyan támogassa:"
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -517,75 +517,86 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr "Tudja meg, hogyan adományozhat ennek a projektnek"
 
-#: qtquick/qml/Page.qml:141
-#, kde-format
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
+#, fuzzy, kde-format
+#| msgid ""
+#| "The content available here has been uploaded by users like you, and has "
+#| "not been reviewed by your distributor for functionality or stability."
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 "Az itt található tartalmakat Önhöz hasonló felhasználók töltötték fel, a "
 "disztribúciója készítője nem ellenőrizte azokat funkcionalitás vagy "
 "stabilitás szempontjából."
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, kde-format
 msgid "Tiles"
 msgstr "Csempék"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "Ikonok"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, kde-format
 msgid "Preview"
 msgstr "Előnézet"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, kde-format
 msgid "Detailed Tiles View Mode"
 msgstr "Részletes csempenézet mód"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, kde-format
 msgid "Icons Only View Mode"
 msgstr "Ikonos nézetmód"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, kde-format
 msgid "Large Preview View Mode"
 msgstr "Nagy előnézeti nézetmód"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr "Minden"
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "Telepítve"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, kde-format
 msgid "Updateable"
 msgstr "Frissíthető"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, kde-format
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "Minden bejegyzés"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr "Csak telepített bejegyzések"
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -593,27 +604,27 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr "Csak frissíthető bejegyzések"
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, kde-format
 msgid "Recent"
 msgstr "Legutóbbiak"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr "Betűrendben"
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "Pontszám"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, kde-format
 msgid "Downloads"
 msgstr "Letöltések"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on when items were most "
@@ -621,7 +632,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "Legújabbak előre"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -629,57 +640,57 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr "Rendezés betűrendben név szerint"
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, kde-format
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "Legjobbra értékeltek előre"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on number of downloads"
 msgid "Show Most Downloaded First"
 msgstr "Legtöbbször letöltöttek előre"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, kde-format
 msgid "Upload…"
 msgstr "Feltöltés…"
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr "Ismerje meg, hogyan addhatja hozzá saját munkáját ehhez a listához"
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, kde-format
 msgid "Go to…"
 msgstr "Ugrás ide…"
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, kde-format
 msgid "Search…"
 msgstr "Keresés…"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "Kategória:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, kde-format
 msgid "Contribute your own…"
 msgstr "Tegye közzé sajátját…"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, kde-format
 msgctxt ""
 "Placeholder title for when a comment has no subject, but does have a rating"
 msgid "<i>(no title)</i>"
 msgstr "<i>(nincs cím)</i>"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -687,19 +698,19 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr "%1 <i>(szerző)</i>"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr "%1 megjegyzései és értékelései"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, kde-format
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "Minden megjegyzés megjelenítése"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -707,7 +718,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr "Csak értékelések megjelenítése"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -715,15 +726,15 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr "Értékelések és válaszok megjelenítése"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, kde-format
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
 msgstr "%1 letöltés"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, kde-format
 msgctxt ""
 "Subheading for the tile view, located immediately underneath the name of the "
@@ -731,7 +742,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "<i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -739,7 +750,7 @@ msgctxt ""
 msgid "Working…"
 msgstr "Folyamatban…"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is in the process of being "
@@ -747,7 +758,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "Frissítés…"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -761,7 +772,7 @@ msgstr ""
 "enter_bug.cgi?product=frameworks-knewstuff\">Jelentse ezt a hibát a KDE "
 "Communitynek</a>."
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, kde-format
 msgctxt "Label for the busy indicator showing an item is installing"
 msgid "Installing…"
@@ -778,44 +789,44 @@ msgstr "Hiba történt"
 msgid "Please try again later."
 msgstr "Próbálja újra később."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, kde-format
 msgid "None"
 msgstr "Nincs"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, kde-format
 msgctxt ""
 "A text representation of the rating, shown as a fraction of the max value"
 msgid "(%1/%2)"
 msgstr "(%1/%2)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, kde-format
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "Új dolog feltöltése: %1"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, kde-format
 msgctxt ""
 "A text shown beside a busy indicator suggesting that data is being fetched"
 msgid "Updating information…"
 msgstr "Adatok frissítése…"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, kde-format
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "KDE Store"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, kde-format
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "Az Ön szolgáltatója"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, kde-format
 msgctxt ""
 "Text for an action which causes the specified website to be opened using the "
@@ -823,7 +834,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "Weboldal megnyitása: %1"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, kde-format
 msgctxt ""
 "Text for an action which will attempt to send an email using the user's "
@@ -831,15 +842,22 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "E-mail küldése: %1"
 
-#: qtquick/qml/UploadPage.qml:154
-#, kde-format
+#: qtquick/qml/UploadPage.qml:159
+#, fuzzy, kde-format
+#| msgctxt "A description of how to upload content to a generic provider"
+#| msgid ""
+#| "To upload new entries, or to add content to an existing entry on the KDE "
+#| "Store, please open the website and log in. Once you have done this, you "
+#| "will be able to find the My Products entry in the menu which pops up when "
+#| "you click your user icon. Click on this entry to go to the product "
+#| "management system, where you can work on your products ."
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
 "To upload new entries, or to add content to an existing entry on the KDE "
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 "Új bejegyzések feltöltéséhez, vagy egy meglévő bejegyzés tartalmának "
 "hozzáadásához a KDE Store-hoz, kérjük, nyissa meg a weboldalt, és "
@@ -848,7 +866,7 @@ msgstr ""
 "ikonjára kattintva. Erre a bejegyzésre kattintva léphet a termékkezelési "
 "rendszerbe, ahol dolgozhat a termékein."
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -867,18 +885,18 @@ msgstr ""
 "hogy közvetlenül a webhely kezelőivel kell kapcsolatba lépnie az új tartalom "
 "hozzáadásához."
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "Adatok betöltése"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "Telepítés"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -891,73 +909,73 @@ msgstr ""
 "hiba, vegye fel a kapcsolatot az illetékessel a jogosultságai "
 "megváltoztatásához."
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "Vissza"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr "Népszerű"
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "Kiemelt"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "Újraindítás"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "New"
 msgstr "Új"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Kezdőlap"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr "Polc"
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "Fel"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "Ajánlott"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "Feliratkozások"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "Minden bejegyzés"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -1014,9 +1032,17 @@ msgstr ""
 " Egy példa egy ilyen url-re: kns://peruse.knsrc/api.kde-look.org/1316714"
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
-#, kde-format
-msgid "Download New Stuff..."
-msgstr "Új kiegészítők letöltése…"
+#, fuzzy, kde-format
+#| msgctxt ""
+#| "A placeholder title used in the dialog when there is no better title "
+#| "available"
+#| msgid "Download New Stuff"
+msgctxt "@action"
+msgid "Download New Stuff…"
+msgstr "Új cuccok letöltése"
+
+#~ msgid "Download New Stuff..."
+#~ msgstr "Új kiegészítők letöltése…"
 
 #~ msgctxt ""
 #~ "A message which is shown when the user attempts to display a specific "
diff -pruN 6.0.0-3/po/hy/knewstuff6.po 6.3.0-1/po/hy/knewstuff6.po
--- 6.0.0-3/po/hy/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/hy/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -6,7 +6,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2013-01-31 01:08+0400\n"
 "Last-Translator: Davit <nikdavnik@mail.ru>\n"
 "Language-Team: Armenian Language: hy\n"
@@ -60,7 +60,7 @@ msgstr "Ձեր ձայնը ընդունվ
 msgid "You are now a fan."
 msgstr "Այսուհետ դուք այս լրացման երկրպագուն եք։"
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -128,7 +128,7 @@ msgstr "Կարգավորումների 
 msgid "Use"
 msgstr ""
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -136,17 +136,17 @@ msgid ""
 "This is a critical error and should be reported to the application author"
 msgstr ""
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr "Հնարավոր չէ նիշքից ներբեռնել մատակարարների ցանկը: %1"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr "Հնարավոր չէ նիշքից ներբեռնել մատակարարների ցանկը: %1"
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr "Մատակարարի նախապատրաստման սխալ։"
@@ -291,7 +291,7 @@ msgid ""
 "the update"
 msgstr ""
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, fuzzy, kde-format
 #| msgid "Failed to load file '%1'"
 msgid ""
@@ -299,7 +299,7 @@ msgid ""
 "%2"
 msgstr "Նիշքի բացման սխալ «%1»"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt ""
@@ -307,7 +307,7 @@ msgctxt ""
 msgid "All Categories"
 msgstr "Բոլոր կատեգորիաները"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, fuzzy, kde-format
 #| msgid "Unknown error"
 msgctxt ""
@@ -333,14 +333,14 @@ msgstr ""
 msgid "Download New %1…"
 msgstr "Загрузить %1"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, fuzzy, kde-format
 #| msgid "Download New %1"
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "Загрузить %1"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
 msgctxt ""
@@ -349,12 +349,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "Загрузить материалы..."
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -363,12 +363,12 @@ msgid ""
 "this through the naming of the items."
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "Տեղադրել"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt ""
@@ -376,7 +376,7 @@ msgctxt ""
 msgid "Installing %1 from %2"
 msgstr "ՏԵղադրում"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -384,10 +384,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -396,10 +396,10 @@ msgctxt ""
 msgid "Install"
 msgstr "Տեղադրել"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -407,24 +407,24 @@ msgctxt ""
 msgid "Install…"
 msgstr "Տեղադրել"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, fuzzy, kde-format
 #| msgid "Update"
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "Թարմացում"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, fuzzy, kde-format
 #| msgid "Uninstall"
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "Ջնջել"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -432,14 +432,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -450,12 +450,12 @@ msgid ""
 "to the KDE Community in a bug report</a>."
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, fuzzy, kde-format
 #| msgid "View Comments"
 msgctxt ""
@@ -464,19 +464,19 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "Նայել մեկնաբանությունները"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, fuzzy, kde-format
 #| msgid "Rating: "
 msgid "Rating:"
 msgstr "Վարկանիշ: "
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, fuzzy, kde-format
 #| msgid "Homepage"
 msgid "Homepage:"
 msgstr "Վեբ-կայք"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -485,12 +485,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -498,79 +498,87 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr ""
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, fuzzy, kde-format
 #| msgctxt "@option:check Do filter on type - show only files"
 #| msgid "Files"
 msgid "Tiles"
 msgstr "նիշքեր"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "Նշաններ"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, kde-format
 msgid "Preview"
 msgstr "Миниатюры"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, fuzzy, kde-format
 #| msgid "Details view mode"
 msgid "Detailed Tiles View Mode"
 msgstr "Ցանկ"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, fuzzy, kde-format
 #| msgid "Icons view mode"
 msgid "Icons Only View Mode"
 msgstr "Նշաններ"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, fuzzy, kde-format
 #| msgid "Details view mode"
 msgid "Large Preview View Mode"
 msgstr "Ցանկ"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr ""
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "Տեղադրված"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, fuzzy, kde-format
 #| msgid "Update"
 msgid "Updateable"
 msgstr "Թարմացում"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "Բոլոր կատեգորիաները"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -578,31 +586,31 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Open Recent"
 msgid "Recent"
 msgstr "Վերջին նիշքերը"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr ""
 
 # վարկանիշ
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "Վարկանիշ"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, fuzzy, kde-format
 #| msgid "Download"
 msgid "Downloads"
 msgstr "Ներբեռնել"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt ""
@@ -611,7 +619,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "Թղթապանակները սկզբում"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -619,14 +627,14 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr ""
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "Թղթապանակները սկզբում"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, fuzzy, kde-format
 #| msgid "Most downloads"
 msgctxt ""
@@ -634,42 +642,42 @@ msgctxt ""
 msgid "Show Most Downloaded First"
 msgstr "Ամենաշատ ներբեռնված"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, fuzzy, kde-format
 #| msgid "Upload..."
 msgid "Upload…"
 msgstr "&Заменить..."
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr ""
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, fuzzy, kde-format
 #| msgid "&Go To..."
 msgid "Go to…"
 msgstr "&Անցնել..."
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, fuzzy, kde-format
 #| msgid "Search:"
 msgid "Search…"
 msgstr "Փնտրել:"
 
 # կարգ
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "Կատեգորիա:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, fuzzy, kde-format
 #| msgid "Continue operation"
 msgid "Contribute your own…"
 msgstr "Շարունակել գործողությունը"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, fuzzy, kde-format
 #| msgctxt "@note/rich"
 #| msgid "<i>Note</i>: %1"
@@ -678,7 +686,7 @@ msgctxt ""
 msgid "<i>(no title)</i>"
 msgstr "<i>Նշում</i>: %1"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -686,20 +694,20 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "Բոլոր կատեգորիաները"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -707,7 +715,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -715,8 +723,8 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, fuzzy, kde-format
 #| msgid "1 download"
 #| msgid_plural "%1 downloads"
@@ -724,8 +732,8 @@ msgctxt "The number of times the item ha
 msgid "%1 downloads"
 msgstr "%1 ներբեռնում"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, fuzzy, kde-format
 #| msgctxt "Show the author of this item in a list"
 #| msgid "By <i>%1</i>"
@@ -735,7 +743,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "Հեղինակ: <i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -743,7 +751,7 @@ msgctxt ""
 msgid "Working…"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, fuzzy, kde-format
 #| msgid "Updating"
 msgctxt ""
@@ -752,7 +760,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "Թարմացում"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -763,7 +771,7 @@ msgid ""
 "bug report</a>."
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt "Label for the busy indicator showing an item is installing"
@@ -782,14 +790,14 @@ msgstr ""
 msgid "Please try again later."
 msgstr "Մուտքագրեք անունը։"
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, fuzzy, kde-format
 #| msgctxt "No border line"
 #| msgid "None"
 msgid "None"
 msgstr "Առանց շրջանակի"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, fuzzy, kde-format
 #| msgid "(%1/s)"
 msgctxt ""
@@ -797,7 +805,7 @@ msgctxt ""
 msgid "(%1/%2)"
 msgstr "(%1/с)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
 msgctxt "@knewstuff6"
@@ -805,7 +813,7 @@ msgid "Upload New Stuff: %1"
 msgstr "Загрузить материалы..."
 
 # տեղեկության  արժեք
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, fuzzy, kde-format
 #| msgid "Billing information:"
 msgctxt ""
@@ -813,21 +821,21 @@ msgctxt ""
 msgid "Updating information…"
 msgstr "Տեղեկության  արժեք:"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, fuzzy, kde-format
 #| msgid "&Store"
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "&Պահպանել"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, fuzzy, kde-format
 #| msgid "Provider:"
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "Մատակարար:"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, fuzzy, kde-format
 #| msgctxt "@label:button"
 #| msgid "&Open with %1"
@@ -837,7 +845,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "&Բացել ըստ... «%1»"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, fuzzy, kde-format
 #| msgid "&Send Email"
 msgctxt ""
@@ -846,7 +854,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "&ՈՒղարկել"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -854,10 +862,10 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -869,18 +877,18 @@ msgid ""
 "content added."
 msgstr ""
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "Ինֆորամացիայի ներբեռնում"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "ՏԵղադրում"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -890,7 +898,7 @@ msgid ""
 "please contact the person in charge of your permissions."
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Back"
@@ -898,20 +906,20 @@ msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "Հետ"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, fuzzy, kde-format
 #| msgid "Saturday"
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "Суббота"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, fuzzy, kde-format
 #| msgctxt "@action:button Restart find & replace"
 #| msgid "Restart"
@@ -919,7 +927,7 @@ msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "Կրկնել"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "New"
@@ -927,7 +935,7 @@ msgctxt "Knewstuff5"
 msgid "New"
 msgstr "Ստեղծել"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Home"
@@ -935,13 +943,13 @@ msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Home"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Up"
@@ -949,7 +957,7 @@ msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "Սլաքը վերև"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, fuzzy, kde-format
 #| msgctxt "dictionary variant"
 #| msgid "extended"
@@ -957,7 +965,7 @@ msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "ընդլայնված"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Subscript"
@@ -965,14 +973,14 @@ msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "Ներքին ինդեքս"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "Բոլոր կատեգորիաները"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -1003,9 +1011,14 @@ msgid ""
 msgstr ""
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
-#, kde-format
-msgid "Download New Stuff..."
-msgstr "Ներբեռնել նյութեր..."
+#, fuzzy, kde-format
+#| msgid "Download New Stuff"
+msgctxt "@action"
+msgid "Download New Stuff…"
+msgstr "Загрузить материалы..."
+
+#~ msgid "Download New Stuff..."
+#~ msgstr "Ներբեռնել նյութեր..."
 
 #~ msgid "Initializing"
 #~ msgstr "Նախապատրաստում"
diff -pruN 6.0.0-3/po/ia/knewstuff6.po 6.3.0-1/po/ia/knewstuff6.po
--- 6.0.0-3/po/ia/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/ia/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -6,8 +6,8 @@ msgid ""
 msgstr ""
 "Project-Id-Version: \n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
-"PO-Revision-Date: 2024-01-19 10:05+0100\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
+"PO-Revision-Date: 2024-05-09 11:17+0200\n"
 "Last-Translator: giovanni <g.sora@tiscali.it>\n"
 "Language-Team: Interlingua <kde-i18n-doc@kde.org>\n"
 "Language: ia\n"
@@ -55,7 +55,7 @@ msgstr "Tu voto esseva registrate."
 msgid "You are now a fan."
 msgstr "Ora tu es un admirator."
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -127,7 +127,7 @@ msgstr "File de configuration non es val
 msgid "Use"
 msgstr "Usa"
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -138,17 +138,17 @@ msgstr ""
 "%2\n"
 "Isto es un error critic e deberea esser reportate al autor del application"
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr "Il carga le fornitores ex file:%1 es fallite"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr "Il non pote cargar le fornitores  de nove cosas ex le file:%1"
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr "Error durante que initialisava le fornitor."
@@ -322,7 +322,7 @@ msgstr ""
 "Noi falleva a identificar un bon ligamoine pro actualisar %1, e es incapace "
 "a executar le actualisation"
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, kde-format
 msgid ""
 "Failed to adopt '%1'\n"
@@ -331,14 +331,14 @@ msgstr ""
 "Il falleva a adoptar '%1'\n"
 "%2"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, kde-format
 msgctxt ""
 "The first entry in the category selection list (also the default value)"
 msgid "All Categories"
 msgstr "Omne categorias"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, kde-format
 msgctxt ""
 "The string passed back in the case the requested category is not known"
@@ -362,13 +362,13 @@ msgstr "Stuff (Cosa)"
 msgid "Download New %1…"
 msgstr "Discarga Nove %1..."
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, kde-format
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "Discarga Nove %1"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, kde-format
 msgctxt ""
 "A placeholder title used in the dialog when there is no better title "
@@ -376,12 +376,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "Il discarga cosas nove "
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr "Selige tu option de installation"
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -394,19 +394,19 @@ msgstr ""
 "optiones disponibile, pro favor tu continge le autor de iste elemento e "
 "demanda que illos clarar isto per nominar le elementos."
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "Installa"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, kde-format
 msgctxt ""
 "A passive notification shown when installation of an item is initiated"
 msgid "Installing %1 from %2"
 msgstr "Il es installante %1 ex %2"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -414,10 +414,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr "%1 per %2"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, kde-format
 msgctxt ""
 "Request installation of this item, available when there is exactly one "
@@ -425,32 +425,32 @@ msgctxt ""
 msgid "Install"
 msgstr "Installa"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, kde-format
 msgctxt ""
 "Show installation options, where there is more than one downloadable item"
 msgid "Install…"
 msgstr "Installa…"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, kde-format
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "Actualisa"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, kde-format
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "De-installa"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -459,7 +459,7 @@ msgid "Currently working on the item %1
 msgstr ""
 "Currentemente travaliante sur le elemento %1 per %2. Pro favor tu attende…"
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
@@ -467,7 +467,7 @@ msgid "Currently updating the item %1 by
 msgstr ""
 "Currentemente actualisante le elemento %1 per %2. Pro favor tu attende…"
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -481,12 +481,12 @@ msgstr ""
 "\"https://bugs.kde.org/enter_bug.cgi?product=frameworks-knewstuff\">Pro "
 "favor tu reporta isto al communitate de KDE in un reporto de bug</a>."
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr "Commentos e Reviews:"
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a new sub page with comments (comments "
@@ -494,17 +494,17 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "%1 Revisiones e Commentos"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, kde-format
 msgid "Rating:"
 msgstr "Evalutation o Punctage:"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, kde-format
 msgid "Homepage:"
 msgstr "Pagina Domo o Principal:"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -513,12 +513,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr "Aperi le pagina de initio per %1"
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr "Como donar:"
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -526,74 +526,86 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr "Discoperi como donar a iste projecto"
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+"Usa precautionquando on accede a contento create per le usator  monstrate "
+"hic, proque illo pote continer codice executabile que non ha essite "
+"verificate per KDE o per tu distributor per sanitate, stabilitate  o "
+"qualitate."
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
-"Le contento ci disponibile ha essite incargate per usatores como te, e non "
-"ha essite controlate per tu distributor per functionalitate o stabilitate."
+"Le contento create per le usator monstrate hic non ha essite controlate per "
+"KDE o per tu distributor per functionalitate o qualitate."
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, kde-format
 msgid "Tiles"
 msgstr "Tegulas "
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "Icones"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, kde-format
 msgid "Preview"
 msgstr "Vista preliminar"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, kde-format
 msgid "Detailed Tiles View Mode"
 msgstr "Modo de vista a detalios a tegulas"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, kde-format
 msgid "Icons Only View Mode"
 msgstr "Modo de vista solmente a icones"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, kde-format
 msgid "Large Preview View Mode"
 msgstr "Modo de vista preliminar grande"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr "Toto"
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "Installate"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, kde-format
 msgid "Updateable"
 msgstr "Actualisabile"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, kde-format
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "Monstra omne entratas"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr "Monstra solmente entratas installate"
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -601,27 +613,27 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr "Monstra solmente entratas actualisabile"
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, kde-format
 msgid "Recent"
 msgstr "Recente"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr "Alphabetic"
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "Evalutation"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, kde-format
 msgid "Downloads"
 msgstr "Discargamentos"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on when items were most "
@@ -629,7 +641,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "Monstra le plus recente prime"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -637,57 +649,57 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr "Ordina alphabeticamente per nomine"
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, kde-format
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "Monstra le plus alte prime"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on number of downloads"
 msgid "Show Most Downloaded First"
 msgstr "Monstra le plus discargate prime"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, kde-format
 msgid "Upload…"
 msgstr "Il carga ..."
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr "Apprende como adder tu proprie cosas nove (hot new stuff) a iste lista"
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, kde-format
 msgid "Go to…"
 msgstr "Vade a..."
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, kde-format
 msgid "Search…"
 msgstr "Cerca…"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "Categoria:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, kde-format
 msgid "Contribute your own…"
 msgstr "Contribue tu proprie..."
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, kde-format
 msgctxt ""
 "Placeholder title for when a comment has no subject, but does have a rating"
 msgid "<i>(no title)</i>"
 msgstr "<i>(necun titulo)</i>"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -695,19 +707,19 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr "%1 <i>(autor)</i>"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr "Commentos e Reviews per %1"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, kde-format
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "Monstra omne commentos"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -715,7 +727,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr "Monstra solmente reviews"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -723,15 +735,15 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr "Monstra reviews e replicas"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, kde-format
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
 msgstr "%1 discargamentos"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, kde-format
 msgctxt ""
 "Subheading for the tile view, located immediately underneath the name of the "
@@ -739,7 +751,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "Per <i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -747,7 +759,7 @@ msgctxt ""
 msgid "Working…"
 msgstr "Travaliante..."
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is in the process of being "
@@ -755,7 +767,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "Actualisante ..."
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -769,7 +781,7 @@ msgstr ""
 "product=frameworks-knewstuff\">Pro fvor tu reporta isto al Communitate de "
 "KDE in un reporto de bug</a>."
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, kde-format
 msgctxt "Label for the busy indicator showing an item is installing"
 msgid "Installing…"
@@ -786,44 +798,44 @@ msgstr "Un error occurreva"
 msgid "Please try again later."
 msgstr "Pro favor, tu essaya plus tarde."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, kde-format
 msgid "None"
 msgstr "Necun"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, kde-format
 msgctxt ""
 "A text representation of the rating, shown as a fraction of the max value"
 msgid "(%1/%2)"
 msgstr "(%1/%2)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, kde-format
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "Incarga cosas nove: %1 "
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, kde-format
 msgctxt ""
 "A text shown beside a busy indicator suggesting that data is being fetched"
 msgid "Updating information…"
 msgstr "Actualisante information ..."
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, kde-format
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "KDE Store (Immagazina de KDE)"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, kde-format
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "Tu fornitor (Provider)"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, kde-format
 msgctxt ""
 "Text for an action which causes the specified website to be opened using the "
@@ -831,7 +843,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "Aperi sito web: %1"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, kde-format
 msgctxt ""
 "Text for an action which will attempt to send an email using the user's "
@@ -839,7 +851,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr " Invia e-posta a : %1"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -847,7 +859,7 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 "Pro incargar nove entratas, o pro adder contento a un entrata existente in "
 "le KDE Store, pro favor aperi le sito web e eccede. Un vice que tu ha facite "
@@ -856,7 +868,7 @@ msgstr ""
 "entrata per vader al systema de gestion de producto, ubi tu pote laborar sur "
 "tu productos."
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -874,18 +886,18 @@ msgstr ""
 "Alternativemente, tu poterea esser rquirite a contactar le gerentes del sito "
 "directemente pro obtener que le nove contento es addite."
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "Cargante datos"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "Il es installante"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -897,73 +909,73 @@ msgstr ""
 "Tu non es autorisate a Obtener Nove Cosa Calide. Si tu pensa que isto es in "
 "error, pro favor tu continge le person incargate de tu permissiones."
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "Retro"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr "Popular"
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "Eminente"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "Re-Initia"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "New"
 msgstr "Nove "
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Domo o initio"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr "Planca"
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "In alto"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "Recommendate"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "Subscriptiones"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "Omne entratas"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -1009,8 +1021,12 @@ msgstr ""
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
 #, kde-format
-msgid "Download New Stuff..."
-msgstr "Il discarga cosas nove ..."
+msgctxt "@action"
+msgid "Download New Stuff…"
+msgstr "Il discarga cosas nove …"
+
+#~ msgid "Download New Stuff..."
+#~ msgstr "Il discarga cosas nove ..."
 
 #~ msgctxt ""
 #~ "A message which is shown when the user attempts to display a specific "
diff -pruN 6.0.0-3/po/id/knewstuff6.po 6.3.0-1/po/id/knewstuff6.po
--- 6.0.0-3/po/id/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/id/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -10,7 +10,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2023-12-27 18:14+0700\n"
 "Last-Translator: Wantoyèk <wantoyek@gmail.com>\n"
 "Language-Team: Indonesian <kde-i18n-doc@kde.org>\n"
@@ -59,7 +59,7 @@ msgstr "Suara Anda telah direkam."
 msgid "You are now a fan."
 msgstr "Anda sekarang seorang penggemar."
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -129,7 +129,7 @@ msgstr "File konfigurasi tidak absah: \"
 msgid "Use"
 msgstr "Gunakan"
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, fuzzy, kde-format
 #| msgid ""
 #| "Could not initialise the installation handler for %1\n"
@@ -143,18 +143,18 @@ msgstr ""
 "Ini adalah kesalahan yang kritis dan seharusnya dilaporkan ke penulis "
 "aplikasi"
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr "Memuat penyedia dari file: %1 gagal"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr ""
 "Tidak dapat memuat penyedia dapatkan barang baru yang keren dari file: %1"
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr "Terjadi kesalahan menginisialisasi penyedia."
@@ -323,7 +323,7 @@ msgstr ""
 "Kami tidak dapat mengidentifikasi tautan yang baik untuk memperbarui %1, dan "
 "tidak dapat melakukan pembaruan"
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, kde-format
 msgid ""
 "Failed to adopt '%1'\n"
@@ -332,14 +332,14 @@ msgstr ""
 "Gagal mengadopsi '%1'\n"
 "%2"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, kde-format
 msgctxt ""
 "The first entry in the category selection list (also the default value)"
 msgid "All Categories"
 msgstr "Semua Kategori"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, kde-format
 msgctxt ""
 "The string passed back in the case the requested category is not known"
@@ -370,13 +370,13 @@ msgstr "Hal-Hal"
 msgid "Download New %1…"
 msgstr "Unduh %1 Baru"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, kde-format
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "Unduh %1 Baru"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, kde-format
 msgctxt ""
 "A placeholder title used in the dialog when there is no better title "
@@ -384,12 +384,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "Unduh Barang Baru"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr "Pilih Opsi Penginstalan Anda"
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -402,19 +402,19 @@ msgstr ""
 "tersedia, silakan hubungi pembuat item ini dan minta mereka menjelaskannya "
 "melalui penamaan item."
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "Instal"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, kde-format
 msgctxt ""
 "A passive notification shown when installation of an item is initiated"
 msgid "Installing %1 from %2"
 msgstr "Menginstal %1 dari %2"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -422,10 +422,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr "%1 oleh %2"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, kde-format
 msgctxt ""
 "Request installation of this item, available when there is exactly one "
@@ -433,10 +433,10 @@ msgctxt ""
 msgid "Install"
 msgstr "Instal"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -444,22 +444,22 @@ msgctxt ""
 msgid "Install…"
 msgstr "Instal"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, kde-format
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "Perbarui"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, kde-format
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "Copot"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, fuzzy, kde-format
 #| msgctxt ""
 #| "Status message to be shown when the entry is in the process of being "
@@ -471,7 +471,7 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr "Sedang bekerja pada item %1 oleh %2. Mohon menunggu..."
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, fuzzy, kde-format
 #| msgctxt ""
 #| "Status message to be shown when the entry is in the process of being "
@@ -482,7 +482,7 @@ msgctxt ""
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr "Sedang memperbarui butir %1 oleh %2. Mohon tunggu..."
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -496,12 +496,12 @@ msgstr ""
 "\"https://bugs.kde.org/enter_bug.cgi?product=frameworks-knewstuff\">Silakan "
 "laporkan ini ke KDE Community sebagai laporan bug</a>."
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr "Komentar dan Ulasan:"
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a new sub page with comments (comments "
@@ -509,17 +509,17 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "%1 Ulasan dan Komentar"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, kde-format
 msgid "Rating:"
 msgstr "Peringkat:"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, kde-format
 msgid "Homepage:"
 msgstr "Laman:"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -528,12 +528,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr "Buka laman untuk %1"
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr "Bagaimana Cara Berdonasi:"
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -541,74 +541,85 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr "Temukan cara bagaimana berdonasi ke projek ini"
 
-#: qtquick/qml/Page.qml:141
-#, kde-format
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
+#, fuzzy, kde-format
+#| msgid ""
+#| "The content available here has been uploaded by users like you, and has "
+#| "not been reviewed by your distributor for functionality or stability."
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 "Konten yang tersedia di sini telah diunggah oleh pengguna seperti Anda, dan "
 "belum dilihat oleh distributor Anda untuk fungsionalitas atau stabilitas."
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, kde-format
 msgid "Tiles"
 msgstr "Ubin"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "Ikon"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, kde-format
 msgid "Preview"
 msgstr "Pratinjau"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, kde-format
 msgid "Detailed Tiles View Mode"
 msgstr "Mode Penampilan Ubin Berinci"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, kde-format
 msgid "Icons Only View Mode"
 msgstr "Mode Tampilan Ikon Saja"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, kde-format
 msgid "Large Preview View Mode"
 msgstr "Mode Penampilan Tampilan Besar"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr "Semuanya"
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "Terinstal"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, kde-format
 msgid "Updateable"
 msgstr "Yang Dapat Diperbarui"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, kde-format
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "Tampilkan Semua Entri"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr "Tampilkan Hanya Entri Yang Terinstal"
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -616,27 +627,27 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr "Tampilkan Hanya Entri Yang Dapat Diperbarui"
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, kde-format
 msgid "Recent"
 msgstr "Terkini"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr "Secara alfabet"
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "Peringkat"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, kde-format
 msgid "Downloads"
 msgstr "Unduhan"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on when items were most "
@@ -644,7 +655,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "Tampilkan Yang Terkini Dulu"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -652,62 +663,62 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr "Urutkan Menurut Abjad Berdasarkan Nama"
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, kde-format
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "Tampilkan Ulasan Tertinggi Dulu"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on number of downloads"
 msgid "Show Most Downloaded First"
 msgstr "Tampilkan Yang Banyak Diunduh Dulu"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, fuzzy, kde-format
 #| msgid "Upload..."
 msgid "Upload…"
 msgstr "Unggah..."
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr ""
 "Pelajari bagaimana untuk menambahkan hal-hal baru yang keren ke daftar ini"
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, fuzzy, kde-format
 #| msgid "Go to..."
 msgid "Go to…"
 msgstr "Pergi ke..."
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, fuzzy, kde-format
 #| msgid "Search:"
 msgid "Search…"
 msgstr "Cari:"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "Kategori:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, fuzzy, kde-format
 #| msgid "Contribute your own..."
 msgid "Contribute your own…"
 msgstr "Kontribusikan hal-hal Anda..."
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, kde-format
 msgctxt ""
 "Placeholder title for when a comment has no subject, but does have a rating"
 msgid "<i>(no title)</i>"
 msgstr "<i>(tidak ada judul)</i>"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -715,19 +726,19 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr "%1 <i>(penulis)</i>"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr "Komentar dan Ulasan untuk %1"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, kde-format
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "Tampilkan Semua Komentar"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -735,7 +746,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr "Tampilkan Ulasan Saja"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -743,15 +754,15 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr "Tampilkan Ulasan dan Balasan"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, kde-format
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
 msgstr "%1 unduhan"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, kde-format
 msgctxt ""
 "Subheading for the tile view, located immediately underneath the name of the "
@@ -759,7 +770,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "Oleh <i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, fuzzy, kde-format
 #| msgctxt ""
 #| "Label for the busy indicator showing an item is being installed OR "
@@ -771,7 +782,7 @@ msgctxt ""
 msgid "Working…"
 msgstr "Bekerja..."
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, fuzzy, kde-format
 #| msgid "Updating"
 msgctxt ""
@@ -780,7 +791,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "Memperbarui"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -794,7 +805,7 @@ msgstr ""
 "enter_bug.cgi?product=frameworks-knewstuff\">Silakan laporkan ini ke KDE "
 "Community sebagai laporan bug</a>."
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt "Label for the busy indicator showing an item is installing"
@@ -813,19 +824,19 @@ msgstr "Terjadi Sebuah Galat"
 msgid "Please try again later."
 msgstr "Tolong masukkan nama."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, kde-format
 msgid "None"
 msgstr "Nihil"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, kde-format
 msgctxt ""
 "A text representation of the rating, shown as a fraction of the max value"
 msgid "(%1/%2)"
 msgstr "(%1/%2)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, fuzzy, kde-format
 #| msgctxt "@knewstuff5"
 #| msgid "Upload New Stuff: %1"
@@ -833,7 +844,7 @@ msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "Unggah Hal-Hal Baru: %1"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, fuzzy, kde-format
 #| msgctxt ""
 #| "A text shown beside a busy indicator suggesting that data is being fetched"
@@ -843,19 +854,19 @@ msgctxt ""
 msgid "Updating information…"
 msgstr "Memperbarui informasi..."
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, kde-format
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "Toko KDE"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, kde-format
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "Penyedia Anda"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, kde-format
 msgctxt ""
 "Text for an action which causes the specified website to be opened using the "
@@ -863,7 +874,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "Buka Situs Web: %1"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, kde-format
 msgctxt ""
 "Text for an action which will attempt to send an email using the user's "
@@ -871,22 +882,29 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "Kirim Email Ke: %1"
 
-#: qtquick/qml/UploadPage.qml:154
-#, kde-format
+#: qtquick/qml/UploadPage.qml:159
+#, fuzzy, kde-format
+#| msgctxt "A description of how to upload content to a generic provider"
+#| msgid ""
+#| "To upload new entries, or to add content to an existing entry on the KDE "
+#| "Store, please open the website and log in. Once you have done this, you "
+#| "will be able to find the My Products entry in the menu which pops up when "
+#| "you click your user icon. Click on this entry to go to the product "
+#| "management system, where you can work on your products ."
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
 "To upload new entries, or to add content to an existing entry on the KDE "
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 "Untuk mengunggah entri baru, atau menambahkan konten baru ke entri yang "
 "sudah ada pada Toko KDE, mohon buka situs web dan masuk. Setelah itu, Anda "
 "akan dapat menemukan ikon pengguna Anda. Klik pada entri ini untuk pergi ke "
 "sistem pengelolaan produk, di mana Anda dapat bekerja pada produk Anda."
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -904,18 +922,18 @@ msgstr ""
 "Anda mungkin harus menghubungi pengelola situs secara langsung untuk dapat "
 "menambahkan konten baru."
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "Memuat data"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "Menginstal"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -928,73 +946,73 @@ msgstr ""
 "pikir ini adalah kesalahan, silakan hubungi seseorang yang berkuasa terhadap "
 "perizinan Anda."
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "Kembali"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr "Populer"
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "Difiturkan"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "Mulai Ulang"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "New"
 msgstr "Baru"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Beranda"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr "Rak"
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "Naik"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "Disarankan"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "Langganan"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "Semua Entri"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -1051,9 +1069,17 @@ msgstr ""
 " Contoh URL tersebut adalah kns://peruse.knsrc/api.kde-look.org/1316714"
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
-#, kde-format
-msgid "Download New Stuff..."
-msgstr "Unduh Hal-Hal Baru..."
+#, fuzzy, kde-format
+#| msgctxt ""
+#| "A placeholder title used in the dialog when there is no better title "
+#| "available"
+#| msgid "Download New Stuff"
+msgctxt "@action"
+msgid "Download New Stuff…"
+msgstr "Unduh Barang Baru"
+
+#~ msgid "Download New Stuff..."
+#~ msgstr "Unduh Hal-Hal Baru..."
 
 #~ msgctxt ""
 #~ "A message which is shown when the user attempts to display a specific "
diff -pruN 6.0.0-3/po/is/knewstuff6.po 6.3.0-1/po/is/knewstuff6.po
--- 6.0.0-3/po/is/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/is/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -11,7 +11,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2013-05-13 22:40+0000\n"
 "Last-Translator: Sveinn í Felli <sveinki@nett.is>\n"
 "Language-Team: Icelandic <kde-isl@molar.is>\n"
@@ -67,7 +67,7 @@ msgstr "Atkvæðið þitt komst til skil
 msgid "You are now a fan."
 msgstr "Þú ert núna aðdáandi."
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -136,7 +136,7 @@ msgstr "Stillingarskrá er ógild: \"%1\
 msgid "Use"
 msgstr ""
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -144,19 +144,19 @@ msgid ""
 "This is a critical error and should be reported to the application author"
 msgstr ""
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr "Hleðsla upplýsinga um útgefendur úr skránni: %1 mistókst"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr ""
 "Gat ekki hlaðið inn upplýsingar um útgefendur á nýju flottu dóti úr skránni: "
 "%1"
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr "Villa við að frumstilla útgefandaupplýsingar."
@@ -301,7 +301,7 @@ msgid ""
 "the update"
 msgstr ""
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, fuzzy, kde-format
 #| msgid "Failed to load file '%1'"
 msgid ""
@@ -309,7 +309,7 @@ msgid ""
 "%2"
 msgstr "Gat ekki lesið skrána '%1'"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt ""
@@ -317,7 +317,7 @@ msgctxt ""
 msgid "All Categories"
 msgstr "Allir flokkar"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, fuzzy, kde-format
 #| msgid "Unknown error"
 msgctxt ""
@@ -343,14 +343,14 @@ msgstr ""
 msgid "Download New %1…"
 msgstr "Sækja nýtt dót..."
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, fuzzy, kde-format
 #| msgid "Download New Stuff..."
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "Sækja nýtt dót..."
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, fuzzy, kde-format
 #| msgid "Download New Stuff..."
 msgctxt ""
@@ -359,12 +359,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "Sækja nýtt dót..."
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -373,12 +373,12 @@ msgid ""
 "this through the naming of the items."
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "Setja inn"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt ""
@@ -386,7 +386,7 @@ msgctxt ""
 msgid "Installing %1 from %2"
 msgstr "Uppsetning"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -394,10 +394,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -406,10 +406,10 @@ msgctxt ""
 msgid "Install"
 msgstr "Setja inn"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -417,24 +417,24 @@ msgctxt ""
 msgid "Install…"
 msgstr "Setja inn"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, fuzzy, kde-format
 #| msgid "Update"
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "Uppfæra"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, fuzzy, kde-format
 #| msgid "Uninstall"
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "Henda út"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -442,14 +442,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -460,12 +460,12 @@ msgid ""
 "to the KDE Community in a bug report</a>."
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, fuzzy, kde-format
 #| msgid "View Comments"
 msgctxt ""
@@ -474,19 +474,19 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "Skoða athugasemdir"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, fuzzy, kde-format
 #| msgid "Rating: "
 msgid "Rating:"
 msgstr "Einkunn: "
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, fuzzy, kde-format
 #| msgid "Homepage"
 msgid "Homepage:"
 msgstr "Heimasíða"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -495,12 +495,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -508,80 +508,88 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr ""
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, fuzzy, kde-format
 #| msgctxt "@option:check Do filter on type - show only files"
 #| msgid "Files"
 msgid "Tiles"
 msgstr "Skrár"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "Táknmyndir"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, fuzzy, kde-format
 #| msgid "Preview URL:"
 msgid "Preview"
 msgstr "Forsýna slóð:"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, fuzzy, kde-format
 #| msgid "Details view mode"
 msgid "Detailed Tiles View Mode"
 msgstr "Hamur smáatriðasýnar"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, fuzzy, kde-format
 #| msgid "Icons view mode"
 msgid "Icons Only View Mode"
 msgstr "Hamur táknmyndasýnar"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, fuzzy, kde-format
 #| msgid "Details view mode"
 msgid "Large Preview View Mode"
 msgstr "Hamur smáatriðasýnar"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr ""
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "Uppsett"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, fuzzy, kde-format
 #| msgid "Update"
 msgid "Updateable"
 msgstr "Uppfæra"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "Allir flokkar"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -589,30 +597,30 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Open Recent"
 msgid "Recent"
 msgstr "Opna nýlegt"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr ""
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "Einkunn"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, fuzzy, kde-format
 #| msgid "Download"
 msgid "Downloads"
 msgstr "Sækja"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt ""
@@ -621,7 +629,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "Sýna möppur fyrst"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -629,14 +637,14 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr ""
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "Sýna möppur fyrst"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, fuzzy, kde-format
 #| msgid "Most downloads"
 msgctxt ""
@@ -644,41 +652,41 @@ msgctxt ""
 msgid "Show Most Downloaded First"
 msgstr "Flest niðurhöl"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, fuzzy, kde-format
 #| msgid "New Upload"
 msgid "Upload…"
 msgstr "Ný sending"
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr ""
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, fuzzy, kde-format
 #| msgid "&Go To..."
 msgid "Go to…"
 msgstr "&Fara að..."
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, fuzzy, kde-format
 #| msgid "Search:"
 msgid "Search…"
 msgstr "Leita:"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "Flokkur:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, fuzzy, kde-format
 #| msgid "Continue operation"
 msgid "Contribute your own…"
 msgstr "Halda áfram aðgerð"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, fuzzy, kde-format
 #| msgctxt "@note/rich"
 #| msgid "<i>Note</i>: %1"
@@ -687,7 +695,7 @@ msgctxt ""
 msgid "<i>(no title)</i>"
 msgstr "<i>Athugasemd</i>: %1"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -695,20 +703,20 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "Allir flokkar"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -716,7 +724,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -724,8 +732,8 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, fuzzy, kde-format
 #| msgid "1 download"
 #| msgid_plural "%1 downloads"
@@ -733,8 +741,8 @@ msgctxt "The number of times the item ha
 msgid "%1 downloads"
 msgstr "1 niðurhal"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, fuzzy, kde-format
 #| msgctxt "Show the author of this item in a list"
 #| msgid "By <i>%1</i>"
@@ -744,7 +752,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "Eftir <i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -752,7 +760,7 @@ msgctxt ""
 msgid "Working…"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, fuzzy, kde-format
 #| msgid "Updating"
 msgctxt ""
@@ -761,7 +769,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "Uppfæri"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -772,7 +780,7 @@ msgid ""
 "bug report</a>."
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt "Label for the busy indicator showing an item is installing"
@@ -791,14 +799,14 @@ msgstr ""
 msgid "Please try again later."
 msgstr "Vinsamlega sláðu inn heiti."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, fuzzy, kde-format
 #| msgctxt "No border line"
 #| msgid "None"
 msgid "None"
 msgstr "Engin"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, fuzzy, kde-format
 #| msgid "(%1/s)"
 msgctxt ""
@@ -806,14 +814,14 @@ msgctxt ""
 msgid "(%1/%2)"
 msgstr "(%1/s)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, fuzzy, kde-format
 #| msgid "Download New Stuff..."
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "Sækja nýtt dót..."
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, fuzzy, kde-format
 #| msgid "Billing information:"
 msgctxt ""
@@ -821,21 +829,21 @@ msgctxt ""
 msgid "Updating information…"
 msgstr "Reikningsupplýsingar:"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, fuzzy, kde-format
 #| msgid "&Store"
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "&Geyma"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, fuzzy, kde-format
 #| msgid "Provider:"
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "Miðlari:"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, fuzzy, kde-format
 #| msgctxt "@label:button"
 #| msgid "&Open with %1"
@@ -845,7 +853,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "&Opna með %1"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, fuzzy, kde-format
 #| msgid "&Send Email"
 msgctxt ""
@@ -854,7 +862,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "&Senda tölvupóst"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -862,10 +870,10 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -877,18 +885,18 @@ msgid ""
 "content added."
 msgstr ""
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "Hleð inn gögnum"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "Uppsetning"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -898,7 +906,7 @@ msgid ""
 "please contact the person in charge of your permissions."
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Back"
@@ -906,19 +914,19 @@ msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "Til baka"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, fuzzy, kde-format
 #| msgctxt "@action:button Restart find & replace"
 #| msgid "Restart"
@@ -926,7 +934,7 @@ msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "Endurræsa"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "New"
@@ -934,7 +942,7 @@ msgctxt "Knewstuff5"
 msgid "New"
 msgstr "Ný"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Home"
@@ -942,13 +950,13 @@ msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Home"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Up"
@@ -956,7 +964,7 @@ msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "Upp"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, fuzzy, kde-format
 #| msgctxt "dictionary variant"
 #| msgid "extended"
@@ -964,7 +972,7 @@ msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "útvíkkað"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Subscript"
@@ -972,14 +980,14 @@ msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "Lágletur"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "Allir flokkar"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -1010,10 +1018,15 @@ msgid ""
 msgstr ""
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
-#, kde-format
-msgid "Download New Stuff..."
+#, fuzzy, kde-format
+#| msgid "Download New Stuff..."
+msgctxt "@action"
+msgid "Download New Stuff…"
 msgstr "Sækja nýtt dót..."
 
+#~ msgid "Download New Stuff..."
+#~ msgstr "Sækja nýtt dót..."
+
 #~ msgid "Initializing"
 #~ msgstr "Frumstilli"
 
diff -pruN 6.0.0-3/po/it/knewstuff6.po 6.3.0-1/po/it/knewstuff6.po
--- 6.0.0-3/po/it/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/it/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -16,8 +16,8 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
-"PO-Revision-Date: 2024-01-19 16:53+0100\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
+"PO-Revision-Date: 2024-05-08 17:11+0200\n"
 "Last-Translator: Vincenzo Reale <smart2128vr@gmail.com>\n"
 "Language-Team: Italian <kde-i18n-it@kde.org>\n"
 "Language: it\n"
@@ -25,7 +25,7 @@ msgstr ""
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=2; plural=(n != 1);\n"
-"X-Generator: Lokalize 23.08.4\n"
+"X-Generator: Lokalize 24.02.2\n"
 
 #: attica/atticaprovider.cpp:165
 #, kde-format
@@ -65,7 +65,7 @@ msgstr "Il tuo voto è stato registrato.
 msgid "You are now a fan."
 msgstr "Adesso sei un fan."
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -135,7 +135,7 @@ msgstr "File di configurazione non valid
 msgid "Use"
 msgstr "Utilizza"
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -146,17 +146,17 @@ msgstr ""
 "%2\n"
 "Questo è un errore grave e deve essere segnalato all'autore dell'applicazione"
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr "Caricamento dei fornitori dal file: %1 non riuscito"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr "Impossibile caricare i fornitori delle Novità dal file: %1"
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr "Errore nell'inizializzazione del fornitore."
@@ -332,7 +332,7 @@ msgstr ""
 "Non siamo riusciti a identificare un buon collegamento per l'aggiornamento "
 "di %1 e non siamo in grado di eseguire l'aggiornamento"
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, kde-format
 msgid ""
 "Failed to adopt '%1'\n"
@@ -341,14 +341,14 @@ msgstr ""
 "Adozione di «%1» non riuscita\n"
 "%2"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, kde-format
 msgctxt ""
 "The first entry in the category selection list (also the default value)"
 msgid "All Categories"
 msgstr "Tutte le categorie"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, kde-format
 msgctxt ""
 "The string passed back in the case the requested category is not known"
@@ -372,13 +372,13 @@ msgstr "Novità"
 msgid "Download New %1…"
 msgstr "Scarica nuova %1…"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, kde-format
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "Scarica nuovi/e %1"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, kde-format
 msgctxt ""
 "A placeholder title used in the dialog when there is no better title "
@@ -386,12 +386,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "Scarica le novità"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr "Scegli le tue opzioni di installazione"
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -404,19 +404,19 @@ msgstr ""
 "dovresti scegliere, contatta l'autore di questo elemento e chiedi un "
 "chiarimento tramite l'assegnazione di nomi agli elementi."
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "Installa"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, kde-format
 msgctxt ""
 "A passive notification shown when installation of an item is initiated"
 msgid "Installing %1 from %2"
 msgstr "Installazione %1 da %2"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -424,10 +424,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr "%1 da %2"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, kde-format
 msgctxt ""
 "Request installation of this item, available when there is exactly one "
@@ -435,32 +435,32 @@ msgctxt ""
 msgid "Install"
 msgstr "Installa"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, kde-format
 msgctxt ""
 "Show installation options, where there is more than one downloadable item"
 msgid "Install…"
 msgstr "Installa…"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, kde-format
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "Aggiorna"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, kde-format
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "Disinstalla"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -468,14 +468,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr "Attualmente in lavorazione sull'elemento %1 da %2. Attendi..."
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr "Aggiornamento dell'elemento %1 da %2 in corso. Attendi…"
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -489,12 +489,12 @@ msgstr ""
 "\"https://bugs.kde.org/enter_bug.cgi?product=frameworks-knewstuff"
 "\">Segnalalo alla comunità di KDE in una segnalazione di bug</a>."
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr "Commenti e revisioni:"
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a new sub page with comments (comments "
@@ -502,17 +502,17 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "%1 revisioni e commenti"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, kde-format
 msgid "Rating:"
 msgstr "Valutazione:"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, kde-format
 msgid "Homepage:"
 msgstr "Pagina principale:"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -521,12 +521,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr "Apri la pagina principale per %1"
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr "Come donare:"
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -534,75 +534,85 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr "Scopri come donare a questo progetto"
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+"Presta attenzione quando accedi ai contenuti creati dagli utenti mostrati "
+"qui, poiché potrebbero contenere codice eseguibile che non è stato testato "
+"da KDE o dal tuo distributore per sicurezza, stabilità o qualità"
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
-"Il contenuto disponibile qui è stato caricato da utenti come te, e non è "
-"stato esaminato dal tuo distributore per verificarne la funzionalità e la "
-"stabilità."
+"Il contenuto creato dall'utente mostrato qui non è stato testato da KDE o "
+"dal tuo distributore per funzionalità o qualità."
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, kde-format
 msgid "Tiles"
 msgstr "Piastrelle"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "Icone"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, kde-format
 msgid "Preview"
 msgstr "Anteprima"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, kde-format
 msgid "Detailed Tiles View Mode"
 msgstr "Modalità di visualizzazione con piastrelle dettagliate"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, kde-format
 msgid "Icons Only View Mode"
 msgstr "Modalità di visualizzazione con sole icone"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, kde-format
 msgid "Large Preview View Mode"
 msgstr "Modalità di visualizzazione con anteprima grande"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr "Tutto"
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "Installato"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, kde-format
 msgid "Updateable"
 msgstr "Aggiornabili"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, kde-format
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "Mostra tutte le voci"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr "Mostra solo le voci degli installati"
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -610,27 +620,27 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr "Mostra solo le voci degli aggiornabili"
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, kde-format
 msgid "Recent"
 msgstr "Recenti"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr "Ordine alfabetico"
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "Valutazione"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, kde-format
 msgid "Downloads"
 msgstr "Scaricamenti"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on when items were most "
@@ -638,7 +648,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "Mostra prima i più recenti"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -646,57 +656,57 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr "Ordine alfabetico dei nomi"
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, kde-format
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "Mostra prima i più valutati"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on number of downloads"
 msgid "Show Most Downloaded First"
 msgstr "Mostra prima i più scaricati"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, kde-format
 msgid "Upload…"
 msgstr "Carica…"
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr "Scopri come aggiungere le tue novità nuove a questo elenco"
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, kde-format
 msgid "Go to…"
 msgstr "Vai a..."
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, kde-format
 msgid "Search…"
 msgstr "Cerca…"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "Categoria:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, kde-format
 msgid "Contribute your own…"
 msgstr "Contribuisci..."
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, kde-format
 msgctxt ""
 "Placeholder title for when a comment has no subject, but does have a rating"
 msgid "<i>(no title)</i>"
 msgstr "<i>(nessun titolo)</i>"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -704,19 +714,19 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr "%1 <i>(autore)</i>"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr "Commenti e revisioni per %1"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, kde-format
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "Mostra tutti commenti"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -724,7 +734,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr "Mostra solo le revisioni"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -732,15 +742,15 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr "Mostra revisioni e risposte"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, kde-format
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
 msgstr "%1 scaricamenti"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, kde-format
 msgctxt ""
 "Subheading for the tile view, located immediately underneath the name of the "
@@ -748,7 +758,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "Di <i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -756,7 +766,7 @@ msgctxt ""
 msgid "Working…"
 msgstr "In lavorazione…"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is in the process of being "
@@ -764,7 +774,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "Aggiornamento…"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -778,7 +788,7 @@ msgstr ""
 "product=frameworks-knewstuff\">Segnalalo alla comunità di KDE in una "
 "segnalazione di bug</a>."
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, kde-format
 msgctxt "Label for the busy indicator showing an item is installing"
 msgid "Installing…"
@@ -795,44 +805,44 @@ msgstr "Si è verificato un errore"
 msgid "Please try again later."
 msgstr "Riprova più tardi."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, kde-format
 msgid "None"
 msgstr "Nessuno"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, kde-format
 msgctxt ""
 "A text representation of the rating, shown as a fraction of the max value"
 msgid "(%1/%2)"
 msgstr "(%1/%2)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, kde-format
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "Carica novità: %1"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, kde-format
 msgctxt ""
 "A text shown beside a busy indicator suggesting that data is being fetched"
 msgid "Updating information…"
 msgstr "Aggiornamento delle informazioni…"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, kde-format
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "KDE Store"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, kde-format
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "Il tuo fornitore"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, kde-format
 msgctxt ""
 "Text for an action which causes the specified website to be opened using the "
@@ -840,7 +850,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "Apri il sito web: %1"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, kde-format
 msgctxt ""
 "Text for an action which will attempt to send an email using the user's "
@@ -848,7 +858,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "Invia messaggio di posta a: %1"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -856,15 +866,15 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 "Per caricare nuove voci o aggiungere contenuto a una voce esistente sul KDE "
 "Store, apri il sito web e accedi. Una volta fatto ciò, sarai in grado di "
-"trovare la voce I miei prodotti nel menu che si apre quando fai clic "
+"trovare la voce I miei prodotti nel menu che appare quando fai clic "
 "sull'icona dell'utente. Fai clic su questa voce per accedere al sistema di "
-"gestione del prodotto, dove è possibile lavorare sui tuoi prodotti."
+"gestione dei prodotti, dove è possibile lavorare sui tuoi prodotti."
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -882,18 +892,18 @@ msgstr ""
 "necessario contattare direttamente i gestori del sito per aggiungere nuovi "
 "contenuti."
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "Caricamento dei dati"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "Installazione"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -905,73 +915,73 @@ msgstr ""
 "Non sei autorizzato a ottenere le novità. Se pensi sia un errore, contatta "
 "la persona che gestisce in tuoi permessi."
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "Indietro"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr "Popolari"
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "In primo piano"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "Riavvia"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "New"
 msgstr "Nuovo"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Pagina principale"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr "Mensola"
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "Su"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "Consigliate"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "Sottoscrizioni"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "Tutte le voci"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -1018,9 +1028,13 @@ msgstr ""
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
 #, kde-format
-msgid "Download New Stuff..."
+msgctxt "@action"
+msgid "Download New Stuff…"
 msgstr "Scarica le novità..."
 
+#~ msgid "Download New Stuff..."
+#~ msgstr "Scarica le novità..."
+
 #~ msgctxt ""
 #~ "A message which is shown when the user attempts to display a specific "
 #~ "entry from a specific provider, but that entry isn't found"
diff -pruN 6.0.0-3/po/ja/knewstuff6.po 6.3.0-1/po/ja/knewstuff6.po
--- 6.0.0-3/po/ja/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/ja/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -15,7 +15,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2024-02-23 02:27+0900\n"
 "Last-Translator: Ryuichi Yamada <ryuichi_ya220@outlook.jp>\n"
 "Language-Team: ja\n"
@@ -66,7 +66,7 @@ msgstr "投票に成功しました。"
 msgid "You are now a fan."
 msgstr "ファンに登録しました。"
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -134,7 +134,7 @@ msgstr "無効な設定ファイルで
 msgid "Use"
 msgstr "使用する"
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -146,17 +146,17 @@ msgstr ""
 "これは重大なエラーです。アプリケーションの作者に報告することを検討してくださ"
 "い。"
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr "ファイル ‘%1’ からプロバイダを読み込めませんでした"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr "ファイル ‘%1’ からホットな新しいもののプロバイダを読み込めませんでした"
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr "プロバイダの初期化に失敗。"
@@ -299,21 +299,21 @@ msgid ""
 "the update"
 msgstr ""
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, kde-format
 msgid ""
 "Failed to adopt '%1'\n"
 "%2"
 msgstr ""
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, kde-format
 msgctxt ""
 "The first entry in the category selection list (also the default value)"
 msgid "All Categories"
 msgstr "すべてのカテゴリ"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, kde-format
 msgctxt ""
 "The string passed back in the case the requested category is not known"
@@ -337,13 +337,13 @@ msgstr "もの"
 msgid "Download New %1…"
 msgstr "新しい %1 をダウンロード…"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, kde-format
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "新しい %1 をダウンロード"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, kde-format
 msgctxt ""
 "A placeholder title used in the dialog when there is no better title "
@@ -351,12 +351,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "新しいものをダウンロード"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr "インストールオプションを選択"
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -368,19 +368,19 @@ msgstr ""
 "ください。どれを選択すべきか分からない場合、このアイテムの作者に連絡し、アイ"
 "テムを明確にするためにわかりやすい名前付けをするよう尋ねてみてください。"
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "インストール"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, kde-format
 msgctxt ""
 "A passive notification shown when installation of an item is initiated"
 msgid "Installing %1 from %2"
 msgstr "%2 から %1 をインストール中"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -388,10 +388,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr "%1 作者: %2"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, kde-format
 msgctxt ""
 "Request installation of this item, available when there is exactly one "
@@ -399,32 +399,32 @@ msgctxt ""
 msgid "Install"
 msgstr "インストール"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, kde-format
 msgctxt ""
 "Show installation options, where there is more than one downloadable item"
 msgid "Install…"
 msgstr "インストール…"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, kde-format
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "アップデート"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, kde-format
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "アンインストール"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -432,14 +432,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr "%2 の %1 に関する処理を実行しています。しばらくお待ちください..."
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr "%2 の %1 を更新しています。しばらくお待ちください..."
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -453,12 +453,12 @@ msgstr ""
 "org/enter_bug.cgi?product=frameworks-knewstuff\">KDE Community にこのバグを報"
 "告してください。</a>"
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr "コメントとレビュー:"
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a new sub page with comments (comments "
@@ -466,17 +466,17 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "%1 個のレビューとコメント"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, kde-format
 msgid "Rating:"
 msgstr "評価:"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, kde-format
 msgid "Homepage:"
 msgstr "ホームページ:"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -485,12 +485,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr "%1 のホームページを開く"
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr "寄付の方法:"
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -498,75 +498,86 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr "このプロジェクトに寄付する方法を調べる"
 
-#: qtquick/qml/Page.qml:141
-#, kde-format
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
+#, fuzzy, kde-format
+#| msgid ""
+#| "The content available here has been uploaded by users like you, and has "
+#| "not been reviewed by your distributor for functionality or stability."
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 "ここで取得できるコンテンツは、あなたのようなユーザによってアップロードされて"
 "います。そのため、ディストリビュータによる機能性や安定性の確認はされていませ"
 "ん。"
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, kde-format
 msgid "Tiles"
 msgstr "タイトル"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "アイコン"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, kde-format
 msgid "Preview"
 msgstr "プレビュー"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, kde-format
 msgid "Detailed Tiles View Mode"
 msgstr "詳細タイル表示モード"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, kde-format
 msgid "Icons Only View Mode"
 msgstr "アイコン表示モード"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, kde-format
 msgid "Large Preview View Mode"
 msgstr "大きなプレビュー表示モード"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr "すべて"
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "インストール済み"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, kde-format
 msgid "Updateable"
 msgstr "更新できるもの"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, kde-format
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "すべてのエントリを表示"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr "インストール済みのエントリのみ表示"
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -574,27 +585,27 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr "更新できるエントリのみ表示"
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, kde-format
 msgid "Recent"
 msgstr "最近更新"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr "アルファベット順"
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "評価"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, kde-format
 msgid "Downloads"
 msgstr "ダウンロード"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on when items were most "
@@ -602,7 +613,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "最新のもの順に表示"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -610,57 +621,57 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr "アルファベット順にソート"
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, kde-format
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "高評価順に表示"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on number of downloads"
 msgid "Show Most Downloaded First"
 msgstr "ダウンロード数が多い順に表示"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, kde-format
 msgid "Upload…"
 msgstr "アップロード…"
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr "作成したものをこのリストに追加する方法を知る"
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, kde-format
 msgid "Go to…"
 msgstr "移動…"
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, kde-format
 msgid "Search…"
 msgstr "検索…"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "カテゴリ:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, kde-format
 msgid "Contribute your own…"
 msgstr "作成したものをアップロード..."
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, kde-format
 msgctxt ""
 "Placeholder title for when a comment has no subject, but does have a rating"
 msgid "<i>(no title)</i>"
 msgstr "(タイトルなし)"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -668,19 +679,19 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr "%1 <i>(作者)</i>"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr "%1 のコメントとレビュー"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, kde-format
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "すべてのコメントを表示"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -688,7 +699,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr "レビューのみ表示"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -696,15 +707,15 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr "レビューと返信を表示"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, kde-format
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
 msgstr "%1 回のダウンロード"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, kde-format
 msgctxt ""
 "Subheading for the tile view, located immediately underneath the name of the "
@@ -712,7 +723,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "作者: <i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -720,7 +731,7 @@ msgctxt ""
 msgid "Working…"
 msgstr "進行中…"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is in the process of being "
@@ -728,7 +739,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "アップデート中…"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -742,7 +753,7 @@ msgstr ""
 "product=frameworks-knewstuff\">KDE Community にこのバグを報告してください。</"
 "a>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, kde-format
 msgctxt "Label for the busy indicator showing an item is installing"
 msgid "Installing…"
@@ -759,44 +770,44 @@ msgstr "エラーが発生しました"
 msgid "Please try again later."
 msgstr "しばらくたってからやり直してください。"
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, kde-format
 msgid "None"
 msgstr "なし"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, kde-format
 msgctxt ""
 "A text representation of the rating, shown as a fraction of the max value"
 msgid "(%1/%2)"
 msgstr "(%1/%2)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, kde-format
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "新しいものをアップロード: %1"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, kde-format
 msgctxt ""
 "A text shown beside a busy indicator suggesting that data is being fetched"
 msgid "Updating information…"
 msgstr "情報を更新中..."
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, kde-format
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "KDE Store"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, kde-format
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "プロバイダ"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, kde-format
 msgctxt ""
 "Text for an action which causes the specified website to be opened using the "
@@ -804,7 +815,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "ウェブサイトを開く: %1"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, kde-format
 msgctxt ""
 "Text for an action which will attempt to send an email using the user's "
@@ -812,22 +823,29 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "メールを送信する: %1"
 
-#: qtquick/qml/UploadPage.qml:154
-#, kde-format
+#: qtquick/qml/UploadPage.qml:159
+#, fuzzy, kde-format
+#| msgctxt "A description of how to upload content to a generic provider"
+#| msgid ""
+#| "To upload new entries, or to add content to an existing entry on the KDE "
+#| "Store, please open the website and log in. Once you have done this, you "
+#| "will be able to find the My Products entry in the menu which pops up when "
+#| "you click your user icon. Click on this entry to go to the product "
+#| "management system, where you can work on your products ."
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
 "To upload new entries, or to add content to an existing entry on the KDE "
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 "新しいエントリをアップロード、もしくは既存のエントリに何かを追加するには、"
 "KDE Store を開いてログインしてください。あなたのユーザアイコンをクリックする"
 "と表示されるメニューに、\"My Products\" エントリがあります。このエントリをク"
 "リックして管理システムを開き、あなたの製作物を公開してください。"
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -843,18 +861,18 @@ msgstr ""
 "ユーザアカウントを作成してログインする必要があります。コンテンツを追加するた"
 "めに、ウェブサイトの管理者への連絡が要求されることもあります。"
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "データをロード中"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "インストール中"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -864,73 +882,73 @@ msgid ""
 "please contact the person in charge of your permissions."
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "戻る"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr "人気"
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "おすすめ"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "再起動"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "New"
 msgstr "最新"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "ホーム"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "上へ"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "おすすめ"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "サブスクリプション"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "すべてのエントリ"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -961,6 +979,14 @@ msgid ""
 msgstr ""
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
-#, kde-format
-msgid "Download New Stuff..."
-msgstr "新しいものをダウンロード..."
+#, fuzzy, kde-format
+#| msgctxt ""
+#| "A placeholder title used in the dialog when there is no better title "
+#| "available"
+#| msgid "Download New Stuff"
+msgctxt "@action"
+msgid "Download New Stuff…"
+msgstr "新しいものをダウンロード"
+
+#~ msgid "Download New Stuff..."
+#~ msgstr "新しいものをダウンロード..."
diff -pruN 6.0.0-3/po/ka/knewstuff6.po 6.3.0-1/po/ka/knewstuff6.po
--- 6.0.0-3/po/ka/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/ka/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -7,8 +7,8 @@ msgid ""
 msgstr ""
 "Project-Id-Version: knewstuff\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
-"PO-Revision-Date: 2024-01-19 06:25+0100\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
+"PO-Revision-Date: 2024-05-08 05:54+0200\n"
 "Last-Translator: Temuri Doghonadze <temuri.doghonadze@gmail.com>\n"
 "Language-Team: Georgian <kde-i18n-doc@kde.org>\n"
 "Language: ka\n"
@@ -56,7 +56,7 @@ msgstr "თქვენი ხმა ჩ
 msgid "You are now a fan."
 msgstr "ახლა ფანი ხარ."
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -124,7 +124,7 @@ msgstr "კონფიგურაც
 msgid "Use"
 msgstr "გამოყენება"
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -135,17 +135,17 @@ msgstr ""
 "%2\n"
 "ეს კრიტიკული შეცდომაა. აცნობეთ ავტორს მის შესახებ"
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr "%1-დან მომწოდებლების ჩატვირთვა შეუძლებელია"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr "ფაილიდან სიახლეების მომწოდებლების სიის წაკითხვა შეუძლებელია: %1"
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr "მომწოდებლის ინიციალიზაციის შეცდომა."
@@ -314,7 +314,7 @@ msgid ""
 msgstr ""
 "%1-ის განახლებისთვის კარგი ბმული ვერ ვიპოვე, ამიტომ განახლება შეუძლებელია"
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, kde-format
 msgid ""
 "Failed to adopt '%1'\n"
@@ -323,14 +323,14 @@ msgstr ""
 "'%1'-ის დამუშავების შეცდომა\n"
 "%2"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, kde-format
 msgctxt ""
 "The first entry in the category selection list (also the default value)"
 msgid "All Categories"
 msgstr "ყველა კატეგორია"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, kde-format
 msgctxt ""
 "The string passed back in the case the requested category is not known"
@@ -354,13 +354,13 @@ msgstr "სხვადასხვა"
 msgid "Download New %1…"
 msgstr "ახალი %1-ის გადმოწერა…"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, kde-format
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "ახალი %1-ის გადმოწერა"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, kde-format
 msgctxt ""
 "A placeholder title used in the dialog when there is no better title "
@@ -368,12 +368,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "ახალი მატერიალების გადმოწერა"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr "აირჩიეთ დაყენების ვარიანტი"
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -385,19 +385,19 @@ msgstr ""
 "გნებავთ, დააყენოთ. თუ ის, რომელი ვარიანტი უნდა აირჩიოთ, გაურკვეველია, "
 "დაუკავშირდით ელემენტის ავტორს და სთხოვეთ, მისი სახელი უფრო გასაგებად აღწეროს."
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "დაყენება"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, kde-format
 msgctxt ""
 "A passive notification shown when installation of an item is initiated"
 msgid "Installing %1 from %2"
 msgstr "%1-ის დაყენება %2-დან"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -405,10 +405,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr "%1 %2-სგან"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, kde-format
 msgctxt ""
 "Request installation of this item, available when there is exactly one "
@@ -416,32 +416,32 @@ msgctxt ""
 msgid "Install"
 msgstr "დაყენება"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, kde-format
 msgctxt ""
 "Show installation options, where there is more than one downloadable item"
 msgid "Install…"
 msgstr "დაყენება…"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, kde-format
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "განახლება"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, kde-format
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "ამოშლა"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -449,14 +449,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr "ამჟამად %2-ის ჩანაწერზე %1 ვმუშაობ. მოითმინეთ…"
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr "ამჟამად მიმდინარეობს %2-ის %1 ელემენტის განახლება. მოითმინეთ…"
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -470,12 +470,12 @@ msgstr ""
 "kde.org/enter_bug.cgi?product=frameworks-knewstuff\">მოგვწერეთ ამ შეცდომის "
 "შესახებ</a>."
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr "კომენტარები და მიმოხილვები:"
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a new sub page with comments (comments "
@@ -483,17 +483,17 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "%1 მიმოხილვა და კომენტარი"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, kde-format
 msgid "Rating:"
 msgstr "შეფასება:"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, kde-format
 msgid "Homepage:"
 msgstr "საწყისი გვერდი:"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -502,12 +502,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr "%1-ის საწყისი გვერდის გახსნა"
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr "როგორ შემოგწიროთ:"
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -515,74 +515,86 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr "გარკვევა, როგორ შევწიროთ ამ პროექტს"
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+"გამოიჩინეთ სიფრთხილე მომხმარებლის მიერ შექმნილ შემცველობასთან წვდომისას, "
+"რადგან ის შეიძლება შეიცავდეს შესრულებად კოდს, რომელიც არ შემოწმებულა KDE-ის "
+"ან თქვენი დისტრიბუტორის მიერ, არის თუ არა ის უსაფრთხო, სტაბილური ან "
+"ხარისხიანი"
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
-"აქ არსებული შიგთავსი ატვირთულია მომხმარებლების მიერ, რომელიც თქვენგან "
-"არაფრით განსხვავდება და ისინი ფუნქციონალზე და სტაბილურობაზე შემოწმებული არაა."
+"აქ ნაჩვენები მომხმარებლის მიერ შექმნილი შემცველობა, რომელიც KDE-ის ან თქვენი "
+"დისტრიბუტორის მიერ ფუნქციონალზე ან ხარისხზე არ შემოწმებულა."
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, kde-format
 msgid "Tiles"
 msgstr "ნაწილები"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "ხატულები"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, kde-format
 msgid "Preview"
 msgstr "გადახედვა"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, kde-format
 msgid "Detailed Tiles View Mode"
 msgstr "დეტალური ფილების ხედის რეჟიმი"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, kde-format
 msgid "Icons Only View Mode"
 msgstr "მხოლოდ ხატულების ხედის რეჟიმი"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, kde-format
 msgid "Large Preview View Mode"
 msgstr "დიდი მინიატურების ხედის რეჟიმი"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr "ყველაფერი"
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "დაყენებულია"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, kde-format
 msgid "Updateable"
 msgstr "განახლებადი"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, kde-format
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "ყველა ჩანაწერის ჩვენება"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr "მხოლოდ დაყენებულების ჩვენება"
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -590,27 +602,27 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr "მხოლოდ განახლებადი ჩანაწერების ჩვენება"
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, kde-format
 msgid "Recent"
 msgstr "Ბოლო"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr "ანბანით დალაგებული"
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "შეფასება"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, kde-format
 msgid "Downloads"
 msgstr "გადმოწერები"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on when items were most "
@@ -618,7 +630,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "ჯერ უახლესები"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -626,57 +638,57 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr "სახელით, ანბანის მიხედვით დალაგება"
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, kde-format
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "რეიტინგის მიხედვით დალაგება"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on number of downloads"
 msgid "Show Most Downloaded First"
 msgstr "ჯერ ხშირად გადმოწერილების ჩვენება"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, kde-format
 msgid "Upload…"
 msgstr "ატვირთვა…"
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr "ისწავლეთ, როგორ დაამატოთ სიაში თქვენი საკუთარი რამები"
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, kde-format
 msgid "Go to…"
 msgstr "გადასვლა…"
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, kde-format
 msgid "Search…"
 msgstr "ძებნა…"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "კატეგორია:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, kde-format
 msgid "Contribute your own…"
 msgstr "თქვენი მასალების შეწირვა…"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, kde-format
 msgctxt ""
 "Placeholder title for when a comment has no subject, but does have a rating"
 msgid "<i>(no title)</i>"
 msgstr "<i>(სათაურის გარეშე)</i>"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -684,19 +696,19 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr "%1 <i>(ავტორი)</i>"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr "%1-ის მიმოხილვა და კომენტარები"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, kde-format
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "ყველა კომენტარის ჩვენება"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -704,7 +716,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr "მხოლოდ მიმოხილვების ჩვენება"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -712,15 +724,15 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr "მიმოხილვებისა და გამოხმაურებების ჩვენება"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, kde-format
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
 msgstr "%1 გადმოწერა"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, kde-format
 msgctxt ""
 "Subheading for the tile view, located immediately underneath the name of the "
@@ -728,7 +740,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "<i>%1</i>-სგან"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -736,7 +748,7 @@ msgctxt ""
 msgid "Working…"
 msgstr "მუშავდება…"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is in the process of being "
@@ -744,7 +756,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "მიმდინარეობს განახლება…"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -757,7 +769,7 @@ msgstr ""
 "არასწორი ან უცნობი მდგომარეობა. <a href=\"https://bugs.kde.org/enter_bug.cgi?"
 "product=frameworks-knewstuff\">მოგვწერეთ ამ შეცდომის შესახებ</a>."
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, kde-format
 msgctxt "Label for the busy indicator showing an item is installing"
 msgid "Installing…"
@@ -774,44 +786,44 @@ msgstr "შეცდომა"
 msgid "Please try again later."
 msgstr "მოგვიანებით სცადეთ."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, kde-format
 msgid "None"
 msgstr "არაფერი"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, kde-format
 msgctxt ""
 "A text representation of the rating, shown as a fraction of the max value"
 msgid "(%1/%2)"
 msgstr "(%1/%2)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, kde-format
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "ახალი მასალების ატვირთვა: %1"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, kde-format
 msgctxt ""
 "A text shown beside a busy indicator suggesting that data is being fetched"
 msgid "Updating information…"
 msgstr "ინფორმაციის განახლება…"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, kde-format
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "KDE -ის მაღაზია"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, kde-format
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "თქვენი მომწოდებელი"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, kde-format
 msgctxt ""
 "Text for an action which causes the specified website to be opened using the "
@@ -819,7 +831,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "ვებგვერდის გახსნა: %1"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, kde-format
 msgctxt ""
 "Text for an action which will attempt to send an email using the user's "
@@ -827,7 +839,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "%1-სთვის ელფოსტის გაგზავნა"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -835,7 +847,7 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 "KDE Store-ში ახალი ელემენტების ჩასამატებლად ან არსებულ ელემენტების "
 "შემცველობის დასამატებლად გახსენით შესაბამისი ვებგვერდი და შედით. შესვლის "
@@ -844,7 +856,7 @@ msgstr ""
 "პროდუქტების მართვის გვერდზე გადახვიდეთ, სადაც შეგიძლიათ, თქვენს პროდუქტებზე "
 "იმუშაოთ."
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -861,18 +873,18 @@ msgstr ""
 "სადაც შეგიძლიათ დამატების მითითებები იხილოთ. ასევე შეიძლება საჭირო იყოს "
 "მმართველებთან დაკავშირება, რათა მათ ახალი შემცველობა ხელით დაამატონ."
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "მონაცემების ჩატვირთვა"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "დაყენება"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -884,73 +896,73 @@ msgstr ""
 "უკანასკნელი სიახლეების მისაღებად ავტორიზაცია არ გაგივლიათ. თუ ფიქრობთ, რომ "
 "ეს შეცდომაა, დაუკავშირდით პირს, რომელიც თქვენს წვდომებს მართავს."
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "უკან"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr "პოპულარული"
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "პოპულარული"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "გადატვრთვა"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "New"
 msgstr "&ახალი"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "საწყისი"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr "Shelf"
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "მაღლა"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "რეკომენდებულია"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "გამოწერები"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "ყველა ჩანაწერი"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -996,8 +1008,12 @@ msgstr ""
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
 #, kde-format
-msgid "Download New Stuff..."
-msgstr "ახალი რამერუმეების მიღება..."
+msgctxt "@action"
+msgid "Download New Stuff…"
+msgstr "ახალი მატერიალების გადმოწერა…"
+
+#~ msgid "Download New Stuff..."
+#~ msgstr "ახალი რამერუმეების მიღება..."
 
 #~ msgctxt ""
 #~ "A message which is shown when the user attempts to display a specific "
diff -pruN 6.0.0-3/po/kk/knewstuff6.po 6.3.0-1/po/kk/knewstuff6.po
--- 6.0.0-3/po/kk/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/kk/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -7,7 +7,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2013-11-08 01:24+0600\n"
 "Last-Translator: Sairan Kikkarin <sairan@computer.org>\n"
 "Language-Team: Kazakh <kde-i18n-doc@kde.org>\n"
@@ -62,7 +62,7 @@ msgstr "Дауысыңыз жазып а
 msgid "You are now a fan."
 msgstr "Сүйермен тізіміне кірдіңіз."
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -131,7 +131,7 @@ msgstr "Баптау файлы жара
 msgid "Use"
 msgstr ""
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -139,17 +139,17 @@ msgid ""
 "This is a critical error and should be reported to the application author"
 msgstr ""
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr "Үлестірушілерін %1 файынан табу жаңылысы"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr "Келесі файлдан жаңа нәрселер үлестірушілер алынбады: %1"
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr "Үлестіруші мәліметінің қатесі."
@@ -294,7 +294,7 @@ msgid ""
 "the update"
 msgstr ""
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, fuzzy, kde-format
 #| msgid "Failed to load file '%1'"
 msgid ""
@@ -302,7 +302,7 @@ msgid ""
 "%2"
 msgstr "'%1' файлын жүктеу жаңылысы"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt ""
@@ -310,7 +310,7 @@ msgctxt ""
 msgid "All Categories"
 msgstr "Барлық санаттар"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, fuzzy, kde-format
 #| msgid "Unknown error"
 msgctxt ""
@@ -336,14 +336,14 @@ msgstr ""
 msgid "Download New %1…"
 msgstr "Жаңа %1 жүктеп алу"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, fuzzy, kde-format
 #| msgid "Download New %1"
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "Жаңа %1 жүктеп алу"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, fuzzy, kde-format
 #| msgid "Download New Stuff..."
 msgctxt ""
@@ -352,12 +352,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "Жаңа нәрсені жүктеп алу"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -366,12 +366,12 @@ msgid ""
 "this through the naming of the items."
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "Орнату"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt ""
@@ -379,7 +379,7 @@ msgctxt ""
 msgid "Installing %1 from %2"
 msgstr "Орнату"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -387,10 +387,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -399,10 +399,10 @@ msgctxt ""
 msgid "Install"
 msgstr "Орнату"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -410,24 +410,24 @@ msgctxt ""
 msgid "Install…"
 msgstr "Орнату"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, fuzzy, kde-format
 #| msgid "Update"
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "Жаңарту"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, fuzzy, kde-format
 #| msgid "Uninstall"
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "Орнатудан шығару"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -435,14 +435,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -453,12 +453,12 @@ msgid ""
 "to the KDE Community in a bug report</a>."
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, fuzzy, kde-format
 #| msgid "View Comments"
 msgctxt ""
@@ -467,19 +467,19 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "Түсініктемелерін қарау"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, fuzzy, kde-format
 #| msgid "Rating: "
 msgid "Rating:"
 msgstr "Ұпайы: "
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, fuzzy, kde-format
 #| msgid "Homepage"
 msgid "Homepage:"
 msgstr "Мекен парағы"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -488,12 +488,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -501,80 +501,88 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr ""
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, fuzzy, kde-format
 #| msgctxt "@option:check Do filter on type - show only files"
 #| msgid "Files"
 msgid "Tiles"
 msgstr "Файлдар"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "Таңбашалар"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, fuzzy, kde-format
 #| msgid "No Preview"
 msgid "Preview"
 msgstr "Нобайы жоқ"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, fuzzy, kde-format
 #| msgid "Details view mode"
 msgid "Detailed Tiles View Mode"
 msgstr "Егжей-тегжейлі көрініс"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, fuzzy, kde-format
 #| msgid "Icons view mode"
 msgid "Icons Only View Mode"
 msgstr "Таңбашалы көрініс"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, fuzzy, kde-format
 #| msgid "Details view mode"
 msgid "Large Preview View Mode"
 msgstr "Егжей-тегжейлі көрініс"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr ""
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "Орнатылған"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, fuzzy, kde-format
 #| msgid "Update"
 msgid "Updateable"
 msgstr "Жаңарту"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "Барлық санаттар"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -582,30 +590,30 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Open Recent"
 msgid "Recent"
 msgstr "Жуырдағыны ашу"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr ""
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "Ұпайы"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, fuzzy, kde-format
 #| msgid "Download"
 msgid "Downloads"
 msgstr "Жүктеп алу"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt ""
@@ -614,7 +622,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "Алдымен қапшықтар көрсетілсін"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -622,14 +630,14 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr ""
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "Алдымен қапшықтар көрсетілсін"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, fuzzy, kde-format
 #| msgid "Most downloads"
 msgctxt ""
@@ -637,41 +645,41 @@ msgctxt ""
 msgid "Show Most Downloaded First"
 msgstr "Жиі жүктеп алынатындар"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, fuzzy, kde-format
 #| msgid "Upload..."
 msgid "Upload…"
 msgstr "Жүктеп беру..."
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr ""
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, fuzzy, kde-format
 #| msgid "&Go To..."
 msgid "Go to…"
 msgstr "&Мынаған өту..."
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, fuzzy, kde-format
 #| msgid "Search:"
 msgid "Search…"
 msgstr "Іздейтіні:"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "Санаты:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, fuzzy, kde-format
 #| msgid "Continue operation"
 msgid "Contribute your own…"
 msgstr "Амалды жалғастыру"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, fuzzy, kde-format
 #| msgctxt "@note/rich"
 #| msgid "<i>Note</i>: %1"
@@ -680,7 +688,7 @@ msgctxt ""
 msgid "<i>(no title)</i>"
 msgstr "<i>Мәлімдеме</i>: %1"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -688,20 +696,20 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "Барлық санаттар"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -709,7 +717,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -717,8 +725,8 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, fuzzy, kde-format
 #| msgid "1 download"
 #| msgid_plural "%1 downloads"
@@ -726,8 +734,8 @@ msgctxt "The number of times the item ha
 msgid "%1 downloads"
 msgstr "%1 рет жүктеп алынған"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, fuzzy, kde-format
 #| msgctxt "Show the author of this item in a list"
 #| msgid "By <i>%1</i>"
@@ -737,7 +745,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "<i>%1</i> бойынша"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -745,7 +753,7 @@ msgctxt ""
 msgid "Working…"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, fuzzy, kde-format
 #| msgid "Updating"
 msgctxt ""
@@ -754,7 +762,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "Жаңарту"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -765,7 +773,7 @@ msgid ""
 "bug report</a>."
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt "Label for the busy indicator showing an item is installing"
@@ -784,14 +792,14 @@ msgstr ""
 msgid "Please try again later."
 msgstr "Атын келтіріңіз."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, fuzzy, kde-format
 #| msgctxt "No border line"
 #| msgid "None"
 msgid "None"
 msgstr "Жоқ"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, fuzzy, kde-format
 #| msgid "(%1/s)"
 msgctxt ""
@@ -799,14 +807,14 @@ msgctxt ""
 msgid "(%1/%2)"
 msgstr "(%1/с)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, fuzzy, kde-format
 #| msgid "Download New Stuff..."
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "Жаңа нәрсені жүктеп алу"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, fuzzy, kde-format
 #| msgid "Billing information:"
 msgctxt ""
@@ -814,21 +822,21 @@ msgctxt ""
 msgid "Updating information…"
 msgstr "Есеп мәліметі:"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, fuzzy, kde-format
 #| msgid "&Store"
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "&Сақтау"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, fuzzy, kde-format
 #| msgid "Provider:"
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "Провайдері:"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, fuzzy, kde-format
 #| msgctxt "@label:button"
 #| msgid "&Open with %1"
@@ -838,7 +846,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "%1 дегенмен &ашу"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, fuzzy, kde-format
 #| msgid "&Send Email"
 msgctxt ""
@@ -847,7 +855,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "&Эл.поштаны жіберу"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -855,10 +863,10 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -870,18 +878,18 @@ msgid ""
 "content added."
 msgstr ""
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "Деректерді жүктеу"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "Орнату"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -891,7 +899,7 @@ msgid ""
 "please contact the person in charge of your permissions."
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Back"
@@ -899,20 +907,20 @@ msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "Шегіну"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, fuzzy, kde-format
 #| msgid "Saturday"
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "Сенбі"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, fuzzy, kde-format
 #| msgctxt "@action:button Restart find & replace"
 #| msgid "Restart"
@@ -920,7 +928,7 @@ msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "Қайта бастау"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "New"
@@ -928,7 +936,7 @@ msgctxt "Knewstuff5"
 msgid "New"
 msgstr "Жаңа"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Home"
@@ -936,13 +944,13 @@ msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Home"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Up"
@@ -950,7 +958,7 @@ msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "Жоғары"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, fuzzy, kde-format
 #| msgctxt "dictionary variant"
 #| msgid "extended"
@@ -958,7 +966,7 @@ msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "кеңейтілген"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Subscript"
@@ -966,14 +974,14 @@ msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "Жол астығы"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "Барлық санаттар"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -1004,9 +1012,14 @@ msgid ""
 msgstr ""
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
-#, kde-format
-msgid "Download New Stuff..."
-msgstr "Жаңа нәрсені жүктеп алу..."
+#, fuzzy, kde-format
+#| msgid "Download New Stuff..."
+msgctxt "@action"
+msgid "Download New Stuff…"
+msgstr "Жаңа нәрсені жүктеп алу"
+
+#~ msgid "Download New Stuff..."
+#~ msgstr "Жаңа нәрсені жүктеп алу..."
 
 #~ msgid "Initializing"
 #~ msgstr "Орнату"
diff -pruN 6.0.0-3/po/km/knewstuff6.po 6.3.0-1/po/km/knewstuff6.po
--- 6.0.0-3/po/km/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/km/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -4,7 +4,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2012-06-27 10:04+0700\n"
 "Last-Translator: Khoem Sokhem <khoemsokhem@khmeros.info>\n"
 "Language-Team: Khmer\n"
@@ -55,7 +55,7 @@ msgstr "ការ​បោះឆ្ន
 msgid "You are now a fan."
 msgstr "ឥឡូវ​អ្នក​រីករាយ​ហើយ ។"
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -123,7 +123,7 @@ msgstr "ឯកសារ​កំណត
 msgid "Use"
 msgstr ""
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -131,17 +131,17 @@ msgid ""
 "This is a critical error and should be reported to the application author"
 msgstr ""
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr "បាន​បរាជ័យ​ក្នុងការ​ផ្ទុក​ក្រុមហ៊ុន​ផ្ដល់​ពី​ឯកសារ ៖ %1"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr "មិន​អាច​ផ្ទុក​​កម្មវិធី​ផ្ដល់​ធាតុ​ថ្មីបំផុត​ពី​ឯកសារ​បានទេ ៖ %1"
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr "កំហុស​ក្នុងការ​ចាប់ផ្ដើម​ក្រុមហ៊ុន​ផ្ដល់ ។"
@@ -286,7 +286,7 @@ msgid ""
 "the update"
 msgstr ""
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, fuzzy, kde-format
 #| msgid "Failed to load file '%1'"
 msgid ""
@@ -294,7 +294,7 @@ msgid ""
 "%2"
 msgstr "បរាជ័យ​ក្នុងការ​ផ្ទុក​​ឯកសារ '%1'"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt ""
@@ -302,7 +302,7 @@ msgctxt ""
 msgid "All Categories"
 msgstr "គ្រប់​ប្រភេទ"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, fuzzy, kde-format
 #| msgid "Unknown error"
 msgctxt ""
@@ -328,14 +328,14 @@ msgstr ""
 msgid "Download New %1…"
 msgstr "ទាញយក​ធាតុ​ថ្មី..."
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, fuzzy, kde-format
 #| msgid "Download New Stuff..."
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "ទាញយក​ធាតុ​ថ្មី..."
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, fuzzy, kde-format
 #| msgid "Download New Stuff..."
 msgctxt ""
@@ -344,12 +344,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "ទាញយក​ធាតុ​ថ្មី..."
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -358,12 +358,12 @@ msgid ""
 "this through the naming of the items."
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "ដំឡើង"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt ""
@@ -371,7 +371,7 @@ msgctxt ""
 msgid "Installing %1 from %2"
 msgstr "ដំឡើង"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -379,10 +379,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -391,10 +391,10 @@ msgctxt ""
 msgid "Install"
 msgstr "ដំឡើង"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -402,24 +402,24 @@ msgctxt ""
 msgid "Install…"
 msgstr "ដំឡើង"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, fuzzy, kde-format
 #| msgid "Update"
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "ធ្វើ​បច្ចុប្បន្នភាព"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, fuzzy, kde-format
 #| msgid "Uninstall"
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "លុប"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -427,14 +427,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -445,12 +445,12 @@ msgid ""
 "to the KDE Community in a bug report</a>."
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, fuzzy, kde-format
 #| msgid "View Comments"
 msgctxt ""
@@ -459,19 +459,19 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "មើល​មតិយោបល់"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, fuzzy, kde-format
 #| msgid "Rating: "
 msgid "Rating:"
 msgstr "ការវាយ​តម្លៃ ៖ "
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, fuzzy, kde-format
 #| msgid "Homepage"
 msgid "Homepage:"
 msgstr "គេហ​ទំព័រ"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -480,12 +480,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -493,80 +493,88 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr ""
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, fuzzy, kde-format
 #| msgctxt "@option:check Do filter on type - show only files"
 #| msgid "Files"
 msgid "Tiles"
 msgstr "ឯកសារ"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "រូបតំណាង"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, fuzzy, kde-format
 #| msgid "Preview URL:"
 msgid "Preview"
 msgstr "មើល URL ជា​មុន ៖"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, fuzzy, kde-format
 #| msgid "Details view mode"
 msgid "Detailed Tiles View Mode"
 msgstr "របៀប​​ទិដ្ឋភាព​លម្អិត"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, fuzzy, kde-format
 #| msgid "Icons view mode"
 msgid "Icons Only View Mode"
 msgstr "របៀប​ទិដ្ឋភាព​រូបតំណាង"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, fuzzy, kde-format
 #| msgid "Details view mode"
 msgid "Large Preview View Mode"
 msgstr "របៀប​​ទិដ្ឋភាព​លម្អិត"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr ""
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "បាន​ដំឡើង"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, fuzzy, kde-format
 #| msgid "Update"
 msgid "Updateable"
 msgstr "ធ្វើ​បច្ចុប្បន្នភាព"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "គ្រប់​ប្រភេទ"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -574,30 +582,30 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Open Recent"
 msgid "Recent"
 msgstr "បើក​ថ្មី​ៗ​នេះ"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr ""
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "ការវាយ​តម្លៃ"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, fuzzy, kde-format
 #| msgid "Download"
 msgid "Downloads"
 msgstr "ទាញយក"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt ""
@@ -606,7 +614,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "បង្ហាញ​ថត​ជាមុន​សិន"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -614,14 +622,14 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr ""
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "បង្ហាញ​ថត​ជាមុន​សិន"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, fuzzy, kde-format
 #| msgid "Most downloads"
 msgctxt ""
@@ -629,41 +637,41 @@ msgctxt ""
 msgid "Show Most Downloaded First"
 msgstr "ទាញយក​ច្រើន​បំផុត"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, fuzzy, kde-format
 #| msgid "New Upload"
 msgid "Upload…"
 msgstr "ផ្ទុក​ឡើង​ថ្មី"
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr ""
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, fuzzy, kde-format
 #| msgid "&Go To..."
 msgid "Go to…"
 msgstr "ទៅកាន់..."
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, fuzzy, kde-format
 #| msgid "Search:"
 msgid "Search…"
 msgstr "ស្វែងរក ៖"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "ប្រភេទ ​៖"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, fuzzy, kde-format
 #| msgid "Continue operation"
 msgid "Contribute your own…"
 msgstr "បន្ត​ប្រតិបត្តិការ"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, fuzzy, kde-format
 #| msgctxt "@note/rich"
 #| msgid "<i>Note</i>: %1"
@@ -672,7 +680,7 @@ msgctxt ""
 msgid "<i>(no title)</i>"
 msgstr "<i>ចំណាំ</i> ៖ %1"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -680,20 +688,20 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "គ្រប់​ប្រភេទ"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -701,7 +709,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -709,8 +717,8 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, fuzzy, kde-format
 #| msgid "1 download"
 #| msgid_plural "%1 downloads"
@@ -718,8 +726,8 @@ msgctxt "The number of times the item ha
 msgid "%1 downloads"
 msgstr "ការ​ទាញយក %1"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, fuzzy, kde-format
 #| msgctxt "Show the author of this item in a list"
 #| msgid "By <i>%1</i>"
@@ -729,7 +737,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "ដោយ <i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -737,7 +745,7 @@ msgctxt ""
 msgid "Working…"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, fuzzy, kde-format
 #| msgid "Updating"
 msgctxt ""
@@ -746,7 +754,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "ធ្វើបច្ចុប្បន្នភាព"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -757,7 +765,7 @@ msgid ""
 "bug report</a>."
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt "Label for the busy indicator showing an item is installing"
@@ -776,14 +784,14 @@ msgstr ""
 msgid "Please try again later."
 msgstr "សូម​បញ្ចូល​ឈ្មោះ ។"
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, fuzzy, kde-format
 #| msgctxt "No border line"
 #| msgid "None"
 msgid "None"
 msgstr "គ្មាន"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, fuzzy, kde-format
 #| msgid "(%1/s)"
 msgctxt ""
@@ -791,14 +799,14 @@ msgctxt ""
 msgid "(%1/%2)"
 msgstr "(%1/វិ.)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, fuzzy, kde-format
 #| msgid "Download New Stuff..."
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "ទាញយក​ធាតុ​ថ្មី..."
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, fuzzy, kde-format
 #| msgid "Billing information:"
 msgctxt ""
@@ -806,21 +814,21 @@ msgctxt ""
 msgid "Updating information…"
 msgstr "ព័ត៌មាន​វិក្ក័យបត្រ ៖"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, fuzzy, kde-format
 #| msgid "&Store"
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "ទុក"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, fuzzy, kde-format
 #| msgid "Provider:"
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "ក្រុមហ៊ុនផ្ដល់ ៖"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, fuzzy, kde-format
 #| msgctxt "@label:button"
 #| msgid "&Open with %1"
@@ -830,7 +838,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "បើក​ជា​មួយ %1"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, fuzzy, kde-format
 #| msgid "&Send Email"
 msgctxt ""
@@ -839,7 +847,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "ផ្ញើ​អ៊ីមែល"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -847,10 +855,10 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -862,18 +870,18 @@ msgid ""
 "content added."
 msgstr ""
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "ផ្ទុក​ទិន្នន័យ"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "ដំឡើង"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -883,7 +891,7 @@ msgid ""
 "please contact the person in charge of your permissions."
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Back"
@@ -891,19 +899,19 @@ msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "ថយក្រោយ"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, fuzzy, kde-format
 #| msgctxt "@action:button Restart find & replace"
 #| msgid "Restart"
@@ -911,7 +919,7 @@ msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "ចាប់ផ្ដើម​ឡើង​វិញ"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "New"
@@ -919,7 +927,7 @@ msgctxt "Knewstuff5"
 msgid "New"
 msgstr "ថ្មី"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Home"
@@ -927,13 +935,13 @@ msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "ដើម"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Up"
@@ -941,7 +949,7 @@ msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "ឡើងលើ"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, fuzzy, kde-format
 #| msgctxt "dictionary variant"
 #| msgid "extended"
@@ -949,7 +957,7 @@ msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "បាន​បន្ថែម"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Subscript"
@@ -957,14 +965,14 @@ msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "អក្សរ​តូច​ក្រោម"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "គ្រប់​ប្រភេទ"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -995,10 +1003,15 @@ msgid ""
 msgstr ""
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
-#, kde-format
-msgid "Download New Stuff..."
+#, fuzzy, kde-format
+#| msgid "Download New Stuff..."
+msgctxt "@action"
+msgid "Download New Stuff…"
 msgstr "ទាញយក​ធាតុ​ថ្មី..."
 
+#~ msgid "Download New Stuff..."
+#~ msgstr "ទាញយក​ធាតុ​ថ្មី..."
+
 #~ msgid "Initializing"
 #~ msgstr "ចាប់ផ្ដើម"
 
diff -pruN 6.0.0-3/po/kn/knewstuff6.po 6.3.0-1/po/kn/knewstuff6.po
--- 6.0.0-3/po/kn/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/kn/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -9,7 +9,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2010-06-24 18:32+0530\n"
 "Last-Translator: Shankar Prasad <svenkate@redhat.com>\n"
 "Language-Team: kn_IN <kde-i18n-doc@kde.org>\n"
@@ -65,7 +65,7 @@ msgstr "ನಿಮ್ಮ ಓಟನ್ನ
 msgid "You are now a fan."
 msgstr ""
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -133,7 +133,7 @@ msgstr "ಸಂರಚನಾ ಕಡತವ
 msgid "Use"
 msgstr ""
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -141,17 +141,17 @@ msgid ""
 "This is a critical error and should be reported to the application author"
 msgstr ""
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr "ಪೂರೈಕೆದಾರರನ್ನು ಕಡತದಿಂದ ಲೋಡ್ ಮಾಡಲಾಗುತ್ತಿದೆ: %1 ವಿಫಲಗೊಂಡಿದೆ"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr ""
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr "ಪೂರೈಕೆದಾರರನ್ನು ಆರಂಭಗೊಳಿಸುವಲ್ಲಿ ದೋಷ ಉಂಟಾಗಿದೆ."
@@ -298,7 +298,7 @@ msgid ""
 "the update"
 msgstr ""
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, fuzzy, kde-format
 #| msgid "Failed to load file '%1'"
 msgid ""
@@ -306,7 +306,7 @@ msgid ""
 "%2"
 msgstr "'%1' ಕಡತವನ್ನು ಲೋಡ್‌ ಮಾಡುವುದು ವಿಫಲವಾಯಿತು"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt ""
@@ -314,7 +314,7 @@ msgctxt ""
 msgid "All Categories"
 msgstr "ಎಲ್ಲಾ ಪಂಗಡಗಳು"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, fuzzy, kde-format
 #| msgid "Unknown error"
 msgctxt ""
@@ -340,14 +340,14 @@ msgstr ""
 msgid "Download New %1…"
 msgstr "ಹೊಸ %1 ಅನ್ನು ನಕಲಿಳಿಸಿ"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, fuzzy, kde-format
 #| msgid "Download New %1"
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "ಹೊಸ %1 ಅನ್ನು ನಕಲಿಳಿಸಿ"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
 msgctxt ""
@@ -356,12 +356,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "ಹೊಸ ಪದಾರ್ಥವನ್ನು ನಕಲಿಳಿಸಿ"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -370,12 +370,12 @@ msgid ""
 "this through the naming of the items."
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "ಅನುಸ್ಥಾಪಿಸು"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt ""
@@ -383,7 +383,7 @@ msgctxt ""
 msgid "Installing %1 from %2"
 msgstr "ಅನುಸ್ಥಾಪಿಸಲಾಗುತ್ತಿದೆ"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -391,10 +391,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -403,10 +403,10 @@ msgctxt ""
 msgid "Install"
 msgstr "ಅನುಸ್ಥಾಪಿಸು"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -414,24 +414,24 @@ msgctxt ""
 msgid "Install…"
 msgstr "ಅನುಸ್ಥಾಪಿಸು"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, fuzzy, kde-format
 #| msgid "Update"
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "ಅಪ್‌ಡೇಟ್"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, fuzzy, kde-format
 #| msgid "Uninstall"
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "ಅನುಸ್ಥಾಪಿಸಿದ್ದನ್ನು ತೆಗೆದುಹಾಕು"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -439,14 +439,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -457,12 +457,12 @@ msgid ""
 "to the KDE Community in a bug report</a>."
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, fuzzy, kde-format
 #| msgid "View Comments"
 msgctxt ""
@@ -471,19 +471,19 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "ಟಿಪ್ಪಣಿಗಳನ್ನು ನೋಡಿ"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, fuzzy, kde-format
 #| msgid "Rating: "
 msgid "Rating:"
 msgstr "ದರ: "
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, fuzzy, kde-format
 #| msgid "Homepage"
 msgid "Homepage:"
 msgstr "ನೆಲೆಪುಟ (ಹೋಮ್ ಪೇಜ್)"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -492,12 +492,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -505,79 +505,87 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr ""
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, fuzzy, kde-format
 #| msgid "File"
 msgid "Tiles"
 msgstr "ಕಡತ"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "ಚಿಹ್ನೆಗಳು"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, fuzzy, kde-format
 #| msgid "No Preview"
 msgid "Preview"
 msgstr "ಯಾವುದೆ ಮುನ್ನೋಟವಿಲ್ಲ"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, fuzzy, kde-format
 #| msgid "Details view mode"
 msgid "Detailed Tiles View Mode"
 msgstr "ವಿವರಗಳ ನೋಟದ ಕ್ರಮ"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, fuzzy, kde-format
 #| msgid "Icons view mode"
 msgid "Icons Only View Mode"
 msgstr "ಚಿಹ್ನೆಗಳ ನೋಟದ ವಿಧ"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, fuzzy, kde-format
 #| msgid "Details view mode"
 msgid "Large Preview View Mode"
 msgstr "ವಿವರಗಳ ನೋಟದ ಕ್ರಮ"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr ""
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "ಅನುಸ್ಥಾಪಿಸಲಾದ"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, fuzzy, kde-format
 #| msgid "Update"
 msgid "Updateable"
 msgstr "ಅಪ್‌ಡೇಟ್"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "ಎಲ್ಲಾ ಪಂಗಡಗಳು"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -585,30 +593,30 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Open Recent"
 msgid "Recent"
 msgstr "ಇತ್ತೀಚಿನದನ್ನು ತೆರೆ"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr ""
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "ಗುಣನಿಶ್ಚಯ (ರೇಟಿಂಗ್)"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, fuzzy, kde-format
 #| msgid "Download"
 msgid "Downloads"
 msgstr "ನಕಲಿಳಿಸು"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt ""
@@ -617,7 +625,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "ಕಡತಕೋಶಗಳನ್ನು ಮೊದಲು ತೋರಿಸು"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -625,14 +633,14 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr ""
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "ಕಡತಕೋಶಗಳನ್ನು ಮೊದಲು ತೋರಿಸು"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, fuzzy, kde-format
 #| msgid "Most downloads"
 msgctxt ""
@@ -640,41 +648,41 @@ msgctxt ""
 msgid "Show Most Downloaded First"
 msgstr "ಅತಿಹೆಚ್ಚು ನಕಲಿಳಿಪುಗಳು"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, fuzzy, kde-format
 #| msgid "&Replace..."
 msgid "Upload…"
 msgstr "ಬದಲಿಸು(&R)..."
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr ""
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, fuzzy, kde-format
 #| msgid "&Go To..."
 msgid "Go to…"
 msgstr "ಇಲ್ಲಿಗೆ ಹೋಗು(&G)..."
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, fuzzy, kde-format
 #| msgid "Search:"
 msgid "Search…"
 msgstr "ಹುಡುಕು:"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "ಪಂಗಡ:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, fuzzy, kde-format
 #| msgid "Continue operation"
 msgid "Contribute your own…"
 msgstr "ಕಾರ್ಯಾಚರಣೆಯನ್ನು ಮುಂದುವರೆಸು"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, fuzzy, kde-format
 #| msgctxt "@note/rich"
 #| msgid "<i>Note</i>: %1"
@@ -683,7 +691,7 @@ msgctxt ""
 msgid "<i>(no title)</i>"
 msgstr "<i>ಸೂಚನೆ</i>: %1"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -691,20 +699,20 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "ಎಲ್ಲಾ ಪಂಗಡಗಳು"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -712,7 +720,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -720,8 +728,8 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, fuzzy, kde-format
 #| msgid "1 download"
 #| msgid_plural "%1 downloads"
@@ -729,8 +737,8 @@ msgctxt "The number of times the item ha
 msgid "%1 downloads"
 msgstr "೧ ನಕಲಿಳಿಪು"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, fuzzy, kde-format
 #| msgctxt "Show the author of this item in a list"
 #| msgid "By <i>%1</i>"
@@ -740,7 +748,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "<i>%1</i> ಇಂದ"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -748,7 +756,7 @@ msgctxt ""
 msgid "Working…"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, fuzzy, kde-format
 #| msgid "Updating"
 msgctxt ""
@@ -757,7 +765,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "ಅಪ್‌ಡೇಟ್ ಮಾಡಲಾಗುತ್ತಿದೆ"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -768,7 +776,7 @@ msgid ""
 "bug report</a>."
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt "Label for the busy indicator showing an item is installing"
@@ -787,14 +795,14 @@ msgstr ""
 msgid "Please try again later."
 msgstr "ದಯವಿಟ್ಟು ಒಂದು ಹೆಸರನ್ನು ಹಾಕಿ."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, fuzzy, kde-format
 #| msgctxt "No border line"
 #| msgid "None"
 msgid "None"
 msgstr "ಯಾವುದೂ ಇಲ್ಲ"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, fuzzy, kde-format
 #| msgid "(%1/s)"
 msgctxt ""
@@ -802,14 +810,14 @@ msgctxt ""
 msgid "(%1/%2)"
 msgstr "(%1/ಸೆಕೆಂಡಿಗೆ)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "ಹೊಸ ಪದಾರ್ಥವನ್ನು ನಕಲಿಳಿಸಿ"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, fuzzy, kde-format
 #| msgid "Billing information:"
 msgctxt ""
@@ -817,21 +825,21 @@ msgctxt ""
 msgid "Updating information…"
 msgstr "ಬಿಲ್‌ ನೀಡಿಕೆಯ ಮಾಹಿತಿ:"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, fuzzy, kde-format
 #| msgid "&Store"
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "ಸಂಗ್ರಹಿಸು(&s)"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, fuzzy, kde-format
 #| msgid "Provider:"
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "ಪೂರೈಕೆದಾರ (ಪ್ರೊವೈಡರ್):"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, fuzzy, kde-format
 #| msgctxt "@label:button"
 #| msgid "&Open with %1"
@@ -841,7 +849,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "%1 ದೊಂದಿಗೆ ತೆರೆ(&O)"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, fuzzy, kde-format
 #| msgid "&Send Email"
 msgctxt ""
@@ -850,7 +858,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "ವಿ-ಅಂಚೆ ಕಳಿಸು(&S)"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -858,10 +866,10 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -873,18 +881,18 @@ msgid ""
 "content added."
 msgstr ""
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "ದತ್ತಾಂಶವನ್ನು ಲೋಡ್ ಮಾಡಲಾಗುತ್ತಿದೆ"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "ಅನುಸ್ಥಾಪಿಸಲಾಗುತ್ತಿದೆ"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -894,7 +902,7 @@ msgid ""
 "please contact the person in charge of your permissions."
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Back"
@@ -902,20 +910,20 @@ msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "ಹಿಂದಕ್ಕೆ"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, fuzzy, kde-format
 #| msgid "Saturday"
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "ಶನಿವಾರ"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, fuzzy, kde-format
 #| msgctxt "@action:button Restart find & replace"
 #| msgid "Restart"
@@ -923,7 +931,7 @@ msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "ಪುನರಾರಂಭಿಸು"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "New"
@@ -931,7 +939,7 @@ msgctxt "Knewstuff5"
 msgid "New"
 msgstr "ಹೊಸ"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Home"
@@ -939,13 +947,13 @@ msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "ಹೋಮ್"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Up"
@@ -953,7 +961,7 @@ msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "ಅಪ್"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, fuzzy, kde-format
 #| msgctxt "dictionary variant"
 #| msgid "extended"
@@ -961,7 +969,7 @@ msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "ವಿಸ್ತೃತ"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Subscript"
@@ -969,14 +977,14 @@ msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "ಉಪಲೇಖ (ಸಬ್ ಸ್ಕ್ರಿಪ್ಟ್)"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "ಎಲ್ಲಾ ಪಂಗಡಗಳು"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -1007,9 +1015,14 @@ msgid ""
 msgstr ""
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
-#, kde-format
-msgid "Download New Stuff..."
-msgstr "ಹೊಸ ಪದಾರ್ಥವನ್ನು ನಕಲಿಳಿಸಿ..."
+#, fuzzy, kde-format
+#| msgid "Download New Stuff"
+msgctxt "@action"
+msgid "Download New Stuff…"
+msgstr "ಹೊಸ ಪದಾರ್ಥವನ್ನು ನಕಲಿಳಿಸಿ"
+
+#~ msgid "Download New Stuff..."
+#~ msgstr "ಹೊಸ ಪದಾರ್ಥವನ್ನು ನಕಲಿಳಿಸಿ..."
 
 #~ msgid "Initializing"
 #~ msgstr "ಆರಂಭಿಸಲಾಗುತ್ತಿದೆ"
diff -pruN 6.0.0-3/po/ko/knewstuff6.po 6.3.0-1/po/ko/knewstuff6.po
--- 6.0.0-3/po/ko/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/ko/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -8,7 +8,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2024-02-09 23:48+0100\n"
 "Last-Translator: Shinjo Park <kde@peremen.name>\n"
 "Language-Team: Korean <kde-kr@kde.org>\n"
@@ -57,7 +57,7 @@ msgstr "투표가 기록되었습니다.
 msgid "You are now a fan."
 msgstr "팬으로 등록되었습니다."
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -124,7 +124,7 @@ msgstr "설정 파일이 잘못됨: \"%1
 msgid "Use"
 msgstr "사용"
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -136,17 +136,17 @@ msgstr ""
 "%2\n"
 "치명적인 오류입니다. 앱 개발자에게 보고해 주십시오"
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr "파일에서 공급자 목록을 불러오는 중: %1 실패"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr "파일에서 새로운 항목 다운로드 공급자를 불러올 수 없음: %1"
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr "공급자를 초기화하는 중 오류가 발생했습니다."
@@ -310,7 +310,7 @@ msgid ""
 "the update"
 msgstr "%1을(를) 업데이트할 수 있는 링크를 찾지 못해서 업데이트할 수 없음"
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, kde-format
 msgid ""
 "Failed to adopt '%1'\n"
@@ -319,14 +319,14 @@ msgstr ""
 "'%1'을(를) 받아들일 수 없음\n"
 "%2"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, kde-format
 msgctxt ""
 "The first entry in the category selection list (also the default value)"
 msgid "All Categories"
 msgstr "모든 분류"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, kde-format
 msgctxt ""
 "The string passed back in the case the requested category is not known"
@@ -350,13 +350,13 @@ msgstr "항목"
 msgid "Download New %1…"
 msgstr "새 %1 다운로드…"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, kde-format
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "새 %1 다운로드"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, kde-format
 msgctxt ""
 "A placeholder title used in the dialog when there is no better title "
@@ -364,12 +364,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "새로운 항목 다운로드"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr "설치 옵션 선택"
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -381,19 +381,19 @@ msgstr ""
 "떤 옵션을 선택해야 할지 모르겠으면 항목의 개발자에게 연락하여 명확한 이름으"
 "로 변경해 줄 것을 요청하십시오."
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "설치"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, kde-format
 msgctxt ""
 "A passive notification shown when installation of an item is initiated"
 msgid "Installing %1 from %2"
 msgstr "%2에서 %1 설치 중"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -401,10 +401,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr "%1(%2 제작)"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, kde-format
 msgctxt ""
 "Request installation of this item, available when there is exactly one "
@@ -412,32 +412,32 @@ msgctxt ""
 msgid "Install"
 msgstr "설치"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, kde-format
 msgctxt ""
 "Show installation options, where there is more than one downloadable item"
 msgid "Install…"
 msgstr "설치…"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, kde-format
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "업데이트"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, kde-format
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "삭제"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -445,14 +445,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr "현재 %1(%2 제작) 항목에서 작업 중입니다. 기다려 주십시오…"
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr "현재 %1(%2 제작) 항목을 업데이트하고 있습니다. 기다려 주십시오…"
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -466,12 +466,12 @@ msgstr ""
 "kde.org/enter_bug.cgi?product=frameworks-knewstuff\">KDE 커뮤니티에 버그를 보"
 "고해 주십시오</a>."
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr "댓글과 리뷰:"
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a new sub page with comments (comments "
@@ -479,17 +479,17 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "댓글과 리뷰 %1개"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, kde-format
 msgid "Rating:"
 msgstr "별점:"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, kde-format
 msgid "Homepage:"
 msgstr "홈페이지:"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -498,12 +498,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr "%1의 홈페이지 열기"
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr "기부 방법:"
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -511,74 +511,85 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr "이 프로젝트에 기부하는 방법 알아보기"
 
-#: qtquick/qml/Page.qml:141
-#, kde-format
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
+#, fuzzy, kde-format
+#| msgid ""
+#| "The content available here has been uploaded by users like you, and has "
+#| "not been reviewed by your distributor for functionality or stability."
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 "여기에 있는 콘텐츠는 여러분과 같은 사용자가 업로드했으며, 배포판 관리자가 기"
 "능 및 안정성을 검증하지 않았을 수도 있습니다."
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, kde-format
 msgid "Tiles"
 msgstr "타일"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "아이콘"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, kde-format
 msgid "Preview"
 msgstr "미리 보기"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, kde-format
 msgid "Detailed Tiles View Mode"
 msgstr "자세한 바둑판식 보기 모드"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, kde-format
 msgid "Icons Only View Mode"
 msgstr "아이콘만 보기 모드"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, kde-format
 msgid "Large Preview View Mode"
 msgstr "큰 미리 보기 보기 모드"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr "모두"
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "설치됨"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, kde-format
 msgid "Updateable"
 msgstr "업데이트 가능"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, kde-format
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "모든 항목 표시"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr "설치한 항목만 표시"
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -586,27 +597,27 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr "업데이트 가능한 항목만 표시"
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, kde-format
 msgid "Recent"
 msgstr "최근"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr "가나다순"
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "별점"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, kde-format
 msgid "Downloads"
 msgstr "다운로드"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on when items were most "
@@ -614,7 +625,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "가장 최근 항목 먼저 표시"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -622,57 +633,57 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr "가나다순으로 정렬"
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, kde-format
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "별점이 높은 항목부터 표시"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on number of downloads"
 msgid "Show Most Downloaded First"
 msgstr "최다 다운로드 항목부터 표시"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, kde-format
 msgid "Upload…"
 msgstr "업로드…"
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr "내가 만든 항목을 목록에 추가하는 방법 알아보기"
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, kde-format
 msgid "Go to…"
 msgstr "다음으로 이동…"
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, kde-format
 msgid "Search…"
 msgstr "검색…"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "분류:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, kde-format
 msgid "Contribute your own…"
 msgstr "내 항목 기여..."
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, kde-format
 msgctxt ""
 "Placeholder title for when a comment has no subject, but does have a rating"
 msgid "<i>(no title)</i>"
 msgstr "<i>(제목 없음)</i>"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -680,19 +691,19 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr "%1<i>(작성자)</i>"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr "%1의 댓글과 리뷰"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, kde-format
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "모든 댓글 표시"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -700,7 +711,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr "리뷰만 표시"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -708,15 +719,15 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr "리뷰와 답글 표시"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, kde-format
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
 msgstr "다운로드 %1회"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, kde-format
 msgctxt ""
 "Subheading for the tile view, located immediately underneath the name of the "
@@ -724,7 +735,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "<i>%1</i> 제작"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -732,7 +743,7 @@ msgctxt ""
 msgid "Working…"
 msgstr "작업 중…"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is in the process of being "
@@ -740,7 +751,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "업데이트 중…"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -753,7 +764,7 @@ msgstr ""
 "잘못되었거나 알 수 없는 상태입니다. <a href=\"https://bugs.kde.org/enter_bug."
 "cgi?product=frameworks-knewstuff\">KDE 커뮤니티에 버그를 보고해 주십시오</a>."
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, kde-format
 msgctxt "Label for the busy indicator showing an item is installing"
 msgid "Installing…"
@@ -770,44 +781,44 @@ msgstr "오류 발생"
 msgid "Please try again later."
 msgstr "나중에 다시 시도하십시오."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, kde-format
 msgid "None"
 msgstr "없음"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, kde-format
 msgctxt ""
 "A text representation of the rating, shown as a fraction of the max value"
 msgid "(%1/%2)"
 msgstr "(%1/%2)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, kde-format
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "새로운 항목 업로드: %1"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, kde-format
 msgctxt ""
 "A text shown beside a busy indicator suggesting that data is being fetched"
 msgid "Updating information…"
 msgstr "정보 업데이트 중…"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, kde-format
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "KDE 스토어"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, kde-format
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "내 제공자"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, kde-format
 msgctxt ""
 "Text for an action which causes the specified website to be opened using the "
@@ -815,7 +826,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "웹사이트 열기: %1"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, kde-format
 msgctxt ""
 "Text for an action which will attempt to send an email using the user's "
@@ -823,22 +834,29 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "이메일 보내기: %1"
 
-#: qtquick/qml/UploadPage.qml:154
-#, kde-format
+#: qtquick/qml/UploadPage.qml:159
+#, fuzzy, kde-format
+#| msgctxt "A description of how to upload content to a generic provider"
+#| msgid ""
+#| "To upload new entries, or to add content to an existing entry on the KDE "
+#| "Store, please open the website and log in. Once you have done this, you "
+#| "will be able to find the My Products entry in the menu which pops up when "
+#| "you click your user icon. Click on this entry to go to the product "
+#| "management system, where you can work on your products ."
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
 "To upload new entries, or to add content to an existing entry on the KDE "
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 "KDE 스토어에 새 항목을 업로드하거나 기존 항목에 내용을 추가하려면 웹사이트를 "
 "열고 로그인하십시오. 로그인 후 사용자 아이콘을 클릭했을 때 나타나는 메뉴에서 "
 "\"My Products\" 항목을 클릭하십시오. 제품 관리 시스템에서 내 제품을 관리할 "
 "수 있습니다."
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -853,18 +871,18 @@ msgstr ""
 "오. 사이트에 따라서 제품 관리 시스템에 계정을 만들고 로그인해야 할 수도 있습"
 "니다. 새 제품을 추가할 때 스토어 관리자에게 직접 연락하여야 할 수도 있습니다."
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "데이터 불러오는 중"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "설치 중"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -876,73 +894,73 @@ msgstr ""
 "새로운 항목 다운로드 사용 권한이 없습니다. 오류가 있다고 생각하면 권한 담당자"
 "에게 문의하십시오."
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "뒤로"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr "인기"
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "특선"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "다시 시작"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "New"
 msgstr "새로운 항목"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "홈페이지"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr "선반"
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "위로"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "추천"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "구독"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "모든 항목"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -984,9 +1002,17 @@ msgstr ""
 " URL 예제: kns://sddmtheme.knsrc/api.kde-look.org/2059021"
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
-#, kde-format
-msgid "Download New Stuff..."
-msgstr "새로운 항목 다운로드..."
+#, fuzzy, kde-format
+#| msgctxt ""
+#| "A placeholder title used in the dialog when there is no better title "
+#| "available"
+#| msgid "Download New Stuff"
+msgctxt "@action"
+msgid "Download New Stuff…"
+msgstr "새로운 항목 다운로드"
+
+#~ msgid "Download New Stuff..."
+#~ msgstr "새로운 항목 다운로드..."
 
 #~ msgctxt ""
 #~ "A message which is shown when the user attempts to display a specific "
diff -pruN 6.0.0-3/po/ku/knewstuff6.po 6.3.0-1/po/ku/knewstuff6.po
--- 6.0.0-3/po/ku/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/ku/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -11,7 +11,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2010-08-13 15:45+0200\n"
 "Last-Translator: Erdal Ronahî <erdal.ronahi@nospam.gmail.com>\n"
 "Language-Team: Kurdish Team http://pckurd.net\n"
@@ -70,7 +70,7 @@ msgstr "Dengdana te hate tomar bûn."
 msgid "You are now a fan."
 msgstr "Tu niha hezkerî."
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -138,7 +138,7 @@ msgstr "Pela veavakirinê nederbasdar e:
 msgid "Use"
 msgstr ""
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -146,17 +146,17 @@ msgid ""
 "This is a critical error and should be reported to the application author"
 msgstr ""
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr "Barkirina peydekeran ji pelê: %1 pêk nehat"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr ""
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr "Destpêkirina peydekerê de çewtî."
@@ -301,7 +301,7 @@ msgid ""
 "the update"
 msgstr ""
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, fuzzy, kde-format
 #| msgid "Failed to load file '%1'"
 msgid ""
@@ -309,7 +309,7 @@ msgid ""
 "%2"
 msgstr "Barkirina pelê '%1' biserneket"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt ""
@@ -317,7 +317,7 @@ msgctxt ""
 msgid "All Categories"
 msgstr "Hemû Kategorî"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, fuzzy, kde-format
 #| msgid "Unknown error"
 msgctxt ""
@@ -343,14 +343,14 @@ msgstr ""
 msgid "Download New %1…"
 msgstr "%1 Daxistina Nû"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, fuzzy, kde-format
 #| msgid "Download New %1"
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "%1 Daxistina Nû"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
 msgctxt ""
@@ -359,12 +359,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "Taybetiyên Nû Daxe"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -373,12 +373,12 @@ msgid ""
 "this through the naming of the items."
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "Saz Bike"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt ""
@@ -386,7 +386,7 @@ msgctxt ""
 msgid "Installing %1 from %2"
 msgstr "Saz dike"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -394,10 +394,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -406,10 +406,10 @@ msgctxt ""
 msgid "Install"
 msgstr "Saz Bike"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -417,24 +417,24 @@ msgctxt ""
 msgid "Install…"
 msgstr "Saz Bike"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, fuzzy, kde-format
 #| msgid "Update"
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "Rojanekirin"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, fuzzy, kde-format
 #| msgid "Uninstall"
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "Rake"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -442,14 +442,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -460,12 +460,12 @@ msgid ""
 "to the KDE Community in a bug report</a>."
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, fuzzy, kde-format
 #| msgid "View Comments"
 msgctxt ""
@@ -474,19 +474,19 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "Şiroveyan Temaşe Bike"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, fuzzy, kde-format
 #| msgid "Rating: "
 msgid "Rating:"
 msgstr "Nirxandin:"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, fuzzy, kde-format
 #| msgid "Homepage"
 msgid "Homepage:"
 msgstr "Serûpel"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -495,12 +495,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -508,78 +508,86 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr ""
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, fuzzy, kde-format
 #| msgid "File"
 msgid "Tiles"
 msgstr "Pel"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "Sembol"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, kde-format
 msgid "Preview"
 msgstr "Pêşdîtin Tune"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, fuzzy, kde-format
 #| msgid "Details view mode"
 msgid "Detailed Tiles View Mode"
 msgstr "Moda dîtina bi kitekit"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, fuzzy, kde-format
 #| msgid "Icons view mode"
 msgid "Icons Only View Mode"
 msgstr "Moda dîtina îkonan"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, fuzzy, kde-format
 #| msgid "Details view mode"
 msgid "Large Preview View Mode"
 msgstr "Moda dîtina bi kitekit"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr ""
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "Hate Sazkirin"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, fuzzy, kde-format
 #| msgid "Update"
 msgid "Updateable"
 msgstr "Rojanekirin"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "Hemû Kategorî"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -587,30 +595,30 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Open Recent"
 msgid "Recent"
 msgstr "Ya herî dawî hatiye bikaranîn veke"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr ""
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "Nirxandin"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, fuzzy, kde-format
 #| msgid "Download"
 msgid "Downloads"
 msgstr "Daxîne"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt ""
@@ -619,7 +627,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "Berê peldankan nîşan bide"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -627,14 +635,14 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr ""
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "Berê peldankan nîşan bide"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, fuzzy, kde-format
 #| msgid "Most downloads"
 msgctxt ""
@@ -642,41 +650,41 @@ msgctxt ""
 msgid "Show Most Downloaded First"
 msgstr "Yên Herî Zêde Hatine Daxistin"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, fuzzy, kde-format
 #| msgid "Upload..."
 msgid "Upload…"
 msgstr "&Biguherîne..."
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr ""
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, fuzzy, kde-format
 #| msgid "&Go To..."
 msgid "Go to…"
 msgstr "&Biçe..."
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, fuzzy, kde-format
 #| msgid "Search:"
 msgid "Search…"
 msgstr "Lê Bigere:"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "Kategorî:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, fuzzy, kde-format
 #| msgid "Continue operation"
 msgid "Contribute your own…"
 msgstr "Kirarê bidomîme"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, fuzzy, kde-format
 #| msgctxt "@note/rich"
 #| msgid "<i>Note</i>: %1"
@@ -685,7 +693,7 @@ msgctxt ""
 msgid "<i>(no title)</i>"
 msgstr "<i>Not</i>: %1"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -693,20 +701,20 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "Hemû Kategorî"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -714,7 +722,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -722,8 +730,8 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, fuzzy, kde-format
 #| msgid "1 download"
 #| msgid_plural "%1 downloads"
@@ -731,8 +739,8 @@ msgctxt "The number of times the item ha
 msgid "%1 downloads"
 msgstr "1 Daxisti"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, fuzzy, kde-format
 #| msgctxt "Show the author of this item in a list"
 #| msgid "By <i>%1</i>"
@@ -742,7 +750,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "Bi <i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -750,7 +758,7 @@ msgctxt ""
 msgid "Working…"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, fuzzy, kde-format
 #| msgid "Updating"
 msgctxt ""
@@ -759,7 +767,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "Tê Rojanekirin"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -770,7 +778,7 @@ msgid ""
 "bug report</a>."
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt "Label for the busy indicator showing an item is installing"
@@ -789,14 +797,14 @@ msgstr ""
 msgid "Please try again later."
 msgstr "Ji kerema xwe re navekî têkevinê."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, fuzzy, kde-format
 #| msgctxt "No border line"
 #| msgid "None"
 msgid "None"
 msgstr "Ne yek jî"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, fuzzy, kde-format
 #| msgid "(%1/s)"
 msgctxt ""
@@ -804,14 +812,14 @@ msgctxt ""
 msgid "(%1/%2)"
 msgstr "(%1/ç)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "Taybetiyên Nû Daxe"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, fuzzy, kde-format
 #| msgid "Billing information:"
 msgctxt ""
@@ -819,21 +827,21 @@ msgctxt ""
 msgid "Updating information…"
 msgstr "Agahiya hesabkirinê:"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, fuzzy, kde-format
 #| msgid "&Store"
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "&Tomar Bike"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, fuzzy, kde-format
 #| msgid "Provider:"
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "Peydeker:"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, fuzzy, kde-format
 #| msgctxt "@label:button"
 #| msgid "&Open with %1"
@@ -843,7 +851,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "Bi %1 &veke"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, fuzzy, kde-format
 #| msgid "&Send Email"
 msgctxt ""
@@ -852,7 +860,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "&E-peyamekê Bişîne"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -860,10 +868,10 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -875,18 +883,18 @@ msgid ""
 "content added."
 msgstr ""
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "Daneyên barkirinê"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "Saz dike"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -896,7 +904,7 @@ msgid ""
 "please contact the person in charge of your permissions."
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Back"
@@ -904,20 +912,20 @@ msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "Paşde"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, fuzzy, kde-format
 #| msgid "Saturday"
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "Şemî"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, fuzzy, kde-format
 #| msgctxt "@action:button Restart find & replace"
 #| msgid "Restart"
@@ -925,7 +933,7 @@ msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "Ji Nû Ve Bide Destpêkirin"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "New"
@@ -933,7 +941,7 @@ msgctxt "Knewstuff5"
 msgid "New"
 msgstr "Nû"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Home"
@@ -941,13 +949,13 @@ msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Mal"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Up"
@@ -955,7 +963,7 @@ msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "Jor"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, fuzzy, kde-format
 #| msgctxt "dictionary variant"
 #| msgid "extended"
@@ -963,7 +971,7 @@ msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "berfirehkirî"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Subscript"
@@ -971,14 +979,14 @@ msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "Abonebûn"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "Hemû Kategorî"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -1009,9 +1017,14 @@ msgid ""
 msgstr ""
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
-#, kde-format
-msgid "Download New Stuff..."
-msgstr "Taybetiyên Nû Daxe..."
+#, fuzzy, kde-format
+#| msgid "Download New Stuff"
+msgctxt "@action"
+msgid "Download New Stuff…"
+msgstr "Taybetiyên Nû Daxe"
+
+#~ msgid "Download New Stuff..."
+#~ msgstr "Taybetiyên Nû Daxe..."
 
 #~ msgid "Initializing"
 #~ msgstr "Destpê dike"
diff -pruN 6.0.0-3/po/lb/knewstuff6.po 6.3.0-1/po/lb/knewstuff6.po
--- 6.0.0-3/po/lb/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/lb/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -5,7 +5,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2006-06-22 16:29+0200\n"
 "Last-Translator: Michel Ludwig <michel.ludwig@kdemail.net>\n"
 "Language-Team: Luxembourgish <kde-i18n-lb@kde.org>\n"
@@ -51,7 +51,7 @@ msgstr "Et ass näischt ersat ginn."
 msgid "You are now a fan."
 msgstr ""
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -122,7 +122,7 @@ msgstr "Configuratiounsdateien"
 msgid "Use"
 msgstr "Erofklappen"
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -130,18 +130,18 @@ msgid ""
 "This is a critical error and should be reported to the application author"
 msgstr ""
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, fuzzy, kde-format
 #| msgid "Loading resource '%1' failed!"
 msgid "Loading of providers from file: %1 failed"
 msgstr "D'Quell '%1' konnt net geluede ginn!"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr ""
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, fuzzy, kde-format
 #| msgid "Error parsing providers list."
 msgid "Error initializing provider."
@@ -289,14 +289,14 @@ msgid ""
 "the update"
 msgstr ""
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, fuzzy, kde-format
 msgid ""
 "Failed to adopt '%1'\n"
 "%2"
 msgstr "Konnt d'Quell '%1' net lueden"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, fuzzy, kde-format
 #| msgid "Categories"
 msgctxt ""
@@ -304,7 +304,7 @@ msgctxt ""
 msgid "All Categories"
 msgstr "Kategorien"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, fuzzy, kde-format
 #| msgctxt "QFile"
 #| msgid "Unknown error"
@@ -331,14 +331,14 @@ msgstr ""
 msgid "Download New %1…"
 msgstr "Nei %1 eroflueden"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, fuzzy, kde-format
 #| msgid "Download New %1"
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "Nei %1 eroflueden"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
 msgctxt ""
@@ -347,13 +347,13 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "Nei Saachen eroflueden"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, fuzzy, kde-format
 #| msgid "Resource Installation Error"
 msgid "Pick Your Installation Option"
 msgstr "Feeler bei der Installatioun vu Ressourcen"
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -362,12 +362,12 @@ msgid ""
 "this through the naming of the items."
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "Installéieren"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -375,7 +375,7 @@ msgctxt ""
 msgid "Installing %1 from %2"
 msgstr "Installéieren"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -383,10 +383,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -395,10 +395,10 @@ msgctxt ""
 msgid "Install"
 msgstr "Installéieren"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -406,24 +406,24 @@ msgctxt ""
 msgid "Install…"
 msgstr "Installéieren"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, fuzzy, kde-format
 #| msgid "Update"
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "Aktualiséieren"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "Installéieren"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -431,14 +431,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -449,12 +449,12 @@ msgid ""
 "to the KDE Community in a bug report</a>."
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, fuzzy, kde-format
 #| msgid "Comment"
 msgctxt ""
@@ -463,19 +463,19 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "Kommentar"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, fuzzy, kde-format
 #| msgid "Rating"
 msgid "Rating:"
 msgstr "Bewertung"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, fuzzy, kde-format
 #| msgid "Homepage"
 msgid "Homepage:"
 msgstr "Homepage"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -484,12 +484,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -497,73 +497,81 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr ""
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, fuzzy, kde-format
 #| msgid "&Tile"
 msgid "Tiles"
 msgstr "&Kachelen"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "Symboler"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, fuzzy, kde-format
 #| msgid "Preview URL:"
 msgid "Preview"
 msgstr "URL-Virschau:"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, fuzzy, kde-format
 #| msgid "Details"
 msgid "Detailed Tiles View Mode"
 msgstr "Detailer"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, fuzzy, kde-format
 #| msgid "Icon Size"
 msgid "Icons Only View Mode"
 msgstr "Gréisst vum Symbol"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, fuzzy, kde-format
 #| msgid "Details"
 msgid "Large Preview View Mode"
 msgstr "Detailer"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr ""
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, fuzzy, kde-format
 #| msgid "Install"
 msgid "Installed"
 msgstr "Installéieren"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, fuzzy, kde-format
 #| msgid "Update"
 msgid "Updateable"
 msgstr "Aktualiséieren"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, fuzzy, kde-format
 #| msgid "Show all options"
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "All Optioune weisen"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, fuzzy, kde-format
 #| msgid "Show all options"
 msgctxt ""
@@ -571,7 +579,7 @@ msgctxt ""
 msgid "Show Only Installed Entries"
 msgstr "All Optioune weisen"
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, fuzzy, kde-format
 #| msgid "Show all options"
 msgctxt ""
@@ -580,31 +588,31 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr "All Optioune weisen"
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, fuzzy, kde-format
 #| msgctxt "QAccel"
 #| msgid "Percent"
 msgid "Recent"
 msgstr "Prozent"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr ""
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, fuzzy, kde-format
 #| msgid "Rating"
 msgid "Rating"
 msgstr "Bewertung"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, fuzzy, kde-format
 #| msgid "Download"
 msgid "Downloads"
 msgstr "Eroflueden"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, fuzzy, kde-format
 #| msgid "Most Downloads"
 msgctxt ""
@@ -613,7 +621,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "Am meeschten erofgelueden"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -621,14 +629,14 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr ""
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, fuzzy, kde-format
 #| msgid "Highest Rated"
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "Am héchste bewäert"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, fuzzy, kde-format
 #| msgid "Most Downloads"
 msgctxt ""
@@ -636,49 +644,49 @@ msgctxt ""
 msgid "Show Most Downloaded First"
 msgstr "Am meeschten erofgelueden"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, fuzzy, kde-format
 #| msgid "&Upload"
 msgid "Upload…"
 msgstr "&Eroplueden"
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr ""
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, fuzzy, kde-format
 #| msgid "&Go To..."
 msgid "Go to…"
 msgstr "&Goen..."
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, fuzzy, kde-format
 #| msgid "S&earch:"
 msgid "Search…"
 msgstr "Siche&n:"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, fuzzy, kde-format
 #| msgid "Categories"
 msgid "Category:"
 msgstr "Kategorien"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, fuzzy, kde-format
 #| msgid "Continue operation"
 msgid "Contribute your own…"
 msgstr "Virgang fortsetzen"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, kde-format
 msgctxt ""
 "Placeholder title for when a comment has no subject, but does have a rating"
 msgid "<i>(no title)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -686,20 +694,20 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, fuzzy, kde-format
 #| msgid "Categories"
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "Kategorien"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -707,7 +715,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -715,16 +723,16 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, fuzzy, kde-format
 #| msgid "Download"
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
 msgstr "Eroflueden"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, fuzzy, kde-format
 #| msgid "<b>Error</b>: %1: %2"
 msgctxt ""
@@ -733,7 +741,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "<b>Feeler</b>: %1: %2"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -741,7 +749,7 @@ msgctxt ""
 msgid "Working…"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, fuzzy, kde-format
 #| msgid "Update"
 msgctxt ""
@@ -750,7 +758,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "Aktualiséieren"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -761,7 +769,7 @@ msgid ""
 "bug report</a>."
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt "Label for the busy indicator showing an item is installing"
@@ -782,13 +790,13 @@ msgstr "Kee Feeler"
 msgid "Please try again later."
 msgstr "Gitt w.e.g. ën Numm an."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, fuzzy, kde-format
 #| msgid "None"
 msgid "None"
 msgstr "Keng"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, fuzzy, kde-format
 #| msgid "(%1/s)"
 msgctxt ""
@@ -796,14 +804,14 @@ msgctxt ""
 msgid "(%1/%2)"
 msgstr "(%1/s)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "Nei Saachen eroflueden"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, fuzzy, kde-format
 #| msgid "Information"
 msgctxt ""
@@ -811,21 +819,21 @@ msgctxt ""
 msgid "Updating information…"
 msgstr "Informatioun"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, fuzzy, kde-format
 #| msgid "Store"
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "Späicheren"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, fuzzy, kde-format
 #| msgid "Hide %1"
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "%1 net weisen"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, fuzzy, kde-format
 #| msgid "&Open with '%1'"
 msgctxt ""
@@ -834,7 +842,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "Mat '%1' &opmaachen"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, fuzzy, kde-format
 #| msgid "&Send Email"
 msgctxt ""
@@ -843,7 +851,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "E-Mail &verschécken"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -851,10 +859,10 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -866,20 +874,20 @@ msgid ""
 "content added."
 msgstr ""
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, fuzzy, kde-format
 #| msgid "Loading Applet"
 msgid "Loading data"
 msgstr "Amgaang, de Miniprogramm ze lueden"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, fuzzy, kde-format
 #| msgid "Install"
 msgid "Installing"
 msgstr "Installéieren"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -889,41 +897,41 @@ msgid ""
 "please contact the person in charge of your permissions."
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, fuzzy, kde-format
 #| msgid "Back"
 msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "Zeréck"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, fuzzy, kde-format
 #| msgid "Saturday"
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "Samschten"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, fuzzy, kde-format
 #| msgid "Restart"
 msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "Nei ufänken"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, fuzzy, kde-format
 #| msgid "New"
 msgctxt "Knewstuff5"
 msgid "New"
 msgstr "Nei"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, fuzzy, kde-format
 #| msgctxt "Opposite to End"
 #| msgid "Home"
@@ -931,39 +939,39 @@ msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Ufank"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, fuzzy, kde-format
 #| msgid "Up"
 msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "Erop"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, fuzzy, kde-format
 msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "&Handschrëft"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, fuzzy, kde-format
 #| msgid "Show all options"
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "All Optioune weisen"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -996,10 +1004,16 @@ msgstr ""
 #: widgets/action.cpp:28 widgets/button.cpp:70
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
-msgid "Download New Stuff..."
+msgctxt "@action"
+msgid "Download New Stuff…"
 msgstr "Nei Saachen eroflueden"
 
 #, fuzzy
+#~| msgid "Download New Stuff"
+#~ msgid "Download New Stuff..."
+#~ msgstr "Nei Saachen eroflueden"
+
+#, fuzzy
 #~| msgid "Install"
 #~ msgid "Initializing"
 #~ msgstr "Installéieren"
diff -pruN 6.0.0-3/po/lt/knewstuff6.po 6.3.0-1/po/lt/knewstuff6.po
--- 6.0.0-3/po/lt/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/lt/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -12,7 +12,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2024-01-27 14:54+0200\n"
 "Last-Translator: Moo <<>>\n"
 "Language-Team: lt <kde-i18n-lt@kde.org>\n"
@@ -62,7 +62,7 @@ msgstr "Jūsų balsas įskaičiuotas."
 msgid "You are now a fan."
 msgstr "Dabar esate fanas."
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -131,7 +131,7 @@ msgstr "Konfigūracijos failas yra netei
 msgid "Use"
 msgstr "Naudoti"
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -142,17 +142,17 @@ msgstr ""
 "%2\n"
 "Tai yra kritinė klaida ir apie ją turėtų būti pranešta programos autoriui"
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr "Tiekėjų įkėlimas iš failo: %1 nepavyko"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr "Nepavyko įkelti karštų naujų elementų gavimo tiekėjų iš failo: %1"
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr "Klaida inicijuojant tiekėją."
@@ -322,7 +322,7 @@ msgstr ""
 "Nepavyko atpažinti tinkamos nuorodos, skirtos atnaujinti %1, taigi negalime "
 "atlikti atnaujinimo"
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, kde-format
 msgid ""
 "Failed to adopt '%1'\n"
@@ -331,14 +331,14 @@ msgstr ""
 "Nepavyko priimti „%1“\n"
 "%2"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, kde-format
 msgctxt ""
 "The first entry in the category selection list (also the default value)"
 msgid "All Categories"
 msgstr "Visos kategorijos"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, kde-format
 msgctxt ""
 "The string passed back in the case the requested category is not known"
@@ -362,13 +362,13 @@ msgstr "elementą"
 msgid "Download New %1…"
 msgstr "Atsisiųsti naują %1…"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, kde-format
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "Atsisiųsti naują %1"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, kde-format
 msgctxt ""
 "A placeholder title used in the dialog when there is no better title "
@@ -376,12 +376,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "Atsisiųsti naujus elementus"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr "Pasirinkite savo įdiegimo parinktį"
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -394,19 +394,19 @@ msgstr ""
 "įdiegti, susisiekite su šio elemento autoriumi ir paprašykite, kad jis tai "
 "patikslintų savo elemento pavadinime."
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "Įdiegti"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, kde-format
 msgctxt ""
 "A passive notification shown when installation of an item is initiated"
 msgid "Installing %1 from %2"
 msgstr "Įdiegiama %1 iš %2"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -414,10 +414,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr "%1 pagal %2"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, kde-format
 msgctxt ""
 "Request installation of this item, available when there is exactly one "
@@ -425,32 +425,32 @@ msgctxt ""
 msgid "Install"
 msgstr "Įdiegti"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, kde-format
 msgctxt ""
 "Show installation options, where there is more than one downloadable item"
 msgid "Install…"
 msgstr "Įdiegti…"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, kde-format
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "Atnaujinti"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, kde-format
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "Pašalinti"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -458,14 +458,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr "Šiuo metu dirbama su elementu %1 pagal %2. Palaukite…"
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr "Šiuo metu atnaujinamas elementas %1 pagal %2. Palaukite…"
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -479,12 +479,12 @@ msgstr ""
 "\"https://bugs.kde.org/enter_bug.cgi?product=frameworks-knewstuff\">Prašome "
 "pranešti apie tai KDE bendruomenei pranešime apie klaidą</a>."
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr "Komentarai ir apžvalgos:"
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a new sub page with comments (comments "
@@ -492,17 +492,17 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "%1 apžvalgos ir komentarai"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, kde-format
 msgid "Rating:"
 msgstr "Įvertinimas:"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, kde-format
 msgid "Homepage:"
 msgstr "Pagrindinis puslapis:"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -511,12 +511,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr "Atverti %1 pagrindinį puslapį"
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr "Kaip paremti:"
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -524,75 +524,86 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr "Sužinokite kaip paremti šį projektą"
 
-#: qtquick/qml/Page.qml:141
-#, kde-format
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
+#, fuzzy, kde-format
+#| msgid ""
+#| "The content available here has been uploaded by users like you, and has "
+#| "not been reviewed by your distributor for functionality or stability."
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 "Čia prieinamą turinį išsiuntė tokie patys naudotojai, kaip ir jūs, todėl "
 "jūsų platinamojo paketo platintojas nepatikrino kaip šis turinys veikia "
 "funkcionalumo ar stabilumo atžvilgiu."
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, kde-format
 msgid "Tiles"
 msgstr "Plytelės"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "Piktogramos"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, kde-format
 msgid "Preview"
 msgstr "Peržiūra"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, kde-format
 msgid "Detailed Tiles View Mode"
 msgstr "Išsamių plytelių rodinio veiksena"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, kde-format
 msgid "Icons Only View Mode"
 msgstr "Tik piktogramų rodinio veiksena"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, kde-format
 msgid "Large Preview View Mode"
 msgstr "Didelės peržiūros rodinio veiksena"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr "Visi"
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "Įdiegti"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, kde-format
 msgid "Updateable"
 msgstr "Galimi atnaujinti"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, kde-format
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "Rodyti visus įrašus"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr "Rodyti tik įdiegtus įrašus"
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -600,27 +611,27 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr "Rodyti tik galimus atnaujinti įrašus"
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, kde-format
 msgid "Recent"
 msgstr "Paskiausi"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr "Pagal abėcėlę"
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "Įvertinimas"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, kde-format
 msgid "Downloads"
 msgstr "Atsiuntimai"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on when items were most "
@@ -628,7 +639,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "Pirmiausia, rodyti paskiausius"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -636,57 +647,57 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr "Rikiuoti pavadinimus pagal abėcėlę"
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, kde-format
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "Pirmiausia, su aukščiausiu įvertinimu"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on number of downloads"
 msgid "Show Most Downloaded First"
 msgstr "Pirmiausia, rodyti daugiausiai atsisiųstus"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, kde-format
 msgid "Upload…"
 msgstr "Išsiųsti…"
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr "Sužinokite kaip pridėti į šį sąrašą savo asmeninius naujus elementus"
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, kde-format
 msgid "Go to…"
 msgstr "Pereiti į…"
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, kde-format
 msgid "Search…"
 msgstr "Ieškoti…"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "Kategorija:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, kde-format
 msgid "Contribute your own…"
 msgstr "Paskelbti viešai savo asmeninį…"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, kde-format
 msgctxt ""
 "Placeholder title for when a comment has no subject, but does have a rating"
 msgid "<i>(no title)</i>"
 msgstr "<i>(be antraštės)</i>"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -694,19 +705,19 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr "%1 <i>(autorius)</i>"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr "%1 komentarai ir apžvalgos"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, kde-format
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "Rodyti visus komentarus"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -714,7 +725,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr "Rodyti tik apžvalgas"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -722,15 +733,15 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr "Rodyti apžvalgas ir atsakymus"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, kde-format
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
 msgstr "Atsiuntimų: %1"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, kde-format
 msgctxt ""
 "Subheading for the tile view, located immediately underneath the name of the "
@@ -738,7 +749,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "Pagal <i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -746,7 +757,7 @@ msgctxt ""
 msgid "Working…"
 msgstr "Dirbama…"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is in the process of being "
@@ -754,7 +765,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "Atnaujinama…"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -768,7 +779,7 @@ msgstr ""
 "cgi?product=frameworks-knewstuff\">Prašome pranešti apie tai KDE "
 "bendruomenei pranešime apie klaidą</a>."
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, kde-format
 msgctxt "Label for the busy indicator showing an item is installing"
 msgid "Installing…"
@@ -785,44 +796,44 @@ msgstr "Įvyko klaida"
 msgid "Please try again later."
 msgstr "Vėliau bandykite dar kartą."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, kde-format
 msgid "None"
 msgstr "Nėra"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, kde-format
 msgctxt ""
 "A text representation of the rating, shown as a fraction of the max value"
 msgid "(%1/%2)"
 msgstr "(%1/%2)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, kde-format
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "Išsiųsti naują elementą: %1"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, kde-format
 msgctxt ""
 "A text shown beside a busy indicator suggesting that data is being fetched"
 msgid "Updating information…"
 msgstr "Atnaujinama informacija…"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, kde-format
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "KDE parduotuvė"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, kde-format
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "Jūsų tiekėjas"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, kde-format
 msgctxt ""
 "Text for an action which causes the specified website to be opened using the "
@@ -830,7 +841,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "Atverti internetinę svetainę: %1"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, kde-format
 msgctxt ""
 "Text for an action which will attempt to send an email using the user's "
@@ -838,15 +849,22 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "Siųsti el. laišką: %1"
 
-#: qtquick/qml/UploadPage.qml:154
-#, kde-format
+#: qtquick/qml/UploadPage.qml:159
+#, fuzzy, kde-format
+#| msgctxt "A description of how to upload content to a generic provider"
+#| msgid ""
+#| "To upload new entries, or to add content to an existing entry on the KDE "
+#| "Store, please open the website and log in. Once you have done this, you "
+#| "will be able to find the My Products entry in the menu which pops up when "
+#| "you click your user icon. Click on this entry to go to the product "
+#| "management system, where you can work on your products ."
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
 "To upload new entries, or to add content to an existing entry on the KDE "
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 "Norėdami išsiųsti naujus įrašus ar pridėti turinį į KDE parduotuvėje esantį "
 "įrašą, apsilankykite internetinėje svetainėje ir prisijunkite. Tai atlikę, "
@@ -855,7 +873,7 @@ msgstr ""
 "pereitumėte į produktų tvarkymo sistemą, kurioje galėsite dirbti su savo "
 "produktais."
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -873,18 +891,18 @@ msgstr ""
 "tai, kaip pridėti įrašą. Priešingu atveju, jums gali tekti tiesiogiai "
 "susisiekti su svetainės administratoriais, kad būtų pridėtas naujas turinys."
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "Įkeliami duomenys"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "Įdiegiama"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -896,73 +914,73 @@ msgstr ""
 "Jūs nesate įgalioti gauti karštus naujus elementus. Jeigu manote, kad tai "
 "klaida, susisiekite su asmeniu, atsakančiu už jūsų leidimus."
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "Atgal"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr "Populiarūs"
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "Pasižymėję"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "Paleisti iš naujo"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "New"
 msgstr "Nauja"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Pradžia"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr "Stalčius"
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "Aukštyn"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "Rekomenduojami"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "Prenumeratos"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "Visi įrašai"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -1006,9 +1024,17 @@ msgstr ""
 " Tokio url pavyzdys yra kns://sddmtheme.knsrc/api.kde-look.org/2059021"
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
-#, kde-format
-msgid "Download New Stuff..."
-msgstr "Atsisiųsti naujus elementus.."
+#, fuzzy, kde-format
+#| msgctxt ""
+#| "A placeholder title used in the dialog when there is no better title "
+#| "available"
+#| msgid "Download New Stuff"
+msgctxt "@action"
+msgid "Download New Stuff…"
+msgstr "Atsisiųsti naujus elementus"
+
+#~ msgid "Download New Stuff..."
+#~ msgstr "Atsisiųsti naujus elementus.."
 
 #~ msgctxt ""
 #~ "A message which is shown when the user attempts to display a specific "
diff -pruN 6.0.0-3/po/lv/knewstuff6.po 6.3.0-1/po/lv/knewstuff6.po
--- 6.0.0-3/po/lv/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/lv/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -8,14 +8,15 @@
 # Viesturs Zarins <viesturs.zarins@mii.lu.lv>, 2007, 2008, 2010.
 # Viesturs Zariņš <viesturs.zarins@mii.lu.lv>, 2009.
 # Einars Sprugis <einars8@gmail.com>, 2009.
+# SPDX-FileCopyrightText: 2024 Toms Trasuns <toms.trasuns@posteo.net>
 msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
-"PO-Revision-Date: 2011-07-06 12:57+0300\n"
-"Last-Translator: Maris Nartiss <maris.kde@gmail.com>\n"
-"Language-Team: Latvian\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
+"PO-Revision-Date: 2024-02-27 17:00+0200\n"
+"Last-Translator: Toms Trasuns <toms.trasuns@posteo.net>\n"
+"Language-Team: Latvian <kde-i18n-doc@kde.org>\n"
 "Language: lv\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
@@ -23,29 +24,23 @@ msgstr ""
 "Plural-Forms: nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : "
 "2);\n"
 "X-Launchpad-Export-Date: 2007-11-22 17:44+0000\n"
-"X-Generator: KBabel 1.11.4\n"
+"X-Generator: Lokalize 23.08.5\n"
 
 #: attica/atticaprovider.cpp:165
-#, fuzzy, kde-format
-#| msgid "All Categories"
+#, kde-format
 msgid "All categories are missing"
-msgstr "Visas kategorijas"
+msgstr "Trūkst visu kategoriju"
 
 #: attica/atticaprovider.cpp:480
-#, fuzzy, kde-format
-#| msgctxt ""
-#| "the price of a download item, parameter 1 is the currency, 2 is the price"
-#| msgid ""
-#| "This items costs %1 %2.\n"
-#| "Do you want to buy it?"
+#, kde-format
 msgctxt ""
 "the price of a download item, parameter 1 is the currency, 2 is the price"
 msgid ""
 "This item costs %1 %2.\n"
 "Do you want to buy it?"
 msgstr ""
-"Šīs lietas maksā %1 %2.\n"
-"Vai vēlaties pirkt tās?"
+"Šis vienums maksā %1 %2.\n"
+"Vai vēlaties to pirkt?"
 
 #: attica/atticaprovider.cpp:494
 #, kde-format
@@ -62,38 +57,38 @@ msgstr ""
 #, kde-format
 msgctxt "voting for an item (good/bad)"
 msgid "Your vote was recorded."
-msgstr "Jūsu balss veiksīgi reģistrēta."
+msgstr "Jūsu balss ir reģistrēta."
 
 #: attica/atticaprovider.cpp:552
 #, kde-format
 msgid "You are now a fan."
 msgstr "Jūs tagad esat fans."
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
 "The service is currently undergoing maintenance and is expected to be back "
 "in %1."
-msgstr ""
+msgstr "Šobrīd serviss veic apkopi un atkal būs pieejams pēc %1."
 
 #: attica/atticaprovider.cpp:585
-#, fuzzy, kde-format
-#| msgid "Network error. (%1)"
+#, kde-format
 msgid "Network error %1: %2"
-msgstr "Tīkla kļūda. (%1)"
+msgstr "Tīkla kļūda %1: %2"
 
 #: attica/atticaprovider.cpp:592
 #, kde-format
 msgid "Too many requests to server. Please try again in a few minutes."
-msgstr "Serveris ir saņēmis pārāk daudz pieprasījumu. Mēģiniet vēlāk."
+msgstr ""
+"Serveris ir saņēmis pārāk daudz pieprasījumu. Mēģiniet pēc dažām minūtēm."
 
 #: attica/atticaprovider.cpp:596
 #, kde-format
 msgid ""
 "The Open Collaboration Services instance %1 does not support the attempted "
 "function."
-msgstr ""
+msgstr "Atvērtās sadarbības servisu instance „%1“ neatbalsta šādu funkciju."
 
 #: attica/atticaprovider.cpp:600
 #, kde-format
@@ -101,12 +96,11 @@ msgid "Unknown Open Collaboration Servic
 msgstr "Nezināma atvērtās sadarbības servisa API kļūda. (%1)"
 
 #: core/commentsmodel.cpp:154
-#, fuzzy, kde-format
-#| msgid "Unknown socket error"
+#, kde-format
 msgctxt ""
 "The value returned for an unknown role when requesting data from the model."
 msgid "Unknown CommentsModel role"
-msgstr "Nezināma ligzdas kļūda"
+msgstr "Nezināma „CommentsModel“ loma"
 
 #: core/enginebase.cpp:43
 #, kde-format
@@ -114,48 +108,51 @@ msgid ""
 "An error occurred during the installation process:\n"
 "%1"
 msgstr ""
+"Notikusi kļūda instalācijas procesa laikā:\n"
+"%1"
 
 #: core/enginebase.cpp:79
-#, fuzzy, kde-format
-#| msgid "Configuration file not found: \"%1\""
+#, kde-format
 msgid "Configuration file does not exist: \"%1\""
-msgstr "Konfigurācijas fails \"%1\" nav atrasts."
+msgstr "Konfigurācijas datne nepastāv: „%1“"
 
 #: core/enginebase.cpp:87
-#, fuzzy, kde-format
-#| msgid "Configuration file not found: \"%1\""
+#, kde-format
 msgid "Configuration file exists, but cannot be opened: \"%1\""
-msgstr "Konfigurācijas fails \"%1\" nav atrasts."
+msgstr "Konfigurācijas datne pastāv, bet to nevar atvērt: „%1“"
 
 #: core/enginebase.cpp:94
 #, kde-format
 msgid "Configuration file is invalid: \"%1\""
-msgstr "Konfigurācijas fails \"%1\" nav derīgs."
+msgstr "Konfigurācijas datne „%1“ nav derīga."
 
 #: core/enginebase.cpp:103
 #, kde-format
 msgid "Use"
-msgstr ""
+msgstr "Lietot"
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
 "%2\n"
 "This is a critical error and should be reported to the application author"
 msgstr ""
+"Neizdevās ieslēgt „%1“ instalācijas nodrošinātāju:\n"
+"%2\n"
+"Šī ir kritiska kļūda un par to ir jāziņo programmas autoram"
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
-msgstr "Neizdevās ielasīt sniedzējusn no faila: %1"
+msgstr "Neizdevās sniedzēju ielāde no datnes: „%1“"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
-msgstr "Neizdevās ielasīt jauno lietu sniedzējus no faila: %1"
+msgstr "Neizdevās ielādēt jauno lietu sniedzējus no„datnes: „%1“"
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr "Kļūda inicializējot sniedzēju."
@@ -168,12 +165,12 @@ msgstr "Nederīgs vienums."
 #: core/installation.cpp:108
 #, kde-format
 msgid "Download of item failed: no download URL for \"%1\"."
-msgstr "Neizdevās lejupielādēt vienumu: nav lejupielādes URL priekš \"%1\"."
+msgstr "Neizdevās lejupielādēt vienumu: „%1“ nav lejupielādes URL."
 
 #: core/installation.cpp:139
 #, kde-format
 msgid "Download of \"%1\" failed, error: %2"
-msgstr "\"%1\" lejupielāde bija nesekmīga. Kļūda: %2"
+msgstr "„%1“ lejupielāde bija nesekmīga. Kļūda: %2"
 
 #: core/installation.cpp:148
 #, kde-format
@@ -181,28 +178,28 @@ msgid ""
 "Cannot install '%1' because it points to a web page. Click <a "
 "href='%2'>here</a> to finish the installation."
 msgstr ""
+"Nevar instalēt „%1“, jo tas norāda uz tīmekļa lapu. Spiediet <a "
+"href='%2'>te</a>, lai pabeigtu instalāciju."
 
 #: core/installation.cpp:186
 #, kde-format
 msgid "Could not install \"%1\": file not found."
-msgstr "Neizdevās instalēt \"%1\": fails nav atrasts."
+msgstr "Neizdevās instalēt „%1“: datne nav atrasta."
 
 #: core/installation.cpp:352 core/installation.cpp:599
-#, fuzzy, kde-format
-#| msgid "Installing"
+#, kde-format
 msgid "Installation of %1 failed: %2"
-msgstr "Instalē"
+msgstr "„%1“ instalācija neizdevās: %2"
 
 #: core/installation.cpp:386
 #, kde-format
 msgid "Could not determine the type of archive of the downloaded file %1"
-msgstr ""
+msgstr "Nevarēja noteikt lejupielādētās datnes „%1“ arhīva tipu"
 
 #: core/installation.cpp:398
-#, fuzzy, kde-format
-#| msgid "Unable to open temporary file."
+#, kde-format
 msgid "Failed to open the archive file %1. The reported error was: %2"
-msgstr "Nevar atvērt pagaidu failu."
+msgstr "Neizdevās atvērt arhīva datni „%1“. Ziņotā kļūda ir: %2"
 
 #: core/installation.cpp:465
 #, kde-format
@@ -211,17 +208,19 @@ msgid ""
 "attempt). Continuing means overwriting it. Do you wish to overwrite the "
 "existing file?"
 msgstr ""
+"Datne diskā jau pastāv (iespējams, tā ir iepriekš neizdevušās lejupielādes "
+"paliekas). Turpināšanas nozīmēs tās pārrakstīšanu. Vai vēlaties pārrakstīt "
+"pastāvošo datni?"
 
 #: core/installation.cpp:468
-#, fuzzy, kde-format
-#| msgid "Overwrite File?"
+#, kde-format
 msgid "Overwrite File"
-msgstr "Pārrakstīt failu?"
+msgstr "Pārrakstīt datni"
 
 #: core/installation.cpp:487
 #, kde-format
 msgid "Unable to move the file %1 to the intended destination %2"
-msgstr ""
+msgstr "Neizdodas pārrakstīt datni „%1“ uz paredzēto atrašanās vietu „%2“"
 
 #: core/installation.cpp:510
 #, kde-format
@@ -232,6 +231,11 @@ msgid ""
 "The returned output was:\n"
 "%2"
 msgstr ""
+"Instalācija neizdevās, mēģinot palaist komandu:\n"
+"%1\n"
+"\n"
+"Atgrieztā izvade ir:\n"
+"%2"
 
 #: core/installation.cpp:521
 #, kde-format
@@ -242,6 +246,11 @@ msgid ""
 "The returned output was:\n"
 "%3"
 msgstr ""
+"Instalācija neizdevās ar kodu „%1“, mēģinot palaist komandu:\n"
+"%2\n"
+"\n"
+"Atgrieztā izvade ir:\n"
+"%3"
 
 #: core/installation.cpp:563
 #, kde-format
@@ -250,6 +259,8 @@ msgid ""
 "automatically removed. You can attempt to manually delete this file, if you "
 "believe this is an error."
 msgstr ""
+"Nav izdevusies „%1“ noņemšana, jo instalēto datni „%2“ nevar manuāli noņemt. "
+"Varat mēģināt manuāli dzēst datni, ja domājat, ka tā ir kļūda."
 
 #: core/installation.cpp:632
 #, kde-format
@@ -260,18 +271,21 @@ msgid ""
 "If you think this is incorrect, you can continue or cancel the "
 "uninstallation process"
 msgstr ""
+"Atinstalēšanas procesam nav izdevies palaist komandu „%1“\n"
+"Izvade ir: \n"
+"%2\n"
+"Ja domājat, ka tā ir kļūda, varat turpināt vai atcelta atinstalēšanas "
+"procesu."
 
 #: core/jobs/filecopyworker.cpp:49
-#, fuzzy, kde-format
-#| msgid "Cannot open %1 for reading"
+#, kde-format
 msgid "Could not open %1 for writing"
-msgstr "Neizdevās atvērt %1 lasīšanai"
+msgstr "Neizdevās atvērt „%1“ rakstīšanai"
 
 #: core/jobs/filecopyworker.cpp:52
-#, fuzzy, kde-format
-#| msgid "Cannot open %1 for reading"
+#, kde-format
 msgid "Could not open %1 for reading"
-msgstr "Neizdevās atvērt %1 lasīšanai"
+msgstr "Neizdevās atvērt „%1“ lasīšanai"
 
 #: core/transaction.cpp:154
 #, kde-format
@@ -279,11 +293,13 @@ msgid ""
 "Could not perform an installation of the entry %1 as it does not have any "
 "downloadable items defined. Please contact the author so they can fix this."
 msgstr ""
+"Neizdevās izpildīt ieraksta „%1“ instalāciju, jo tam nav lejupielādējamu "
+"vienumu. Sazinieties ar autoru, lai to varētu novērst."
 
 #: core/transaction.cpp:263
 #, kde-format
 msgid "Pick Update Item"
-msgstr ""
+msgstr "Atlasīt atjaunināšanas vienumu"
 
 #: core/transaction.cpp:265
 #, kde-format
@@ -292,6 +308,9 @@ msgid ""
 "update. We were unable to identify which item to select, based on the "
 "original item, which was named %1"
 msgstr ""
+"Atlasiet vienumu no saraksta, kas ir izmantojams šī atjauninājuma "
+"pielietošanai. Mums neizdevās identificēt atlasāmo, balstoties uz sākotnējo "
+"vienumu ar nosaukumu „%1“"
 
 #: core/transaction.cpp:289
 #, kde-format
@@ -299,30 +318,31 @@ msgid ""
 "We failed to identify a good link for updating %1, and are unable to perform "
 "the update"
 msgstr ""
+"Nav izdevies identificēt derīgu saiti „%1“ atjaunināšanai, tāpēc nevaram "
+"veikt atjaunināšanu"
 
-#: core/transaction.cpp:376
-#, fuzzy, kde-format
-#| msgid "Failed to load file '%1'"
+#: core/transaction.cpp:381
+#, kde-format
 msgid ""
 "Failed to adopt '%1'\n"
 "%2"
-msgstr "Neizdevās ielādēt failu '%1'"
+msgstr ""
+"Neizdevās pielāgot „%1“\n"
+"%2"
 
-#: qtquick/categoriesmodel.cpp:50
-#, fuzzy, kde-format
-#| msgid "All Categories"
+#: qtquick/categoriesmodel.cpp:52
+#, kde-format
 msgctxt ""
 "The first entry in the category selection list (also the default value)"
 msgid "All Categories"
 msgstr "Visas kategorijas"
 
-#: qtquick/categoriesmodel.cpp:72
-#, fuzzy, kde-format
-#| msgid "Unknown error"
+#: qtquick/categoriesmodel.cpp:74
+#, kde-format
 msgctxt ""
 "The string passed back in the case the requested category is not known"
 msgid "Unknown Category"
-msgstr "Nezināma kļūda"
+msgstr "Nezināma kategorija"
 
 #. i18nd("knewstuff6", "Download New %1…").
 #. *
@@ -334,36 +354,33 @@ msgctxt ""
 "Used to construct the button's label (which will become Download New 'this "
 "value'…)"
 msgid "Stuff"
-msgstr ""
+msgstr "Lietas"
 
 #: qtquick/qml/Button.qml:44
-#, fuzzy, kde-format
-#| msgid "Download New Stuff..."
+#, kde-format
 msgid "Download New %1…"
-msgstr "Lejupielādēt ko jaunu..."
+msgstr "Lejupielādēt jaunu „%1“..."
 
-#: qtquick/qml/Dialog.qml:42
-#, fuzzy, kde-format
-#| msgid "Download New Stuff..."
+#: qtquick/qml/Dialog.qml:44
+#, kde-format
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
-msgstr "Lejupielādēt ko jaunu..."
+msgstr "Lejupielādēt jaunu „%1“"
 
-#: qtquick/qml/Dialog.qml:42
-#, fuzzy, kde-format
-#| msgid "Download New Stuff..."
+#: qtquick/qml/Dialog.qml:45
+#, kde-format
 msgctxt ""
 "A placeholder title used in the dialog when there is no better title "
 "available"
 msgid "Download New Stuff"
-msgstr "Lejupielādēt ko jaunu..."
+msgstr "Lejupielādēt ko jaunu"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
-msgstr ""
+msgstr "Izvēlieties instalācijas opciju"
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -371,84 +388,83 @@ msgid ""
 "options, please contact the author of this item and ask that they clarify "
 "this through the naming of the items."
 msgstr ""
+"Atlasiet šo opciju, ja vēlaties instalēt no lejupielādējamo vienumu "
+"saraksta. Ja nav skaidrs, kuru no visām pieejamajām opcijām izvēlēties, "
+"sazinieties ar vienuma autoru un lūdziet to paskaidrot ar skaidrākiem "
+"vienumu nosaukumiem."
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "Instalēt"
 
-#: qtquick/qml/EntryDetails.qml:87
-#, fuzzy, kde-format
-#| msgid "Installing"
+#: qtquick/qml/EntryDetails.qml:89
+#, kde-format
 msgctxt ""
 "A passive notification shown when installation of an item is initiated"
 msgid "Installing %1 from %2"
-msgstr "Instalē"
+msgstr "Instalēt „%1“ no „%2“"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
 "the author's name"
 msgid "%1 by %2"
-msgstr ""
+msgstr "„%1“, autors: %2"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
-#, fuzzy, kde-format
-#| msgid "Install"
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
+#, kde-format
 msgctxt ""
 "Request installation of this item, available when there is exactly one "
 "downloadable item"
 msgid "Install"
 msgstr "Instalēt"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
-#, fuzzy, kde-format
-#| msgid "Install"
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
+#, kde-format
 msgctxt ""
 "Show installation options, where there is more than one downloadable item"
 msgid "Install…"
-msgstr "Instalēt"
+msgstr "Instalēt..."
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
-#, fuzzy, kde-format
-#| msgid "Update"
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
+#, kde-format
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "Atjaunināt"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
-#, fuzzy, kde-format
-#| msgid "Uninstall"
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
+#, kde-format
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "Atinstalēt"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
 "installed OR uninstalled"
 msgid "Currently working on the item %1 by %2. Please wait…"
-msgstr ""
+msgstr "Šobrīd darbojas ar vienumu „%1“ (autors: %2). Uzgaidiet..."
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
-msgstr ""
+msgstr "Šobrīd atjaunina vienumu „%1“ (autors: %2). Uzgaidiet..."
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -458,309 +474,297 @@ msgid ""
 "bugs.kde.org/enter_bug.cgi?product=frameworks-knewstuff\">Please report this "
 "to the KDE Community in a bug report</a>."
 msgstr ""
+"Šis vienums šobrīd atrodas nederīgā vai nezināmā stāvoklī. <a href=\"https://"
+"bugs.kde.org/enter_bug.cgi?product=frameworks-knewstuff\">Ziņojiet par to "
+"KDE kopienai, iesniedzot kļūdas ziņojumu</a>."
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
-msgstr ""
+msgstr "Komentāri un atsauksmes"
 
-#: qtquick/qml/EntryDetails.qml:211
-#, fuzzy, kde-format
-#| msgid "View Comments"
+#: qtquick/qml/EntryDetails.qml:216
+#, kde-format
 msgctxt ""
 "A link which, when clicked, opens a new sub page with comments (comments "
 "with or without ratings) for this entry"
 msgid "%1 Reviews and Comments"
-msgstr "Skatīt komentārus"
+msgstr "„%1“ atsauksmes un komentāri"
 
-#: qtquick/qml/EntryDetails.qml:217
-#, fuzzy, kde-format
-#| msgid "Rating: "
+#: qtquick/qml/EntryDetails.qml:222
+#, kde-format
 msgid "Rating:"
-msgstr "Vērtējums: "
+msgstr "Vērtējums:"
 
-#: qtquick/qml/EntryDetails.qml:222
-#, fuzzy, kde-format
-#| msgid "Homepage"
+#: qtquick/qml/EntryDetails.qml:227
+#, kde-format
 msgid "Homepage:"
-msgstr "Mājas lapa"
+msgstr "Mājaslapa:"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
 "(this could be either one specific to the project, the author's homepage, or "
 "any other website they have chosen for the purpose)"
 msgid "Open the homepage for %1"
-msgstr ""
+msgstr "Atvērt „%1“ mājaslapu"
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
-msgstr ""
+msgstr "Kā ziedot:"
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
 "support of the entry"
 msgid "Find out how to donate to this project"
-msgstr ""
+msgstr "Uzziniet, kā varat ziedot šim projektam"
 
-#: qtquick/qml/Page.qml:141
-#, kde-format
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
 msgstr ""
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:140
 #, fuzzy, kde-format
-#| msgctxt "@option:check Do filter on type - show only files"
-#| msgid "Files"
+#| msgid ""
+#| "The content available here has been uploaded by users like you, and has "
+#| "not been reviewed by your distributor for functionality or stability."
+msgid ""
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
+msgstr ""
+"Šeit pieejamo saturu ir augšupielādējuši parasti lietotāji un to nav "
+"pārbaudījuši jūsu operētājsistēmas izplatītāji, tāpēc tas var nedarboties "
+"vai darboties nestabili."
+
+#: qtquick/qml/Page.qml:172
+#, kde-format
 msgid "Tiles"
-msgstr "Faili"
+msgstr "Flīzes"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "Ikonas"
 
-#: qtquick/qml/Page.qml:175
-#, fuzzy, kde-format
-#| msgid "Preview URL:"
+#: qtquick/qml/Page.qml:176
+#, kde-format
 msgid "Preview"
-msgstr "Priekšapskates URL:"
+msgstr "Priekšskatījums"
 
-#: qtquick/qml/Page.qml:191
-#, fuzzy, kde-format
-#| msgid "Details view mode"
+#: qtquick/qml/Page.qml:192
+#, kde-format
 msgid "Detailed Tiles View Mode"
-msgstr "Detaļu skata režīms"
+msgstr "Informatīvu flīžu skata režīms"
 
-#: qtquick/qml/Page.qml:200
-#, fuzzy, kde-format
-#| msgid "Icons view mode"
+#: qtquick/qml/Page.qml:203
+#, kde-format
 msgid "Icons Only View Mode"
-msgstr "Ikonu skata režīms"
+msgstr "Tikai ikonu skata režīms"
 
-#: qtquick/qml/Page.qml:209
-#, fuzzy, kde-format
-#| msgid "Details view mode"
+#: qtquick/qml/Page.qml:214
+#, kde-format
 msgid "Large Preview View Mode"
-msgstr "Detaļu skata režīms"
+msgstr "Lielu priekšskatījumu skata režīms"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
-msgstr ""
+msgstr "Visi"
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
-msgstr "Instalēts"
+msgstr "Instalēti"
 
-#: qtquick/qml/Page.qml:224
-#, fuzzy, kde-format
-#| msgid "Update"
+#: qtquick/qml/Page.qml:231
+#, kde-format
 msgid "Updateable"
-msgstr "Atjaunināt"
+msgstr "Atjaunināmi"
 
-#: qtquick/qml/Page.qml:244
-#, fuzzy, kde-format
-#| msgid "All Categories"
+#: qtquick/qml/Page.qml:251
+#, kde-format
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
-msgstr "Visas kategorijas"
+msgstr "Rādīt visus ierakstus"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
-msgstr ""
+msgstr "Rādīt tikai instalētos ierakstus"
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
 "available are shown"
 msgid "Show Only Updateable Entries"
-msgstr ""
+msgstr "Rādīt tikai atjaunināmos ierakstus"
 
-#: qtquick/qml/Page.qml:273
-#, fuzzy, kde-format
-#| msgctxt "@action"
-#| msgid "Open Recent"
+#: qtquick/qml/Page.qml:286
+#, kde-format
 msgid "Recent"
-msgstr "Atvērt nesenos"
+msgstr "Nesenie"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
-msgstr ""
+msgstr "Alfabēta kārtībā"
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "Vērtējums"
 
-#: qtquick/qml/Page.qml:279
-#, fuzzy, kde-format
-#| msgid "Download"
+#: qtquick/qml/Page.qml:292
+#, kde-format
 msgid "Downloads"
-msgstr "Lejupielādēt"
+msgstr "Lejupielādes"
 
-#: qtquick/qml/Page.qml:299
-#, fuzzy, kde-format
-#| msgid "Show directories first"
+#: qtquick/qml/Page.qml:312
+#, kde-format
 msgctxt ""
 "List option which will set the sort order to based on when items were most "
 "recently updated"
 msgid "Show Most Recent First"
-msgstr "Rādīt mapes vispirms"
+msgstr "Jaunākos rādīt vispirms"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
 "name"
 msgid "Sort Alphabetically By Name"
-msgstr ""
+msgstr "Kārtot alfabētiski pēc nosaukuma"
 
-#: qtquick/qml/Page.qml:317
-#, fuzzy, kde-format
-#| msgid "Show directories first"
+#: qtquick/qml/Page.qml:334
+#, kde-format
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
-msgstr "Rādīt mapes vispirms"
+msgstr "Augstāk norādītos rādīt pirmos"
 
-#: qtquick/qml/Page.qml:326
-#, fuzzy, kde-format
-#| msgid "Most downloads"
+#: qtquick/qml/Page.qml:345
+#, kde-format
 msgctxt ""
 "List option which will set the sort order to based on number of downloads"
 msgid "Show Most Downloaded First"
-msgstr "Visvairāk lejupielādētie"
+msgstr "Visvairāk lejupielādētos rādīt pirmos"
 
-#: qtquick/qml/Page.qml:337
-#, fuzzy, kde-format
-#| msgid "New Upload"
+#: qtquick/qml/Page.qml:358
+#, kde-format
 msgid "Upload…"
-msgstr "Jauna augšupielāde"
+msgstr "Augšupielādēt..."
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
-msgstr ""
+msgstr "Uzziniet, kā sarakstam pievienot savu saturu"
 
-#: qtquick/qml/Page.qml:348
-#, fuzzy, kde-format
-#| msgid "&Go To..."
+#: qtquick/qml/Page.qml:369
+#, kde-format
 msgid "Go to…"
-msgstr "&Iet uz..."
+msgstr "Iet uz..."
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
-#, fuzzy, kde-format
-#| msgid "Search:"
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
+#, kde-format
 msgid "Search…"
-msgstr "Meklēt:"
+msgstr "Meklēt..."
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "Kategorija:"
 
-#: qtquick/qml/Page.qml:438
-#, fuzzy, kde-format
-#| msgid "Continue operation"
+#: qtquick/qml/Page.qml:459
+#, kde-format
 msgid "Contribute your own…"
-msgstr "Turpināt darbību"
+msgstr "Iesniegt savu..."
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
-#, fuzzy, kde-format
-#| msgctxt "@note/rich"
-#| msgid "<i>Note</i>: %1"
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
+#, kde-format
 msgctxt ""
 "Placeholder title for when a comment has no subject, but does have a rating"
 msgid "<i>(no title)</i>"
-msgstr "<i>Piezīme</i>: %1"
+msgstr "<i>(bez nosaukuma)</i>"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
 "content entry the comment is attached to"
 msgid "%1 <i>(author)</i>"
-msgstr ""
+msgstr "%1 <i>(autors)</i>"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
-msgstr ""
+msgstr "„%1“ komentāri un atsauksmes"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
-#, fuzzy, kde-format
-#| msgid "All Categories"
+#: qtquick/qml/private/EntryCommentsPage.qml:30
+#, kde-format
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
-msgstr "Visas kategorijas"
+msgstr "Rādīt visus komentārus"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
 "should be shown"
 msgid "Show Reviews Only"
-msgstr ""
+msgstr "Rādīt tikai atsauksmes"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
 "their children should be shown"
 msgid "Show Reviews and Replies"
-msgstr ""
+msgstr "Rādīt atsauksmes un atbildes"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
-#, fuzzy, kde-format
-#| msgid "1 download"
-#| msgid_plural "%1 downloads"
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
+#, kde-format
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
-msgstr "%1 lejupielāde"
+msgstr "%1 lejupielādes"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
-#, fuzzy, kde-format
-#| msgctxt "Show the author of this item in a list"
-#| msgid "By <i>%1</i>"
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
+#, kde-format
 msgctxt ""
 "Subheading for the tile view, located immediately underneath the name of the "
 "item"
 msgid "By <i>%1</i>"
-msgstr "Veidoja <i>%1</i>"
+msgstr "Autors: <i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
 "uninstalled"
 msgid "Working…"
-msgstr ""
+msgstr "Darbojas..."
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
-#, fuzzy, kde-format
-#| msgid "Updating"
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is in the process of being "
 "updated"
 msgid "Updating…"
-msgstr "Atjaunina"
+msgstr "Atjaunina..."
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -770,101 +774,104 @@ msgid ""
 "product=frameworks-knewstuff\">Please report this to the KDE Community in a "
 "bug report</a>."
 msgstr ""
+"Nederīgs vai nezināms stāvoklis. <a href=\"https://bugs.kde.org/enter_bug."
+"cgi?product=frameworks-knewstuff\">Ziiņojiet par to KDE kopienai, iesniedzot "
+"kļūdas ziņojumu</a>."
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
-#, fuzzy, kde-format
-#| msgid "Installing"
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
+#, kde-format
 msgctxt "Label for the busy indicator showing an item is installing"
 msgid "Installing…"
-msgstr "Instalē"
+msgstr "Instalē..."
 
 #: qtquick/qml/private/ErrorDisplayer.qml:15
 #, kde-format
 msgctxt "Title for a dialog box which shows error messages"
 msgid "An Error Occurred"
-msgstr ""
+msgstr "Ir notikusi kļūda"
 
 #: qtquick/qml/private/ErrorDisplayer.qml:81
-#, fuzzy, kde-format
-#| msgid "Please put in a name."
+#, kde-format
 msgid "Please try again later."
-msgstr "Lūdzu, ievadiet nosaukumu."
+msgstr "Mēģiniet vēlāk."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
-#, fuzzy, kde-format
-#| msgctxt "No border line"
-#| msgid "None"
+#: qtquick/qml/private/GridTileDelegate.qml:120
+#, kde-format
 msgid "None"
 msgstr "Nav"
 
-#: qtquick/qml/private/Rating.qml:80
-#, fuzzy, kde-format
-#| msgid "(%1/s)"
+#: qtquick/qml/private/Rating.qml:81
+#, kde-format
 msgctxt ""
 "A text representation of the rating, shown as a fraction of the max value"
 msgid "(%1/%2)"
-msgstr "(%1/s)"
+msgstr "(%1/%2)"
 
-#: qtquick/qml/UploadPage.qml:51
-#, fuzzy, kde-format
-#| msgid "Download New Stuff..."
+#: qtquick/qml/UploadPage.qml:50
+#, kde-format
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
-msgstr "Lejupielādēt ko jaunu..."
+msgstr "Augšupielādēt jaunas lietas: %1"
 
-#: qtquick/qml/UploadPage.qml:110
-#, fuzzy, kde-format
-#| msgid "Billing information:"
+#: qtquick/qml/UploadPage.qml:111
+#, kde-format
 msgctxt ""
 "A text shown beside a busy indicator suggesting that data is being fetched"
 msgid "Updating information…"
-msgstr "Apmaksas informācija:"
+msgstr "Atjaunina informāciju..."
 
-#: qtquick/qml/UploadPage.qml:125
-#, fuzzy, kde-format
-#| msgid "&Store"
+#: qtquick/qml/UploadPage.qml:126
+#, kde-format
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
-msgstr "&Saglabāt"
+msgstr "KDE veikals"
 
-#: qtquick/qml/UploadPage.qml:131
-#, fuzzy, kde-format
-#| msgid "Provider:"
+#: qtquick/qml/UploadPage.qml:132
+#, kde-format
 msgctxt "An unnamed provider"
 msgid "Your Provider"
-msgstr "Publicētājs:"
+msgstr "Jūsu pakalpojuma sniedzējs"
 
-#: qtquick/qml/UploadPage.qml:140
-#, fuzzy, kde-format
-#| msgctxt "@label:button"
-#| msgid "&Open with %1"
+#: qtquick/qml/UploadPage.qml:141
+#, kde-format
 msgctxt ""
 "Text for an action which causes the specified website to be opened using the "
 "user's system default browser"
 msgid "Open Website: %1"
-msgstr "&Atvērt ar %1"
+msgstr "Atvērt mājaslapu: %1"
 
-#: qtquick/qml/UploadPage.qml:146
-#, fuzzy, kde-format
-#| msgid "&Send Email"
+#: qtquick/qml/UploadPage.qml:149
+#, kde-format
 msgctxt ""
 "Text for an action which will attempt to send an email using the user's "
 "system default email client"
 msgid "Send Email To: %1"
-msgstr "&Sūtīt e-pastu"
+msgstr "Sūtīt e-pastu: %1"
 
-#: qtquick/qml/UploadPage.qml:154
-#, kde-format
+#: qtquick/qml/UploadPage.qml:159
+#, fuzzy, kde-format
+#| msgctxt "A description of how to upload content to a generic provider"
+#| msgid ""
+#| "To upload new entries, or to add content to an existing entry on the KDE "
+#| "Store, please open the website and log in. Once you have done this, you "
+#| "will be able to find the My Products entry in the menu which pops up when "
+#| "you click your user icon. Click on this entry to go to the product "
+#| "management system, where you can work on your products ."
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
 "To upload new entries, or to add content to an existing entry on the KDE "
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
+"Lai augšupielādētu jaunus vienumus vai pievienotu saturu eksistējošiem "
+"vienumiem KDE veikalā, atveriet tīmekļa vietni un ierakstieties. Pēc tam "
+"izvēlnē, kas atvērsies pēc nospiešanas uz lietotāja ikonas, varēsiet atrast "
+"„Mani produkti“ („My products“). Spiediet uz tā, lai nokļūtu produktu "
+"pārvaldības sistēmā, kurā varēsiet rediģēt savus produktus."
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -875,19 +882,25 @@ msgid ""
 "might be required to contact the managers of the site directly to get new "
 "content added."
 msgstr ""
+"Lai augšupielādētu jaunus vienumus vai pievienotu saturu jau "
+"eksistējošajiem, atveriet pakalpojuma sniedzēju tīmekļa vietni un sekot "
+"instrukcijām tajā. Iespējams, jums būs jāizveido lietotājs un jāierakstās "
+"produkta vadības sistēmā, bet pēc tam jāseko pievienošanas norādēm tajā. "
+"Tāpat var būt nepieciešamas sazināties ar vietnes vadītājiem tiešā veidā, "
+"lai viņi pievienotu jaunu saturu."
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "Ielādē datus"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "Instalē"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -896,93 +909,80 @@ msgid ""
 "You are not authorized to Get Hot New Stuff. If you think this is in error, "
 "please contact the person in charge of your permissions."
 msgstr ""
+"Jums nav tiesību iegūt jaunas lietas. Ja domājat, ka tā ir kļūda, "
+"sazinieties ar personu, kas atbild par sistēmas atļaujām."
 
-#: qtquick/searchpresetmodel.cpp:43
-#, fuzzy, kde-format
-#| msgctxt "@action"
-#| msgid "Back"
+#: qtquick/searchpresetmodel.cpp:44
+#, kde-format
 msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "Atpakaļ"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
-msgstr ""
+msgstr "Populāri"
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Featured"
-msgstr ""
+msgstr "Izcelti"
 
-#: qtquick/searchpresetmodel.cpp:49
-#, fuzzy, kde-format
-#| msgctxt "@action:button Restart find & replace"
-#| msgid "Restart"
+#: qtquick/searchpresetmodel.cpp:50
+#, kde-format
 msgctxt "Knewstuff5"
 msgid "Restart"
-msgstr "No sākuma"
+msgstr "Pārstartēt"
 
-#: qtquick/searchpresetmodel.cpp:51
-#, fuzzy, kde-format
-#| msgctxt "@action"
-#| msgid "New"
+#: qtquick/searchpresetmodel.cpp:52
+#, kde-format
 msgctxt "Knewstuff5"
 msgid "New"
-msgstr "Jauns"
+msgstr "Jauni"
 
-#: qtquick/searchpresetmodel.cpp:53
-#, fuzzy, kde-format
-#| msgctxt "keyboard-key-name"
-#| msgid "Home"
+#: qtquick/searchpresetmodel.cpp:54
+#, kde-format
 msgctxt "Knewstuff5"
 msgid "Home"
-msgstr "Home"
+msgstr "Mājas"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
-msgstr ""
+msgstr "Plaukts"
 
-#: qtquick/searchpresetmodel.cpp:57
-#, fuzzy, kde-format
-#| msgctxt "keyboard-key-name"
-#| msgid "Up"
+#: qtquick/searchpresetmodel.cpp:58
+#, kde-format
 msgctxt "Knewstuff5"
 msgid "Up"
-msgstr "Uz augšu"
+msgstr "Augšup"
 
-#: qtquick/searchpresetmodel.cpp:59
-#, fuzzy, kde-format
-#| msgctxt "dictionary variant"
-#| msgid "extended"
+#: qtquick/searchpresetmodel.cpp:60
+#, kde-format
 msgctxt "Knewstuff5"
 msgid "Recommended"
-msgstr "paplašinātais"
+msgstr "Ieteicams"
 
-#: qtquick/searchpresetmodel.cpp:61
-#, fuzzy, kde-format
-#| msgctxt "@action"
-#| msgid "Subscript"
+#: qtquick/searchpresetmodel.cpp:62
+#, kde-format
 msgctxt "Knewstuff5"
 msgid "Subscriptions"
-msgstr "Apakšraksts"
+msgstr "Abonements"
 
-#: qtquick/searchpresetmodel.cpp:63
-#, fuzzy, kde-format
-#| msgid "All Categories"
+#: qtquick/searchpresetmodel.cpp:64
+#, kde-format
 msgctxt "Knewstuff5"
 msgid "All Entries"
-msgstr "Visas kategorijas"
+msgstr "Visi ieraksti"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
-msgstr ""
+msgstr "Meklēšanas priekšiestatījums: %1"
 
 #: tools/knewstuff-dialog/main.cpp:29
 #, kde-format
@@ -991,6 +991,9 @@ msgid ""
 "with a dialog which lets you switch between all the config files installed "
 "into the systemwide knsrc file location"
 msgstr ""
+"KNSRC datne, kuru vēlaties parādīt, ja neviena nav parādīta, atvērsies logs, "
+"kurā varēsiet pārslēgties starp visām instalētajām konfigurācijas datnēm "
+"sistēmas KNSRC datnes atrašanās vietā"
 
 #: tools/knewstuff-dialog/main.cpp:33
 #, kde-format
@@ -1007,11 +1010,30 @@ msgid ""
 "file.\n"
 " An example of such a url is kns://sddmtheme.knsrc/api.kde-look.org/2059021"
 msgstr ""
+"KNS URL, no kuras parādīt informāciju. KNS URL formāts ir  „kns://knsrcdatne/"
+"sniedzējaid/ierakstaid“\n"
+"„knsrcdatne“\n"
+"ir KNSRC datnes nosaukums, ko var tieši nodot caur šī rīka „knsrcfile“ "
+"argumentu\n"
+"„sniedzējaid“\n"
+"ir pakalpojumu sniedzēja saimniekdatora nosaukums, uz kura ir ieraksts\n"
+"„ierakstaid“\n"
+"ir unikālais ieraksta, kas atrodas „knsrc“ datnes norādītajā pakalpojumu "
+"sniedzēja ierakstā, identifikators.\n"
+" Šādas saites piemērs ir kns://sddmtheme.knsrc/api.kde-look.org/2059021"
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
-#, kde-format
-msgid "Download New Stuff..."
-msgstr "Lejupielādēt ko jaunu..."
+#, fuzzy, kde-format
+#| msgctxt ""
+#| "A placeholder title used in the dialog when there is no better title "
+#| "available"
+#| msgid "Download New Stuff"
+msgctxt "@action"
+msgid "Download New Stuff…"
+msgstr "Lejupielādēt ko jaunu"
+
+#~ msgid "Download New Stuff..."
+#~ msgstr "Lejupielādēt ko jaunu..."
 
 #~ msgid "Initializing"
 #~ msgstr "Inicializē"
diff -pruN 6.0.0-3/po/mai/knewstuff6.po 6.3.0-1/po/mai/knewstuff6.po
--- 6.0.0-3/po/mai/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/mai/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -9,7 +9,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2010-09-24 15:44+0530\n"
 "Last-Translator: Rajesh Ranjan <rranjan@redhat.com>\n"
 "Language-Team: Hindi <fedora-trans-hi@redhat.com>\n"
@@ -62,7 +62,7 @@ msgstr "अहाँक वोट सफ
 msgid "You are now a fan."
 msgstr "अहाँ एकटा प्रशसंक छी"
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -131,7 +131,7 @@ msgstr "बिन्यास फाइ
 msgid "Use"
 msgstr ""
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -139,17 +139,17 @@ msgid ""
 "This is a critical error and should be reported to the application author"
 msgstr ""
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr ""
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr ""
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr ""
@@ -295,7 +295,7 @@ msgid ""
 "the update"
 msgstr ""
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, fuzzy, kde-format
 #| msgid "Failed to load file '%1'"
 msgid ""
@@ -303,7 +303,7 @@ msgid ""
 "%2"
 msgstr "फाइल '%1' लोड करब मे असफल"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt ""
@@ -311,7 +311,7 @@ msgctxt ""
 msgid "All Categories"
 msgstr "सभ श्रेणीसभ"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, fuzzy, kde-format
 #| msgid "Unknown error"
 msgctxt ""
@@ -337,14 +337,14 @@ msgstr ""
 msgid "Download New %1…"
 msgstr "टटका सामग्री डाउनलोड करू..."
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, fuzzy, kde-format
 #| msgid "Download New Stuff..."
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "टटका सामग्री डाउनलोड करू..."
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, fuzzy, kde-format
 #| msgid "Download New Stuff..."
 msgctxt ""
@@ -353,12 +353,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "टटका सामग्री डाउनलोड करू..."
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -367,12 +367,12 @@ msgid ""
 "this through the naming of the items."
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "संस्थापित करू"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt ""
@@ -380,7 +380,7 @@ msgctxt ""
 msgid "Installing %1 from %2"
 msgstr "संस्थापित कए रहल अछि"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -388,10 +388,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -400,10 +400,10 @@ msgctxt ""
 msgid "Install"
 msgstr "संस्थापित करू"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -411,24 +411,24 @@ msgctxt ""
 msgid "Install…"
 msgstr "संस्थापित करू"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, fuzzy, kde-format
 #| msgid "Update"
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "अद्यतन"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, fuzzy, kde-format
 #| msgid "Uninstall"
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "विसंस्थापित करू"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -436,14 +436,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -454,12 +454,12 @@ msgid ""
 "to the KDE Community in a bug report</a>."
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, fuzzy, kde-format
 #| msgid "View Comments"
 msgctxt ""
@@ -468,20 +468,20 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "टिप्पणीसभ देखू"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, fuzzy, kde-format
 #| msgid "Rating: "
 msgid "Rating:"
 msgstr "रेटिंग:"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, fuzzy, kde-format
 #| msgctxt "A link to the description of this Get Hot New Stuff item"
 #| msgid "Homepage"
 msgid "Homepage:"
 msgstr "मुख्य पृष्ठ"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -490,12 +490,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -503,79 +503,87 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr ""
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, fuzzy, kde-format
 #| msgid "File"
 msgid "Tiles"
 msgstr "फाइल"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "प्रतीक"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, fuzzy, kde-format
 #| msgid "Preview URL:"
 msgid "Preview"
 msgstr "पूर्वावलोकन यूआरएल:"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, fuzzy, kde-format
 #| msgid "Details view mode"
 msgid "Detailed Tiles View Mode"
 msgstr "विभाजित दृश्य मोड"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, fuzzy, kde-format
 #| msgid "Icons view mode"
 msgid "Icons Only View Mode"
 msgstr "चिह्न दृश्य केवल"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, fuzzy, kde-format
 #| msgid "Details view mode"
 msgid "Large Preview View Mode"
 msgstr "विभाजित दृश्य मोड"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr ""
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "संस्थापित"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, fuzzy, kde-format
 #| msgid "Update"
 msgid "Updateable"
 msgstr "अद्यतन"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "सभ श्रेणीसभ"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -583,30 +591,30 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Open Recent"
 msgid "Recent"
 msgstr "हाल क' खोलू"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr ""
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "दर"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, fuzzy, kde-format
 #| msgid "Download"
 msgid "Downloads"
 msgstr "डाउनलोड"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt ""
@@ -615,7 +623,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "पहिने डिरेक्ट्री देखाबू"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -623,14 +631,14 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr ""
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "पहिने डिरेक्ट्री देखाबू"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, fuzzy, kde-format
 #| msgid "Most downloads"
 msgctxt ""
@@ -638,41 +646,41 @@ msgctxt ""
 msgid "Show Most Downloaded First"
 msgstr "अधिकतम डाउनलोड्स"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, fuzzy, kde-format
 #| msgid "New Upload"
 msgid "Upload…"
 msgstr "नव अपलोड"
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr ""
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, fuzzy, kde-format
 #| msgid "&Go To..."
 msgid "Go to…"
 msgstr "एतए जाउ... (&G)"
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, fuzzy, kde-format
 #| msgid "Search:"
 msgid "Search…"
 msgstr "खोजू:"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "श्रेणी"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, fuzzy, kde-format
 #| msgid "Continue operation"
 msgid "Contribute your own…"
 msgstr "आपरेशन जारी राखू"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, fuzzy, kde-format
 #| msgctxt "@note/rich"
 #| msgid "<i>Note</i>: %1"
@@ -681,7 +689,7 @@ msgctxt ""
 msgid "<i>(no title)</i>"
 msgstr "<i>टीप</i>: %1"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -689,20 +697,20 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "सभ श्रेणीसभ"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -710,7 +718,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -718,8 +726,8 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, fuzzy, kde-format
 #| msgid "1 download"
 #| msgid_plural "%1 downloads"
@@ -727,8 +735,8 @@ msgctxt "The number of times the item ha
 msgid "%1 downloads"
 msgstr "1 डाउनलोड"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, fuzzy, kde-format
 #| msgctxt "Show the author of this item in a list"
 #| msgid "By <i>%1</i>"
@@ -738,7 +746,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "By <i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -746,7 +754,7 @@ msgctxt ""
 msgid "Working…"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, fuzzy, kde-format
 #| msgid "Updating"
 msgctxt ""
@@ -755,7 +763,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "अद्यतन कए रहल अछि"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -766,7 +774,7 @@ msgid ""
 "bug report</a>."
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt "Label for the busy indicator showing an item is installing"
@@ -785,14 +793,14 @@ msgstr ""
 msgid "Please try again later."
 msgstr "कृप्या नाम भरू"
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, fuzzy, kde-format
 #| msgctxt "No border line"
 #| msgid "None"
 msgid "None"
 msgstr "किछु नहि"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, fuzzy, kde-format
 #| msgid "(%1/s)"
 msgctxt ""
@@ -800,14 +808,14 @@ msgctxt ""
 msgid "(%1/%2)"
 msgstr "(%1/s)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, fuzzy, kde-format
 #| msgid "Download New Stuff..."
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "टटका सामग्री डाउनलोड करू..."
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, fuzzy, kde-format
 #| msgid "Billing information:"
 msgctxt ""
@@ -815,21 +823,21 @@ msgctxt ""
 msgid "Updating information…"
 msgstr "बिलिंगक जानकारी"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, fuzzy, kde-format
 #| msgid "&Store"
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "जमा करू (&St)"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, fuzzy, kde-format
 #| msgid "Provider:"
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "देनिहार"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, fuzzy, kde-format
 #| msgctxt "@label:button"
 #| msgid "&Open with %1"
@@ -839,7 +847,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "%1 केर सँग खोलू (&O)"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, fuzzy, kde-format
 #| msgid "&Send Email"
 msgctxt ""
@@ -848,7 +856,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "इमेल भेजू (&S)"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -856,10 +864,10 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -871,19 +879,19 @@ msgid ""
 "content added."
 msgstr ""
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, fuzzy, kde-format
 #| msgid "Loading Applet"
 msgid "Loading data"
 msgstr "डाटा लोड करैछै"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "संस्थापित कए रहल अछि"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -893,7 +901,7 @@ msgid ""
 "please contact the person in charge of your permissions."
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Back"
@@ -901,19 +909,19 @@ msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "पाछाँ"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, fuzzy, kde-format
 #| msgctxt "@action:button Restart find & replace"
 #| msgid "Restart"
@@ -921,7 +929,7 @@ msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "पुनः प्रारंभ करू"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "New"
@@ -929,7 +937,7 @@ msgctxt "Knewstuff5"
 msgid "New"
 msgstr "नवीन"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Home"
@@ -937,13 +945,13 @@ msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "घर"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Up"
@@ -951,7 +959,7 @@ msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "उप्पर"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, fuzzy, kde-format
 #| msgctxt "dictionary variant"
 #| msgid "extended"
@@ -959,7 +967,7 @@ msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "विस्तारित"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Subscript"
@@ -967,14 +975,14 @@ msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "उपस्क्रिप्ट"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "सभ श्रेणीसभ"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -1005,10 +1013,15 @@ msgid ""
 msgstr ""
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
-#, kde-format
-msgid "Download New Stuff..."
+#, fuzzy, kde-format
+#| msgid "Download New Stuff..."
+msgctxt "@action"
+msgid "Download New Stuff…"
 msgstr "टटका सामग्री डाउनलोड करू..."
 
+#~ msgid "Download New Stuff..."
+#~ msgstr "टटका सामग्री डाउनलोड करू..."
+
 #~ msgid "Initializing"
 #~ msgstr "आरँभीकरण"
 
diff -pruN 6.0.0-3/po/mk/knewstuff6.po 6.3.0-1/po/mk/knewstuff6.po
--- 6.0.0-3/po/mk/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/mk/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -17,7 +17,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2010-01-27 10:39+0100\n"
 "Last-Translator: Bozidar Proevski <bobibobi@freemail.com.mk>\n"
 "Language-Team: Macedonian <mkde-l10n@lists.sourceforge.net>\n"
@@ -74,7 +74,7 @@ msgstr "Вашето гласање бе
 msgid "You are now a fan."
 msgstr ""
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -141,7 +141,7 @@ msgstr "Датотеки со конфи
 msgid "Use"
 msgstr ""
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -149,19 +149,19 @@ msgid ""
 "This is a critical error and should be reported to the application author"
 msgstr ""
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr "Вчитувањето на доставувачи од датотеката: %1 не успеа"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr ""
 "Не можам да преземам листа со доставувачи на последни новости од датотеката: "
 "%1"
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr ""
@@ -307,7 +307,7 @@ msgid ""
 "the update"
 msgstr ""
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, fuzzy, kde-format
 #| msgid "Failed to load file '%1'"
 msgid ""
@@ -315,7 +315,7 @@ msgid ""
 "%2"
 msgstr "Не успеав да ја вчитам датотеката „%1“"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt ""
@@ -323,7 +323,7 @@ msgctxt ""
 msgid "All Categories"
 msgstr "Сите категории"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, fuzzy, kde-format
 #| msgid "Unknown error"
 msgctxt ""
@@ -349,14 +349,14 @@ msgstr ""
 msgid "Download New %1…"
 msgstr "Земете ги последните новости..."
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, fuzzy, kde-format
 #| msgid "Download New Stuff..."
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "Земете ги последните новости..."
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, fuzzy, kde-format
 #| msgid "Download New Stuff..."
 msgctxt ""
@@ -365,12 +365,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "Земете ги последните новости..."
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -379,12 +379,12 @@ msgid ""
 "this through the naming of the items."
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "Инсталирај"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt ""
@@ -392,7 +392,7 @@ msgctxt ""
 msgid "Installing %1 from %2"
 msgstr "Инсталирам"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -400,10 +400,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -412,10 +412,10 @@ msgctxt ""
 msgid "Install"
 msgstr "Инсталирај"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -423,24 +423,24 @@ msgctxt ""
 msgid "Install…"
 msgstr "Инсталирај"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, fuzzy, kde-format
 #| msgid "Update"
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "Ажурирај"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, fuzzy, kde-format
 #| msgid "Uninstall"
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "Одинсталирај"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -448,14 +448,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -466,12 +466,12 @@ msgid ""
 "to the KDE Community in a bug report</a>."
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, fuzzy, kde-format
 #| msgid "View Comments"
 msgctxt ""
@@ -480,19 +480,19 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "Преглед на коментари"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, fuzzy, kde-format
 #| msgid "Rating: "
 msgid "Rating:"
 msgstr "Рангирање: "
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, fuzzy, kde-format
 #| msgid "Homepage"
 msgid "Homepage:"
 msgstr "Домашна страница"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -501,12 +501,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -514,78 +514,86 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr ""
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, fuzzy, kde-format
 #| msgid "File"
 msgid "Tiles"
 msgstr "Датотека"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "Икони"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, fuzzy, kde-format
 #| msgid "Previews"
 msgid "Preview"
 msgstr "Прегледи"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, kde-format
 msgid "Detailed Tiles View Mode"
 msgstr ""
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, fuzzy, kde-format
 #| msgid "Icons Only"
 msgid "Icons Only View Mode"
 msgstr "Само икони"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, fuzzy, kde-format
 #| msgid "Preview Image:"
 msgid "Large Preview View Mode"
 msgstr "Преглед на слика:"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr ""
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "Инсталирано"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, fuzzy, kde-format
 #| msgid "Update"
 msgid "Updateable"
 msgstr "Ажурирај"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "Сите категории"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -593,30 +601,30 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Open Recent"
 msgid "Recent"
 msgstr "Отвори неодамнешни"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr ""
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "Рангирање"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, fuzzy, kde-format
 #| msgid "Download"
 msgid "Downloads"
 msgstr "Симни"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt ""
@@ -625,7 +633,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "Прикажи прво папки"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -633,14 +641,14 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr ""
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "Прикажи прво папки"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, fuzzy, kde-format
 #| msgid "Most Downloads"
 msgctxt ""
@@ -648,41 +656,41 @@ msgctxt ""
 msgid "Show Most Downloaded First"
 msgstr "Најмногу симнувања"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, fuzzy, kde-format
 #| msgid "Upload..."
 msgid "Upload…"
 msgstr "Качи..."
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr ""
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, fuzzy, kde-format
 #| msgid "&Go To..."
 msgid "Go to…"
 msgstr "&Оди на..."
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, fuzzy, kde-format
 #| msgid "Search:"
 msgid "Search…"
 msgstr "Барање:"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "Категорија:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, fuzzy, kde-format
 #| msgid "Continue operation"
 msgid "Contribute your own…"
 msgstr "Продолжи со операцијата"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, fuzzy, kde-format
 #| msgctxt "@note/rich"
 #| msgid "<i>Note</i>: %1"
@@ -691,7 +699,7 @@ msgctxt ""
 msgid "<i>(no title)</i>"
 msgstr "<i>Забелешка</i>: %1"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -699,20 +707,20 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "Сите категории"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -720,7 +728,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -728,16 +736,16 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, fuzzy, kde-format
 #| msgid "Download"
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
 msgstr "Симни"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, fuzzy, kde-format
 #| msgctxt "Show the author of this item in a list"
 #| msgid "By <i>%1</i>"
@@ -747,7 +755,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "Од <i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -755,7 +763,7 @@ msgctxt ""
 msgid "Working…"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, fuzzy, kde-format
 #| msgid "Updating"
 msgctxt ""
@@ -764,7 +772,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "Ажурирам"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -775,7 +783,7 @@ msgid ""
 "bug report</a>."
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt "Label for the busy indicator showing an item is installing"
@@ -794,14 +802,14 @@ msgstr ""
 msgid "Please try again later."
 msgstr "Ставете име."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, fuzzy, kde-format
 #| msgctxt "No border line"
 #| msgid "None"
 msgid "None"
 msgstr "Нема"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, fuzzy, kde-format
 #| msgid "(%1/s)"
 msgctxt ""
@@ -809,14 +817,14 @@ msgctxt ""
 msgid "(%1/%2)"
 msgstr "(%1/s)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, fuzzy, kde-format
 #| msgid "Download New Stuff..."
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "Земете ги последните новости..."
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, fuzzy, kde-format
 #| msgid "Billing information:"
 msgctxt ""
@@ -824,21 +832,21 @@ msgctxt ""
 msgid "Updating information…"
 msgstr "Информација за наплата:"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, fuzzy, kde-format
 #| msgid "&Store"
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "&Зачувај"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, fuzzy, kde-format
 #| msgid "Provider:"
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "Доставувач:"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, fuzzy, kde-format
 #| msgctxt "@label:button"
 #| msgid "&Open with %1"
@@ -848,7 +856,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "&Отвори со „%1“"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, fuzzy, kde-format
 #| msgid "&Send Email"
 msgctxt ""
@@ -857,7 +865,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "&Испрати е-пошта"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -865,10 +873,10 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -880,19 +888,19 @@ msgid ""
 "content added."
 msgstr ""
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, fuzzy, kde-format
 #| msgid "Loading Applet"
 msgid "Loading data"
 msgstr "Вчитувам аплет"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "Инсталирам"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -902,7 +910,7 @@ msgid ""
 "please contact the person in charge of your permissions."
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Back"
@@ -910,19 +918,19 @@ msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "Назад"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, fuzzy, kde-format
 #| msgctxt "@action:button Restart find & replace"
 #| msgid "Restart"
@@ -930,7 +938,7 @@ msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "Рестартирај"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "New"
@@ -938,7 +946,7 @@ msgctxt "Knewstuff5"
 msgid "New"
 msgstr "Ново"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Home"
@@ -946,13 +954,13 @@ msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Дома"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Up"
@@ -960,7 +968,7 @@ msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "Горе"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, fuzzy, kde-format
 #| msgctxt "dictionary variant"
 #| msgid "extended"
@@ -968,7 +976,7 @@ msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "проширен"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Subscript"
@@ -976,14 +984,14 @@ msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "Долен индекс"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "Сите категории"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -1014,10 +1022,15 @@ msgid ""
 msgstr ""
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
-#, kde-format
-msgid "Download New Stuff..."
+#, fuzzy, kde-format
+#| msgid "Download New Stuff..."
+msgctxt "@action"
+msgid "Download New Stuff…"
 msgstr "Земете ги последните новости..."
 
+#~ msgid "Download New Stuff..."
+#~ msgstr "Земете ги последните новости..."
+
 #, fuzzy
 #~| msgid "Installing"
 #~ msgid "Initializing"
diff -pruN 6.0.0-3/po/ml/knewstuff6.po 6.3.0-1/po/ml/knewstuff6.po
--- 6.0.0-3/po/ml/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/ml/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -11,7 +11,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2010-12-29 15:32+0530\n"
 "Last-Translator: \n"
 "Language-Team: SMC <smc.org.in>\n"
@@ -54,7 +54,7 @@ msgstr "നിങ്ങളുടെ വ
 msgid "You are now a fan."
 msgstr "നിങ്ങളിപ്പോള്‍ ഒരു ആരാധകനാണു്."
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -120,7 +120,7 @@ msgstr "ക്രമീകരണ ഫയ
 msgid "Use"
 msgstr ""
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -128,17 +128,17 @@ msgid ""
 "This is a critical error and should be reported to the application author"
 msgstr ""
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr ""
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr ""
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr ""
@@ -282,7 +282,7 @@ msgid ""
 "the update"
 msgstr ""
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, fuzzy, kde-format
 #| msgid "Failed to load file '%1'"
 msgid ""
@@ -290,7 +290,7 @@ msgid ""
 "%2"
 msgstr "'%1' ഫയല്‍ ലഭ്യമാക്കുവാനായില്ല"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt ""
@@ -298,7 +298,7 @@ msgctxt ""
 msgid "All Categories"
 msgstr "എല്ലാ വിഭാഗങ്ങളും"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, fuzzy, kde-format
 #| msgid "Unknown error"
 msgctxt ""
@@ -324,14 +324,14 @@ msgstr ""
 msgid "Download New %1…"
 msgstr "പുതിയവ ഇറക്കുക..."
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, fuzzy, kde-format
 #| msgid "Download New Stuff..."
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "പുതിയവ ഇറക്കുക..."
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, fuzzy, kde-format
 #| msgid "Download New Stuff..."
 msgctxt ""
@@ -340,12 +340,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "പുതിയവ ഇറക്കുക..."
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -354,12 +354,12 @@ msgid ""
 "this through the naming of the items."
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "ഇന്‍സ്റ്റാള്‍ ചെയ്യുക"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt ""
@@ -367,7 +367,7 @@ msgctxt ""
 msgid "Installing %1 from %2"
 msgstr "ഇന്‍സ്റ്റാള്‍ ചെയ്തുകൊണ്ടിരിയ്ക്കുന്നു"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -375,10 +375,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -387,10 +387,10 @@ msgctxt ""
 msgid "Install"
 msgstr "ഇന്‍സ്റ്റാള്‍ ചെയ്യുക"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -398,22 +398,22 @@ msgctxt ""
 msgid "Install…"
 msgstr "ഇന്‍സ്റ്റാള്‍ ചെയ്യുക"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, fuzzy, kde-format
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "പുതുക്കല്‍"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, fuzzy, kde-format
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "അണ്‍ഇന്‍സ്റ്റോള്‍ ചെയ്യുക"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -421,14 +421,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -439,12 +439,12 @@ msgid ""
 "to the KDE Community in a bug report</a>."
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, fuzzy, kde-format
 #| msgid "View Comments"
 msgctxt ""
@@ -453,19 +453,19 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "അഭിപ്രായങ്ങള്‍ കാണുക"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, fuzzy, kde-format
 #| msgid "Rating: "
 msgid "Rating:"
 msgstr "വിലയിരുത്തല്‍: "
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, fuzzy, kde-format
 #| msgid "Homepage"
 msgid "Homepage:"
 msgstr "പൂമുഖം"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -474,12 +474,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -487,79 +487,87 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr ""
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, fuzzy, kde-format
 #| msgctxt "@option:check Do filter on type - show only files"
 #| msgid "Files"
 msgid "Tiles"
 msgstr "ഫയലുകള്‍"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, fuzzy, kde-format
 msgid "Icons"
 msgstr "ചിഹ്നങ്ങള്‍"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, fuzzy, kde-format
 #| msgid "Preview URL:"
 msgid "Preview"
 msgstr "മുമ്പത്തെ യുആര്‍എല്‍:"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, kde-format
 msgid "Detailed Tiles View Mode"
 msgstr ""
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, fuzzy, kde-format
 #| msgid "Icons Only"
 msgid "Icons Only View Mode"
 msgstr "ചിഹ്നങ്ങള്‍ മാത്രം"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, fuzzy, kde-format
 #| msgid "Preview Images"
 msgid "Large Preview View Mode"
 msgstr "ചിത്രങ്ങളുടെ തിരനോട്ടം കാണിയ്ക്കുക"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr ""
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "ഇന്‍സ്റ്റാള്‍ ചെയ്തതു്"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, fuzzy, kde-format
 #| msgid "Update"
 msgid "Updateable"
 msgstr "പുതുക്കല്‍"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "എല്ലാ വിഭാഗങ്ങളും"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -567,30 +575,30 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Open Recent"
 msgid "Recent"
 msgstr "അടുത്തുപയോഗിച്ചതു് തുറക്കുക"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr ""
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "വിലയിരുത്തല്‍"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, fuzzy, kde-format
 #| msgid "Download"
 msgid "Downloads"
 msgstr "ഡൌണ്‍ലോട് ചെയ്യുക"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt ""
@@ -599,7 +607,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "തട്ടുകള്‍ ആദ്യം കാണിയ്ക്കുക"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -607,14 +615,14 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr ""
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "തട്ടുകള്‍ ആദ്യം കാണിയ്ക്കുക"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, fuzzy, kde-format
 #| msgid "Most downloads"
 msgctxt ""
@@ -622,41 +630,41 @@ msgctxt ""
 msgid "Show Most Downloaded First"
 msgstr "ഏറ്റവുമധികം ഇറക്കിയത്"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, fuzzy, kde-format
 #| msgid "New Upload"
 msgid "Upload…"
 msgstr "പുതുതായി കയറ്റുക"
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr ""
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, fuzzy, kde-format
 #| msgid "&Go To..."
 msgid "Go to…"
 msgstr "പോകുക &g..."
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, fuzzy, kde-format
 #| msgid "Search:"
 msgid "Search…"
 msgstr "തെരയുക:"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "വിഭാഗം:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, fuzzy, kde-format
 #| msgid "Continue operation"
 msgid "Contribute your own…"
 msgstr "പ്രവര്‍ത്തനം തുടരുക"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, fuzzy, kde-format
 #| msgctxt "@note/rich"
 #| msgid "<i>Note</i>: %1"
@@ -665,7 +673,7 @@ msgctxt ""
 msgid "<i>(no title)</i>"
 msgstr "<i>കുറിപ്പു്</i>: %1"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -673,20 +681,20 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "എല്ലാ വിഭാഗങ്ങളും"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -694,7 +702,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -702,8 +710,8 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, fuzzy, kde-format
 #| msgid "1 download"
 #| msgid_plural "%1 downloads"
@@ -711,8 +719,8 @@ msgctxt "The number of times the item ha
 msgid "%1 downloads"
 msgstr "1 ഡൌണ്‍ലോഡ്"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, fuzzy, kde-format
 #| msgctxt "Show the author of this item in a list"
 #| msgid "By <i>%1</i>"
@@ -722,7 +730,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "<i>%1</i> അണിയിച്ചൊരുക്കിയതു്"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -730,7 +738,7 @@ msgctxt ""
 msgid "Working…"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, fuzzy, kde-format
 #| msgid "Updating"
 msgctxt ""
@@ -739,7 +747,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "പുതുക്കിക്കൊണ്ടിരിയ്ക്കുന്നു"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -750,7 +758,7 @@ msgid ""
 "bug report</a>."
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt "Label for the busy indicator showing an item is installing"
@@ -769,14 +777,14 @@ msgstr ""
 msgid "Please try again later."
 msgstr "ദയവായി ഒരു പേര് നല്‍കുക."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, fuzzy, kde-format
 #| msgctxt "No border line"
 #| msgid "None"
 msgid "None"
 msgstr "ഒന്നുമില്ല"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, fuzzy, kde-format
 #| msgid "(%1/s)"
 msgctxt ""
@@ -784,14 +792,14 @@ msgctxt ""
 msgid "(%1/%2)"
 msgstr "(%1/s)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, fuzzy, kde-format
 #| msgid "Download New Stuff..."
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "പുതിയവ ഇറക്കുക..."
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, fuzzy, kde-format
 #| msgid "Billing information:"
 msgctxt ""
@@ -799,21 +807,21 @@ msgctxt ""
 msgid "Updating information…"
 msgstr "ബില്ലിങ് വിവരങ്ങള്‍:"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, fuzzy, kde-format
 #| msgid "&Store"
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "&സൂക്ഷിക്കുക"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, fuzzy, kde-format
 #| msgid "Provider:"
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "ദാതാവ്:"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, fuzzy, kde-format
 #| msgctxt "@label:button"
 #| msgid "&Open with %1"
@@ -823,7 +831,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "%1 ഉപയോഗിച്ചു് &തുറക്കുക"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, fuzzy, kde-format
 #| msgid "&Send Email"
 msgctxt ""
@@ -832,7 +840,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "ഈമെയില്‍ &അയയ്ക്കുക"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -840,10 +848,10 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -855,18 +863,18 @@ msgid ""
 "content added."
 msgstr ""
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "ഡേറ്റാ ലഭ്യമാക്കുന്നു"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "ഇന്‍സ്റ്റാള്‍ ചെയ്തുകൊണ്ടിരിയ്ക്കുന്നു"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -876,7 +884,7 @@ msgid ""
 "please contact the person in charge of your permissions."
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Back"
@@ -884,19 +892,19 @@ msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "പുറകിലേയ്ക്കു്"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, fuzzy, kde-format
 #| msgctxt "@action:button Restart find & replace"
 #| msgid "Restart"
@@ -904,7 +912,7 @@ msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "വീണ്ടും ആരംഭിക്കുക"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "New"
@@ -912,7 +920,7 @@ msgctxt "Knewstuff5"
 msgid "New"
 msgstr "പുതിയതു്"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Home"
@@ -920,13 +928,13 @@ msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Home"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Up"
@@ -934,7 +942,7 @@ msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "Up"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, fuzzy, kde-format
 #| msgctxt "dictionary variant"
 #| msgid "extended"
@@ -942,7 +950,7 @@ msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "വികസിപ്പിച്ചത്"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Subscript"
@@ -950,14 +958,14 @@ msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "വരിയ്ക്കുതാഴെ"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "എല്ലാ വിഭാഗങ്ങളും"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -988,10 +996,15 @@ msgid ""
 msgstr ""
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
-#, kde-format
-msgid "Download New Stuff..."
+#, fuzzy, kde-format
+#| msgid "Download New Stuff..."
+msgctxt "@action"
+msgid "Download New Stuff…"
 msgstr "പുതിയവ ഇറക്കുക..."
 
+#~ msgid "Download New Stuff..."
+#~ msgstr "പുതിയവ ഇറക്കുക..."
+
 #~ msgid "Initializing"
 #~ msgstr "ആരംഭിയ്ക്കുന്നു"
 
diff -pruN 6.0.0-3/po/mr/knewstuff6.po 6.3.0-1/po/mr/knewstuff6.po
--- 6.0.0-3/po/mr/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/mr/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -8,7 +8,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2013-03-29 16:14+0530\n"
 "Last-Translator: Chetan Khona <chetan@kompkin.com>\n"
 "Language-Team: Marathi <kde-i18n-doc@kde.org>\n"
@@ -58,7 +58,7 @@ msgstr "तुमचे मत नों
 msgid "You are now a fan."
 msgstr "तुम्ही आता प्रशंसक बनला आहात."
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -126,7 +126,7 @@ msgstr "संयोजना फाई
 msgid "Use"
 msgstr ""
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -134,17 +134,17 @@ msgid ""
 "This is a critical error and should be reported to the application author"
 msgstr ""
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr "%1 या फाईलमधून पुरवठाकर्ते लोड करताना अपयश"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr "%1 या फाईलमधून पुरवठाकर्ते लोड करताना अपयश"
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr "पुरवठाकर्ता सुरु करताना त्रुटी"
@@ -289,7 +289,7 @@ msgid ""
 "the update"
 msgstr ""
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, fuzzy, kde-format
 #| msgid "Failed to load file '%1'"
 msgid ""
@@ -297,7 +297,7 @@ msgid ""
 "%2"
 msgstr "फाईल '%1' दाखल करण्यास अपयशी"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt ""
@@ -305,7 +305,7 @@ msgctxt ""
 msgid "All Categories"
 msgstr "सर्व विभाग"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, fuzzy, kde-format
 #| msgid "Unknown error"
 msgctxt ""
@@ -331,14 +331,14 @@ msgstr ""
 msgid "Download New %1…"
 msgstr "नविन %1 डाउनलोड करा"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, fuzzy, kde-format
 #| msgid "Download New %1"
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "नविन %1 डाउनलोड करा"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
 msgctxt ""
@@ -347,12 +347,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "नविन वस्तु डाउनलोड करा"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -361,12 +361,12 @@ msgid ""
 "this through the naming of the items."
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "प्रतिष्ठापन"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt ""
@@ -374,7 +374,7 @@ msgctxt ""
 msgid "Installing %1 from %2"
 msgstr "प्रतिष्ठापन"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -382,10 +382,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -394,10 +394,10 @@ msgctxt ""
 msgid "Install"
 msgstr "प्रतिष्ठापन"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -405,24 +405,24 @@ msgctxt ""
 msgid "Install…"
 msgstr "प्रतिष्ठापन"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, fuzzy, kde-format
 #| msgid "Update"
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "अद्ययावत करा"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, fuzzy, kde-format
 #| msgid "Uninstall"
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "अप्रतिष्ठापन करा"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -430,14 +430,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -448,12 +448,12 @@ msgid ""
 "to the KDE Community in a bug report</a>."
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, fuzzy, kde-format
 #| msgid "View Comments"
 msgctxt ""
@@ -462,19 +462,19 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "टिपण्णी पहा"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, fuzzy, kde-format
 #| msgid "Rating: "
 msgid "Rating:"
 msgstr "गुणवत्ताश्रेणी: "
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, fuzzy, kde-format
 #| msgid "Homepage"
 msgid "Homepage:"
 msgstr "मुख्यपान"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -483,12 +483,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -496,80 +496,88 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr ""
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, fuzzy, kde-format
 #| msgctxt "@option:check Do filter on type - show only files"
 #| msgid "Files"
 msgid "Tiles"
 msgstr "फाईल्स"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "चिन्ह"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, fuzzy, kde-format
 #| msgid "No Preview"
 msgid "Preview"
 msgstr "पूर्वदृश्य नाही"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, fuzzy, kde-format
 #| msgid "Details view mode"
 msgid "Detailed Tiles View Mode"
 msgstr "तपशील दृश्य"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, fuzzy, kde-format
 #| msgid "Icons view mode"
 msgid "Icons Only View Mode"
 msgstr "चिन्ह दृश्य"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, fuzzy, kde-format
 #| msgid "Details view mode"
 msgid "Large Preview View Mode"
 msgstr "तपशील दृश्य"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr ""
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "प्रतिष्ठापन झालेले"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, fuzzy, kde-format
 #| msgid "Update"
 msgid "Updateable"
 msgstr "अद्ययावत करा"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "सर्व विभाग"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -577,30 +585,30 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Open Recent"
 msgid "Recent"
 msgstr "अलिकडील उघडा"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr ""
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "गुणवत्ताश्रेणी"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, fuzzy, kde-format
 #| msgid "Download"
 msgid "Downloads"
 msgstr "डाउनलोड"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt ""
@@ -609,7 +617,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "प्रथम संचयीका दर्शवा"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -617,14 +625,14 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr ""
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "प्रथम संचयीका दर्शवा"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, fuzzy, kde-format
 #| msgid "Most downloads"
 msgctxt ""
@@ -632,41 +640,41 @@ msgctxt ""
 msgid "Show Most Downloaded First"
 msgstr "बहुतांश डाउनलोड्स"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, fuzzy, kde-format
 #| msgid "&Replace..."
 msgid "Upload…"
 msgstr "बदलवा (&R)..."
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr ""
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, fuzzy, kde-format
 #| msgid "&Go To..."
 msgid "Go to…"
 msgstr "येथे जा (&G)..."
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, fuzzy, kde-format
 #| msgid "Search:"
 msgid "Search…"
 msgstr "शोधा :"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "विभाग:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, fuzzy, kde-format
 #| msgid "Continue operation"
 msgid "Contribute your own…"
 msgstr "कार्यपध्दती सुरु ठेवा"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, fuzzy, kde-format
 #| msgctxt "@note/rich"
 #| msgid "<i>Note</i>: %1"
@@ -675,7 +683,7 @@ msgctxt ""
 msgid "<i>(no title)</i>"
 msgstr "<i>टिप</i>: %1"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -683,20 +691,20 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "सर्व विभाग"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -704,7 +712,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -712,8 +720,8 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, fuzzy, kde-format
 #| msgid "1 download"
 #| msgid_plural "%1 downloads"
@@ -721,8 +729,8 @@ msgctxt "The number of times the item ha
 msgid "%1 downloads"
 msgstr "1 डाउनलोड"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, fuzzy, kde-format
 #| msgctxt "Show the author of this item in a list"
 #| msgid "By <i>%1</i>"
@@ -732,7 +740,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "द्वारा <i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -740,7 +748,7 @@ msgctxt ""
 msgid "Working…"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, fuzzy, kde-format
 #| msgid "Updating"
 msgctxt ""
@@ -749,7 +757,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "अद्ययावत करत आहे"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -760,7 +768,7 @@ msgid ""
 "bug report</a>."
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt "Label for the busy indicator showing an item is installing"
@@ -779,14 +787,14 @@ msgstr ""
 msgid "Please try again later."
 msgstr "कृपया नाव दाखल करा."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, fuzzy, kde-format
 #| msgctxt "No border line"
 #| msgid "None"
 msgid "None"
 msgstr "काहीच नाही"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, fuzzy, kde-format
 #| msgid "(%1/s)"
 msgctxt ""
@@ -794,14 +802,14 @@ msgctxt ""
 msgid "(%1/%2)"
 msgstr "(%1/s)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "नविन वस्तु डाउनलोड करा"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, fuzzy, kde-format
 #| msgid "Billing information:"
 msgctxt ""
@@ -809,21 +817,21 @@ msgctxt ""
 msgid "Updating information…"
 msgstr "बिलाची माहिती:"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, fuzzy, kde-format
 #| msgid "&Store"
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "संचयन (&S)"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, fuzzy, kde-format
 #| msgid "Provider:"
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "पुरवठाकर्ता:"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, fuzzy, kde-format
 #| msgctxt "@label:button"
 #| msgid "&Open with %1"
@@ -833,7 +841,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "%1 सह उघडा (&O)"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, fuzzy, kde-format
 #| msgid "&Send Email"
 msgctxt ""
@@ -842,7 +850,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "इमेल पाठवा (&S)"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -850,10 +858,10 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -865,18 +873,18 @@ msgid ""
 "content added."
 msgstr ""
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "डेटा दाखल करत आहे"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "प्रतिष्ठापन"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -886,7 +894,7 @@ msgid ""
 "please contact the person in charge of your permissions."
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Back"
@@ -894,20 +902,20 @@ msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "मागे"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, fuzzy, kde-format
 #| msgid "Saturday"
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "शनिवार"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, fuzzy, kde-format
 #| msgctxt "@action:button Restart find & replace"
 #| msgid "Restart"
@@ -915,7 +923,7 @@ msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "पुन्हा सुरु करा"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "New"
@@ -923,7 +931,7 @@ msgctxt "Knewstuff5"
 msgid "New"
 msgstr "नवीन"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Home"
@@ -931,13 +939,13 @@ msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Home"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Up"
@@ -945,7 +953,7 @@ msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "वर"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, fuzzy, kde-format
 #| msgctxt "dictionary variant"
 #| msgid "extended"
@@ -953,7 +961,7 @@ msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "विस्तारीत"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Subscript"
@@ -961,14 +969,14 @@ msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "सबस्क्रिप्ट"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "सर्व विभाग"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -999,9 +1007,14 @@ msgid ""
 msgstr ""
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
-#, kde-format
-msgid "Download New Stuff..."
-msgstr "नवीन वस्तु डाउनलोड करा ..."
+#, fuzzy, kde-format
+#| msgid "Download New Stuff"
+msgctxt "@action"
+msgid "Download New Stuff…"
+msgstr "नविन वस्तु डाउनलोड करा"
+
+#~ msgid "Download New Stuff..."
+#~ msgstr "नवीन वस्तु डाउनलोड करा ..."
 
 #~ msgid "Initializing"
 #~ msgstr "सुरु करत आहे"
diff -pruN 6.0.0-3/po/ms/knewstuff6.po 6.3.0-1/po/ms/knewstuff6.po
--- 6.0.0-3/po/ms/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/ms/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -10,7 +10,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2011-07-16 00:57+0800\n"
 "Last-Translator: Sharuzzaman Ahmat Raslan <sharuzzaman@gmail.com>\n"
 "Language-Team: Malay <kedidiemas@yahoogroups.com>\n"
@@ -66,7 +66,7 @@ msgstr "Undian anda berjaya."
 msgid "You are now a fan."
 msgstr "Anda sekarang adalah peminat."
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -134,7 +134,7 @@ msgstr "Tetapan fail"
 msgid "Use"
 msgstr ""
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -142,17 +142,17 @@ msgid ""
 "This is a critical error and should be reported to the application author"
 msgstr ""
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr "Memuatkan senarai penyedia dari fail: %1 gagal"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr "Tidak dapat memuatkan penyedia dapatkan barangan terbaru dari fail: %1"
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, fuzzy, kde-format
 msgid "Error initializing provider."
 msgstr "Ralat."
@@ -298,7 +298,7 @@ msgid ""
 "the update"
 msgstr ""
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, fuzzy, kde-format
 #| msgid "Failed to load file '%1'"
 msgid ""
@@ -306,7 +306,7 @@ msgid ""
 "%2"
 msgstr "Gagal untuk memuatkan fail '%1'"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt ""
@@ -314,7 +314,7 @@ msgctxt ""
 msgid "All Categories"
 msgstr "Semua Kategori"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, fuzzy, kde-format
 #| msgid "Unknown error"
 msgctxt ""
@@ -340,14 +340,14 @@ msgstr ""
 msgid "Download New %1…"
 msgstr "Muatturun Barangan Baru..."
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, fuzzy, kde-format
 #| msgid "Download New Stuff..."
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "Muatturun Barangan Baru..."
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, fuzzy, kde-format
 #| msgid "Download New Stuff..."
 msgctxt ""
@@ -356,12 +356,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "Muatturun Barangan Baru..."
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -370,12 +370,12 @@ msgid ""
 "this through the naming of the items."
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "Pasang"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt ""
@@ -383,7 +383,7 @@ msgctxt ""
 msgid "Installing %1 from %2"
 msgstr "Memasang"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -391,10 +391,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -403,10 +403,10 @@ msgctxt ""
 msgid "Install"
 msgstr "Pasang"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -414,24 +414,24 @@ msgctxt ""
 msgid "Install…"
 msgstr "Pasang"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, fuzzy, kde-format
 #| msgid "Update"
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "Kemaskini"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, fuzzy, kde-format
 #| msgid "Uninstall"
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "Nyahpasang"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -439,14 +439,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -457,12 +457,12 @@ msgid ""
 "to the KDE Community in a bug report</a>."
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, fuzzy, kde-format
 #| msgid "View Comments"
 msgctxt ""
@@ -471,19 +471,19 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "Lihat Komen"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, fuzzy, kde-format
 #| msgid "Rating: "
 msgid "Rating:"
 msgstr "Kadaran: "
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, fuzzy, kde-format
 #| msgid "Homepage"
 msgid "Homepage:"
 msgstr "Laman Web"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -492,12 +492,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -505,80 +505,88 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr ""
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, fuzzy, kde-format
 #| msgctxt "@option:check Do filter on type - show only files"
 #| msgid "Files"
 msgid "Tiles"
 msgstr "Fail"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "Ikon"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, fuzzy, kde-format
 #| msgid "Preview URL:"
 msgid "Preview"
 msgstr "URL Pralihat:"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, fuzzy, kde-format
 #| msgid "Details view mode"
 msgid "Detailed Tiles View Mode"
 msgstr "Mod lihat terperinci"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, fuzzy, kde-format
 #| msgid "Icons view mode"
 msgid "Icons Only View Mode"
 msgstr "Mod lihat ikon"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, fuzzy, kde-format
 #| msgid "Details view mode"
 msgid "Large Preview View Mode"
 msgstr "Mod lihat terperinci"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr ""
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "Telah dipasang"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, fuzzy, kde-format
 #| msgid "Update"
 msgid "Updateable"
 msgstr "Kemaskini"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "Semua Kategori"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -586,30 +594,30 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Open Recent"
 msgid "Recent"
 msgstr "Buka Terbaru"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr ""
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "Kadaran"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, fuzzy, kde-format
 #| msgid "Download"
 msgid "Downloads"
 msgstr "Muatturun"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt ""
@@ -618,7 +626,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "Papar direktori dahulu"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -626,14 +634,14 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr ""
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "Papar direktori dahulu"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, fuzzy, kde-format
 #| msgid "Most downloads"
 msgctxt ""
@@ -641,41 +649,41 @@ msgctxt ""
 msgid "Show Most Downloaded First"
 msgstr "Muatturun terbanyak"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, fuzzy, kde-format
 #| msgid "New Upload"
 msgid "Upload…"
 msgstr "Muatnaik Baru"
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr ""
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, fuzzy, kde-format
 #| msgid "&Go To..."
 msgid "Go to…"
 msgstr "&Pergi Ke..."
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, fuzzy, kde-format
 #| msgid "Search:"
 msgid "Search…"
 msgstr "Cari:"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "Kategori:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, fuzzy, kde-format
 #| msgid "Continue operation"
 msgid "Contribute your own…"
 msgstr "Teruskan operasi"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, fuzzy, kde-format
 #| msgctxt "@note/rich"
 #| msgid "<i>Note</i>: %1"
@@ -684,7 +692,7 @@ msgctxt ""
 msgid "<i>(no title)</i>"
 msgstr "<i>Nota</i>: %1"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -692,20 +700,20 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "Semua Kategori"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -713,7 +721,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -721,16 +729,16 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, fuzzy, kde-format
 #| msgid "Download"
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
 msgstr "Muatturun"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, fuzzy, kde-format
 #| msgctxt "Show the author of this item in a list"
 #| msgid "By <i>%1</i>"
@@ -740,7 +748,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "Oleh <i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -748,7 +756,7 @@ msgctxt ""
 msgid "Working…"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, fuzzy, kde-format
 #| msgid "Updating"
 msgctxt ""
@@ -757,7 +765,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "Mengemaskini"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -768,7 +776,7 @@ msgid ""
 "bug report</a>."
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt "Label for the busy indicator showing an item is installing"
@@ -787,14 +795,14 @@ msgstr ""
 msgid "Please try again later."
 msgstr "Sila letakkan nama."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, fuzzy, kde-format
 #| msgctxt "No border line"
 #| msgid "None"
 msgid "None"
 msgstr "Tiada"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, fuzzy, kde-format
 #| msgid "(%1/s)"
 msgctxt ""
@@ -802,14 +810,14 @@ msgctxt ""
 msgid "(%1/%2)"
 msgstr "(%1/s)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, fuzzy, kde-format
 #| msgid "Download New Stuff..."
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "Muatturun Barangan Baru..."
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, fuzzy, kde-format
 #| msgid "Billing information:"
 msgctxt ""
@@ -817,21 +825,21 @@ msgctxt ""
 msgid "Updating information…"
 msgstr "Maklumat bil:"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, fuzzy, kde-format
 #| msgid "&Store"
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "&Simpan"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, fuzzy, kde-format
 #| msgid "Provider:"
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "Penyedia:"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, fuzzy, kde-format
 #| msgid "&Open with '%1'"
 msgctxt ""
@@ -840,7 +848,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "Buka 1"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, fuzzy, kde-format
 #| msgid "&Send Email"
 msgctxt ""
@@ -849,7 +857,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "&Hantar E-mel"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -857,10 +865,10 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -872,19 +880,19 @@ msgid ""
 "content added."
 msgstr ""
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, fuzzy, kde-format
 #| msgid "Loading Applet"
 msgid "Loading data"
 msgstr "Memuatkan Aplet"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "Memasang"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -894,7 +902,7 @@ msgid ""
 "please contact the person in charge of your permissions."
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Back"
@@ -902,19 +910,19 @@ msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "Undur"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, fuzzy, kde-format
 #| msgctxt "@action:button Restart find & replace"
 #| msgid "Restart"
@@ -922,7 +930,7 @@ msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "Ulangmula"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "New"
@@ -930,7 +938,7 @@ msgctxt "Knewstuff5"
 msgid "New"
 msgstr "Baru"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Home"
@@ -938,13 +946,13 @@ msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Rumah"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Up"
@@ -952,7 +960,7 @@ msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "Naik"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, fuzzy, kde-format
 #| msgctxt "dictionary variant"
 #| msgid "extended"
@@ -960,7 +968,7 @@ msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "tersambung"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Subscript"
@@ -968,14 +976,14 @@ msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "Subskrip"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "Semua Kategori"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -1006,10 +1014,15 @@ msgid ""
 msgstr ""
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
-#, kde-format
-msgid "Download New Stuff..."
+#, fuzzy, kde-format
+#| msgid "Download New Stuff..."
+msgctxt "@action"
+msgid "Download New Stuff…"
 msgstr "Muatturun Barangan Baru..."
 
+#~ msgid "Download New Stuff..."
+#~ msgstr "Muatturun Barangan Baru..."
+
 #, fuzzy
 #~| msgid "Installing"
 #~ msgid "Initializing"
diff -pruN 6.0.0-3/po/nb/knewstuff6.po 6.3.0-1/po/nb/knewstuff6.po
--- 6.0.0-3/po/nb/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/nb/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -11,7 +11,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2015-05-17 20:49+0200\n"
 "Last-Translator: Bjørn Steensrud <bjornst@skogkatt.homelinux.org>\n"
 "Language-Team: Norwegian Bokmål <l10n-no@lister.huftis.org>\n"
@@ -63,7 +63,7 @@ msgstr "Din stemme ble registrert."
 msgid "You are now a fan."
 msgstr "Du er nå en fan."
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -127,7 +127,7 @@ msgstr "Oppsettsfila er ugyldig: «%1».
 msgid "Use"
 msgstr "Bruk"
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -135,17 +135,17 @@ msgid ""
 "This is a critical error and should be reported to the application author"
 msgstr ""
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr "Det lyktes ikke å laste inn leverandører fra fil: %1"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr "Klarte ikke laste inn leverandører av supre nye saker fra fil: %1"
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr "Feil under klargjøring av leverandør."
@@ -285,21 +285,21 @@ msgid ""
 "the update"
 msgstr ""
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, kde-format
 msgid ""
 "Failed to adopt '%1'\n"
 "%2"
 msgstr ""
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, kde-format
 msgctxt ""
 "The first entry in the category selection list (also the default value)"
 msgid "All Categories"
 msgstr ""
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, kde-format
 msgctxt ""
 "The string passed back in the case the requested category is not known"
@@ -323,13 +323,13 @@ msgstr ""
 msgid "Download New %1…"
 msgstr "Last ned nye saker …"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, kde-format
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr ""
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, kde-format
 msgctxt ""
 "A placeholder title used in the dialog when there is no better title "
@@ -337,12 +337,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -351,19 +351,19 @@ msgid ""
 "this through the naming of the items."
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "Installer"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, kde-format
 msgctxt ""
 "A passive notification shown when installation of an item is initiated"
 msgid "Installing %1 from %2"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -371,10 +371,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, kde-format
 msgctxt ""
 "Request installation of this item, available when there is exactly one "
@@ -382,32 +382,32 @@ msgctxt ""
 msgid "Install"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, fuzzy, kde-format
 msgctxt ""
 "Show installation options, where there is more than one downloadable item"
 msgid "Install…"
 msgstr "Installer"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, kde-format
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, kde-format
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -415,14 +415,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -433,12 +433,12 @@ msgid ""
 "to the KDE Community in a bug report</a>."
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a new sub page with comments (comments "
@@ -446,17 +446,17 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, kde-format
 msgid "Rating:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, kde-format
 msgid "Homepage:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -465,12 +465,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -478,72 +478,80 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr ""
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, kde-format
 msgid "Tiles"
 msgstr ""
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr ""
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, kde-format
 msgid "Preview"
 msgstr ""
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, kde-format
 msgid "Detailed Tiles View Mode"
 msgstr ""
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, kde-format
 msgid "Icons Only View Mode"
 msgstr ""
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, kde-format
 msgid "Large Preview View Mode"
 msgstr ""
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr ""
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "Installert"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, kde-format
 msgid "Updateable"
 msgstr ""
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, kde-format
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -551,27 +559,27 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, kde-format
 msgid "Recent"
 msgstr ""
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr ""
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "Vurdering"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, kde-format
 msgid "Downloads"
 msgstr ""
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on when items were most "
@@ -579,7 +587,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr ""
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -587,57 +595,57 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr ""
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, kde-format
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr ""
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on number of downloads"
 msgid "Show Most Downloaded First"
 msgstr ""
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, kde-format
 msgid "Upload…"
 msgstr ""
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr ""
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, kde-format
 msgid "Go to…"
 msgstr ""
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, kde-format
 msgid "Search…"
 msgstr ""
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "Kategori:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, kde-format
 msgid "Contribute your own…"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, kde-format
 msgctxt ""
 "Placeholder title for when a comment has no subject, but does have a rating"
 msgid "<i>(no title)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -645,19 +653,19 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, kde-format
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -665,7 +673,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -673,15 +681,15 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, kde-format
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, kde-format
 msgctxt ""
 "Subheading for the tile view, located immediately underneath the name of the "
@@ -689,7 +697,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -697,7 +705,7 @@ msgctxt ""
 msgid "Working…"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is in the process of being "
@@ -705,7 +713,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -716,7 +724,7 @@ msgid ""
 "bug report</a>."
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, fuzzy, kde-format
 msgctxt "Label for the busy indicator showing an item is installing"
 msgid "Installing…"
@@ -733,44 +741,44 @@ msgstr ""
 msgid "Please try again later."
 msgstr ""
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, kde-format
 msgid "None"
 msgstr ""
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, kde-format
 msgctxt ""
 "A text representation of the rating, shown as a fraction of the max value"
 msgid "(%1/%2)"
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, fuzzy, kde-format
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "Last ned nye saker …"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, fuzzy, kde-format
 msgctxt ""
 "A text shown beside a busy indicator suggesting that data is being fetched"
 msgid "Updating information…"
 msgstr "Laster inn leverandørinformasjon"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, kde-format
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, kde-format
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, kde-format
 msgctxt ""
 "Text for an action which causes the specified website to be opened using the "
@@ -778,7 +786,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, kde-format
 msgctxt ""
 "Text for an action which will attempt to send an email using the user's "
@@ -786,7 +794,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -794,10 +802,10 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -809,18 +817,18 @@ msgid ""
 "content added."
 msgstr ""
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "Laster inn data"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "Installerer"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -830,73 +838,73 @@ msgid ""
 "please contact the person in charge of your permissions."
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Back"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "New"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Home"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Up"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -927,6 +935,8 @@ msgid ""
 msgstr ""
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
-#, kde-format
-msgid "Download New Stuff..."
+#, fuzzy, kde-format
+#| msgid "Download New Stuff..."
+msgctxt "@action"
+msgid "Download New Stuff…"
 msgstr "Last ned nye saker …"
diff -pruN 6.0.0-3/po/nds/knewstuff6.po 6.3.0-1/po/nds/knewstuff6.po
--- 6.0.0-3/po/nds/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/nds/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -8,7 +8,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2014-06-18 01:32+0200\n"
 "Last-Translator: Sönke Dibbern <s_dibbern@web.de>\n"
 "Language-Team: Low Saxon <kde-i18n-nds@kde.org>\n"
@@ -58,7 +58,7 @@ msgstr "Dien Beweerten wöör opnahmen..
 msgid "You are now a fan."
 msgstr "Nu büst Du en Fan."
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -127,7 +127,7 @@ msgstr "Instellendatei „%1“ is leeg.
 msgid "Use"
 msgstr ""
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -135,17 +135,17 @@ msgid ""
 "This is a critical error and should be reported to the application author"
 msgstr ""
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr "Laden vun Anbeders ut Datei „%1“ fehlslaan."
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr "Ut de Datei laat sik keen Anbeders för deegte niege Saken laden: %1"
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr "Anbeder lett sik nich torechtmaken."
@@ -290,7 +290,7 @@ msgid ""
 "the update"
 msgstr ""
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, fuzzy, kde-format
 #| msgid "Failed to load file '%1'"
 msgid ""
@@ -298,7 +298,7 @@ msgid ""
 "%2"
 msgstr "De Datei \"%1\" lett sik nich laden"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt ""
@@ -306,7 +306,7 @@ msgctxt ""
 msgid "All Categories"
 msgstr "All Kategorien"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, fuzzy, kde-format
 #| msgid "Unknown error"
 msgctxt ""
@@ -332,14 +332,14 @@ msgstr ""
 msgid "Download New %1…"
 msgstr "Nieg %1 daalladen"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, fuzzy, kde-format
 #| msgid "Download New %1"
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "Nieg %1 daalladen"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
 msgctxt ""
@@ -348,12 +348,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "\"Niege Saken\" daalladen"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -362,12 +362,12 @@ msgid ""
 "this through the naming of the items."
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "Installeren"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt ""
@@ -375,7 +375,7 @@ msgctxt ""
 msgid "Installing %1 from %2"
 msgstr "An't Installeren"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -383,10 +383,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -395,10 +395,10 @@ msgctxt ""
 msgid "Install"
 msgstr "Installeren"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -406,24 +406,24 @@ msgctxt ""
 msgid "Install…"
 msgstr "Installeren"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, fuzzy, kde-format
 #| msgid "Update"
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "Opfrischen"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, fuzzy, kde-format
 #| msgid "Uninstall"
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "Deinstalleren"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -431,14 +431,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -449,12 +449,12 @@ msgid ""
 "to the KDE Community in a bug report</a>."
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, fuzzy, kde-format
 #| msgid "View Comments"
 msgctxt ""
@@ -463,19 +463,19 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "Kommentaren wiesen"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, fuzzy, kde-format
 #| msgid "Rating: "
 msgid "Rating:"
 msgstr "Beweerten: "
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, fuzzy, kde-format
 #| msgid "Homepage"
 msgid "Homepage:"
 msgstr "Tohuussiet"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -484,12 +484,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -497,73 +497,81 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr ""
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, fuzzy, kde-format
 #| msgctxt "@option:check Do filter on type - show only files"
 #| msgid "Files"
 msgid "Tiles"
 msgstr "Dateien"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "Lüttbiller"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, fuzzy, kde-format
 #| msgid "Previews"
 msgid "Preview"
 msgstr "Vöransichten"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, fuzzy, kde-format
 #| msgid "Detailed Tree View"
 msgid "Detailed Tiles View Mode"
 msgstr "Enkelheiten-Boomansicht"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, fuzzy, kde-format
 #| msgid "Icons view mode"
 msgid "Icons Only View Mode"
 msgstr "Lüttbildansicht"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, fuzzy, kde-format
 #| msgid "Details view mode"
 msgid "Large Preview View Mode"
 msgstr "Enkelheiten-Ansicht"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr ""
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "Installeert"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, fuzzy, kde-format
 #| msgid "Update"
 msgid "Updateable"
 msgstr "Opfrischen"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, fuzzy, kde-format
 #| msgid "&Show All Entries"
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "All Indrääg &wiesen"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, fuzzy, kde-format
 #| msgid "&Show All Entries"
 msgctxt ""
@@ -571,7 +579,7 @@ msgctxt ""
 msgid "Show Only Installed Entries"
 msgstr "All Indrääg &wiesen"
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, fuzzy, kde-format
 #| msgid "&Show All Entries"
 msgctxt ""
@@ -580,30 +588,30 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr "All Indrääg &wiesen"
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "OpenRecent"
 msgid "Recent"
 msgstr "VerledenOpmaken"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr ""
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "Beweerten"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, fuzzy, kde-format
 #| msgid "Download"
 msgid "Downloads"
 msgstr "Daalladen"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt ""
@@ -612,7 +620,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "Ornern toeerst wiesen"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -620,14 +628,14 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr ""
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "Ornern toeerst wiesen"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, fuzzy, kde-format
 #| msgid "Most downloads"
 msgctxt ""
@@ -635,41 +643,41 @@ msgctxt ""
 msgid "Show Most Downloaded First"
 msgstr "Tomehrst daallaadt"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, fuzzy, kde-format
 #| msgid "Upload..."
 msgid "Upload…"
 msgstr "Hoochladen..."
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr ""
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, fuzzy, kde-format
 #| msgid "&Go To..."
 msgid "Go to…"
 msgstr "&Gah na..."
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, fuzzy, kde-format
 #| msgid "Search:"
 msgid "Search…"
 msgstr "Söken:"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "Kategorie:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, fuzzy, kde-format
 #| msgid "Continue operation"
 msgid "Contribute your own…"
 msgstr "Mit de Akschoon wiedermaken"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, fuzzy, kde-format
 #| msgctxt "@note/rich"
 #| msgid "<i>Note</i>: %1"
@@ -678,7 +686,7 @@ msgctxt ""
 msgid "<i>(no title)</i>"
 msgstr "<i>Beacht</i>: %1"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -686,20 +694,20 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "All Kategorien"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, fuzzy, kde-format
 #| msgid "Show Preview"
 msgctxt ""
@@ -708,7 +716,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr "Vöransicht wiesen"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -716,8 +724,8 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, fuzzy, kde-format
 #| msgid "1 download"
 #| msgid_plural "%1 downloads"
@@ -725,8 +733,8 @@ msgctxt "The number of times the item ha
 msgid "%1 downloads"
 msgstr "1 Daalladen"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, fuzzy, kde-format
 #| msgctxt "Show the author of this item in a list"
 #| msgid "By <i>%1</i>"
@@ -736,7 +744,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "Vun <i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -744,7 +752,7 @@ msgctxt ""
 msgid "Working…"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, fuzzy, kde-format
 #| msgid "Updating"
 msgctxt ""
@@ -753,7 +761,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "An't Opfrischen"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -764,7 +772,7 @@ msgid ""
 "bug report</a>."
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt "Label for the busy indicator showing an item is installing"
@@ -783,14 +791,14 @@ msgstr ""
 msgid "Please try again later."
 msgstr "Bitte giff en Naam in."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, fuzzy, kde-format
 #| msgctxt "No border line"
 #| msgid "None"
 msgid "None"
 msgstr "Keen"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, fuzzy, kde-format
 #| msgid "(%1/s)"
 msgctxt ""
@@ -798,14 +806,14 @@ msgctxt ""
 msgid "(%1/%2)"
 msgstr "(%1/s)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "\"Niege Saken\" daalladen"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, fuzzy, kde-format
 #| msgid "Billing information:"
 msgctxt ""
@@ -813,21 +821,21 @@ msgctxt ""
 msgid "Updating information…"
 msgstr "Afreken-Informatschoon:"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, fuzzy, kde-format
 #| msgid "&Store"
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "&Sekern"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, fuzzy, kde-format
 #| msgid "Provider:"
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "Anbeder:"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, fuzzy, kde-format
 #| msgid ""
 #| "\n"
@@ -844,7 +852,7 @@ msgstr ""
 "Nettsiet:\n"
 "%1"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, fuzzy, kde-format
 #| msgid "&Send Email"
 msgctxt ""
@@ -853,7 +861,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "Nettbreef &schicken"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -861,10 +869,10 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -876,18 +884,18 @@ msgid ""
 "content added."
 msgstr ""
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "Daten warrt laadt."
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "An't Installeren"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -897,7 +905,7 @@ msgid ""
 "please contact the person in charge of your permissions."
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Back"
@@ -905,20 +913,20 @@ msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "Torüch"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, fuzzy, kde-format
 #| msgid "Saturday"
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "Sünnavend"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, fuzzy, kde-format
 #| msgctxt "@action:button Restart find & replace"
 #| msgid "Restart"
@@ -926,7 +934,7 @@ msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "Nieg opropen"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "New"
@@ -934,7 +942,7 @@ msgctxt "Knewstuff5"
 msgid "New"
 msgstr "Nieg"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Home"
@@ -942,13 +950,13 @@ msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Pos1"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Up"
@@ -956,7 +964,7 @@ msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "Rop"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, fuzzy, kde-format
 #| msgctxt "dictionary variant"
 #| msgid "extended"
@@ -964,7 +972,7 @@ msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "verwiedert"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Subscript"
@@ -972,14 +980,14 @@ msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "Daalsetten"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, fuzzy, kde-format
 #| msgid "&Show All Entries"
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "All Indrääg &wiesen"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -1010,9 +1018,14 @@ msgid ""
 msgstr ""
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
-#, kde-format
-msgid "Download New Stuff..."
-msgstr "„Niege Saken“ daalladen..."
+#, fuzzy, kde-format
+#| msgid "Download New Stuff"
+msgctxt "@action"
+msgid "Download New Stuff…"
+msgstr "\"Niege Saken\" daalladen"
+
+#~ msgid "Download New Stuff..."
+#~ msgstr "„Niege Saken“ daalladen..."
 
 #~ msgid "Initializing"
 #~ msgstr "An't Torechtmaken"
diff -pruN 6.0.0-3/po/ne/knewstuff6.po 6.3.0-1/po/ne/knewstuff6.po
--- 6.0.0-3/po/ne/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/ne/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -11,7 +11,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2007-11-05 15:41+0545\n"
 "Last-Translator: Shyam Krishna Bal <shyamkrishna_bal@yahoo.com>\n"
 "Language-Team: Nepali <info@mpp.org.np>\n"
@@ -57,7 +57,7 @@ msgstr "पाठ बदलिएको
 msgid "You are now a fan."
 msgstr ""
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -126,7 +126,7 @@ msgstr "कन्फिगरेसन 
 msgid "Use"
 msgstr ""
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -134,17 +134,17 @@ msgid ""
 "This is a critical error and should be reported to the application author"
 msgstr ""
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr ""
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr ""
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr ""
@@ -291,7 +291,7 @@ msgid ""
 "the update"
 msgstr ""
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, fuzzy, kde-format
 #| msgid "Failed to load file '%1'"
 msgid ""
@@ -299,7 +299,7 @@ msgid ""
 "%2"
 msgstr "'%1' फाइल लोड गर्न असफल"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, fuzzy, kde-format
 #| msgid "PageUp"
 msgctxt ""
@@ -307,7 +307,7 @@ msgctxt ""
 msgid "All Categories"
 msgstr "PageUp"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, fuzzy, kde-format
 #| msgid "Unknown error"
 msgctxt ""
@@ -333,14 +333,14 @@ msgstr ""
 msgid "Download New %1…"
 msgstr "नयाँ %1 डाउनलोड गर्नुहोस्"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, fuzzy, kde-format
 #| msgid "Download New %1"
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "नयाँ %1 डाउनलोड गर्नुहोस्"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
 msgctxt ""
@@ -349,12 +349,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "नयाँ स्टफ डाउनलोड गर्नुहोस्"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -363,12 +363,12 @@ msgid ""
 "this through the naming of the items."
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "स्थापना गर्नुहोस्"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -376,7 +376,7 @@ msgctxt ""
 msgid "Installing %1 from %2"
 msgstr "स्थापना गर्नुहोस्"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -384,10 +384,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -396,10 +396,10 @@ msgctxt ""
 msgid "Install"
 msgstr "स्थापना गर्नुहोस्"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -407,24 +407,24 @@ msgctxt ""
 msgid "Install…"
 msgstr "स्थापना गर्नुहोस्"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, fuzzy, kde-format
 #| msgid "Update"
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "अद्यावधिक गर्नुहोस्"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, fuzzy, kde-format
 #| msgid "Uninstall"
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "विस्थापन गर्नुहोस्"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -432,14 +432,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -450,12 +450,12 @@ msgid ""
 "to the KDE Community in a bug report</a>."
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, fuzzy, kde-format
 #| msgid "Comments"
 msgctxt ""
@@ -464,19 +464,19 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "टिप्पणी"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, fuzzy, kde-format
 #| msgid "Rating"
 msgid "Rating:"
 msgstr "स्थान"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, fuzzy, kde-format
 #| msgid "Homepage"
 msgid "Homepage:"
 msgstr "गृहपृष्ठ"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -485,12 +485,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -498,73 +498,81 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr ""
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, fuzzy, kde-format
 #| msgid "File"
 msgid "Tiles"
 msgstr "फाइल"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "प्रतिमा"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, fuzzy, kde-format
 #| msgid "Show Preview"
 msgid "Preview"
 msgstr "पूर्वावलोकन देखाउनुहोस्"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, fuzzy, kde-format
 #| msgid "Detailed View"
 msgid "Detailed Tiles View Mode"
 msgstr "विस्तृत दृश्य"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, fuzzy, kde-format
 #| msgid "Icons Only"
 msgid "Icons Only View Mode"
 msgstr "प्रतिमा मात्र"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, fuzzy, kde-format
 #| msgid "Detailed View"
 msgid "Large Preview View Mode"
 msgstr "विस्तृत दृश्य"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr ""
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, fuzzy, kde-format
 #| msgid "Install"
 msgid "Installed"
 msgstr "स्थापना गर्नुहोस्"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, fuzzy, kde-format
 #| msgid "Update"
 msgid "Updateable"
 msgstr "अद्यावधिक गर्नुहोस्"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, fuzzy, kde-format
 #| msgid "&Show All Entries"
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "सबै प्रविष्टि देखाउनुहोस्"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, fuzzy, kde-format
 #| msgid "&Show All Entries"
 msgctxt ""
@@ -572,7 +580,7 @@ msgctxt ""
 msgid "Show Only Installed Entries"
 msgstr "सबै प्रविष्टि देखाउनुहोस्"
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, fuzzy, kde-format
 #| msgid "&Show All Entries"
 msgctxt ""
@@ -581,30 +589,30 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr "सबै प्रविष्टि देखाउनुहोस्"
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, fuzzy, kde-format
 #| msgid "Open &Recent"
 msgid "Recent"
 msgstr "हालैको खोल्नुहोस्"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr ""
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, fuzzy, kde-format
 #| msgid "Rating"
 msgid "Rating"
 msgstr "स्थान"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, fuzzy, kde-format
 #| msgid "Download"
 msgid "Downloads"
 msgstr "डाउनलोड गर्नुहोस्"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt ""
@@ -613,7 +621,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "डाइरेक्टरी पहिला देखाउनुहोस्"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -621,14 +629,14 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr ""
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "डाइरेक्टरी पहिला देखाउनुहोस्"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, fuzzy, kde-format
 #| msgid "Most downloads"
 msgctxt ""
@@ -636,42 +644,42 @@ msgctxt ""
 msgid "Show Most Downloaded First"
 msgstr "धेरै डाउनलोड"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, fuzzy, kde-format
 #| msgid "&Replace..."
 msgid "Upload…"
 msgstr "बदल्नुहोस्..."
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr ""
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, fuzzy, kde-format
 #| msgid "&Go To..."
 msgid "Go to…"
 msgstr "यसमा जानुहोस्..."
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, fuzzy, kde-format
 #| msgid "Search:"
 msgid "Search…"
 msgstr "खोजी:"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, fuzzy, kde-format
 #| msgid "Character:"
 msgid "Category:"
 msgstr "क्यारेक्टर:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, fuzzy, kde-format
 #| msgid "Continue operation"
 msgid "Contribute your own…"
 msgstr "सञ्चालन जारी राख्नुहोस्"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, fuzzy, kde-format
 #| msgctxt "@note/rich"
 #| msgid "<i>Note</i>: %1"
@@ -680,7 +688,7 @@ msgctxt ""
 msgid "<i>(no title)</i>"
 msgstr "<i>द्रष्टब्य</i>: %1"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -688,20 +696,20 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, fuzzy, kde-format
 #| msgid "PageUp"
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "PageUp"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, fuzzy, kde-format
 #| msgid "Show Preview"
 msgctxt ""
@@ -710,7 +718,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr "पूर्वावलोकन देखाउनुहोस्"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -718,16 +726,16 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, fuzzy, kde-format
 #| msgid "Download"
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
 msgstr "डाउनलोड गर्नुहोस्"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, fuzzy, kde-format
 #| msgctxt "@interface/rich"
 #| msgid "<i>%1</i>"
@@ -737,7 +745,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "<i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -745,7 +753,7 @@ msgctxt ""
 msgid "Working…"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, fuzzy, kde-format
 #| msgid "Update"
 msgctxt ""
@@ -754,7 +762,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "अद्यावधिक गर्नुहोस्"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -765,7 +773,7 @@ msgid ""
 "bug report</a>."
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt "Label for the busy indicator showing an item is installing"
@@ -784,13 +792,13 @@ msgstr ""
 msgid "Please try again later."
 msgstr "कृपया नाममा राख्नुहोस् ।"
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, fuzzy, kde-format
 #| msgid "None"
 msgid "None"
 msgstr "कुनै पनि होइन"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, fuzzy, kde-format
 #| msgid "(%1/s)"
 msgctxt ""
@@ -798,14 +806,14 @@ msgctxt ""
 msgid "(%1/%2)"
 msgstr "(%1/s)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "नयाँ स्टफ डाउनलोड गर्नुहोस्"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, fuzzy, kde-format
 #| msgid "Information"
 msgctxt ""
@@ -813,21 +821,21 @@ msgctxt ""
 msgid "Updating information…"
 msgstr "सूचना"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, fuzzy, kde-format
 #| msgid "Store"
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "भण्डारण गर्नुहोस्"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, fuzzy, kde-format
 #| msgid "Provider: %1"
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "प्रदायक: %1"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, fuzzy, kde-format
 #| msgid "Website:"
 msgctxt ""
@@ -836,7 +844,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "वेबसाइट:"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, fuzzy, kde-format
 #| msgid "&Send Email"
 msgctxt ""
@@ -845,7 +853,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "इमेल पठाउनुहोस्"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -853,10 +861,10 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -868,20 +876,20 @@ msgid ""
 "content added."
 msgstr ""
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, fuzzy, kde-format
 #| msgid "Loading Applet"
 msgid "Loading data"
 msgstr "एप्लेट लोड गर्दै"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, fuzzy, kde-format
 #| msgid "Install"
 msgid "Installing"
 msgstr "स्थापना गर्नुहोस्"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -891,7 +899,7 @@ msgid ""
 "please contact the person in charge of your permissions."
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Back"
@@ -899,27 +907,27 @@ msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "पछाडि"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, fuzzy, kde-format
 #| msgid "Saturday"
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "शनिबार"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, fuzzy, kde-format
 #| msgid "Restart"
 msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "फेरि सुरु गर्नुहोस्"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "New"
@@ -927,7 +935,7 @@ msgctxt "Knewstuff5"
 msgid "New"
 msgstr "नयाँ"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Home"
@@ -935,13 +943,13 @@ msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Home"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Up"
@@ -949,7 +957,7 @@ msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "माथि"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, fuzzy, kde-format
 #| msgctxt "dictionary variant"
 #| msgid "extended"
@@ -957,21 +965,21 @@ msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "विस्तारित"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, fuzzy, kde-format
 #| msgid "Subscribe"
 msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "सदस्यता लिनुहोस्"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, fuzzy, kde-format
 #| msgid "&Show All Entries"
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "सबै प्रविष्टि देखाउनुहोस्"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -1004,10 +1012,16 @@ msgstr ""
 #: widgets/action.cpp:28 widgets/button.cpp:70
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
-msgid "Download New Stuff..."
+msgctxt "@action"
+msgid "Download New Stuff…"
 msgstr "नयाँ स्टफ डाउनलोड गर्नुहोस्"
 
 #, fuzzy
+#~| msgid "Download New Stuff"
+#~ msgid "Download New Stuff..."
+#~ msgstr "नयाँ स्टफ डाउनलोड गर्नुहोस्"
+
+#, fuzzy
 #~| msgid "Install"
 #~ msgid "Initializing"
 #~ msgstr "स्थापना गर्नुहोस्"
diff -pruN 6.0.0-3/po/nl/knewstuff6.po 6.3.0-1/po/nl/knewstuff6.po
--- 6.0.0-3/po/nl/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/nl/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -18,8 +18,8 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
-"PO-Revision-Date: 2024-01-19 11:12+0100\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
+"PO-Revision-Date: 2024-05-08 10:48+0200\n"
 "Last-Translator: Freek de Kruijf <freekdekruijf@kde.nl>\n"
 "Language-Team: \n"
 "Language: nl\n"
@@ -28,7 +28,7 @@ msgstr ""
 "Content-Transfer-Encoding: 8bit\n"
 "Files: kfarch.cpp kfdird.cpp kfind.cpp kfindtop.cpp kfoptions.cpp kfsave.cpp "
 "kftabdlg.cpp kftypes.cpp kfwin.cpp main.cpp mkfdird.cpp mkfind.cpp\n"
-"X-Generator: Lokalize 23.08.4\n"
+"X-Generator: Lokalize 24.02.2\n"
 "Plural-Forms: nplurals=2; plural=n != 1;\n"
 
 #: attica/atticaprovider.cpp:165
@@ -69,7 +69,7 @@ msgstr "Uw uitgebrachte stem is opgeslag
 msgid "You are now a fan."
 msgstr "U bent nu een fan."
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -140,7 +140,7 @@ msgstr "Configuratiebestand is ongeldig:
 msgid "Use"
 msgstr "Gebruik"
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -152,18 +152,18 @@ msgstr ""
 "Dit is een kritieke fout en zou gerapporteerd moeten worden aan de auteur "
 "van de toepassing"
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr "Laden van leveranciers uit bestand: %1 is mislukt"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr ""
 "Kon de leveranciers van \"Vers van de pers\" niet laden uit bestand: %1"
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr "Fout bij het initialiseren van leverancier."
@@ -339,7 +339,7 @@ msgstr ""
 "Het is mislukt om een goede koppeling voor bijwerken van %1 te identificeren "
 "en zijn niet in staat om het bijwerken uit te voeren"
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, kde-format
 msgid ""
 "Failed to adopt '%1'\n"
@@ -348,14 +348,14 @@ msgstr ""
 "Aanpassen van '%1' is mislukt\n"
 "%2"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, kde-format
 msgctxt ""
 "The first entry in the category selection list (also the default value)"
 msgid "All Categories"
 msgstr "Alle categorieën"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, kde-format
 msgctxt ""
 "The string passed back in the case the requested category is not known"
@@ -379,13 +379,13 @@ msgstr "Zaken"
 msgid "Download New %1…"
 msgstr "Nieuwe %1 downloaden…"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, kde-format
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "Nieuwe %1 downloaden"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, kde-format
 msgctxt ""
 "A placeholder title used in the dialog when there is no better title "
@@ -393,12 +393,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "Nieuwe zaken downloaden"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr "Kies uw installatieoptie"
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -411,19 +411,19 @@ msgstr ""
 "beschikbare opties, neem dan contact op met de auteur van dit item en vraag "
 "om verheldering hiervan via de naam van de items."
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "Installeren"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, kde-format
 msgctxt ""
 "A passive notification shown when installation of an item is initiated"
 msgid "Installing %1 from %2"
 msgstr "Installeren van %1 uit %2"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -431,10 +431,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr "%1 door %2"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, kde-format
 msgctxt ""
 "Request installation of this item, available when there is exactly one "
@@ -442,32 +442,32 @@ msgctxt ""
 msgid "Install"
 msgstr "Installeren"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, kde-format
 msgctxt ""
 "Show installation options, where there is more than one downloadable item"
 msgid "Install…"
 msgstr "Installeren…"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, kde-format
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "Bijwerken"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, kde-format
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "Deïnstalleren"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -475,14 +475,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr "Aan het item %1 wordt gewerkt door %2. Een moment geduld…"
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr "Het item %1 wordt nu bijgewerkt door %2. Een moment geduld…"
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -496,12 +496,12 @@ msgstr ""
 "<a href=\"https://bugs.kde.org/enter_bug.cgi?product=frameworks-knewstuff"
 "\">KDE-gemeenschap in een bug-rapport</a>."
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr "Commentaar en recensies:"
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a new sub page with comments (comments "
@@ -509,17 +509,17 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "%1 recensies en commentaar"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, kde-format
 msgid "Rating:"
 msgstr "Waardering:"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, kde-format
 msgid "Homepage:"
 msgstr "Homepagina:"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -528,12 +528,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr "Open de homepagina voor %1"
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr "Hoe doneren:"
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -541,74 +541,85 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr "Zoek uit hoe te doneren aan dit project"
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+"Wees voorzichtig bij benaderen van gebruiker-gemaakte, hier getoonde inhoud, "
+"omdat het uitvoerbare code kan bevatten die niet is getest op veiligheid, "
+"stabiliteit of kwaliteit door KDE of uw distributie"
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
-"De hier beschikbare inhoud is geüpload door gebruikers zoals u en is niet "
-"beoordeeld door uw leverancier op functionaliteit of stabiliteit."
+"Gebruiker-gemaakte, hier getoonde inhoud, is niet getest op functionaliteit "
+"of kwaliteit door KDE of uw distributie."
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, kde-format
 msgid "Tiles"
 msgstr "Stenen"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "Pictogrammen"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, kde-format
 msgid "Preview"
 msgstr "Voorbeeld"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, kde-format
 msgid "Detailed Tiles View Mode"
 msgstr "Detailweergavemodus van stenen"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, kde-format
 msgid "Icons Only View Mode"
 msgstr "Modus alleen pictogramweergave"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, kde-format
 msgid "Large Preview View Mode"
 msgstr "Groot voorbeeld weergavemodus"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr "Alles"
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "Geïnstalleerd"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, kde-format
 msgid "Updateable"
 msgstr "Bij te werken"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, kde-format
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "Alle items tonen"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr "Alleen geïnstalleerde items tonen"
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -616,27 +627,27 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr "Alleen bij te werken items tonen"
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, kde-format
 msgid "Recent"
 msgstr "Recent"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr "Alfabetisch"
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "Waardering"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, kde-format
 msgid "Downloads"
 msgstr "Downloads"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on when items were most "
@@ -644,7 +655,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "Meest recente eerst tonen"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -652,57 +663,57 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr "Alfabetisch op naam sorteren"
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, kde-format
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "Hoogst gewaardeerde eerst tonen"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on number of downloads"
 msgid "Show Most Downloaded First"
 msgstr "Meest gedownloade eerst tonen"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, kde-format
 msgid "Upload…"
 msgstr "Uploaden…"
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr "Leren hoe u uw eigen heet van de naald aan deze lijst toevoegt"
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, kde-format
 msgid "Go to…"
 msgstr "Ga naar…"
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, kde-format
 msgid "Search…"
 msgstr "Zoeken…"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "Categorie:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, kde-format
 msgid "Contribute your own…"
 msgstr "Bijdragen van uzelf…"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, kde-format
 msgctxt ""
 "Placeholder title for when a comment has no subject, but does have a rating"
 msgid "<i>(no title)</i>"
 msgstr "<i>(geen titel)</i>"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -710,19 +721,19 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr "%1 <i>(auteur)</i>"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr "Commentaar en recensies voor %1"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, kde-format
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "Alle commentaar tonen"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -730,7 +741,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr "Alleen recensies tonen"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -738,15 +749,15 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr "Recenseren en antwoorden tonen"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, kde-format
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
 msgstr "%1 downloads"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, kde-format
 msgctxt ""
 "Subheading for the tile view, located immediately underneath the name of the "
@@ -754,7 +765,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "Door <i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -762,7 +773,7 @@ msgctxt ""
 msgid "Working…"
 msgstr "Er wordt gewerkt…"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is in the process of being "
@@ -770,7 +781,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "Bezig met bijwerken…"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -784,7 +795,7 @@ msgstr ""
 "product=frameworks-knewstuff\">Rapporteer dit aan de KDE-gemeenschap in een "
 "bugrapport</a>."
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, kde-format
 msgctxt "Label for the busy indicator showing an item is installing"
 msgid "Installing…"
@@ -801,44 +812,44 @@ msgstr "Er is een fout opgetreden"
 msgid "Please try again later."
 msgstr "Probeer het later nog eens."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, kde-format
 msgid "None"
 msgstr "Geen"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, kde-format
 msgctxt ""
 "A text representation of the rating, shown as a fraction of the max value"
 msgid "(%1/%2)"
 msgstr "(%1/%2)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, kde-format
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "Nieuwe zaken uploaden: %1"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, kde-format
 msgctxt ""
 "A text shown beside a busy indicator suggesting that data is being fetched"
 msgid "Updating information…"
 msgstr "Informatie wordt bijgewerkt…"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, kde-format
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "KDE Store"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, kde-format
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "Uw leverancier"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, kde-format
 msgctxt ""
 "Text for an action which causes the specified website to be opened using the "
@@ -846,7 +857,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "Website openen: %1"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, kde-format
 msgctxt ""
 "Text for an action which will attempt to send an email using the user's "
@@ -854,7 +865,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "E-mail verzenden naar: %1"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -862,7 +873,7 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 "Om nieuwe items te uploaden of inhoud toe te voegen aan een bestaand item in "
 "de KDE Store, open de website en meld u aan. Hierna zult u in staat zijn om "
@@ -870,7 +881,7 @@ msgstr ""
 "gebruikerspictogram klikt. Klik op dit item om naar het productbeheersysteem "
 "te gaan, waar u aan uw producten kunt werken."
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -888,18 +899,18 @@ msgstr ""
 "voegen. Als alternatief zou u gevraagd kunnen worden direct contact op te "
 "nemen met de beheerders van de site om nieuwe inhoud toe te voegen."
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "Gegevens laden"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "Installeren"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -911,73 +922,73 @@ msgstr ""
 "U bent niet geautoriseerd om Hot New Stuff. If you think this is in error, "
 "please contact the person in charge of your permissions."
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "Terug"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr "Populair"
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "Ondersteund"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "Herstarten"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "New"
 msgstr "Nieuw"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Home"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr "Shelf"
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "Omhoog"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "Aanbevolen"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "Inschrijvingen"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "Alle items:"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -1023,8 +1034,12 @@ msgstr ""
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
 #, kde-format
-msgid "Download New Stuff..."
-msgstr "Nieuwe zaken downloaden..."
+msgctxt "@action"
+msgid "Download New Stuff…"
+msgstr "Nieuwe zaken downloaden…"
+
+#~ msgid "Download New Stuff..."
+#~ msgstr "Nieuwe zaken downloaden..."
 
 #~ msgctxt ""
 #~ "A message which is shown when the user attempts to display a specific "
diff -pruN 6.0.0-3/po/nn/knewstuff6.po 6.3.0-1/po/nn/knewstuff6.po
--- 6.0.0-3/po/nn/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/nn/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -9,7 +9,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2023-07-30 21:57+0200\n"
 "Last-Translator: Karl Ove Hufthammer <karl@huftis.org>\n"
 "Language-Team: Norwegian Nynorsk <l10n-no@lister.huftis.org>\n"
@@ -61,7 +61,7 @@ msgstr "Stemmen din er registrert."
 msgid "You are now a fan."
 msgstr "Du er no ein tilhengjar."
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -129,7 +129,7 @@ msgstr "Oppsettfila er ugyldig: «%1»"
 msgid "Use"
 msgstr "Bruk"
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -141,17 +141,17 @@ msgstr ""
 "Dette er ein kritisk feil, som du bør melda frå om til utviklaren av "
 "programmet."
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr "Klarte ikkje henta leverandørinfo frå fila: %1 mislukka"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr "Klarte ikkje henta nye godsaker frå fila: %1"
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr "Feil ved klargjering av leverandør."
@@ -322,7 +322,7 @@ msgstr ""
 "Fann ikkje ei fungerande lenkje for oppdatering av %1, og kan derfor ikkje "
 "utføra oppdateringa."
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, kde-format
 msgid ""
 "Failed to adopt '%1'\n"
@@ -331,14 +331,14 @@ msgstr ""
 "Klarte ikkje ta i bruk «%1»\n"
 "%2"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, kde-format
 msgctxt ""
 "The first entry in the category selection list (also the default value)"
 msgid "All Categories"
 msgstr "Alle kategoriar"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, kde-format
 msgctxt ""
 "The string passed back in the case the requested category is not known"
@@ -363,13 +363,13 @@ msgstr "ting"
 msgid "Download New %1…"
 msgstr "Last ned nye %1 …"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, kde-format
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "Last ned nye %1"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, kde-format
 msgctxt ""
 "A placeholder title used in the dialog when there is no better title "
@@ -377,12 +377,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "Last ned nye ting"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr "Installasjonsval"
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -394,19 +394,19 @@ msgstr ""
 "klart kven av dei du bør velja, ta kontakt med opphavspersonen og be hen "
 "endra namna slik at dette vert klarare."
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "Installer"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, kde-format
 msgctxt ""
 "A passive notification shown when installation of an item is initiated"
 msgid "Installing %1 from %2"
 msgstr "Installerer %1 frå %2"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -414,10 +414,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr "%1 av %2"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, kde-format
 msgctxt ""
 "Request installation of this item, available when there is exactly one "
@@ -425,32 +425,32 @@ msgctxt ""
 msgid "Install"
 msgstr "Installer"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, kde-format
 msgctxt ""
 "Show installation options, where there is more than one downloadable item"
 msgid "Install…"
 msgstr "Installerer …"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, kde-format
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "Oppdater"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, kde-format
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "Avinstaller"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -458,14 +458,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr "Arbeider på elementet %1 av %2. Vent litt …"
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr "Oppdaterer %1 av %2. Vent litt …"
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -479,12 +479,12 @@ msgstr ""
 "org/enter_bug.cgi?product=frameworks-knewstuff\">Meld dette inn som ein "
 "feilrapport til KDE-fellesskapet</a>."
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr "Kommentarar og vurderingar:"
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a new sub page with comments (comments "
@@ -492,17 +492,17 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "%1 vurderingar og kommentarar"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, kde-format
 msgid "Rating:"
 msgstr "Karakter:"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, kde-format
 msgid "Homepage:"
 msgstr "Heimeside:"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -511,12 +511,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr "Opna heimesida til %1"
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr "Korleis gje pengegåver:"
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -524,75 +524,86 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr "Les om korleis du kan gje ei pengegåve til prosjektet"
 
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
 # Sjå tilsvarande tekst i «plasma-welcome.po».
-#: qtquick/qml/Page.qml:141
-#, kde-format
+#: qtquick/qml/Page.qml:140
+#, fuzzy, kde-format
+#| msgid ""
+#| "The content available here has been uploaded by users like you, and has "
+#| "not been reviewed by your distributor for functionality or stability."
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 "Alt innhaldet her er lasta opp av andre brukarar. Leverandøren din har ikkje "
 "kvalitets­sikra at det verkar skikkeleg eller stabilt."
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, kde-format
 msgid "Tiles"
 msgstr "Fliser"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "Ikon"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, kde-format
 msgid "Preview"
 msgstr "Førehandsvising"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, kde-format
 msgid "Detailed Tiles View Mode"
 msgstr "Flisvisings­modus"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, kde-format
 msgid "Icons Only View Mode"
 msgstr "Ikonmodus"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, kde-format
 msgid "Large Preview View Mode"
 msgstr "Førehandsvisings­modus"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr "Alt"
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "Installert"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, kde-format
 msgid "Updateable"
 msgstr "Oppdaterbare"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, kde-format
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "Vis alle oppføringar"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr "Vis berre installerte oppføringar"
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -600,27 +611,27 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr "Vis berre oppdaterbare oppføringar"
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, kde-format
 msgid "Recent"
 msgstr "Nylege"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr "Alfabetisk"
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "Karakter"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, kde-format
 msgid "Downloads"
 msgstr "Nedlastingar"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on when items were most "
@@ -628,7 +639,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "Nyaste først"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -636,57 +647,57 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr "Sorter alfabetisk etter namn"
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, kde-format
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "Høgaste karakter først"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on number of downloads"
 msgid "Show Most Downloaded First"
 msgstr "Mest nedlasta først"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, kde-format
 msgid "Upload…"
 msgstr "Last opp …"
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr "Les om korleis du kan bidra med kule, nye ting til lista"
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, kde-format
 msgid "Go to…"
 msgstr "Gå til …"
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, kde-format
 msgid "Search…"
 msgstr "Søk …"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "Kategori:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, kde-format
 msgid "Contribute your own…"
 msgstr "Bidra med noko sjølv …"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, kde-format
 msgctxt ""
 "Placeholder title for when a comment has no subject, but does have a rating"
 msgid "<i>(no title)</i>"
 msgstr "<i>(namnlaus)</i>"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -694,19 +705,19 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr "%1 <i>(opphavsperson)</i>"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr "Kommentarar og vurderingar for %1"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, kde-format
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "Vis alle kommentarane"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -714,7 +725,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr "Vis berre vurderingar"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -722,15 +733,15 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr "Vis vurderingar og svar"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, kde-format
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
 msgstr "%1 nedlastingar"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, kde-format
 msgctxt ""
 "Subheading for the tile view, located immediately underneath the name of the "
@@ -738,7 +749,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "Av <i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -746,7 +757,7 @@ msgctxt ""
 msgid "Working…"
 msgstr "Arbeider …"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is in the process of being "
@@ -754,7 +765,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "Oppdaterer …"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -768,7 +779,7 @@ msgstr ""
 "product=frameworks-knewstuff\">Meld dette inn som ein feilrapport til KDE-"
 "fellesskapet</a>."
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, kde-format
 msgctxt "Label for the busy indicator showing an item is installing"
 msgid "Installing…"
@@ -785,44 +796,44 @@ msgstr "Det oppstod ein feil"
 msgid "Please try again later."
 msgstr "Prøv på nytt seinare."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, kde-format
 msgid "None"
 msgstr "Ingen"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, kde-format
 msgctxt ""
 "A text representation of the rating, shown as a fraction of the max value"
 msgid "(%1/%2)"
 msgstr "(%1/%2)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, kde-format
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "Last opp nye ting: %1"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, kde-format
 msgctxt ""
 "A text shown beside a busy indicator suggesting that data is being fetched"
 msgid "Updating information…"
 msgstr "Oppdaterer informasjon …"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, kde-format
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "KDE-nettbutikken"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, kde-format
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "Leverandør:"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, kde-format
 msgctxt ""
 "Text for an action which causes the specified website to be opened using the "
@@ -830,7 +841,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "Opna heime­side: %1"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, kde-format
 msgctxt ""
 "Text for an action which will attempt to send an email using the user's "
@@ -838,21 +849,28 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "Send e-post til: %1"
 
-#: qtquick/qml/UploadPage.qml:154
-#, kde-format
+#: qtquick/qml/UploadPage.qml:159
+#, fuzzy, kde-format
+#| msgctxt "A description of how to upload content to a generic provider"
+#| msgid ""
+#| "To upload new entries, or to add content to an existing entry on the KDE "
+#| "Store, please open the website and log in. Once you have done this, you "
+#| "will be able to find the My Products entry in the menu which pops up when "
+#| "you click your user icon. Click on this entry to go to the product "
+#| "management system, where you can work on your products ."
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
 "To upload new entries, or to add content to an existing entry on the KDE "
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 "For å lasta opp eller redigera innhald i KDE-butikken kan du opna nettsida "
 "og logga inn. Vel så «My Products» i menyen som dukkar opp når du trykkjer "
 "på ikonet til brukarprofilen din. Du kan så arbeida med produkta dine."
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -868,18 +886,18 @@ msgstr ""
 "du kan leggja til innhald. Det kan òg vera du må kontakta system­ansvarleg på "
 "nettstaden direkte for å få lagt inn nytt innhald."
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "Hentar data"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "Installerer"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -891,73 +909,73 @@ msgstr ""
 "Du har ikkje godkjenning til å henta kule, nye ting. Viss du meiner dette er "
 "feil, ta kontakt med personen ansvarleg for godkjenningane dine."
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "Tilbake"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr "Mest populære"
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "Framheva"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "Start på nytt"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "New"
 msgstr "Nye"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Heim"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr "Hylle"
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "Opp"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "Tilrådd"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "Abonnement"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "Alle oppføringar"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -1014,6 +1032,11 @@ msgstr ""
 "look.org/1316714"
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
-#, kde-format
-msgid "Download New Stuff..."
-msgstr "Last ned nye saker …"
+#, fuzzy, kde-format
+#| msgctxt ""
+#| "A placeholder title used in the dialog when there is no better title "
+#| "available"
+#| msgid "Download New Stuff"
+msgctxt "@action"
+msgid "Download New Stuff…"
+msgstr "Last ned nye ting"
diff -pruN 6.0.0-3/po/oc/knewstuff6.po 6.3.0-1/po/oc/knewstuff6.po
--- 6.0.0-3/po/oc/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/oc/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -7,7 +7,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2008-08-06 00:07+0200\n"
 "Last-Translator: \n"
 "Language-Team: Occitan <oc@li.org>\n"
@@ -53,7 +53,7 @@ msgstr "Cap de tèxt es pas estat rempla
 msgid "You are now a fan."
 msgstr ""
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -121,7 +121,7 @@ msgstr "Fichièrs de configuracion"
 msgid "Use"
 msgstr ""
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -129,17 +129,17 @@ msgid ""
 "This is a critical error and should be reported to the application author"
 msgstr ""
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr ""
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr ""
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr ""
@@ -292,14 +292,14 @@ msgid ""
 "the update"
 msgstr ""
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, kde-format
 msgid ""
 "Failed to adopt '%1'\n"
 "%2"
 msgstr ""
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, fuzzy, kde-format
 #| msgid "Pause"
 msgctxt ""
@@ -307,7 +307,7 @@ msgctxt ""
 msgid "All Categories"
 msgstr "Paginas"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, fuzzy, kde-format
 #| msgid "Unknown error"
 msgctxt ""
@@ -333,14 +333,14 @@ msgstr ""
 msgid "Download New %1…"
 msgstr "Telecargar lo %1 novèl"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, fuzzy, kde-format
 #| msgid "Download New %1"
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "Telecargar lo %1 novèl"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
 msgctxt ""
@@ -349,12 +349,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "Telecargar las novetats"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -363,12 +363,12 @@ msgid ""
 "this through the naming of the items."
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "Installar"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -376,7 +376,7 @@ msgctxt ""
 msgid "Installing %1 from %2"
 msgstr "Installar"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -384,10 +384,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -396,10 +396,10 @@ msgctxt ""
 msgid "Install"
 msgstr "Installar"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -407,24 +407,24 @@ msgctxt ""
 msgid "Install…"
 msgstr "Installar"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, fuzzy, kde-format
 #| msgid "Update"
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "Actualizar"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, fuzzy, kde-format
 #| msgid "Uninstall"
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "Desinstallar"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -432,14 +432,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -450,12 +450,12 @@ msgid ""
 "to the KDE Community in a bug report</a>."
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, fuzzy, kde-format
 #| msgid "Comments"
 msgctxt ""
@@ -464,19 +464,19 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "Comentaris"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, fuzzy, kde-format
 #| msgid "Launching %1"
 msgid "Rating:"
 msgstr "Aviada de %1"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, fuzzy, kde-format
 #| msgid "Homepage"
 msgid "Homepage:"
 msgstr "Pagina Web"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -485,12 +485,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -498,79 +498,87 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr ""
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, fuzzy, kde-format
 #| msgid "File"
 msgid "Tiles"
 msgstr "Fichièr"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "Icònas"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, fuzzy, kde-format
 #| msgid "Print Preview"
 msgid "Preview"
 msgstr "Previsualizacion de l'estampatge"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, kde-format
 msgid "Detailed Tiles View Mode"
 msgstr ""
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, fuzzy, kde-format
 #| msgid "Icons Only"
 msgid "Icons Only View Mode"
 msgstr "Sonque icònas"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, fuzzy, kde-format
 #| msgid "Preview URL:"
 msgid "Large Preview View Mode"
 msgstr "URL de l'apercebut :"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr ""
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, fuzzy, kde-format
 #| msgid "Install"
 msgid "Installed"
 msgstr "Installar"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, fuzzy, kde-format
 #| msgid "Update"
 msgid "Updateable"
 msgstr "Actualizar"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, fuzzy, kde-format
 #| msgid "Pause"
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "Paginas"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -578,30 +586,30 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, fuzzy, kde-format
 #| msgid "Open &Recent"
 msgid "Recent"
 msgstr "Dobert(s) &Recentament"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr ""
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, fuzzy, kde-format
 #| msgid "Launching %1"
 msgid "Rating"
 msgstr "Aviada de %1"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, fuzzy, kde-format
 #| msgid "Download"
 msgid "Downloads"
 msgstr "Telecargar"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, fuzzy, kde-format
 #| msgid "Most Downloads"
 msgctxt ""
@@ -610,7 +618,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "Los mai telecargats"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -618,14 +626,14 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr ""
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, fuzzy, kde-format
 #| msgid "Highest Rated"
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "Los mièlhs notats"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, fuzzy, kde-format
 #| msgid "Most Downloads"
 msgctxt ""
@@ -633,49 +641,49 @@ msgctxt ""
 msgid "Show Most Downloaded First"
 msgstr "Los mai telecargats"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, fuzzy, kde-format
 #| msgid "&Replace..."
 msgid "Upload…"
 msgstr "&Remplaçar..."
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr ""
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, fuzzy, kde-format
 #| msgid "&Go To..."
 msgid "Go to…"
 msgstr "&Anar a..."
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, fuzzy, kde-format
 #| msgid "S&earch:"
 msgid "Search…"
 msgstr "R&ecercar :"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, fuzzy, kde-format
 #| msgid "Pause"
 msgid "Category:"
 msgstr "Paginas"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, fuzzy, kde-format
 #| msgid "Continue operation"
 msgid "Contribute your own…"
 msgstr "Perseguir l'operacion"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, kde-format
 msgctxt ""
 "Placeholder title for when a comment has no subject, but does have a rating"
 msgid "<i>(no title)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -683,20 +691,20 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, fuzzy, kde-format
 #| msgid "Pause"
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "Paginas"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -704,7 +712,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -712,16 +720,16 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, fuzzy, kde-format
 #| msgid "Download"
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
 msgstr "Telecargar"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, kde-format
 msgctxt ""
 "Subheading for the tile view, located immediately underneath the name of the "
@@ -729,7 +737,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -737,7 +745,7 @@ msgctxt ""
 msgid "Working…"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, fuzzy, kde-format
 #| msgid "Update"
 msgctxt ""
@@ -746,7 +754,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "Actualizar"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -757,7 +765,7 @@ msgid ""
 "bug report</a>."
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt "Label for the busy indicator showing an item is installing"
@@ -776,13 +784,13 @@ msgstr ""
 msgid "Please try again later."
 msgstr "Picatz un nom."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, fuzzy, kde-format
 #| msgid "None"
 msgid "None"
 msgstr "Pas cap"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, fuzzy, kde-format
 #| msgid "(%1/s)"
 msgctxt ""
@@ -790,14 +798,14 @@ msgctxt ""
 msgid "(%1/%2)"
 msgstr "(%1/s)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "Telecargar las novetats"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, fuzzy, kde-format
 #| msgid "Information"
 msgctxt ""
@@ -805,21 +813,21 @@ msgctxt ""
 msgid "Updating information…"
 msgstr "Entresenhas"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, fuzzy, kde-format
 #| msgid "Store"
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "Store"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, fuzzy, kde-format
 #| msgid "Services"
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "Servicis"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, fuzzy, kde-format
 #| msgid "&Open with '%1'"
 msgctxt ""
@@ -828,7 +836,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "&Dobrir amb '%1'"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, fuzzy, kde-format
 #| msgid "&Send Email"
 msgctxt ""
@@ -837,7 +845,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "&Mandar lo corrièr electronic"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -845,10 +853,10 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -860,20 +868,20 @@ msgid ""
 "content added."
 msgstr ""
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, fuzzy, kde-format
 #| msgid "Loading Applet"
 msgid "Loading data"
 msgstr "Cargament de l'applet"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, fuzzy, kde-format
 #| msgid "Install"
 msgid "Installing"
 msgstr "Installar"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -883,7 +891,7 @@ msgid ""
 "please contact the person in charge of your permissions."
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Back"
@@ -891,27 +899,27 @@ msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "Precedent"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, fuzzy, kde-format
 #| msgid "Saturday"
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "Dissabte"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, fuzzy, kde-format
 #| msgid "Restart"
 msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "Tornar lançar"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "New"
@@ -919,7 +927,7 @@ msgctxt "Knewstuff5"
 msgid "New"
 msgstr "Novèl"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Home"
@@ -927,13 +935,13 @@ msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Repertòri personal"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Up"
@@ -941,27 +949,27 @@ msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "Amont"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, fuzzy, kde-format
 #| msgid "Subscribe"
 msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "S'inscriure"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, fuzzy, kde-format
 #| msgid "Pause"
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "Paginas"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -994,10 +1002,16 @@ msgstr ""
 #: widgets/action.cpp:28 widgets/button.cpp:70
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
-msgid "Download New Stuff..."
+msgctxt "@action"
+msgid "Download New Stuff…"
 msgstr "Telecargar las novetats"
 
 #, fuzzy
+#~| msgid "Download New Stuff"
+#~ msgid "Download New Stuff..."
+#~ msgstr "Telecargar las novetats"
+
+#, fuzzy
 #~| msgid "Install"
 #~ msgid "Initializing"
 #~ msgstr "Installar"
diff -pruN 6.0.0-3/po/or/knewstuff6.po 6.3.0-1/po/or/knewstuff6.po
--- 6.0.0-3/po/or/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/or/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -8,7 +8,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2009-01-02 17:37+0530\n"
 "Last-Translator: Manoj Kumar Giri <mgiri@redhat.com>\n"
 "Language-Team: Oriya <oriya-it@googlegroups.com>\n"
@@ -58,7 +58,7 @@ msgstr "କୌଣସି ପାଠ୍ୟ
 msgid "You are now a fan."
 msgstr ""
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -126,7 +126,7 @@ msgstr "ବିନ୍ୟାସ ଫାଇ
 msgid "Use"
 msgstr ""
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -134,17 +134,17 @@ msgid ""
 "This is a critical error and should be reported to the application author"
 msgstr ""
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr ""
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr ""
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr ""
@@ -290,7 +290,7 @@ msgid ""
 "the update"
 msgstr ""
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, fuzzy, kde-format
 #| msgid "Failed to load file '%1'"
 msgid ""
@@ -298,7 +298,7 @@ msgid ""
 "%2"
 msgstr "ଫାଇଲ '%1'କୁ ଆରହୋଣ କରିବାରେ ବିଫଳ ହେଲା"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, fuzzy, kde-format
 #| msgid "Pages"
 msgctxt ""
@@ -306,7 +306,7 @@ msgctxt ""
 msgid "All Categories"
 msgstr "ପୃଷ୍ଠାଗୁଡିକ"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, fuzzy, kde-format
 #| msgid "Unknown error"
 msgctxt ""
@@ -332,14 +332,14 @@ msgstr ""
 msgid "Download New %1…"
 msgstr "ନୂତନ %1 ଆହରଣ କରନ୍ତୁ"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, fuzzy, kde-format
 #| msgid "Download New %1"
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "ନୂତନ %1 ଆହରଣ କରନ୍ତୁ"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
 msgctxt ""
@@ -348,12 +348,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "ନୁତନ ଉପାଦାନ ଆହରଣ କରନ୍ତୁ"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -362,12 +362,12 @@ msgid ""
 "this through the naming of the items."
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "ସ୍ଥାପନ କରନ୍ତୁ"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -375,7 +375,7 @@ msgctxt ""
 msgid "Installing %1 from %2"
 msgstr "ସ୍ଥାପନ କରନ୍ତୁ"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -383,10 +383,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -395,10 +395,10 @@ msgctxt ""
 msgid "Install"
 msgstr "ସ୍ଥାପନ କରନ୍ତୁ"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -406,24 +406,24 @@ msgctxt ""
 msgid "Install…"
 msgstr "ସ୍ଥାପନ କରନ୍ତୁ"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, fuzzy, kde-format
 #| msgid "Update"
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "ଅଦ୍ୟତନ"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, fuzzy, kde-format
 #| msgid "Uninstall"
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "ଅପସାରଣ କରନ୍ତୁ"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -431,14 +431,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -449,12 +449,12 @@ msgid ""
 "to the KDE Community in a bug report</a>."
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, fuzzy, kde-format
 #| msgid "View Comments"
 msgctxt ""
@@ -463,19 +463,19 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "ଟୀପ୍ପଣୀଗୁଡିକୁ ଦେଖନ୍ତୁ"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, fuzzy, kde-format
 #| msgid "Rating: "
 msgid "Rating:"
 msgstr "ଆକଳନ: "
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, fuzzy, kde-format
 #| msgid "Homepage"
 msgid "Homepage:"
 msgstr "ମୂଳସ୍ଥାନ ପୃଷ୍ଠା"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -484,12 +484,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -497,79 +497,87 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr ""
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, fuzzy, kde-format
 #| msgid "File"
 msgid "Tiles"
 msgstr "ଫାଇଲ"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "ଚିତ୍ରସଂକେତ"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, fuzzy, kde-format
 #| msgid "No Preview"
 msgid "Preview"
 msgstr "ପ୍ରାକଦର୍ଶନ ନାହିଁ"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, kde-format
 msgid "Detailed Tiles View Mode"
 msgstr ""
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, fuzzy, kde-format
 #| msgid "Icons Only"
 msgid "Icons Only View Mode"
 msgstr "କେବଳ ଚିତ୍ରସଙ୍କେତ"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, fuzzy, kde-format
 #| msgid "Preview URL:"
 msgid "Large Preview View Mode"
 msgstr "ପ୍ରାକଦର୍ଶନ URL:"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr ""
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, fuzzy, kde-format
 #| msgid "Install"
 msgid "Installed"
 msgstr "ସ୍ଥାପନ କରନ୍ତୁ"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, fuzzy, kde-format
 #| msgid "Update"
 msgid "Updateable"
 msgstr "ଅଦ୍ୟତନ"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, fuzzy, kde-format
 #| msgid "Pages"
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "ପୃଷ୍ଠାଗୁଡିକ"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -577,30 +585,30 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, fuzzy, kde-format
 #| msgid "Open &Recent"
 msgid "Recent"
 msgstr "ସାମ୍ପ୍ରତିକକୁ ଖୋଲନ୍ତୁ (&R)"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr ""
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, fuzzy, kde-format
 #| msgid "Rating: "
 msgid "Rating"
 msgstr "ଆକଳନ: "
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, fuzzy, kde-format
 #| msgid "Download"
 msgid "Downloads"
 msgstr "ଆହରଣ"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt ""
@@ -609,7 +617,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "ଡିରେକ୍ଟରିଗୁଡିକୁ ପ୍ରଥମେ ଦର୍ଶାନ୍ତୁ"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -617,14 +625,14 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr ""
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "ଡିରେକ୍ଟରିଗୁଡିକୁ ପ୍ରଥମେ ଦର୍ଶାନ୍ତୁ"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, fuzzy, kde-format
 #| msgid "Most Downloads"
 msgctxt ""
@@ -632,42 +640,42 @@ msgctxt ""
 msgid "Show Most Downloaded First"
 msgstr "ଅଧିକାଂଶ ଆହରଣଗୁଡିକ"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, fuzzy, kde-format
 #| msgid "&Replace..."
 msgid "Upload…"
 msgstr "ବଦଳାନ୍ତୁ (&R)..."
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr ""
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, fuzzy, kde-format
 #| msgid "&Go To..."
 msgid "Go to…"
 msgstr "କୁ ଯାଆନ୍ତୁ (&G)..."
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, fuzzy, kde-format
 #| msgid "S&earch:"
 msgid "Search…"
 msgstr "ଖୋଜନ୍ତୁ (&e):"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, fuzzy, kde-format
 #| msgid "Character:"
 msgid "Category:"
 msgstr "ଅକ୍ଷର:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, fuzzy, kde-format
 #| msgid "Continue operation"
 msgid "Contribute your own…"
 msgstr "ପ୍ରଚଳନକୁ ଆଗକୁ ବଢାନ୍ତୁ"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, fuzzy, kde-format
 #| msgctxt "@note/rich"
 #| msgid "<i>Note</i>: %1"
@@ -676,7 +684,7 @@ msgctxt ""
 msgid "<i>(no title)</i>"
 msgstr "<i>ଟୀକା</i>: %1"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -684,20 +692,20 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, fuzzy, kde-format
 #| msgid "Pages"
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "ପୃଷ୍ଠାଗୁଡିକ"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -705,7 +713,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -713,16 +721,16 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, fuzzy, kde-format
 #| msgid "Download"
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
 msgstr "ଆହରଣ"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, fuzzy, kde-format
 #| msgctxt "@interface/rich"
 #| msgid "<i>%1</i>"
@@ -732,7 +740,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "<i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -740,7 +748,7 @@ msgctxt ""
 msgid "Working…"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, fuzzy, kde-format
 #| msgid "Update"
 msgctxt ""
@@ -749,7 +757,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "ଅଦ୍ୟତନ"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -760,7 +768,7 @@ msgid ""
 "bug report</a>."
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt "Label for the busy indicator showing an item is installing"
@@ -779,14 +787,14 @@ msgstr ""
 msgid "Please try again later."
 msgstr "ଦୟାକରି ଗୋଟିଏ ନାମରେ ରଖନ୍ତୁ।"
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, fuzzy, kde-format
 #| msgctxt "No border line"
 #| msgid "None"
 msgid "None"
 msgstr "କେହିନୁହଁ"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, fuzzy, kde-format
 #| msgid "(%1/s)"
 msgctxt ""
@@ -794,14 +802,14 @@ msgctxt ""
 msgid "(%1/%2)"
 msgstr "(%1/s)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "ନୁତନ ଉପାଦାନ ଆହରଣ କରନ୍ତୁ"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, fuzzy, kde-format
 #| msgid "Billing Information:"
 msgctxt ""
@@ -809,21 +817,21 @@ msgctxt ""
 msgid "Updating information…"
 msgstr "ବିଲ କରିବାର ସୂଚନା:"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, fuzzy, kde-format
 #| msgid "Store"
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "ଭଣ୍ଡାର"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, fuzzy, kde-format
 #| msgid "Provider: %1"
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "ପ୍ରଦାତା: %1"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, fuzzy, kde-format
 #| msgid "&Open with '%1'"
 msgctxt ""
@@ -832,7 +840,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "'%1' ସହିତ ଖୋଲନ୍ତୁ (&O)..."
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, fuzzy, kde-format
 #| msgid "&Send Email"
 msgctxt ""
@@ -841,7 +849,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "ଇମେଲ ପଠାନ୍ତୁ (&S)"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -849,10 +857,10 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -864,20 +872,20 @@ msgid ""
 "content added."
 msgstr ""
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, fuzzy, kde-format
 #| msgid "Loading Applet"
 msgid "Loading data"
 msgstr "ଆପଲେଟ ଧାରଣ କରାଯାଉଛି"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, fuzzy, kde-format
 #| msgid "Install"
 msgid "Installing"
 msgstr "ସ୍ଥାପନ କରନ୍ତୁ"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -887,7 +895,7 @@ msgid ""
 "please contact the person in charge of your permissions."
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Back"
@@ -895,20 +903,20 @@ msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "ପଛକୁ"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, fuzzy, kde-format
 #| msgid "Saturday"
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "ଶନିବାର"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, fuzzy, kde-format
 #| msgctxt "@action:button Restart find & replace"
 #| msgid "Restart"
@@ -916,7 +924,7 @@ msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "ପୁନଃପ୍ରାରମ୍ଭ କରନ୍ତୁ"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "New"
@@ -924,7 +932,7 @@ msgctxt "Knewstuff5"
 msgid "New"
 msgstr "ନୂତନ"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Home"
@@ -932,13 +940,13 @@ msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "ମୂଳସ୍ଥାନ"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Up"
@@ -946,7 +954,7 @@ msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "ଉପର"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, fuzzy, kde-format
 #| msgctxt "dictionary variant"
 #| msgid "extended"
@@ -954,7 +962,7 @@ msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "ବର୍ଦ୍ଧିତ"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Subscript"
@@ -962,14 +970,14 @@ msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "ପାଦାଙ୍କ"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, fuzzy, kde-format
 #| msgid "Pages"
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "ପୃଷ୍ଠାଗୁଡିକ"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -1002,10 +1010,16 @@ msgstr ""
 #: widgets/action.cpp:28 widgets/button.cpp:70
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
-msgid "Download New Stuff..."
+msgctxt "@action"
+msgid "Download New Stuff…"
 msgstr "ନୁତନ ଉପାଦାନ ଆହରଣ କରନ୍ତୁ"
 
 #, fuzzy
+#~| msgid "Download New Stuff"
+#~ msgid "Download New Stuff..."
+#~ msgstr "ନୁତନ ଉପାଦାନ ଆହରଣ କରନ୍ତୁ"
+
+#, fuzzy
 #~| msgid "Install"
 #~ msgid "Initializing"
 #~ msgstr "ସ୍ଥାପନ କରନ୍ତୁ"
diff -pruN 6.0.0-3/po/pa/knewstuff6.po 6.3.0-1/po/pa/knewstuff6.po
--- 6.0.0-3/po/pa/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/pa/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -13,7 +13,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2024-01-03 14:00-0600\n"
 "Last-Translator: A S Alam <aalam@punlinux.org>\n"
 "Language-Team: Punjabi <kde-i18n-doc@kde.org>\n"
@@ -63,7 +63,7 @@ msgstr "ਤੁਹਾਡੀ ਵੋਟ ਭ
 msgid "You are now a fan."
 msgstr "ਹੁਣ ਤੁਸੀਂ ਸ਼ੌਕੀਨ ਹੋ।"
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -131,7 +131,7 @@ msgstr "ਸੰਰਚਨਾ ਫਾਇਲ
 msgid "Use"
 msgstr ""
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -139,17 +139,17 @@ msgid ""
 "This is a critical error and should be reported to the application author"
 msgstr ""
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr "ਫਾਇਲ ਤੋਂ ਪਰੋਵਾਇਡਰ ਲੋਡ ਕੀਤੇ ਜਾ ਰਹੇ ਹਨ: %1 ਫੇਲ੍ਹ"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr "ਫਾਇਲ ਤੋਂ ਨਵਾਂ ਮੇਲ ਦੇਣ ਵਾਲੇ ਪਰੋਵਾਇਡਰ ਲੋਡ ਨਹੀਂ ਕੀਤੇ ਜਾ ਸਕੇ: %1"
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr "ਪ੍ਰੋਵਾਇਡਰ ਸ਼ੁਰੂ ਕਰਨ ਵਿੱਚ ਗਲਤੀ ਹੈ।"
@@ -294,7 +294,7 @@ msgid ""
 "the update"
 msgstr ""
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, fuzzy, kde-format
 #| msgid "Failed to load file '%1'"
 msgid ""
@@ -302,7 +302,7 @@ msgid ""
 "%2"
 msgstr "ਫਾਇਲ '%1' ਲੋਡ ਕਰਨ ਲਈ ਫੇਲ੍ਹ"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt ""
@@ -310,7 +310,7 @@ msgctxt ""
 msgid "All Categories"
 msgstr "ਸਭ ਕੈਟਾਗਰੀਆਂ"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, fuzzy, kde-format
 #| msgid "Unknown error"
 msgctxt ""
@@ -336,14 +336,14 @@ msgstr ""
 msgid "Download New %1…"
 msgstr "ਨਵਾਂ %1 ਡਾਊਨਲੋਡ"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, fuzzy, kde-format
 #| msgid "Download New %1"
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "ਨਵਾਂ %1 ਡਾਊਨਲੋਡ"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
 msgctxt ""
@@ -352,12 +352,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "ਨਵਾਂ ਮਾਲ ਡਾਊਨਲੋਡ"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -366,12 +366,12 @@ msgid ""
 "this through the naming of the items."
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "ਇੰਸਟਾਲ"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt ""
@@ -379,7 +379,7 @@ msgctxt ""
 msgid "Installing %1 from %2"
 msgstr "ਇੰਸਟਾਲ ਕੀਤਾ ਜਾ ਰਿਹਾ ਹੈ"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -387,10 +387,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -399,10 +399,10 @@ msgctxt ""
 msgid "Install"
 msgstr "ਇੰਸਟਾਲ"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -410,24 +410,24 @@ msgctxt ""
 msgid "Install…"
 msgstr "ਇੰਸਟਾਲ"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, fuzzy, kde-format
 #| msgid "Update"
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "ਅੱਪਡੇਟ"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, fuzzy, kde-format
 #| msgid "Uninstall"
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "ਅਣ-ਇੰਸਟਾਲ"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -435,14 +435,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -453,12 +453,12 @@ msgid ""
 "to the KDE Community in a bug report</a>."
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, fuzzy, kde-format
 #| msgid "View Comments"
 msgctxt ""
@@ -467,19 +467,19 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "ਟਿੱਪਣੀ ਵੇਖੋ"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, fuzzy, kde-format
 #| msgid "Rating: "
 msgid "Rating:"
 msgstr "ਰੇਟਿੰਗ:"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, fuzzy, kde-format
 #| msgid "Homepage"
 msgid "Homepage:"
 msgstr "ਮੁੱਖ ਪੇਜ਼"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -488,12 +488,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -501,80 +501,88 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr ""
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, fuzzy, kde-format
 #| msgctxt "@option:check Do filter on type - show only files"
 #| msgid "Files"
 msgid "Tiles"
 msgstr "ਫਾਇਲਾਂ"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "ਆਈਕਾਨ"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, fuzzy, kde-format
 #| msgid "Previews"
 msgid "Preview"
 msgstr "ਝਲਕ"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, fuzzy, kde-format
 #| msgid "Details view mode"
 msgid "Detailed Tiles View Mode"
 msgstr "ਵੇਰਵਾ ਝਲਕ ਮੋਡ"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, fuzzy, kde-format
 #| msgid "Icons view mode"
 msgid "Icons Only View Mode"
 msgstr "ਆਈਕਾਨ ਝਲਕ ਮੋਡ"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, fuzzy, kde-format
 #| msgid "Details view mode"
 msgid "Large Preview View Mode"
 msgstr "ਵੇਰਵਾ ਝਲਕ ਮੋਡ"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr ""
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "ਇੰਸਟਾਲ ਕੀਤੇ"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, fuzzy, kde-format
 #| msgid "Update"
 msgid "Updateable"
 msgstr "ਅੱਪਡੇਟ"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "ਸਭ ਕੈਟਾਗਰੀਆਂ"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -582,30 +590,30 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Open Recent"
 msgid "Recent"
 msgstr "ਤਾਜ਼ਾ ਖੋਲ੍ਹੇ"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr ""
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "ਰੇਟਿੰਗ"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, fuzzy, kde-format
 #| msgid "Download"
 msgid "Downloads"
 msgstr "ਡਾਊਨਲੋਡ"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt ""
@@ -614,7 +622,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "ਡਾਇਰੈਕਟਰੀਆਂ ਪਹਿਲਾਂ ਵੇਖੋ"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -622,14 +630,14 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr ""
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "ਡਾਇਰੈਕਟਰੀਆਂ ਪਹਿਲਾਂ ਵੇਖੋ"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, fuzzy, kde-format
 #| msgid "Most downloads"
 msgctxt ""
@@ -637,41 +645,41 @@ msgctxt ""
 msgid "Show Most Downloaded First"
 msgstr "ਸਭ ਤੋਂ ਵੱਧ ਡਾਊਨਲੋਡ"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, fuzzy, kde-format
 #| msgid "Upload..."
 msgid "Upload…"
 msgstr "ਅੱਪਲੋਡ..."
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr ""
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, fuzzy, kde-format
 #| msgid "&Go To..."
 msgid "Go to…"
 msgstr "ਜਾਓ(&G)..."
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, fuzzy, kde-format
 #| msgid "Search:"
 msgid "Search…"
 msgstr "ਖੋਜ:"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "ਕੈਟਾਗਰੀ:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, fuzzy, kde-format
 #| msgid "Continue operation"
 msgid "Contribute your own…"
 msgstr "ਓਪਰੇਸ਼ਨ ਜਾਰੀ ਰੱਖੋ"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, fuzzy, kde-format
 #| msgctxt "@note/rich"
 #| msgid "<i>Note</i>: %1"
@@ -680,7 +688,7 @@ msgctxt ""
 msgid "<i>(no title)</i>"
 msgstr "<i>ਨੋਟ</i>: %1"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -688,20 +696,20 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "ਸਭ ਕੈਟਾਗਰੀਆਂ"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -709,7 +717,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -717,8 +725,8 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, fuzzy, kde-format
 #| msgid "1 download"
 #| msgid_plural "%1 downloads"
@@ -726,8 +734,8 @@ msgctxt "The number of times the item ha
 msgid "%1 downloads"
 msgstr "੧ ਡਾਊਨਲੋਡ"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, fuzzy, kde-format
 #| msgctxt "Show the author of this item in a list"
 #| msgid "By <i>%1</i>"
@@ -737,7 +745,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "<i>%1</i> ਵਲੋਂ"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -745,7 +753,7 @@ msgctxt ""
 msgid "Working…"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, fuzzy, kde-format
 #| msgid "Updating"
 msgctxt ""
@@ -754,7 +762,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "ਅੱਪਡੇਟ ਜਾਰੀ"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -765,7 +773,7 @@ msgid ""
 "bug report</a>."
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt "Label for the busy indicator showing an item is installing"
@@ -784,14 +792,14 @@ msgstr ""
 msgid "Please try again later."
 msgstr "ਨਾਂ ਵਿੱਚ ਲਿਖੋ ਜੀ।"
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, fuzzy, kde-format
 #| msgctxt "No border line"
 #| msgid "None"
 msgid "None"
 msgstr "ਕੋਈ ਨਹੀਂ"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, fuzzy, kde-format
 #| msgid "(%1/s)"
 msgctxt ""
@@ -799,14 +807,14 @@ msgctxt ""
 msgid "(%1/%2)"
 msgstr "(%1/s)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "ਨਵਾਂ ਮਾਲ ਡਾਊਨਲੋਡ"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, fuzzy, kde-format
 #| msgid "Billing information:"
 msgctxt ""
@@ -814,21 +822,21 @@ msgctxt ""
 msgid "Updating information…"
 msgstr "ਬਿੱਲ ਜਾਣਕਾਰੀ:"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, fuzzy, kde-format
 #| msgid "&Store"
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "ਸੰਭਾਲੋ(&S)"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, fuzzy, kde-format
 #| msgid "Provider:"
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "ਪਰੋਵਾਈਡਰ:"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, fuzzy, kde-format
 #| msgctxt "@label:button"
 #| msgid "&Open with %1"
@@ -838,7 +846,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "%1 ਨਾਲ ਖੋਲ੍ਹੋ(&O)"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, fuzzy, kde-format
 #| msgid "&Send Email"
 msgctxt ""
@@ -847,7 +855,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "ਈ-ਮੇਲ ਭੇਜੋ(&S)"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -855,10 +863,10 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -870,18 +878,18 @@ msgid ""
 "content added."
 msgstr ""
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "ਡਾਟਾ ਲੋਡ ਕੀਤਾ ਜਾ ਰਿਹਾ ਹੈ"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "ਇੰਸਟਾਲ ਕੀਤਾ ਜਾ ਰਿਹਾ ਹੈ"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -891,7 +899,7 @@ msgid ""
 "please contact the person in charge of your permissions."
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Back"
@@ -899,20 +907,20 @@ msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "ਪਿੱਛੇ"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, fuzzy, kde-format
 #| msgid "Saturday"
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "ਸ਼ਨਿੱਚਰਵਾਰ"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, fuzzy, kde-format
 #| msgctxt "@action:button Restart find & replace"
 #| msgid "Restart"
@@ -920,7 +928,7 @@ msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "ਮੁੜ ਚਾਲੂ ਕਰੋ"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "New"
@@ -928,7 +936,7 @@ msgctxt "Knewstuff5"
 msgid "New"
 msgstr "ਨਵਾਂ"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Home"
@@ -936,13 +944,13 @@ msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "ਘਰ"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Up"
@@ -950,7 +958,7 @@ msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "ਉੱਤੇ"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, fuzzy, kde-format
 #| msgctxt "dictionary variant"
 #| msgid "extended"
@@ -958,7 +966,7 @@ msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "ਐਕਸਟੈੱਡ"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Subscript"
@@ -966,14 +974,14 @@ msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "ਸਬ-ਸਕ੍ਰਿਪਟ"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "ਸਭ ਕੈਟਾਗਰੀਆਂ"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -1004,9 +1012,14 @@ msgid ""
 msgstr ""
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
-#, kde-format
-msgid "Download New Stuff..."
-msgstr "ਨਵਾਂ ਮਾਲ ਡਾਊਨਲੋਡ..."
+#, fuzzy, kde-format
+#| msgid "Download New Stuff"
+msgctxt "@action"
+msgid "Download New Stuff…"
+msgstr "ਨਵਾਂ ਮਾਲ ਡਾਊਨਲੋਡ"
+
+#~ msgid "Download New Stuff..."
+#~ msgstr "ਨਵਾਂ ਮਾਲ ਡਾਊਨਲੋਡ..."
 
 #~ msgid "Initializing"
 #~ msgstr "ਸ਼ੁਰੂ ਕੀਤਾ ਜਾ ਰਿਹਾ ਹੈ"
diff -pruN 6.0.0-3/po/pl/knewstuff6.po 6.3.0-1/po/pl/knewstuff6.po
--- 6.0.0-3/po/pl/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/pl/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -16,99 +16,14 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
-"PO-Revision-Date: 2024-02-11 13:00+0100\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
+"PO-Revision-Date: 2024-05-12 08:46+0200\n"
 "Last-Translator: Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>\n"
 "Language-Team: Polish <kde-i18n-doc@kde.org>\n"
 "Language: pl\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-">\n"
-"X-Generator: Lokalize 23.08.4\n"
 "Plural-Forms: nplurals=3; plural=(n==1 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 "
 "|| n%100>=20) ? 1 : 2);\n"
 
@@ -150,7 +65,7 @@ msgstr "Twój głos został zapisany."
 msgid "You are now a fan."
 msgstr "Teraz jesteś wielbicielem."
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -218,7 +133,7 @@ msgstr "Nieprawidłowy plik ustawień: \
 msgid "Use"
 msgstr "Użyj"
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -229,17 +144,17 @@ msgstr ""
 "%2\n"
 "To poważny błąd i zalecamy zgłoszenie go autorowi programu"
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr "Wczytywanie dostawców z pliku: %1 nie powiodło się"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr "Nie można pobrać dostawców nowej zawartości z pliku: %1"
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr "Błąd podczas inicjowania dostawcy."
@@ -407,7 +322,7 @@ msgstr ""
 "Nie udało się wybrać dobrego odnośnika uaktualniającego %1, więc nie można "
 "wykonać uaktualnienia"
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, kde-format
 msgid ""
 "Failed to adopt '%1'\n"
@@ -416,14 +331,14 @@ msgstr ""
 "Nie można dostosować '%1'\n"
 "%2"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, kde-format
 msgctxt ""
 "The first entry in the category selection list (also the default value)"
 msgid "All Categories"
 msgstr "Wszystkie kategorie"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, kde-format
 msgctxt ""
 "The string passed back in the case the requested category is not known"
@@ -447,13 +362,13 @@ msgstr "Rzeczy"
 msgid "Download New %1…"
 msgstr "Pobierz nowe %1..."
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, kde-format
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "Pobierz nowe %1"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, kde-format
 msgctxt ""
 "A placeholder title used in the dialog when there is no better title "
@@ -461,12 +376,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "Pobierz nowe rzeczy"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr "Wybierz opcję wgrywania"
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -478,19 +393,19 @@ msgstr ""
 "nie jest jasne, co należy wybrać, to skontaktuj się z autorem tego elementu "
 "i poproś o wyjaśnienie nazewnictwa elementów."
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "Wgraj"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, kde-format
 msgctxt ""
 "A passive notification shown when installation of an item is initiated"
 msgid "Installing %1 from %2"
 msgstr "Wgrywanie %1 z %2"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -498,10 +413,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr "%1 autorstwa %2"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, kde-format
 msgctxt ""
 "Request installation of this item, available when there is exactly one "
@@ -509,32 +424,32 @@ msgctxt ""
 msgid "Install"
 msgstr "Wgraj"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, kde-format
 msgctxt ""
 "Show installation options, where there is more than one downloadable item"
 msgid "Install…"
 msgstr "Wgraj…"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, kde-format
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "Uaktualnij"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, kde-format
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "Usuń"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -542,14 +457,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr "Obecnie pracuję nad rzeczą %1 autorstwa %2. Czekaj…"
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr "Uaktualniany jest element %1 autorstwa %2. Czekaj…"
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -563,12 +478,12 @@ msgstr ""
 "href=\"https://bugs.kde.org/enter_bug.cgi?product=frameworks-knewstuff"
 "\">Zalecane jest zgłoszenie tego Społeczności KDE jako błąd</a>."
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr "Opinie i uwagi:"
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a new sub page with comments (comments "
@@ -576,17 +491,17 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "Liczba opinii i uwag: %1"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, kde-format
 msgid "Rating:"
 msgstr "Ocena:"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, kde-format
 msgid "Homepage:"
 msgstr "Strona domowa:"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -595,12 +510,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr "Otwórz stronę domową dla %1"
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr "Jak wesprzeć pieniężnie:"
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -608,75 +523,85 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr "Dowiedz się jak pieniężnie wesprzeć ten projekt"
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+"Zachowaj ostrożność pobierając stąd treści stworzone przez użytkowników, bo "
+"mogą zawierać kod, który nie został sprawdzony ani przez KDE, ani przez "
+"twojego dystrybutora pod kątem bezpieczeństwa, stabilności, czy jakości"
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
-"Treść dostępna tutaj został wysłana przez użytkowników takich jak ty i nie "
-"została sprawdzona przez dystrybutora pod kątem stabilności, czy zdatności "
-"do użytku."
+"Treści pokazywane tutaj nie zostały sprawdzone ani przez KDE, ani przez "
+"twojego dystrybutora pod kątem funkcjonalności, czy jakości."
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, kde-format
 msgid "Tiles"
 msgstr "Kafelki"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "Ikony"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, kde-format
 msgid "Preview"
 msgstr "Podgląd"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, kde-format
 msgid "Detailed Tiles View Mode"
 msgstr "Tryb widoku szczegółowych kafelków"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, kde-format
 msgid "Icons Only View Mode"
 msgstr "Ikonowy tryb widoku"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, kde-format
 msgid "Large Preview View Mode"
 msgstr "Tryb widoku z dużymi podglądami"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr "Wszystkie"
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "Wgranych"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, kde-format
 msgid "Updateable"
 msgstr "Tylko do uaktualnienia"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, kde-format
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "Pokaż wszystkie rzeczy"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr "Pokaż tylko wgrane rzeczy"
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -684,27 +609,27 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr "Pokaż tylko rzeczy do uaktualnienia"
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, kde-format
 msgid "Recent"
 msgstr "Ostatnie"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr "Alfabetycznie"
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "Ocen"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, kde-format
 msgid "Downloads"
 msgstr "Pobierane"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on when items were most "
@@ -712,7 +637,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "Najpierw pokaż najnowsze"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -720,57 +645,57 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr "Uszereguj alfabetycznie po nazwie"
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, kde-format
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "Najpierw pokaż najwyżej oceniane"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on number of downloads"
 msgid "Show Most Downloaded First"
 msgstr "Najpierw pokaż najczęściej pobierane"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, kde-format
 msgid "Upload…"
 msgstr "Wyślij…"
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr "Naucz się jak dodawać swoje własne rzeczy do tej listy"
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, kde-format
 msgid "Go to…"
 msgstr "Przejdź do…"
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, kde-format
 msgid "Search…"
 msgstr "Poszukaj…"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "Kategoria:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, kde-format
 msgid "Contribute your own…"
 msgstr "Dodaj coś od siebie..."
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, kde-format
 msgctxt ""
 "Placeholder title for when a comment has no subject, but does have a rating"
 msgid "<i>(no title)</i>"
 msgstr "<i>(bez tytułu)</i>"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -778,19 +703,19 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr "%1 <i>(twórca)</i>"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr "Opinie i uwagi do %1"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, kde-format
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "Pokaż wszystkie uwagi"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -798,7 +723,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr "Pokaż tylko opinie"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -806,15 +731,15 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr "Pokaż opinie i odpowiedzi"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, kde-format
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
 msgstr "%1 pobrań"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, kde-format
 msgctxt ""
 "Subheading for the tile view, located immediately underneath the name of the "
@@ -822,7 +747,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "Autorstwa <i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -830,7 +755,7 @@ msgctxt ""
 msgid "Working…"
 msgstr "Pracuję…"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is in the process of being "
@@ -838,7 +763,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "Uaktualnianie…"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -852,7 +777,7 @@ msgstr ""
 "product=frameworks-knewstuff\">Zalecane jest zgłoszenie tego Społeczności "
 "KDE jako błąd</a>."
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, kde-format
 msgctxt "Label for the busy indicator showing an item is installing"
 msgid "Installing…"
@@ -869,44 +794,44 @@ msgstr "Napotkano błąd"
 msgid "Please try again later."
 msgstr "Spróbuj ponownie później."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, kde-format
 msgid "None"
 msgstr "Brak"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, kde-format
 msgctxt ""
 "A text representation of the rating, shown as a fraction of the max value"
 msgid "(%1/%2)"
 msgstr "(%1/%2)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, kde-format
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "Wyślij nową rzecz: %1"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, kde-format
 msgctxt ""
 "A text shown beside a busy indicator suggesting that data is being fetched"
 msgid "Updating information…"
 msgstr "Uaktualnianie danych…"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, kde-format
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "Sklep KDE"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, kde-format
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "Twój dostawca"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, kde-format
 msgctxt ""
 "Text for an action which causes the specified website to be opened using the "
@@ -914,7 +839,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "Otwórz stronę sieciową: %1"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, kde-format
 msgctxt ""
 "Text for an action which will attempt to send an email using the user's "
@@ -922,7 +847,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "Wyślij wiadomość do: %1"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -930,15 +855,15 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 "Aby wysłać nową rzecz lub dodać treść do istniejącej rzeczy w Sklepie KDE, "
 "otwórz stronę sieciową i zaloguj się. Po wykonaniu tego, rzecz Mój Produkt "
-"znajdziesz w menu,  które pojawi się, gdy naciśniesz na ikonie użytkownika. "
+"znajdziesz w menu, które pojawi się, gdy naciśniesz na ikonie użytkownika. "
 "Naciśnij na ten wpis, aby przejść do systemu zarządzania produktem, gdzie "
 "możesz zacząć pracować nad swoimi produktami."
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -956,18 +881,18 @@ msgstr ""
 "dodawać. W pewnych przypadkach będziesz musiał napisać do zarządców systemu, "
 "aby dodali oni twoją nową treść."
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "Wczytywanie danych"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "Wgrywanie"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -979,73 +904,73 @@ msgstr ""
 "Odmówiono uprawnień do pobierania z Get Hot New Stuff. Jeśli uważasz, że to "
 "błąd, to skontaktuj się z osobą przyznającą ci uprawnienia."
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "Wstecz"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr "Popularny"
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "Wyróżnione"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "Uruchom ponownie"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "New"
 msgstr "Nowy"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Dom"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr "Shelf"
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "W górę"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "Zalecane"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "Subskrypcje"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "Wszystkie wpisy"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -1092,8 +1017,12 @@ msgstr ""
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
 #, kde-format
-msgid "Download New Stuff..."
-msgstr "Pobierz nowe rzeczy..."
+msgctxt "@action"
+msgid "Download New Stuff…"
+msgstr "Pobierz nowe rzeczy…"
+
+#~ msgid "Download New Stuff..."
+#~ msgstr "Pobierz nowe rzeczy..."
 
 #~ msgctxt ""
 #~ "A message which is shown when the user attempts to display a specific "
diff -pruN 6.0.0-3/po/ps/knewstuff6.po 6.3.0-1/po/ps/knewstuff6.po
--- 6.0.0-3/po/ps/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/ps/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -7,7 +7,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2008-08-16 16:01-0800\n"
 "Last-Translator: Zabeeh Khan <zabeehkhan@gmail.com>\n"
 "Language-Team: Pashto <pathanisation@googlegroups.com>\n"
@@ -54,7 +54,7 @@ msgstr "کومه ليکنه ونه ځا
 msgid "You are now a fan."
 msgstr ""
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -123,7 +123,7 @@ msgstr "د سازونې دوتنې"
 msgid "Use"
 msgstr ""
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -131,17 +131,17 @@ msgid ""
 "This is a critical error and should be reported to the application author"
 msgstr ""
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr ""
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr ""
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr ""
@@ -288,7 +288,7 @@ msgid ""
 "the update"
 msgstr ""
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, fuzzy, kde-format
 #| msgid "Failed to load file '%1'"
 msgid ""
@@ -296,7 +296,7 @@ msgid ""
 "%2"
 msgstr "دوتنې لېښلو کې پاتې راغی '%1'"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, fuzzy, kde-format
 #| msgid "Pages"
 msgctxt ""
@@ -304,7 +304,7 @@ msgctxt ""
 msgid "All Categories"
 msgstr "مخونه"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, fuzzy, kde-format
 #| msgid "Unknown error"
 msgctxt ""
@@ -330,14 +330,14 @@ msgstr ""
 msgid "Download New %1…"
 msgstr "رالېښل %1 نوی"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, fuzzy, kde-format
 #| msgid "Download New %1"
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "رالېښل %1 نوی"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
 msgctxt ""
@@ -346,12 +346,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "نوي څيزونه رالېښل"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -360,12 +360,12 @@ msgid ""
 "this through the naming of the items."
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "لګول"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -373,7 +373,7 @@ msgctxt ""
 msgid "Installing %1 from %2"
 msgstr "لګول"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -381,10 +381,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -393,10 +393,10 @@ msgctxt ""
 msgid "Install"
 msgstr "لګول"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -404,24 +404,24 @@ msgctxt ""
 msgid "Install…"
 msgstr "لګول"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, fuzzy, kde-format
 #| msgid "Update"
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "اوسمهالول"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, fuzzy, kde-format
 #| msgid "Uninstall"
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "نالګول"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -429,14 +429,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -447,12 +447,12 @@ msgid ""
 "to the KDE Community in a bug report</a>."
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, fuzzy, kde-format
 #| msgid "View Comments"
 msgctxt ""
@@ -461,19 +461,19 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "څرګندونونه کتل"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, fuzzy, kde-format
 #| msgid "Rating: "
 msgid "Rating:"
 msgstr ":کچونه"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, fuzzy, kde-format
 #| msgid "Homepage"
 msgid "Homepage:"
 msgstr "کورپاڼه"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -482,12 +482,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -495,73 +495,81 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr ""
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, fuzzy, kde-format
 #| msgid "File"
 msgid "Tiles"
 msgstr "دوتنه"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "انځورنونه"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, fuzzy, kde-format
 #| msgid "No Preview"
 msgid "Preview"
 msgstr "هېڅ مخکوت"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, fuzzy, kde-format
 #| msgid "Detailed Tree View"
 msgid "Detailed Tiles View Mode"
 msgstr "سپړاويز ونه کوت"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, fuzzy, kde-format
 #| msgid "Icons Only"
 msgid "Icons Only View Mode"
 msgstr "يوازې انځورنونه"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, fuzzy, kde-format
 #| msgid "Detailed View"
 msgid "Large Preview View Mode"
 msgstr "سپړاوی کوت"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr ""
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, fuzzy, kde-format
 #| msgid "Install"
 msgid "Installed"
 msgstr "لګول"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, fuzzy, kde-format
 #| msgid "Update"
 msgid "Updateable"
 msgstr "اوسمهالول"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, fuzzy, kde-format
 #| msgid "&Show All Entries"
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "ټولې ننوتنې ښودل&"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, fuzzy, kde-format
 #| msgid "&Show All Entries"
 msgctxt ""
@@ -569,7 +577,7 @@ msgctxt ""
 msgid "Show Only Installed Entries"
 msgstr "ټولې ننوتنې ښودل&"
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, fuzzy, kde-format
 #| msgid "&Show All Entries"
 msgctxt ""
@@ -578,31 +586,31 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr "ټولې ننوتنې ښودل&"
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "OpenRecent"
 msgid "Recent"
 msgstr "اوسنی پرانيستل"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr ""
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, fuzzy, kde-format
 #| msgid "Rating: "
 msgid "Rating"
 msgstr ":کچونه"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, fuzzy, kde-format
 #| msgid "Download"
 msgid "Downloads"
 msgstr "رالېښنې"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt ""
@@ -611,7 +619,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "لومړی پوښۍ ښودل"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -619,14 +627,14 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr ""
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "لومړی پوښۍ ښودل"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, fuzzy, kde-format
 #| msgid "Most Downloads"
 msgctxt ""
@@ -634,42 +642,42 @@ msgctxt ""
 msgid "Show Most Downloaded First"
 msgstr "ډېرې رالېښنې"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, fuzzy, kde-format
 #| msgid "&Replace..."
 msgid "Upload…"
 msgstr "...ځاېناستول&"
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr ""
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, fuzzy, kde-format
 #| msgid "&Go To..."
 msgid "Go to…"
 msgstr "ته ورتګ"
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, fuzzy, kde-format
 #| msgid "S&earch:"
 msgid "Search…"
 msgstr ":پ&لټون"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, fuzzy, kde-format
 #| msgid "Character:"
 msgid "Category:"
 msgstr ":لوښه"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, fuzzy, kde-format
 #| msgid "Continue operation"
 msgid "Contribute your own…"
 msgstr "چلښت پرمخبيول"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, fuzzy, kde-format
 #| msgctxt "@note/rich"
 #| msgid "<i>Note</i>: %1"
@@ -678,7 +686,7 @@ msgctxt ""
 msgid "<i>(no title)</i>"
 msgstr "%1 :<i>يادښت</i>"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -686,20 +694,20 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, fuzzy, kde-format
 #| msgid "Pages"
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "مخونه"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, fuzzy, kde-format
 #| msgid "Show Preview"
 msgctxt ""
@@ -708,7 +716,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr "مخکوت ښودل"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -716,16 +724,16 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, fuzzy, kde-format
 #| msgid "Download"
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
 msgstr "رالېښنې"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, fuzzy, kde-format
 #| msgctxt "@interface/rich"
 #| msgid "<i>%1</i>"
@@ -735,7 +743,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "<i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -743,7 +751,7 @@ msgctxt ""
 msgid "Working…"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, fuzzy, kde-format
 #| msgid "Update"
 msgctxt ""
@@ -752,7 +760,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "اوسمهالول"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -763,7 +771,7 @@ msgid ""
 "bug report</a>."
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt "Label for the busy indicator showing an item is installing"
@@ -782,14 +790,14 @@ msgstr ""
 msgid "Please try again later."
 msgstr ".لورينه وکړﺉ يو نوم وليکﺉ"
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, fuzzy, kde-format
 #| msgctxt "No border line"
 #| msgid "None"
 msgid "None"
 msgstr "هېڅ"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, fuzzy, kde-format
 #| msgid "(%1/s)"
 msgctxt ""
@@ -797,14 +805,14 @@ msgctxt ""
 msgid "(%1/%2)"
 msgstr "(%1/س)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "نوي څيزونه رالېښل"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, fuzzy, kde-format
 #| msgid "Billing Information:"
 msgctxt ""
@@ -812,21 +820,21 @@ msgctxt ""
 msgid "Updating information…"
 msgstr ":د بېلونې خبرتياوې"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, fuzzy, kde-format
 #| msgid "Store"
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "زېرمل"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, fuzzy, kde-format
 #| msgid "Provider: %1"
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "%1 :رابروونی"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, fuzzy, kde-format
 #| msgid "&Open with '%1'"
 msgctxt ""
@@ -835,7 +843,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "پرانيستل '%1' په&"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, fuzzy, kde-format
 #| msgid "&Send Email"
 msgctxt ""
@@ -844,7 +852,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "برېښليک لېږل"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -852,10 +860,10 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -867,20 +875,20 @@ msgid ""
 "content added."
 msgstr ""
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, fuzzy, kde-format
 #| msgid "Loading Applet"
 msgid "Loading data"
 msgstr "څېرمه کړنلار لېښل کيږي"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, fuzzy, kde-format
 #| msgid "Install"
 msgid "Installing"
 msgstr "لګول"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -890,7 +898,7 @@ msgid ""
 "please contact the person in charge of your permissions."
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Back"
@@ -898,27 +906,27 @@ msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "شاته"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, fuzzy, kde-format
 #| msgid "Saturday"
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "نۍ"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, fuzzy, kde-format
 #| msgid "Restart"
 msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "بياپېلول"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "New"
@@ -926,7 +934,7 @@ msgctxt "Knewstuff5"
 msgid "New"
 msgstr "نوی"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Home"
@@ -934,13 +942,13 @@ msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "کور"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Up"
@@ -948,7 +956,7 @@ msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "پاس"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, fuzzy, kde-format
 #| msgctxt "dictionary variant"
 #| msgid "extended"
@@ -956,21 +964,21 @@ msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "ژور"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, fuzzy, kde-format
 #| msgid "Subscribe"
 msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "ګډون کول"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, fuzzy, kde-format
 #| msgid "&Show All Entries"
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "ټولې ننوتنې ښودل&"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -1003,10 +1011,16 @@ msgstr ""
 #: widgets/action.cpp:28 widgets/button.cpp:70
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
-msgid "Download New Stuff..."
+msgctxt "@action"
+msgid "Download New Stuff…"
 msgstr "نوي څيزونه رالېښل"
 
 #, fuzzy
+#~| msgid "Download New Stuff"
+#~ msgid "Download New Stuff..."
+#~ msgstr "نوي څيزونه رالېښل"
+
+#, fuzzy
 #~| msgid "Install"
 #~ msgid "Initializing"
 #~ msgstr "لګول"
diff -pruN 6.0.0-3/po/pt/knewstuff6.po 6.3.0-1/po/pt/knewstuff6.po
--- 6.0.0-3/po/pt/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/pt/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -2,7 +2,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2022-12-15 09:31+0000\n"
 "Last-Translator: José Nuno Pires <zepires@gmail.com>\n"
 "Language-Team: pt <kde-i18n-pt@kde.org>\n"
@@ -147,7 +147,7 @@ msgstr "O seu voto foi registado."
 msgid "You are now a fan."
 msgstr "Você é agora um fã."
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -220,7 +220,7 @@ msgstr "O ficheiro de configuração é
 msgid "Use"
 msgstr "Usar"
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, fuzzy, kde-format
 #| msgid ""
 #| "Could not initialise the installation handler for %1\n"
@@ -233,19 +233,19 @@ msgstr ""
 "Não foi possível inicializar a rotina de instalação do %1\n"
 "Este é um erro crítico e deverá ser comunicado ao autor da aplicação"
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr "O carregamento de fornecedores do ficheiro: %1 foi mal-sucedido"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr ""
 "Não foi possível obter os fornecedores de itens novos a partir do ficheiro: "
 "%1"
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr "Ocorreu um erro ao inicializar o fornecedor."
@@ -420,7 +420,7 @@ msgstr ""
 "Não foi possível encontrar uma boa ligação para actualizar o %1, pelo que "
 "não serrá possível efectuar a actualização"
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, kde-format
 msgid ""
 "Failed to adopt '%1'\n"
@@ -429,14 +429,14 @@ msgstr ""
 "Não foi possível adoptar o '%1'\n"
 "%2"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, kde-format
 msgctxt ""
 "The first entry in the category selection list (also the default value)"
 msgid "All Categories"
 msgstr "Todas as Categorias"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, kde-format
 msgctxt ""
 "The string passed back in the case the requested category is not known"
@@ -467,13 +467,13 @@ msgstr "Coisas"
 msgid "Download New %1…"
 msgstr "Obter %1 Novos/as"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, kde-format
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "Obter %1 Novos/as"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, kde-format
 msgctxt ""
 "A placeholder title used in the dialog when there is no better title "
@@ -481,12 +481,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "Obter Coisas Novas"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr "Escolha o seu Local de Instalação"
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -499,19 +499,19 @@ msgstr ""
 "contacte por favor o autor deste item e peça para clarificar isto com base "
 "no nome dos itens."
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "Instalar"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, kde-format
 msgctxt ""
 "A passive notification shown when installation of an item is initiated"
 msgid "Installing %1 from %2"
 msgstr "A Instalar %1 de %2"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -519,10 +519,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr "%1 de %2"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, kde-format
 msgctxt ""
 "Request installation of this item, available when there is exactly one "
@@ -530,10 +530,10 @@ msgctxt ""
 msgid "Install"
 msgstr "Instalar"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -541,22 +541,22 @@ msgctxt ""
 msgid "Install…"
 msgstr "Instalar"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, kde-format
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "Actualizar"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, kde-format
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "Desinstalar"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, fuzzy, kde-format
 #| msgctxt ""
 #| "Status message to be shown when the entry is in the process of being "
@@ -568,7 +568,7 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr "A tratar de momento o item %1 de %2. Espere por favor..."
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, fuzzy, kde-format
 #| msgctxt ""
 #| "Status message to be shown when the entry is in the process of being "
@@ -579,7 +579,7 @@ msgctxt ""
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr "A actualizar de momento o item %1 de %2. Espere por favor..."
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -593,12 +593,12 @@ msgstr ""
 "\"https://bugs.kde.org/enter_bug.cgi?product=frameworks-knewstuff\">Por "
 "favor, comunique isto à Comunidade do KDE num relatório de erros</a>."
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr "Comentários e Revisões:"
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a new sub page with comments (comments "
@@ -606,17 +606,17 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "%1 Revisões e Comentários"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, kde-format
 msgid "Rating:"
 msgstr "Classificação:"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, kde-format
 msgid "Homepage:"
 msgstr "Página Web:"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -625,12 +625,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr "Abrir a página Web de %1"
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr "Como Doar:"
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -638,75 +638,86 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr "Descubra como fazer uma doação para este projecto"
 
-#: qtquick/qml/Page.qml:141
-#, kde-format
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
+#, fuzzy, kde-format
+#| msgid ""
+#| "The content available here has been uploaded by users like you, and has "
+#| "not been reviewed by your distributor for functionality or stability."
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 "O conteúdo aqui disponível foi submetido por utilizadores como você, pelo "
 "que não feita nenhuma revisão de funcionalidades ou estabilidade por parte "
 "da sua distribuição."
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, kde-format
 msgid "Tiles"
 msgstr "Padrões"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "Ícones"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, kde-format
 msgid "Preview"
 msgstr "Antevisão"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, kde-format
 msgid "Detailed Tiles View Mode"
 msgstr "Modo de Vista em Padrões Detalhados"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, kde-format
 msgid "Icons Only View Mode"
 msgstr "Modo de Vista Apenas em Ícones"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, kde-format
 msgid "Large Preview View Mode"
 msgstr "Modo de Vista em Antevisão Grande"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr "Tudo"
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "Instalado"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, kde-format
 msgid "Updateable"
 msgstr "Actualizáveis"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, kde-format
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "Mostrar Todos os Itens"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr "Mostrar Apenas os Itens Instalados"
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -714,27 +725,27 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr "Mostrar Apenas os Itens para Actualização"
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, kde-format
 msgid "Recent"
 msgstr "Recentes"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr "Alfabética"
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "Classificação"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, kde-format
 msgid "Downloads"
 msgstr "Transferências"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on when items were most "
@@ -742,7 +753,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "Mostrar as Mais Recentes Primeiro"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -750,60 +761,60 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr "Ordenar Alfabeticamente pelo Nome"
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, kde-format
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "Mostrar os Melhor Classificados Primeiro"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on number of downloads"
 msgid "Show Most Downloaded First"
 msgstr "Mostrar os Mais Transferidos Primeiro"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, fuzzy, kde-format
 #| msgid "Upload..."
 msgid "Upload…"
 msgstr "Enviar..."
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr "Aprenda como adicionar os seus itens novos a esta lista"
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, fuzzy, kde-format
 #| msgid "Go to..."
 msgid "Go to…"
 msgstr "Ir para..."
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, fuzzy, kde-format
 #| msgid "Search:"
 msgid "Search…"
 msgstr "Procurar:"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "Categoria:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, kde-format
 msgid "Contribute your own…"
 msgstr "Contribua com os seus…"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, kde-format
 msgctxt ""
 "Placeholder title for when a comment has no subject, but does have a rating"
 msgid "<i>(no title)</i>"
 msgstr "<i>(sem título)</i>"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -811,19 +822,19 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr "%1 <i>(autor)</i>"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr "Comentários e Revisões de %1"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, kde-format
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "Mostrar Todos os Comentários"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -831,7 +842,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr "Mostrar Apenas as Revisões"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -839,15 +850,15 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr "Mostrar as Revisões e as Respostas"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, kde-format
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
 msgstr "%1 transferências"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, kde-format
 msgctxt ""
 "Subheading for the tile view, located immediately underneath the name of the "
@@ -855,7 +866,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "De <i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, fuzzy, kde-format
 #| msgctxt ""
 #| "Label for the busy indicator showing an item is being installed OR "
@@ -867,7 +878,7 @@ msgctxt ""
 msgid "Working…"
 msgstr "Em curso..."
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, fuzzy, kde-format
 #| msgid "Updating"
 msgctxt ""
@@ -876,7 +887,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "A Actualizar"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -890,7 +901,7 @@ msgstr ""
 "cgi?product=frameworks-knewstuff\"> Por favor, comunique isto à Comunidade "
 "do KDE num relatório de erros</a>."
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt "Label for the busy indicator showing an item is installing"
@@ -908,19 +919,19 @@ msgstr "Ocorreu um Erro"
 msgid "Please try again later."
 msgstr "Por favor, tente mais tarde de novo."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, kde-format
 msgid "None"
 msgstr "Nenhum"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, kde-format
 msgctxt ""
 "A text representation of the rating, shown as a fraction of the max value"
 msgid "(%1/%2)"
 msgstr "(%1/%2)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, fuzzy, kde-format
 #| msgctxt "@knewstuff5"
 #| msgid "Upload New Stuff: %1"
@@ -928,7 +939,7 @@ msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "Enviar Coisas Novas: %1"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, fuzzy, kde-format
 #| msgctxt ""
 #| "A text shown beside a busy indicator suggesting that data is being fetched"
@@ -938,19 +949,19 @@ msgctxt ""
 msgid "Updating information…"
 msgstr "A actualizar as informações..."
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, kde-format
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "Loja do KDE"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, kde-format
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "O Seu Fornecedor"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, kde-format
 msgctxt ""
 "Text for an action which causes the specified website to be opened using the "
@@ -958,7 +969,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "Abrir a Página Web: %1"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, kde-format
 msgctxt ""
 "Text for an action which will attempt to send an email using the user's "
@@ -966,15 +977,22 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "Enviar um E-Mail Para: %1"
 
-#: qtquick/qml/UploadPage.qml:154
-#, kde-format
+#: qtquick/qml/UploadPage.qml:159
+#, fuzzy, kde-format
+#| msgctxt "A description of how to upload content to a generic provider"
+#| msgid ""
+#| "To upload new entries, or to add content to an existing entry on the KDE "
+#| "Store, please open the website and log in. Once you have done this, you "
+#| "will be able to find the My Products entry in the menu which pops up when "
+#| "you click your user icon. Click on this entry to go to the product "
+#| "management system, where you can work on your products ."
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
 "To upload new entries, or to add content to an existing entry on the KDE "
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 "Para enviar novos itens, ou para adicionar um item existente à Loja do KDE, "
 "por favor abra a página Web e autentique-se. Assim que o tiver feito, será "
@@ -982,7 +1000,7 @@ msgstr ""
 "carrega no ícone do seu utilizador. Carregue neste item para ir para o "
 "sistema de gestão de produtos, no qual poderá lidar com os seus produtos."
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -1000,18 +1018,18 @@ msgstr ""
 "os produtos. Em alternativa, poderá ter de contactar os gestores da página "
 "directamente para poder adicionar novos conteúdos."
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "A carregar os dados"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "A Instalar"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -1023,73 +1041,73 @@ msgstr ""
 "Não está autorizado para Obter Coisas Novas. Se pensa que isto é um erro, "
 "contacte por favor a pessoa responsável pelas suas permissões."
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "Recuar"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr "Populares"
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "Em Destaque"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "Reiniciar"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "New"
 msgstr "Novos"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Início"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr "Prateleira"
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "Subir"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "Recomendados"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "Subscrições"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "Todos os Itens"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -1146,9 +1164,17 @@ msgstr ""
 "Um exemplo destes URL's é 'kns://peruse.knsrc/api.kde-look.org/1316714'"
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
-#, kde-format
-msgid "Download New Stuff..."
-msgstr "Obter Coisas Novas..."
+#, fuzzy, kde-format
+#| msgctxt ""
+#| "A placeholder title used in the dialog when there is no better title "
+#| "available"
+#| msgid "Download New Stuff"
+msgctxt "@action"
+msgid "Download New Stuff…"
+msgstr "Obter Coisas Novas"
+
+#~ msgid "Download New Stuff..."
+#~ msgstr "Obter Coisas Novas..."
 
 #~ msgctxt ""
 #~ "A message which is shown when the user attempts to display a specific "
diff -pruN 6.0.0-3/po/pt_BR/knewstuff6.po 6.3.0-1/po/pt_BR/knewstuff6.po
--- 6.0.0-3/po/pt_BR/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/pt_BR/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -20,7 +20,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: knewstuff\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2023-08-11 23:54-0300\n"
 "Last-Translator: Geraldo Simiao <geraldosimiao@fedoraproject.org>\n"
 "Language-Team: Brazilian Portuguese <kde-i18n-pt_BR@kde.org>\n"
@@ -69,7 +69,7 @@ msgstr "Seu voto foi registrado."
 msgid "You are now a fan."
 msgstr "Você agora é um fã."
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -137,7 +137,7 @@ msgstr "O arquivo de configuração é i
 msgid "Use"
 msgstr "Usar"
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -148,18 +148,18 @@ msgstr ""
 "%2\n"
 "Este é um erro crítico e deve ser relatado ao autor do aplicativo"
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr "Não foi possível efetuar o carregamento de fornecedores do arquivo: %1"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr ""
 "Não foi possível baixar os fornecedores de novidades a partir do arquivo: %1"
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr "Erro ao inicializar o fornecedor."
@@ -329,7 +329,7 @@ msgstr ""
 "Falhamos em identificar um bom link para atualizar %1 e não conseguimos "
 "realizar a atualização"
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, kde-format
 msgid ""
 "Failed to adopt '%1'\n"
@@ -338,14 +338,14 @@ msgstr ""
 "Falhas ao adotar '%1'\n"
 "%2"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, kde-format
 msgctxt ""
 "The first entry in the category selection list (also the default value)"
 msgid "All Categories"
 msgstr "Todas as categorias"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, kde-format
 msgctxt ""
 "The string passed back in the case the requested category is not known"
@@ -369,13 +369,13 @@ msgstr "Coisas"
 msgid "Download New %1…"
 msgstr "Baixar %1 novas..."
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, kde-format
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "Baixar %1 novas"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, kde-format
 msgctxt ""
 "A placeholder title used in the dialog when there is no better title "
@@ -383,12 +383,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "Baixar coisas novas"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr "Escolha sua opção de instalação"
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -401,19 +401,19 @@ msgstr ""
 "disponíveis. Se possível, contate o autor deste item e peça para esclarecer "
 "isto através do nome dos itens."
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "Instalar"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, kde-format
 msgctxt ""
 "A passive notification shown when installation of an item is initiated"
 msgid "Installing %1 from %2"
 msgstr "Instalando %1 de %2"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -421,10 +421,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr "%1 por %2"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, kde-format
 msgctxt ""
 "Request installation of this item, available when there is exactly one "
@@ -432,32 +432,32 @@ msgctxt ""
 msgid "Install"
 msgstr "Instalar"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, kde-format
 msgctxt ""
 "Show installation options, where there is more than one downloadable item"
 msgid "Install…"
 msgstr "Instalar..."
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, kde-format
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "Atualizar"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, kde-format
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "Desinstalar"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -465,14 +465,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr "Trabalhando atualmente no item %1 por %2. Aguarde..."
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr "Atualizando o item %1 de %2. Aguarde um momento..."
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -487,12 +487,12 @@ msgstr ""
 "favor, comunique isto à Comunidade do KDE através de um relatório de erros</"
 "a>."
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr "Comentários e avaliações:"
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a new sub page with comments (comments "
@@ -500,17 +500,17 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "%1 avaliações e comentários"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, kde-format
 msgid "Rating:"
 msgstr "Classificação:"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, kde-format
 msgid "Homepage:"
 msgstr "Site:"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -519,12 +519,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr "Abrir o site de %1"
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr "Como doar:"
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -532,74 +532,85 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr "Saiba como doar para este projeto"
 
-#: qtquick/qml/Page.qml:141
-#, kde-format
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
+#, fuzzy, kde-format
+#| msgid ""
+#| "The content available here has been uploaded by users like you, and has "
+#| "not been reviewed by your distributor for functionality or stability."
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 "O conteúdo disponível aqui foi enviado por usuários como você e não foi "
 "revisto pelo nosso distribuidor por funcionalidade ou estabilidade."
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, kde-format
 msgid "Tiles"
 msgstr "Blocos"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "Ícones"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, kde-format
 msgid "Preview"
 msgstr "Visualização"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, kde-format
 msgid "Detailed Tiles View Mode"
 msgstr "Modo de exibição em blocos"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, kde-format
 msgid "Icons Only View Mode"
 msgstr "Modo de exibição apenas ícones"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, kde-format
 msgid "Large Preview View Mode"
 msgstr "Modo de exibição em visualização grande"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr "Tudo"
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "Instalado"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, kde-format
 msgid "Updateable"
 msgstr "Atualizáveis"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, kde-format
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "Mostrar todas as entradas"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr "Mostrar apenas as entradas instaladas"
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -607,27 +618,27 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr "Mostrar apenas as entradas atualizáveis"
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, kde-format
 msgid "Recent"
 msgstr "Recentes"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr "Alfabética"
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "Classificação"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, kde-format
 msgid "Downloads"
 msgstr "Downloads"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on when items were most "
@@ -635,7 +646,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "Primeiro as mais recentes"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -643,57 +654,57 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr "Ordenar alfabeticamente pelo nome"
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, kde-format
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "Mostrar primeiro os melhores avaliados"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on number of downloads"
 msgid "Show Most Downloaded First"
 msgstr "Mostrar primeiro os mais baixados"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, kde-format
 msgid "Upload…"
 msgstr "Enviar..."
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr "Aprenda como adicionar suas próprias coisas novas nesta lista"
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, kde-format
 msgid "Go to…"
 msgstr "Ir para..."
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, kde-format
 msgid "Search…"
 msgstr "Pesquisar..."
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "Categoria:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, kde-format
 msgid "Contribute your own…"
 msgstr "Contribua com o seu próprio…"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, kde-format
 msgctxt ""
 "Placeholder title for when a comment has no subject, but does have a rating"
 msgid "<i>(no title)</i>"
 msgstr "<i>(sem título)</i>"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -701,19 +712,19 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr "%1 <i>(autor)</i>"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr "Comentários e avaliações de %1"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, kde-format
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "Mostrar todos os comentários"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -721,7 +732,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr "Mostrar apenas as avalizações"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -729,15 +740,15 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr "Mostrar as avaliações e respostas"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, kde-format
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
 msgstr "%1 downloads"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, kde-format
 msgctxt ""
 "Subheading for the tile view, located immediately underneath the name of the "
@@ -745,7 +756,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "Por <i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -753,7 +764,7 @@ msgctxt ""
 msgid "Working…"
 msgstr "Trabalhando..."
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is in the process of being "
@@ -761,7 +772,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "Atualizando..."
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -775,7 +786,7 @@ msgstr ""
 "cgi?product=frameworks-knewstuff\">Por favor, comunique isto à Comunidade do "
 "KDE através de um relatório de erros</a>."
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, kde-format
 msgctxt "Label for the busy indicator showing an item is installing"
 msgid "Installing…"
@@ -792,44 +803,44 @@ msgstr "Ocorreu um erro"
 msgid "Please try again later."
 msgstr "Tente novamente mais tarde."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, kde-format
 msgid "None"
 msgstr "Nenhum"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, kde-format
 msgctxt ""
 "A text representation of the rating, shown as a fraction of the max value"
 msgid "(%1/%2)"
 msgstr "(%1/%2)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, kde-format
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "Enviar coisas novas: %1"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, kde-format
 msgctxt ""
 "A text shown beside a busy indicator suggesting that data is being fetched"
 msgid "Updating information…"
 msgstr "Atualizando informação..."
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, kde-format
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "KDE Store"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, kde-format
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "Seu provedor"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, kde-format
 msgctxt ""
 "Text for an action which causes the specified website to be opened using the "
@@ -837,7 +848,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "Abrir site: %1"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, kde-format
 msgctxt ""
 "Text for an action which will attempt to send an email using the user's "
@@ -845,15 +856,22 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "Enviar e-mail para: %1"
 
-#: qtquick/qml/UploadPage.qml:154
-#, kde-format
+#: qtquick/qml/UploadPage.qml:159
+#, fuzzy, kde-format
+#| msgctxt "A description of how to upload content to a generic provider"
+#| msgid ""
+#| "To upload new entries, or to add content to an existing entry on the KDE "
+#| "Store, please open the website and log in. Once you have done this, you "
+#| "will be able to find the My Products entry in the menu which pops up when "
+#| "you click your user icon. Click on this entry to go to the product "
+#| "management system, where you can work on your products ."
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
 "To upload new entries, or to add content to an existing entry on the KDE "
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 "Para enviar novas entradas ou adicionar conteúdo a uma entrada existente na "
 "KDE Store, abra o site e faça o login. Depois de fazer isso, você poderá "
@@ -861,7 +879,7 @@ msgstr ""
 "seu ícone de usuário. Clique nesta entrada para ir para o sistema de "
 "gerenciamento de produtos, onde você pode trabalhar em seus produtos."
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -879,18 +897,18 @@ msgstr ""
 "alternativa, pode ser necessário entrar em contato diretamente com os "
 "administradores do site para adicionar novos conteúdos."
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "Carregando dados"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "Instalando"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -902,73 +920,73 @@ msgstr ""
 "Você não está autorizado a usar o recurso de Baixar novidades. Se achar que "
 "isto é um erro, contate a pessoa responsável pelas suas permissões."
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "Voltar"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr "Popular"
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "Em destaque"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "Reiniciar"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "New"
 msgstr "Novo"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Início"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr "Prateleira"
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "Para cima"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "Recomendado"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "Inscrições"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "Todas as entradas"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -1025,9 +1043,17 @@ msgstr ""
 " An example of such a url is kns://peruse.knsrc/api.kde-look.org/1316714"
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
-#, kde-format
-msgid "Download New Stuff..."
-msgstr "Baixar coisas novas..."
+#, fuzzy, kde-format
+#| msgctxt ""
+#| "A placeholder title used in the dialog when there is no better title "
+#| "available"
+#| msgid "Download New Stuff"
+msgctxt "@action"
+msgid "Download New Stuff…"
+msgstr "Baixar coisas novas"
+
+#~ msgid "Download New Stuff..."
+#~ msgstr "Baixar coisas novas..."
 
 #~ msgctxt ""
 #~ "A message which is shown when the user attempts to display a specific "
diff -pruN 6.0.0-3/po/ro/knewstuff6.po 6.3.0-1/po/ro/knewstuff6.po
--- 6.0.0-3/po/ro/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/ro/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -6,8 +6,8 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
-"PO-Revision-Date: 2024-02-24 17:13+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
+"PO-Revision-Date: 2024-02-25 14:48+0000\n"
 "Last-Translator: Sergiu Bivol <sergiu@cip.md>\n"
 "Language-Team: Romanian <kde-i18n-ro@kde.org>\n"
 "Language: ro\n"
@@ -56,7 +56,7 @@ msgstr "Votul a fost înregistrat."
 msgid "You are now a fan."
 msgstr "Sunteți fan acum."
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -122,7 +122,7 @@ msgstr "Fișierul de configurare nu e va
 msgid "Use"
 msgstr "Folosește"
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -133,17 +133,17 @@ msgstr ""
 "%2\n"
 "Această eroare e critică și trebuie raportată autorului aplicației"
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr "Încărcarea furnizorilor din fișier: %1 a eșuat"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr "Nu s-au putut obține furnizori de lucruri noi din fișier: %1"
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr "Eroare la inițializarea furnizorului."
@@ -170,6 +170,8 @@ msgid ""
 "Cannot install '%1' because it points to a web page. Click <a "
 "href='%2'>here</a> to finish the installation."
 msgstr ""
+"Nu se poate instala „%1” deoarece acesta indică spre o pagină web. Apăsați "
+"<a href='%2'>aici</a> pentru a finaliza instalarea."
 
 #: core/installation.cpp:186
 #, kde-format
@@ -312,7 +314,7 @@ msgstr ""
 "Nu s-a putut identifica o legătură bună pentru actualizarea %1 și nu se "
 "poate efectua actualizarea"
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, kde-format
 msgid ""
 "Failed to adopt '%1'\n"
@@ -321,14 +323,14 @@ msgstr ""
 "Adoptarea „%1” a eșuat\n"
 "%2"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, kde-format
 msgctxt ""
 "The first entry in the category selection list (also the default value)"
 msgid "All Categories"
 msgstr "Toate categoriile"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, kde-format
 msgctxt ""
 "The string passed back in the case the requested category is not known"
@@ -352,13 +354,13 @@ msgstr "Chestii"
 msgid "Download New %1…"
 msgstr "Descarcă noi %1…"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, kde-format
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "Descarcă noi %1"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, kde-format
 msgctxt ""
 "A placeholder title used in the dialog when there is no better title "
@@ -366,12 +368,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "Descarcă lucruri noi"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr "Alegeți opțiunea de instalare"
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -384,19 +386,19 @@ msgstr ""
 "disponibile, contactați autorul acestui element și rugați-l să clarifice "
 "aceasta prin denumirile elementelor."
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "Instalează"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, kde-format
 msgctxt ""
 "A passive notification shown when installation of an item is initiated"
 msgid "Installing %1 from %2"
 msgstr "Se instalează %1 din %2"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -404,10 +406,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr "%1 de %2"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, kde-format
 msgctxt ""
 "Request installation of this item, available when there is exactly one "
@@ -415,32 +417,32 @@ msgctxt ""
 msgid "Install"
 msgstr "Instalează"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, kde-format
 msgctxt ""
 "Show installation options, where there is more than one downloadable item"
 msgid "Install…"
 msgstr "Instalează…"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, kde-format
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "Actualizează"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, kde-format
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "Dezinstalează"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -448,14 +450,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr "Se lucrează asupra elementului %1 de %2. Așteptați…"
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr "Se actualizează elementul %1 de %2. Așteptați…"
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -469,12 +471,12 @@ msgstr ""
 "bugs.kde.org/enter_bug.cgi?product=frameworks-knewstuff\">Raportați aceasta "
 "comunității KDE într-un raport de eroare</a>."
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr "Comentarii și recenzii:"
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a new sub page with comments (comments "
@@ -482,17 +484,17 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "Recenzii și comentarii pentru %1"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, kde-format
 msgid "Rating:"
 msgstr "Evaluare:"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, kde-format
 msgid "Homepage:"
 msgstr "Pagină web:"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -501,12 +503,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr "Deschide pagina pentru %1"
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr "Cum să donați:"
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -514,75 +516,86 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr "Aflați cum să donați acestui proiect"
 
-#: qtquick/qml/Page.qml:141
-#, kde-format
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
+#, fuzzy, kde-format
+#| msgid ""
+#| "The content available here has been uploaded by users like you, and has "
+#| "not been reviewed by your distributor for functionality or stability."
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 "Conținutul disponibil aici a fost încărcat de utilizatori ca dumneavoastră "
 "și nu a fost revizuit de către distribuitor pentru funcționalitate sau "
 "stabilitate."
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, kde-format
 msgid "Tiles"
 msgstr "Dale"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "Pictograme"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, kde-format
 msgid "Preview"
 msgstr "Previzualizare"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, kde-format
 msgid "Detailed Tiles View Mode"
 msgstr "Regim de vizualizare cu dale detaliate"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, kde-format
 msgid "Icons Only View Mode"
 msgstr "Regim de vizualizare numai cu pictograme"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, kde-format
 msgid "Large Preview View Mode"
 msgstr "Regim de vizualizare cu previzualizare mare"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr "Tot"
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "Instalat"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, kde-format
 msgid "Updateable"
 msgstr "Actualizabile"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, kde-format
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "Arată toate înregistrările"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr "Arată doar înregistrări instalate"
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -590,27 +603,27 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr "Arată doar înregistrări actualizabile"
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, kde-format
 msgid "Recent"
 msgstr "Recente"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr "Alfabetic"
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "Evaluare"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, kde-format
 msgid "Downloads"
 msgstr "Descărcări"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on when items were most "
@@ -618,7 +631,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "Arată întâi pe cele mai recente"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -626,57 +639,57 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr "Sortează alfabetic după denumire"
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, kde-format
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "Arată întâi pe cele mai apreciate"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on number of downloads"
 msgid "Show Most Downloaded First"
 msgstr "Arată întâi pe cele mai descărcate"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, kde-format
 msgid "Upload…"
 msgstr "Încarcă…"
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr "Învățați cum să vă adăugați propriile lucruri noi la această listă"
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, kde-format
 msgid "Go to…"
 msgstr "Mergi la…"
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, kde-format
 msgid "Search…"
 msgstr "Caută…"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "Categorie:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, kde-format
 msgid "Contribute your own…"
 msgstr "Contribuiți propriul conținut…"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, kde-format
 msgctxt ""
 "Placeholder title for when a comment has no subject, but does have a rating"
 msgid "<i>(no title)</i>"
 msgstr "<i>(fără titlu)</i>"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -684,19 +697,19 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr "%1 <i>(autor)</i>"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr "Comentarii și recenzii pentru %1"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, kde-format
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "Arată toate comentariile"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -704,7 +717,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr "Arată numai recenzii"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -712,15 +725,15 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr "Arată recenzii și răspunsuri"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, kde-format
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
 msgstr "%1 descărcări"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, kde-format
 msgctxt ""
 "Subheading for the tile view, located immediately underneath the name of the "
@@ -728,7 +741,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "De <i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -736,7 +749,7 @@ msgctxt ""
 msgid "Working…"
 msgstr "Se lucrează…"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is in the process of being "
@@ -744,7 +757,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "Se actualizează…"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -758,7 +771,7 @@ msgstr ""
 "product=frameworks-knewstuff\">Raportați aceasta comunității KDE într-un "
 "raport de eroare</a>."
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, kde-format
 msgctxt "Label for the busy indicator showing an item is installing"
 msgid "Installing…"
@@ -775,44 +788,44 @@ msgstr "A intervenit o eroare"
 msgid "Please try again later."
 msgstr "Încercați mai târziu."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, kde-format
 msgid "None"
 msgstr "Niciuna"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, kde-format
 msgctxt ""
 "A text representation of the rating, shown as a fraction of the max value"
 msgid "(%1/%2)"
 msgstr "(%1/%2)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, kde-format
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "Încarcă lucruri noi: %1"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, kde-format
 msgctxt ""
 "A text shown beside a busy indicator suggesting that data is being fetched"
 msgid "Updating information…"
 msgstr "Se actualizează informațiile…"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, kde-format
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "Magazin KDE"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, kde-format
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "Furnizorul dumneavoastră"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, kde-format
 msgctxt ""
 "Text for an action which causes the specified website to be opened using the "
@@ -820,7 +833,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "Deschide saitul: %1"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, kde-format
 msgctxt ""
 "Text for an action which will attempt to send an email using the user's "
@@ -828,18 +841,31 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "Trimite e-mail către: %1"
 
-#: qtquick/qml/UploadPage.qml:154
-#, kde-format
+#: qtquick/qml/UploadPage.qml:159
+#, fuzzy, kde-format
+#| msgctxt "A description of how to upload content to a generic provider"
+#| msgid ""
+#| "To upload new entries, or to add content to an existing entry on the KDE "
+#| "Store, please open the website and log in. Once you have done this, you "
+#| "will be able to find the My Products entry in the menu which pops up when "
+#| "you click your user icon. Click on this entry to go to the product "
+#| "management system, where you can work on your products ."
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
 "To upload new entries, or to add content to an existing entry on the KDE "
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
+"Pentru a încărca articole noi, sau pentru a adăuga conținut la un articol "
+"existent în Magazinul KDE, deschideți saitul și autentificați-vă. După "
+"aceasta, veți putea găsi înregistrarea „Produsele mele” în meniul ce apare "
+"când apăsați pe pictograma utilizatorului dumneavoastră. Apăsați pe această "
+"înregistrare pentru a merge la sistemul de gestiune a produselor, unde "
+"puteți lucra asupra produselor dumneavoastră."
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -850,19 +876,25 @@ msgid ""
 "might be required to contact the managers of the site directly to get new "
 "content added."
 msgstr ""
+"Pentru a încărca articole noi, sau pentru a adăuga conținut la un articol "
+"existent, deschideți saitul furnizorului și urmați instrucțiunile de acolo. "
+"Probabil va fi nevoie să vă creați un cont și să vă autentificați într-un "
+"sistem de gestiune a produselor, unde să urmați instrucțiuni pentru "
+"adăugare. Alternativ, vi se poate cere să contactați administratorul "
+"saitului direct pentru a încărca conținut nou."
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "Se încarcă date"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "Se instalează"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -874,73 +906,73 @@ msgstr ""
 "Nu aveți autorizare să preluați lucruri noi. Dacă considerați că e o "
 "greșeală, contactați persoana responsabilă de permisiuni."
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "Înapoi"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr "Popular"
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "Promovat"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "Repornește"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "New"
 msgstr "Nou"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Acasă"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr "Raft"
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "Sus"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "Recomandat"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "Abonamente"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "Toate înregistrările"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -972,8 +1004,27 @@ msgid ""
 "file.\n"
 " An example of such a url is kns://sddmtheme.knsrc/api.kde-look.org/2059021"
 msgstr ""
+"Un URL KNS de pe care să fie arătate informații. Formatul unui URL KNS e "
+"kns://fișierknsrc/idfurnizor/idarticol\n"
+"„fișierknsrc”\n"
+"e denumirea unui fișier knsrc după cum se transmite direct prin argumentul "
+"„knsrcfile” al acestei unelte\n"
+"„idfurnizor”\n"
+"e numele de gazdă al furnizorului la care trebuie să existe articolul\n"
+"„idarticol”\n"
+"e identificatorul unic al unui articol găsit la furnizorul specificat de "
+"fișierul knsrc.\n"
+" Un exemplu de astfel de URL e kns://sddmtheme.knsrc/api.kde-look.org/2059021"
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
-#, kde-format
-msgid "Download New Stuff..."
-msgstr "Descarcă lucruri noi..."
+#, fuzzy, kde-format
+#| msgctxt ""
+#| "A placeholder title used in the dialog when there is no better title "
+#| "available"
+#| msgid "Download New Stuff"
+msgctxt "@action"
+msgid "Download New Stuff…"
+msgstr "Descarcă lucruri noi"
+
+#~ msgid "Download New Stuff..."
+#~ msgstr "Descărcare lucruri noi..."
diff -pruN 6.0.0-3/po/ru/knewstuff6.po 6.3.0-1/po/ru/knewstuff6.po
--- 6.0.0-3/po/ru/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/ru/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -1,6 +1,7 @@
 # KDE - kdelibs/kdelibs4.po Russian translation.
 # Copyright (C) 2005, KDE Russian translation team.
 #
+# SPDX-FileCopyrightText: 2019, 2020, 2021, 2022, 2023, 2024 Alexander Yavorsky <kekcuha@gmail.com>
 # Denis Perchine <dyp@perchine.com>, 2000.
 # Gregory Mokhin <mok@kde.ru>, 2000, 2004, 2005.
 # Albert R. Valiev <darkstar@altlinux.ru>, 2002, 2008.
@@ -14,21 +15,21 @@
 # Inga Barinova <ingabarinova@gmail.com>, 2012.
 # Julia Dronova <juliette.tux@gmail.com>, 2012.
 # Alexander Lakhin <exclusion@gmail.com>, 2013.
-# SPDX-FileCopyrightText: 2019, 2020, 2021, 2022, 2023, 2024 Alexander Yavorsky <kekcuha@gmail.com>
 # Мария Шикунова <translation-team@basealt.ru>, 2021, 2022.
+# Alexander Yavorsky <kekcuha@gmail.com>, 2024.
 msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
-"PO-Revision-Date: 2024-01-20 09:31+0300\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
+"PO-Revision-Date: 2024-05-21 22:39+0300\n"
 "Last-Translator: Alexander Yavorsky <kekcuha@gmail.com>\n"
 "Language-Team: Russian <kde-russian@lists.kde.ru>\n"
 "Language: ru\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Generator: Lokalize 23.08.4\n"
+"X-Generator: Lokalize 21.08.3\n"
 "Plural-Forms: nplurals=4; plural=n==1 ? 3 : n%10==1 && n%100!=11 ? 0 : n"
 "%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;\n"
 "X-Environment: kde\n"
@@ -73,7 +74,7 @@ msgstr "Ваш голос учтён."
 msgid "You are now a fan."
 msgstr "Теперь вы фанат этого дополнения."
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -143,7 +144,7 @@ msgstr "Некорректный кон
 msgid "Use"
 msgstr "Использовать"
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -154,17 +155,17 @@ msgstr ""
 "%2\n"
 "Это критическая ошибка, и о ней следует сообщить автору приложения"
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr "Ошибка загрузки поставщиков из файла: %1"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr "Не удалось загрузить список поставщиков из файла: %1"
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr "Ошибка инициализации поставщика."
@@ -326,7 +327,7 @@ msgid ""
 msgstr ""
 "Обновление невозможно, не удалось распознать ссылку для обновления «%1»"
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, kde-format
 msgid ""
 "Failed to adopt '%1'\n"
@@ -335,14 +336,14 @@ msgstr ""
 "Не удалось обработать «%1»\n"
 "%2"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, kde-format
 msgctxt ""
 "The first entry in the category selection list (also the default value)"
 msgid "All Categories"
 msgstr "Все категории"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, kde-format
 msgctxt ""
 "The string passed back in the case the requested category is not known"
@@ -367,13 +368,13 @@ msgid "Download New %1…"
 msgstr "Загрузить новые %1…"
 
 # BUGME: please split window title and button --aspotashev
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, kde-format
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "Загрузка новых %1"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, kde-format
 msgctxt ""
 "A placeholder title used in the dialog when there is no better title "
@@ -381,12 +382,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "Загрузка новых материалов"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr "Выберите вариант материала для установки"
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -399,19 +400,19 @@ msgstr ""
 "выбрать, свяжитесь с автором материала и попросите его сделать названия "
 "объектов более понятными."
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "Установить"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, kde-format
 msgctxt ""
 "A passive notification shown when installation of an item is initiated"
 msgid "Installing %1 from %2"
 msgstr "Установка %1 из %2"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -419,10 +420,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr "%1 от %2"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, kde-format
 msgctxt ""
 "Request installation of this item, available when there is exactly one "
@@ -430,32 +431,32 @@ msgctxt ""
 msgid "Install"
 msgstr "Установить"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, kde-format
 msgctxt ""
 "Show installation options, where there is more than one downloadable item"
 msgid "Install…"
 msgstr "Установить…"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, kde-format
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "Обновить"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, kde-format
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "Удалить"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -463,14 +464,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr "Дождитесь окончания обработки компонента %1 от %2…"
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr "Выполняется обновление компонента %1 от %2. Подождите…"
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -484,13 +485,13 @@ msgstr ""
 "\"https://bugs.kde.org/enter_bug.cgi?product=frameworks-knewstuff\">Сообщите "
 "об этом сообществу KDE в вашем отчёте об ошибке.</a>"
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr "Комментарии и отзывы:"
 
 # BUGME: add plurals please --ayavorsky 20191130
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a new sub page with comments (comments "
@@ -498,17 +499,17 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "%1 отзывов и комментариев"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, kde-format
 msgid "Rating:"
 msgstr "Оценка:"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, kde-format
 msgid "Homepage:"
 msgstr "Веб-сайт:"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -517,12 +518,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr "Открыть домашнюю страницу %1"
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr "Как сделать пожертвование:"
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -530,74 +531,86 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr "Узнать, как поддержать проект финансово"
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+"Будьте осторожны при использовании материалов, загруженных пользователями: "
+"такие материалы могут содержать исполняемый код, который не был "
+"протестирован KDE или разработчиками используемого вами дистрибутива на "
+"предмет безопасности, стабильности или качества."
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 "Доступное здесь содержимое было загружено обычными пользователями и не "
 "проверялось разработчиками на функциональность и стабильность."
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, kde-format
 msgid "Tiles"
 msgstr "Плитки"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "Значки"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, kde-format
 msgid "Preview"
 msgstr "Режим просмотра"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, kde-format
 msgid "Detailed Tiles View Mode"
 msgstr "Список"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, kde-format
 msgid "Icons Only View Mode"
 msgstr "Значки"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, kde-format
 msgid "Large Preview View Mode"
 msgstr "Крупные миниатюры"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr "Показать все"
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "Установленные"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, kde-format
 msgid "Updateable"
 msgstr "Только обновляемые"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, kde-format
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "Показать все категории"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr "Показать только установленные"
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -605,27 +618,27 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr "Показать только обновляемые"
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, kde-format
 msgid "Recent"
 msgstr "Последние"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr "Сортировать по алфавиту"
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "Высоко оценённые"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, kde-format
 msgid "Downloads"
 msgstr "Загрузки"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on when items were most "
@@ -633,7 +646,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "Сначала самые новые"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -641,57 +654,57 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr "Сортировать по алфавиту по имени"
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, kde-format
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "Сначала с наивысшей оценкой"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on number of downloads"
 msgid "Show Most Downloaded First"
 msgstr "Сначала самые популярные"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, kde-format
 msgid "Upload…"
 msgstr "Загрузить…"
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr "Узнайте, как добавить свои материалы в этот список"
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, kde-format
 msgid "Go to…"
 msgstr "Перейти…"
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, kde-format
 msgid "Search…"
 msgstr "Поиск…"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "Категория:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, kde-format
 msgid "Contribute your own…"
 msgstr "Загрузить свои материалы…"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, kde-format
 msgctxt ""
 "Placeholder title for when a comment has no subject, but does have a rating"
 msgid "<i>(no title)</i>"
 msgstr "<i>(без заголовка)</i>"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -699,19 +712,19 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr "%1 <i>(автор)</i>"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr "Комментарии и отзывы о %1"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, kde-format
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "Показывать все комментарии"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -719,7 +732,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr "Показывать только отзывы"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -728,15 +741,15 @@ msgid "Show Reviews and Replies"
 msgstr "Показывать отзывы и ответы на них"
 
 # BUGME: please add plurals --aspotashev
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, kde-format
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
 msgstr "%1 загрузок"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, kde-format
 msgctxt ""
 "Subheading for the tile view, located immediately underneath the name of the "
@@ -744,7 +757,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "Автор: <i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -752,7 +765,7 @@ msgctxt ""
 msgid "Working…"
 msgstr "Операция выполняется…"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is in the process of being "
@@ -760,7 +773,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "Обновление…"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -774,7 +787,7 @@ msgstr ""
 "enter_bug.cgi?product=frameworks-knewstuff\">Сообщите об этом сообществу KDE "
 "в вашем отчёте об ошибке</a>."
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, kde-format
 msgctxt "Label for the busy indicator showing an item is installing"
 msgid "Installing…"
@@ -791,44 +804,44 @@ msgstr "Произошла ошибка"
 msgid "Please try again later."
 msgstr "Повторите попытку позже."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, kde-format
 msgid "None"
 msgstr "Нет"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, kde-format
 msgctxt ""
 "A text representation of the rating, shown as a fraction of the max value"
 msgid "(%1/%2)"
 msgstr "(%1/%2)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, kde-format
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "Загрузка новых материалов: %1"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, kde-format
 msgctxt ""
 "A text shown beside a busy indicator suggesting that data is being fetched"
 msgid "Updating information…"
 msgstr "Обновление информации…"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, kde-format
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "KDE Store"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, kde-format
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "Поставщик"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, kde-format
 msgctxt ""
 "Text for an action which causes the specified website to be opened using the "
@@ -836,7 +849,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "Открыть сайт: %1"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, kde-format
 msgctxt ""
 "Text for an action which will attempt to send an email using the user's "
@@ -844,7 +857,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "Отправить письмо по адресу: %1"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -852,7 +865,7 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 "Чтобы загружать свои дополнения или редактировать уже существующие в KDE "
 "Store материалы, откройте веб-сайт и войдите в свою учётную запись. После "
@@ -861,7 +874,7 @@ msgstr ""
 "систему управления материалами, где возможно работать над своими "
 "дополнениями."
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -878,18 +891,18 @@ msgstr ""
 "где будет располагаться инструкция по загрузке своих материалов. Либо "
 "потребуется связаться с владельцами сайта."
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "Загрузка данных"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "Установка"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -902,73 +915,73 @@ msgstr ""
 "Get Hot New Stuff. Если так не должно быть, обратитесь к ответственному за "
 "выдачу вам прав доступа."
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "Назад"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr "Популярные"
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "Рекомендованные"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "Перезапустить"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "New"
 msgstr "Создать"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Домой"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr "Полка"
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "Вверх"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "Рекомендуется"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "Подписки"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "Все записи"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -1014,8 +1027,12 @@ msgstr ""
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
 #, kde-format
-msgid "Download New Stuff..."
-msgstr "Загрузить материалы..."
+msgctxt "@action"
+msgid "Download New Stuff…"
+msgstr "Загрузить материалы…"
+
+#~ msgid "Download New Stuff..."
+#~ msgstr "Загрузить материалы..."
 
 #~ msgctxt ""
 #~ "A message which is shown when the user attempts to display a specific "
diff -pruN 6.0.0-3/po/se/knewstuff6.po 6.3.0-1/po/se/knewstuff6.po
--- 6.0.0-3/po/se/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/se/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -5,7 +5,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2012-05-30 23:19+0200\n"
 "Last-Translator: Børre Gaup <boerre@skolelinux.no>\n"
 "Language-Team: Northern Sami <l10n-no@lister.huftis.org>\n"
@@ -57,7 +57,7 @@ msgstr "Du jienasteapmi registrerejuvvui
 msgid "You are now a fan."
 msgstr "Dál don liikot dása."
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -121,7 +121,7 @@ msgstr "Heivehusfiila ii gusto: «%1»"
 msgid "Use"
 msgstr "Geavat"
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -129,17 +129,17 @@ msgid ""
 "This is a critical error and should be reported to the application author"
 msgstr ""
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr "Ii gávdnan skáhppojeddjiid «%1»-fiillas"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr "Ii gávdnan hot-new-stuff-skáhppojeddjiid «%1»-fiillas"
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr ""
@@ -279,21 +279,21 @@ msgid ""
 "the update"
 msgstr ""
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, kde-format
 msgid ""
 "Failed to adopt '%1'\n"
 "%2"
 msgstr ""
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, kde-format
 msgctxt ""
 "The first entry in the category selection list (also the default value)"
 msgid "All Categories"
 msgstr ""
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, kde-format
 msgctxt ""
 "The string passed back in the case the requested category is not known"
@@ -317,13 +317,13 @@ msgstr ""
 msgid "Download New %1…"
 msgstr "Viečča ođđa, somás tiŋggaid …"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, kde-format
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr ""
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, kde-format
 msgctxt ""
 "A placeholder title used in the dialog when there is no better title "
@@ -331,12 +331,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -345,19 +345,19 @@ msgid ""
 "this through the naming of the items."
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "Sajáiduhte"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, kde-format
 msgctxt ""
 "A passive notification shown when installation of an item is initiated"
 msgid "Installing %1 from %2"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -365,10 +365,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, kde-format
 msgctxt ""
 "Request installation of this item, available when there is exactly one "
@@ -376,32 +376,32 @@ msgctxt ""
 msgid "Install"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, fuzzy, kde-format
 msgctxt ""
 "Show installation options, where there is more than one downloadable item"
 msgid "Install…"
 msgstr "Sajáiduhte"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, kde-format
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, kde-format
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -409,14 +409,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -427,12 +427,12 @@ msgid ""
 "to the KDE Community in a bug report</a>."
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a new sub page with comments (comments "
@@ -440,17 +440,17 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, kde-format
 msgid "Rating:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, kde-format
 msgid "Homepage:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -459,12 +459,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -472,72 +472,80 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr ""
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, kde-format
 msgid "Tiles"
 msgstr ""
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr ""
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, kde-format
 msgid "Preview"
 msgstr ""
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, kde-format
 msgid "Detailed Tiles View Mode"
 msgstr ""
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, kde-format
 msgid "Icons Only View Mode"
 msgstr ""
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, kde-format
 msgid "Large Preview View Mode"
 msgstr ""
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr ""
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "Sajáiduhtton"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, kde-format
 msgid "Updateable"
 msgstr ""
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, kde-format
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -545,27 +553,27 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, kde-format
 msgid "Recent"
 msgstr ""
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr ""
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "Árvoortnet"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, kde-format
 msgid "Downloads"
 msgstr ""
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on when items were most "
@@ -573,7 +581,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr ""
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -581,57 +589,57 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr ""
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, kde-format
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr ""
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on number of downloads"
 msgid "Show Most Downloaded First"
 msgstr ""
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, kde-format
 msgid "Upload…"
 msgstr ""
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr ""
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, kde-format
 msgid "Go to…"
 msgstr ""
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, kde-format
 msgid "Search…"
 msgstr ""
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "Kategoriija:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, kde-format
 msgid "Contribute your own…"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, kde-format
 msgctxt ""
 "Placeholder title for when a comment has no subject, but does have a rating"
 msgid "<i>(no title)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -639,19 +647,19 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, kde-format
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -659,7 +667,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -667,15 +675,15 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, kde-format
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, kde-format
 msgctxt ""
 "Subheading for the tile view, located immediately underneath the name of the "
@@ -683,7 +691,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -691,7 +699,7 @@ msgctxt ""
 msgid "Working…"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is in the process of being "
@@ -699,7 +707,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -710,7 +718,7 @@ msgid ""
 "bug report</a>."
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, fuzzy, kde-format
 msgctxt "Label for the busy indicator showing an item is installing"
 msgid "Installing…"
@@ -727,44 +735,44 @@ msgstr ""
 msgid "Please try again later."
 msgstr ""
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, kde-format
 msgid "None"
 msgstr ""
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, kde-format
 msgctxt ""
 "A text representation of the rating, shown as a fraction of the max value"
 msgid "(%1/%2)"
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, fuzzy, kde-format
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "Viečča ođđa, somás tiŋggaid …"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, fuzzy, kde-format
 msgctxt ""
 "A text shown beside a busy indicator suggesting that data is being fetched"
 msgid "Updating information…"
 msgstr "Viežžamin skáhppojeaddjidieđuid"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, kde-format
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, kde-format
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, kde-format
 msgctxt ""
 "Text for an action which causes the specified website to be opened using the "
@@ -772,7 +780,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, kde-format
 msgctxt ""
 "Text for an action which will attempt to send an email using the user's "
@@ -780,7 +788,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -788,10 +796,10 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -803,18 +811,18 @@ msgid ""
 "content added."
 msgstr ""
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "Viežžamin dataid"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "Sajáiduhttimin"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -824,73 +832,73 @@ msgid ""
 "please contact the person in charge of your permissions."
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Back"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "New"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Home"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Up"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -921,6 +929,8 @@ msgid ""
 msgstr ""
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
-#, kde-format
-msgid "Download New Stuff..."
+#, fuzzy, kde-format
+#| msgid "Download New Stuff..."
+msgctxt "@action"
+msgid "Download New Stuff…"
 msgstr "Viečča ođđa, somás tiŋggaid …"
diff -pruN 6.0.0-3/po/si/knewstuff6.po 6.3.0-1/po/si/knewstuff6.po
--- 6.0.0-3/po/si/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/si/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -5,7 +5,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2011-07-25 07:45+0530\n"
 "Last-Translator: Danishka Navin <danishka@gmail.com>\n"
 "Language-Team: Sinhala <danishka@gmail.com>\n"
@@ -63,7 +63,7 @@ msgstr "කිසිදු පෙළක
 msgid "You are now a fan."
 msgstr ""
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -132,7 +132,7 @@ msgstr "මානකරණ ගොනු"
 msgid "Use"
 msgstr ""
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -140,17 +140,17 @@ msgid ""
 "This is a critical error and should be reported to the application author"
 msgstr ""
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr ""
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr ""
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr "සැපසුම ඇරඹීම දෝෂ සහිතයි."
@@ -297,7 +297,7 @@ msgid ""
 "the update"
 msgstr ""
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, fuzzy, kde-format
 #| msgid "Failed to load file '%1'"
 msgid ""
@@ -305,7 +305,7 @@ msgid ""
 "%2"
 msgstr "'%1' ගොනුව පූරණය අසමත් විය"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, fuzzy, kde-format
 #| msgid "All Pages"
 msgctxt ""
@@ -313,7 +313,7 @@ msgctxt ""
 msgid "All Categories"
 msgstr "සියලු පිටු"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, fuzzy, kde-format
 #| msgid "Unknown error"
 msgctxt ""
@@ -339,14 +339,14 @@ msgstr ""
 msgid "Download New %1…"
 msgstr "නව %1 බාගන්න"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, fuzzy, kde-format
 #| msgid "Download New %1"
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "නව %1 බාගන්න"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
 msgctxt ""
@@ -355,12 +355,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "නවතම දේ බාගන්න"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -369,12 +369,12 @@ msgid ""
 "this through the naming of the items."
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "ස්ථාපනය"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -382,7 +382,7 @@ msgctxt ""
 msgid "Installing %1 from %2"
 msgstr "ස්ථාපනය"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -390,10 +390,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -402,10 +402,10 @@ msgctxt ""
 msgid "Install"
 msgstr "ස්ථාපනය"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -413,24 +413,24 @@ msgctxt ""
 msgid "Install…"
 msgstr "ස්ථාපනය"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, fuzzy, kde-format
 #| msgid "Update"
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "යාවත්කාලීන"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, fuzzy, kde-format
 #| msgid "Uninstall"
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "අස්ථාපනය"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -438,14 +438,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -456,12 +456,12 @@ msgid ""
 "to the KDE Community in a bug report</a>."
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, fuzzy, kde-format
 #| msgid "View Comments"
 msgctxt ""
@@ -470,19 +470,19 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "සටහන් දර්ශනය"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, fuzzy, kde-format
 #| msgid "Rating: "
 msgid "Rating:"
 msgstr "ඇගැයුම:"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, fuzzy, kde-format
 #| msgid "Homepage"
 msgid "Homepage:"
 msgstr "නිවාස පිටුව"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -491,12 +491,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -504,73 +504,81 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr ""
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, fuzzy, kde-format
 #| msgctxt "@option:check Do filter on type - show only files"
 #| msgid "Files"
 msgid "Tiles"
 msgstr "ගොනු"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "අයිකන"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, fuzzy, kde-format
 #| msgid "No Preview"
 msgid "Preview"
 msgstr "පූර්‍ව දසුන් නැත"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, fuzzy, kde-format
 #| msgid "Detailed View"
 msgid "Detailed Tiles View Mode"
 msgstr "විස්තරාත්මක දසුන"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, fuzzy, kde-format
 #| msgid "Icons view mode"
 msgid "Icons Only View Mode"
 msgstr "අයිකන පෙනෙන ආකාරය"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, fuzzy, kde-format
 #| msgid "Detailed View"
 msgid "Large Preview View Mode"
 msgstr "විස්තරාත්මක දසුන"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr ""
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "ස්ථාපනය"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, fuzzy, kde-format
 #| msgid "Update"
 msgid "Updateable"
 msgstr "යාවත්කාලීන"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, fuzzy, kde-format
 #| msgid "&Show All Entries"
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "සියලු ඇතුළත් කිරීම් දර්ෂණය කරන්න (&S)"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, fuzzy, kde-format
 #| msgid "&Show All Entries"
 msgctxt ""
@@ -578,7 +586,7 @@ msgctxt ""
 msgid "Show Only Installed Entries"
 msgstr "සියලු ඇතුළත් කිරීම් දර්ෂණය කරන්න (&S)"
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, fuzzy, kde-format
 #| msgid "&Show All Entries"
 msgctxt ""
@@ -587,30 +595,30 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr "සියලු ඇතුළත් කිරීම් දර්ෂණය කරන්න (&S)"
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Open Recent"
 msgid "Recent"
 msgstr "මෑතකදි භාවිතා කළ දැ විවෘත කරන්න"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr ""
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "ඇගැයුම"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, fuzzy, kde-format
 #| msgid "Download"
 msgid "Downloads"
 msgstr "බාගන්න"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt ""
@@ -619,7 +627,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "පළමුව බහලුම් පෙන්වන්න"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -627,14 +635,14 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr ""
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "පළමුව බහලුම් පෙන්වන්න"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, fuzzy, kde-format
 #| msgid "Most downloads"
 msgctxt ""
@@ -642,41 +650,41 @@ msgctxt ""
 msgid "Show Most Downloaded First"
 msgstr "වැඩිම බාගැනීම්"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, fuzzy, kde-format
 #| msgid "&Replace..."
 msgid "Upload…"
 msgstr "ආදේශය... (&R)"
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr ""
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, fuzzy, kde-format
 #| msgid "&Go To..."
 msgid "Go to…"
 msgstr "යායුත්තේ... (&G)"
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, fuzzy, kde-format
 #| msgid "Search:"
 msgid "Search…"
 msgstr "සොයන්න:"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "ප්‍රභේදය:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, fuzzy, kde-format
 #| msgid "Continue operation"
 msgid "Contribute your own…"
 msgstr "මෙහෙයුම දිගටම කරගෙන යන්න"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, fuzzy, kde-format
 #| msgctxt "@note/rich"
 #| msgid "<i>Note</i>: %1"
@@ -685,7 +693,7 @@ msgctxt ""
 msgid "<i>(no title)</i>"
 msgstr "<i>සටහන</i>: %1"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -693,20 +701,20 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, fuzzy, kde-format
 #| msgid "All Pages"
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "සියලු පිටු"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -714,7 +722,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -722,16 +730,16 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, fuzzy, kde-format
 #| msgid "Download"
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
 msgstr "බාගන්න"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, fuzzy, kde-format
 #| msgctxt "@interface/rich"
 #| msgid "<i>%1</i>"
@@ -741,7 +749,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "<i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -749,7 +757,7 @@ msgctxt ""
 msgid "Working…"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, fuzzy, kde-format
 #| msgid "Update"
 msgctxt ""
@@ -758,7 +766,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "යාවත්කාලීන"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -769,7 +777,7 @@ msgid ""
 "bug report</a>."
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt "Label for the busy indicator showing an item is installing"
@@ -788,14 +796,14 @@ msgstr ""
 msgid "Please try again later."
 msgstr "කරුණාකර නමක් තුළ යොදන්න."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, fuzzy, kde-format
 #| msgctxt "No border line"
 #| msgid "None"
 msgid "None"
 msgstr "කිසිවක් නැත"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, fuzzy, kde-format
 #| msgid "(%1/s)"
 msgctxt ""
@@ -803,14 +811,14 @@ msgctxt ""
 msgid "(%1/%2)"
 msgstr "(%1/s)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "නවතම දේ බාගන්න"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, fuzzy, kde-format
 #| msgid "Billing information:"
 msgctxt ""
@@ -818,21 +826,21 @@ msgctxt ""
 msgid "Updating information…"
 msgstr "බිල්පත් තොරතුරු:"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, fuzzy, kde-format
 #| msgid "&Store"
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "ගබඩා කරන්න (&S)"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, fuzzy, kde-format
 #| msgid "Provider:"
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "ප්‍රතිපාදක:"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, fuzzy, kde-format
 #| msgid "&Open with '%1'"
 msgctxt ""
@@ -841,7 +849,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "'%1' සමඟ විවෘත කරන්න (&O)"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, fuzzy, kde-format
 #| msgid "&Send Email"
 msgctxt ""
@@ -850,7 +858,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "විද්‍යෘත් තැපෑල යවන්න (&S)"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -858,10 +866,10 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -873,20 +881,20 @@ msgid ""
 "content added."
 msgstr ""
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, fuzzy, kde-format
 #| msgid "Loading Applet"
 msgid "Loading data"
 msgstr "යෙදුම්පත පූරණය වෙමින්"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, fuzzy, kde-format
 #| msgid "Install"
 msgid "Installing"
 msgstr "ස්ථාපනය"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -896,7 +904,7 @@ msgid ""
 "please contact the person in charge of your permissions."
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Back"
@@ -904,20 +912,20 @@ msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "පසු පසට"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, fuzzy, kde-format
 #| msgid "Saturday"
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "සෙනසුරාදා"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, fuzzy, kde-format
 #| msgctxt "@action:button Restart find & replace"
 #| msgid "Restart"
@@ -925,7 +933,7 @@ msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "යළි ඇරඹුම"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "New"
@@ -933,7 +941,7 @@ msgctxt "Knewstuff5"
 msgid "New"
 msgstr "නව"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Home"
@@ -941,13 +949,13 @@ msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Home"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Up"
@@ -955,7 +963,7 @@ msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "Up"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, fuzzy, kde-format
 #| msgctxt "dictionary variant"
 #| msgid "extended"
@@ -963,7 +971,7 @@ msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "දීර්ඝ කළ"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Subscript"
@@ -971,14 +979,14 @@ msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "දායකත්වය"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, fuzzy, kde-format
 #| msgid "&Show All Entries"
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "සියලු ඇතුළත් කිරීම් දර්ෂණය කරන්න (&S)"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -1011,10 +1019,16 @@ msgstr ""
 #: widgets/action.cpp:28 widgets/button.cpp:70
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
-msgid "Download New Stuff..."
+msgctxt "@action"
+msgid "Download New Stuff…"
 msgstr "නවතම දේ බාගන්න"
 
 #, fuzzy
+#~| msgid "Download New Stuff"
+#~ msgid "Download New Stuff..."
+#~ msgstr "නවතම දේ බාගන්න"
+
+#, fuzzy
 #~| msgid "Install"
 #~ msgid "Initializing"
 #~ msgstr "ස්ථාපනය"
diff -pruN 6.0.0-3/po/sk/knewstuff6.po 6.3.0-1/po/sk/knewstuff6.po
--- 6.0.0-3/po/sk/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/sk/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -13,7 +13,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2023-12-02 20:07+0100\n"
 "Last-Translator: Matej Mrenica <matejm98mthw@gmail.com>\n"
 "Language-Team: Slovak <kde-i18n-doc@kde.org>\n"
@@ -62,7 +62,7 @@ msgstr "Váš hlas bol zaznamenaný."
 msgid "You are now a fan."
 msgstr "Teraz ste fanúšik."
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -131,7 +131,7 @@ msgstr "Konfiguračný súbor je neplatn
 msgid "Use"
 msgstr "Použiť"
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -142,17 +142,17 @@ msgstr ""
 "%2\n"
 "Toto je kritická chyba a mala by sa nahlásiť autorovi aplikácie"
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr "Načítavanie poskytovateľov zo súboru: %1 zlyhalo"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr "Nepodarilo sa načítať poskytovateľov obsahu zo súboru: %1"
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr "Chyba pri inicializácii poskytovateľa."
@@ -321,7 +321,7 @@ msgstr ""
 "Nepodarilo sa identifikovať dobrý odkaz na aktualizáciu %1 a nie je možné "
 "vykonať aktualizáciu"
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, kde-format
 msgid ""
 "Failed to adopt '%1'\n"
@@ -330,14 +330,14 @@ msgstr ""
 "Nepodarilo sa prijať '%1'\n"
 "%2"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, kde-format
 msgctxt ""
 "The first entry in the category selection list (also the default value)"
 msgid "All Categories"
 msgstr "Všetky kategórie"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, kde-format
 msgctxt ""
 "The string passed back in the case the requested category is not known"
@@ -361,13 +361,13 @@ msgstr "Veci"
 msgid "Download New %1…"
 msgstr "Stiahnuť nové %1..."
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, kde-format
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "Stiahnuť nové %1"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, kde-format
 msgctxt ""
 "A placeholder title used in the dialog when there is no better title "
@@ -375,12 +375,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "Stiahnuť novú vec"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr "Vyberte si možnosť inštalácie"
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -393,19 +393,19 @@ msgstr ""
 "si máte vybrať, kontaktujte prosím autora tejto položky na objasnenie názvov "
 "položiek."
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "Inštalovať"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, kde-format
 msgctxt ""
 "A passive notification shown when installation of an item is initiated"
 msgid "Installing %1 from %2"
 msgstr "Inštaluje sa %1 z %2"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -413,10 +413,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr "%1 od %2"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, kde-format
 msgctxt ""
 "Request installation of this item, available when there is exactly one "
@@ -424,32 +424,32 @@ msgctxt ""
 msgid "Install"
 msgstr "Inštalovať"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, kde-format
 msgctxt ""
 "Show installation options, where there is more than one downloadable item"
 msgid "Install…"
 msgstr "Inštalovanie..."
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, kde-format
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "Aktualizovať"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, kde-format
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "Odinštalovať"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -457,14 +457,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr "Momentálne sa pracuje na položke %1 od %2. Počkajte prosím..."
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr "Aktuálne sa aktualizuje položka %1 od %2. Prosím čakajte..."
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -478,12 +478,12 @@ msgstr ""
 "\"https://bugs.kde.org/enter_bug.cgi?product=frameworks-knewstuff\">Prosím "
 "nahláste to KDE Komunite v hlásení o chybe</a>."
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr "Komentáre a recenzie:"
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a new sub page with comments (comments "
@@ -491,17 +491,17 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "%1 Hodnotení a komentárov"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, kde-format
 msgid "Rating:"
 msgstr "Hodnotenie: "
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, kde-format
 msgid "Homepage:"
 msgstr "Domovská stránka:"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -510,12 +510,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr "Otvoriť domovskú stránku pre %1"
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr "Ako prispieť:"
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -523,74 +523,85 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr "Zistiť ako sa dá prispieť na tento projekt"
 
-#: qtquick/qml/Page.qml:141
-#, kde-format
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
+#, fuzzy, kde-format
+#| msgid ""
+#| "The content available here has been uploaded by users like you, and has "
+#| "not been reviewed by your distributor for functionality or stability."
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 "Obsah, ktorý je tu k dispozícii, nahrali používatelia, ako ste vy, a nebol "
 "skontrolovaný distribútorom z hľadiska funkčnosti alebo stability."
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, kde-format
 msgid "Tiles"
 msgstr "Dlaždice"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "Ikony"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, kde-format
 msgid "Preview"
 msgstr "Náhľad"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, kde-format
 msgid "Detailed Tiles View Mode"
 msgstr "Režim zobrazenia podrobných dlaždíc"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, kde-format
 msgid "Icons Only View Mode"
 msgstr "Režim zobrazenia iba ikony"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, kde-format
 msgid "Large Preview View Mode"
 msgstr "Režim zobrazenia veľkých ukážok"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr "Všetko"
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "Nainštalované"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, kde-format
 msgid "Updateable"
 msgstr "Aktualizovateľné"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, kde-format
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "Zobraziť všetky položky"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr "Zobraziť iba inštalované položky"
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -598,27 +609,27 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr "Zobraziť iba aktualizovateľné položky"
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, kde-format
 msgid "Recent"
 msgstr "Nedávne"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr "Abecedne"
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "Hodnotenie"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, kde-format
 msgid "Downloads"
 msgstr "Preberania"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on when items were most "
@@ -626,7 +637,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "Zobraziť najnovšie ako prvé"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -634,57 +645,57 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr "Zoradiť abecedne podľa názvu"
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, kde-format
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "Zobraziť najlepšie ako prvé"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on number of downloads"
 msgid "Show Most Downloaded First"
 msgstr "Zobraziť najsťahovanejšie ako prvé"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, kde-format
 msgid "Upload…"
 msgstr "Odosielanie..."
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr "Naučiť sa, ako do tohto zoznamu pridať vlastné horúce novinky"
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, kde-format
 msgid "Go to…"
 msgstr "Prejsť na..."
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, kde-format
 msgid "Search…"
 msgstr "Hľadať..."
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "Kategória:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, kde-format
 msgid "Contribute your own…"
 msgstr "Pridajte svoje vlastné..."
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, kde-format
 msgctxt ""
 "Placeholder title for when a comment has no subject, but does have a rating"
 msgid "<i>(no title)</i>"
 msgstr "<i>(žiadny názov)</i>"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -692,19 +703,19 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr "%1 <i>(autor)</i>"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr "Komentáre a recenzie pre %1"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, kde-format
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "Zobraziť všetky komentáre"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -712,7 +723,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr "Zobraziť iba hodnotenia"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -720,15 +731,15 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr "Zobraziť hodnotenia aj odpovede"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, kde-format
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
 msgstr "%1 stiahnutí"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, kde-format
 msgctxt ""
 "Subheading for the tile view, located immediately underneath the name of the "
@@ -736,7 +747,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "Od <i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -744,7 +755,7 @@ msgctxt ""
 msgid "Working…"
 msgstr "Pracujem..."
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is in the process of being "
@@ -752,7 +763,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "Aktualizuje sa..."
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -766,7 +777,7 @@ msgstr ""
 "product=frameworks-knewstuff\">Prosím nahláste to KDE Komunite v hlásení o "
 "chybe</a>."
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, kde-format
 msgctxt "Label for the busy indicator showing an item is installing"
 msgid "Installing…"
@@ -783,44 +794,44 @@ msgstr "Došlo k chybe"
 msgid "Please try again later."
 msgstr "Skúste prosím neskôr."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, kde-format
 msgid "None"
 msgstr "Žiadny"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, kde-format
 msgctxt ""
 "A text representation of the rating, shown as a fraction of the max value"
 msgid "(%1/%2)"
 msgstr "(%1/%2)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, kde-format
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "Odoslať novú vec: %1"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, kde-format
 msgctxt ""
 "A text shown beside a busy indicator suggesting that data is being fetched"
 msgid "Updating information…"
 msgstr "Aktualizujú sa informácie..."
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, kde-format
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "KDE Store"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, kde-format
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "Váš poskytovateľ"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, kde-format
 msgctxt ""
 "Text for an action which causes the specified website to be opened using the "
@@ -828,7 +839,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "Otvoriť webovú stránku: %1"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, kde-format
 msgctxt ""
 "Text for an action which will attempt to send an email using the user's "
@@ -836,15 +847,22 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "Poslať Email do: %1"
 
-#: qtquick/qml/UploadPage.qml:154
-#, kde-format
+#: qtquick/qml/UploadPage.qml:159
+#, fuzzy, kde-format
+#| msgctxt "A description of how to upload content to a generic provider"
+#| msgid ""
+#| "To upload new entries, or to add content to an existing entry on the KDE "
+#| "Store, please open the website and log in. Once you have done this, you "
+#| "will be able to find the My Products entry in the menu which pops up when "
+#| "you click your user icon. Click on this entry to go to the product "
+#| "management system, where you can work on your products ."
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
 "To upload new entries, or to add content to an existing entry on the KDE "
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 "Ak chcete nahrať nové položky alebo pridať obsah do existujúcej položky v "
 "obchode KDE, otvorte webovú stránku a prihláste sa. Keď to urobíte, v "
@@ -852,7 +870,7 @@ msgstr ""
 "Moje produkty. Kliknutím na túto položku prejdete do správy produktov kde "
 "môžete pracovať so svojimi výrobkami ."
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -870,18 +888,18 @@ msgstr ""
 "Prípadne môžete možno budete musieť kontaktovať priamo správcov stránky, aby "
 "ste získali nové pridanie obsahu."
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "Načítavajú sa dáta"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "Inštaluje sa"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -893,73 +911,73 @@ msgstr ""
 "Nemáte oprávnenie na získanie nových vecí. Ak si myslíte že toto je chyba, "
 "prosím kontaktujte osobu zodpovednú za vaše oprávnenia."
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "Späť"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr "Populárne"
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "Odporúčané"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "Znovu spustiť"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "New"
 msgstr "Nový"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Home"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr "Polička"
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "Hore"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "Odporúčaný"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "Odbery"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "Zobraziť položky"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -1015,9 +1033,17 @@ msgstr ""
 "Príklad takého URL je kns://peruse.knsrc/api.kde-look.org/1316714"
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
-#, kde-format
-msgid "Download New Stuff..."
-msgstr "Stiahnuť nové veci..."
+#, fuzzy, kde-format
+#| msgctxt ""
+#| "A placeholder title used in the dialog when there is no better title "
+#| "available"
+#| msgid "Download New Stuff"
+msgctxt "@action"
+msgid "Download New Stuff…"
+msgstr "Stiahnuť novú vec"
+
+#~ msgid "Download New Stuff..."
+#~ msgstr "Stiahnuť nové veci..."
 
 #~ msgctxt ""
 #~ "A message which is shown when the user attempts to display a specific "
diff -pruN 6.0.0-3/po/sl/knewstuff6.po 6.3.0-1/po/sl/knewstuff6.po
--- 6.0.0-3/po/sl/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/sl/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -17,8 +17,8 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
-"PO-Revision-Date: 2024-01-19 06:40+0100\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
+"PO-Revision-Date: 2024-05-08 07:36+0200\n"
 "Last-Translator: Matjaž Jeran <matjaz.jeran@amis.net>\n"
 "Language-Team: Slovenian <lugos-slo@lugos.si>\n"
 "Language: sl\n"
@@ -68,7 +68,7 @@ msgstr "Vaš glas je bil zabeležen."
 msgid "You are now a fan."
 msgstr "Sedaj ste postali oboževalec."
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -135,7 +135,7 @@ msgstr "Nastavitvena datoteka ni veljavn
 msgid "Use"
 msgstr "Uporabi"
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -146,17 +146,17 @@ msgstr ""
 "%2\n"
 "To je kritična napaka in bi jo bilo treba sporočiti avtorju programa"
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr "Nalaganje ponudnikov iz datoteke: %1 ni uspel"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr "Iz datoteke ni bilo mogoče naložiti ponudnikov vročih novosti: %1"
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr "Napaka pri inicializaciji ponudnika."
@@ -327,7 +327,7 @@ msgstr ""
 "Identifikacije dobre povezave za posodobitev %1 nismo pridobili, zato "
 "posodobitve ne moremo izvesti"
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, kde-format
 msgid ""
 "Failed to adopt '%1'\n"
@@ -336,14 +336,14 @@ msgstr ""
 "Ni bilo mogoče sprejeti '%1'\n"
 "%2"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, kde-format
 msgctxt ""
 "The first entry in the category selection list (also the default value)"
 msgid "All Categories"
 msgstr "Vse kategorije"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, kde-format
 msgctxt ""
 "The string passed back in the case the requested category is not known"
@@ -367,13 +367,13 @@ msgstr "Stvari"
 msgid "Download New %1…"
 msgstr "Prejmi novosti %1…"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, kde-format
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "Prejmi novosti %1"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, kde-format
 msgctxt ""
 "A placeholder title used in the dialog when there is no better title "
@@ -381,12 +381,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "Prejmi novosti"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr "Izberite način namestitve"
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -399,19 +399,19 @@ msgstr ""
 "se obrnite na avtorja tega predmeta in ga prosite, da to pojasni s "
 "poimenovanjem predmetov."
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "Namesti"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, kde-format
 msgctxt ""
 "A passive notification shown when installation of an item is initiated"
 msgid "Installing %1 from %2"
 msgstr "Nameščam %1 od %2"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -419,10 +419,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr "%1 z %2"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, kde-format
 msgctxt ""
 "Request installation of this item, available when there is exactly one "
@@ -430,32 +430,32 @@ msgctxt ""
 msgid "Install"
 msgstr "Namesti"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, kde-format
 msgctxt ""
 "Show installation options, where there is more than one downloadable item"
 msgid "Install…"
 msgstr "Namesti…"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, kde-format
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "Posodobi"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, kde-format
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "Odstrani"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -463,14 +463,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr "Trenutno delam na postavki %1 za %2. Prosimo počakajte…"
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr "Trenutno posodabljam %1 za %2. Prosimo počakajte…"
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -484,12 +484,12 @@ msgstr ""
 "bugs.kde.org/enter_bug.cgi?product=frameworks-knewstuff\">Sporočite to "
 "skupnosti KDE v poročilu o napakah</a>."
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr "Komentarji in ocene:"
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a new sub page with comments (comments "
@@ -497,17 +497,17 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "%1 Ocene in komentarji"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, kde-format
 msgid "Rating:"
 msgstr "Ocena:"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, kde-format
 msgid "Homepage:"
 msgstr "Domača stran:"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -516,12 +516,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr "Odpri domačo stran za %1"
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr "Kako donirati:"
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -529,75 +529,85 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr "Ugotovite, kako lahko donirate za ta projekt"
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+"Bodite previdni, ko dostopate do tukaj prikazane vsebine, ki jo ustvarijo "
+"uporabniki, saj lahko vsebuje izvedljivo kodo, ki je KDE ali vaš distributer "
+"ni testiral glede varnosti, stabilnosti ali kakovosti"
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
-"Razpoložljiva vsebina, ki je na voljo tukaj, je bila poslana od uporabnikov "
-"kakor ste vi in ni bila pregledana s strani distributerja glede "
-"funkcionalnosti ali stabilnosti."
+"Uporabniško ustvarjena vsebina, prikazana tukaj, ni bila testirana s strani "
+"KDE ali vašega distributerja glede funkcionalnosti ali kakovosti."
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, kde-format
 msgid "Tiles"
 msgstr "Ploskve"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "Ikone"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, kde-format
 msgid "Preview"
 msgstr "Predogled"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, kde-format
 msgid "Detailed Tiles View Mode"
 msgstr "Način podrobnega ogleda ploskev"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, kde-format
 msgid "Icons Only View Mode"
 msgstr "Način prikaza ikon samih"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, kde-format
 msgid "Large Preview View Mode"
 msgstr "Način prikaza velikega predogleda"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr "Vse"
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "Nameščeno"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, kde-format
 msgid "Updateable"
 msgstr "Posodobljivo"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, kde-format
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "Prikaži vse vnose"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr "Prikaži samo nameščene vnose"
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -605,27 +615,27 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr "Prikaži samo posodobljive vnose"
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, kde-format
 msgid "Recent"
 msgstr "Nedavne"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr "Abecedno"
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "Ocena"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, kde-format
 msgid "Downloads"
 msgstr "Prejemi"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on when items were most "
@@ -633,7 +643,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "Najprej pokaži nedavne"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -641,57 +651,57 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr "Uredi po abecednem redu imen"
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, kde-format
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "Pokaži najprej najbolje ocenjene"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on number of downloads"
 msgid "Show Most Downloaded First"
 msgstr "Pokaži najprej največkrat prenesene"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, kde-format
 msgid "Upload…"
 msgstr "Pošlji…"
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr "Naučite se dodati lastno vroče blago v ta seznam"
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, kde-format
 msgid "Go to…"
 msgstr "Pojdi na…"
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, kde-format
 msgid "Search…"
 msgstr "Išči…"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "Kategorija:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, kde-format
 msgid "Contribute your own…"
 msgstr "Prispevajte vaše lastne…"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, kde-format
 msgctxt ""
 "Placeholder title for when a comment has no subject, but does have a rating"
 msgid "<i>(no title)</i>"
 msgstr "<i>(ni naslova)</i>"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -699,19 +709,19 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr "%1 <i>(avtor)</i>"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr "Komentarji in ocene za %1"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, kde-format
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "Prikaži vse komentarje"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -719,7 +729,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr "Prikaži samo ocene"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -727,15 +737,15 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr "Prikaži ocene in odzive"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, kde-format
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
 msgstr "%1 prejemov"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, kde-format
 msgctxt ""
 "Subheading for the tile view, located immediately underneath the name of the "
@@ -743,7 +753,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "Avtor <i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -751,7 +761,7 @@ msgctxt ""
 msgid "Working…"
 msgstr "Delam…"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is in the process of being "
@@ -759,7 +769,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "Posodabljanje…"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -773,7 +783,7 @@ msgstr ""
 "product=frameworks-knewstuff\">Sporočite to skupnosti KDE v poročilu o "
 "napaki</a>."
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, kde-format
 msgctxt "Label for the busy indicator showing an item is installing"
 msgid "Installing…"
@@ -790,44 +800,44 @@ msgstr "Prišlo je do napake"
 msgid "Please try again later."
 msgstr "Prosim, poskusite kasneje."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, kde-format
 msgid "None"
 msgstr "Brez"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, kde-format
 msgctxt ""
 "A text representation of the rating, shown as a fraction of the max value"
 msgid "(%1/%2)"
 msgstr "(%1/%2)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, kde-format
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "Prenesi tja novosti: %1"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, kde-format
 msgctxt ""
 "A text shown beside a busy indicator suggesting that data is being fetched"
 msgid "Updating information…"
 msgstr "Osveževanje informacij…"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, kde-format
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "Shramba KDE"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, kde-format
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "Vaš ponudnik"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, kde-format
 msgctxt ""
 "Text for an action which causes the specified website to be opened using the "
@@ -835,7 +845,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "Odpri spletišče: %1"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, kde-format
 msgctxt ""
 "Text for an action which will attempt to send an email using the user's "
@@ -843,7 +853,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "Pošlji e-pošto za: %1"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -851,15 +861,15 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
-"Naložiti nove vnose ali dodati vsebino obstoječemu vnosu na shrambi KDE, "
-"odprite spletišče in se prijavite. Ko ste to storili, lahko najdete vnos "
-"svojega izdelka v meniju My Products (Moji izdelki), ki se pojavi, ko ste "
-"kliknili ikono uporabnika. Kliknite na ta vnos, da pridete na sistem "
+"Za prenos novih vnosov ali dodajanje vsebine obstoječemu vnosu na shrambi "
+"KDE, odprite spletišče in se prijavite. Ko ste to storili, lahko najdete "
+"vnos svojega izdelka v meniju My Products (Moji izdelki), ki se pojavi, ko "
+"ste kliknili ikono uporabnika. Kliknite na ta vnos, da pridete na sistem "
 "upravljanja izdelkov, kjer lahko delate na svojih izdelkih."
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -876,18 +886,18 @@ msgstr ""
 "boste morali upoštevati navodila za dodajanje. Druga možnost je, da se "
 "obrnete na upravljavce spletišča, da dodajo novo vsebino."
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "Nalaganje podatkov"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "Nameščanje"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -899,73 +909,73 @@ msgstr ""
 "Nimate pooblastil za \"Get Hot New Stuff\". Če menite, da je to napaka, se "
 "obrnite na osebo, ki je odgovorna za vaša dovoljenja."
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "Nazaj"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr "Popularno"
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "Predstavljeno"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "Ponovno zaženi"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "New"
 msgstr "Novi"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Domov"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr "Polica"
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "Gor"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "Priporočen"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "Naročila"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "Vsi vnosi"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -1011,8 +1021,12 @@ msgstr ""
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
 #, kde-format
-msgid "Download New Stuff..."
-msgstr "Prejmi vroče novosti ..."
+msgctxt "@action"
+msgid "Download New Stuff…"
+msgstr "Prenesi novosti…"
+
+#~ msgid "Download New Stuff..."
+#~ msgstr "Prejmi vroče novosti ..."
 
 #~ msgctxt ""
 #~ "A message which is shown when the user attempts to display a specific "
diff -pruN 6.0.0-3/po/sq/knewstuff6.po 6.3.0-1/po/sq/knewstuff6.po
--- 6.0.0-3/po/sq/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/sq/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -3,7 +3,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kde4libs\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2012-01-19 00:20-0500\n"
 "Last-Translator: Agron Selimaj <as9902613@gmail.com>\n"
 "Language-Team: Albanian <sq@li.org>\n"
@@ -50,7 +50,7 @@ msgstr "Nuk u zëvendësua asnjë tekst.
 msgid "You are now a fan."
 msgstr ""
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -119,7 +119,7 @@ msgstr "Skedarët e konfigurimit"
 msgid "Use"
 msgstr "Përdoruesi"
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -127,17 +127,17 @@ msgid ""
 "This is a critical error and should be reported to the application author"
 msgstr ""
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr ""
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr ""
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr ""
@@ -289,14 +289,14 @@ msgid ""
 "the update"
 msgstr ""
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, kde-format
 msgid ""
 "Failed to adopt '%1'\n"
 "%2"
 msgstr ""
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt ""
@@ -304,7 +304,7 @@ msgctxt ""
 msgid "All Categories"
 msgstr "Të Gjitha Kategoritë"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, fuzzy, kde-format
 #| msgid "Unknown error"
 msgctxt ""
@@ -330,14 +330,14 @@ msgstr ""
 msgid "Download New %1…"
 msgstr "Shkarko"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, fuzzy, kde-format
 #| msgid "Download"
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "Shkarko"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, fuzzy, kde-format
 #| msgid "Download"
 msgctxt ""
@@ -346,12 +346,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "Shkarko"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -360,12 +360,12 @@ msgid ""
 "this through the naming of the items."
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "Instalo"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt ""
@@ -373,7 +373,7 @@ msgctxt ""
 msgid "Installing %1 from %2"
 msgstr "Duke Instaluar"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -381,10 +381,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -393,10 +393,10 @@ msgctxt ""
 msgid "Install"
 msgstr "Instalo"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -404,24 +404,24 @@ msgctxt ""
 msgid "Install…"
 msgstr "Instalo"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, fuzzy, kde-format
 #| msgid "Update"
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "Azhuro"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, fuzzy, kde-format
 #| msgid "Uninstall"
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "Çinstalo"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -429,14 +429,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -447,12 +447,12 @@ msgid ""
 "to the KDE Community in a bug report</a>."
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, fuzzy, kde-format
 #| msgid "View Comments"
 msgctxt ""
@@ -461,19 +461,19 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "Shfaq Komentet"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, fuzzy, kde-format
 #| msgid "Rating: "
 msgid "Rating:"
 msgstr "Shkalla: "
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, fuzzy, kde-format
 #| msgid "Homepage"
 msgid "Homepage:"
 msgstr "Faqe Hyrëse"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -482,12 +482,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -495,79 +495,87 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr ""
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, fuzzy, kde-format
 #| msgctxt "@option:check Do filter on type - show only files"
 #| msgid "Files"
 msgid "Tiles"
 msgstr "Skedarët"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "Ikonat"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, fuzzy, kde-format
 #| msgid "Preview URL:"
 msgid "Preview"
 msgstr "Parapamje e URL:"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, kde-format
 msgid "Detailed Tiles View Mode"
 msgstr ""
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, fuzzy, kde-format
 #| msgid "Icons Only"
 msgid "Icons Only View Mode"
 msgstr "Vetëm Ikonat"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, fuzzy, kde-format
 #| msgid "Preview Images"
 msgid "Large Preview View Mode"
 msgstr "Shiko imazhet"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr ""
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "I Instaluar"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, fuzzy, kde-format
 #| msgid "Update"
 msgid "Updateable"
 msgstr "Azhuro"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "Të Gjitha Kategoritë"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -575,31 +583,31 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Open Recent"
 msgid "Recent"
 msgstr "Hap të deritanishëm"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, fuzzy, kde-format
 #| msgid "Alphabetical"
 msgid "Alphabetical"
 msgstr "Në Rend Alfabetik"
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "Vlerësimi"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, fuzzy, kde-format
 #| msgid "Download"
 msgid "Downloads"
 msgstr "Shkarko"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, fuzzy, kde-format
 #| msgid "Most downloads"
 msgctxt ""
@@ -608,7 +616,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "Shumica e shkarkimeve"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, fuzzy, kde-format
 #| msgid "Alphabetical"
 msgctxt ""
@@ -617,14 +625,14 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr "Në Rend Alfabetik"
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, fuzzy, kde-format
 #| msgid "Highest Rated"
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "Më të Vlerësuarit"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, fuzzy, kde-format
 #| msgid "Most downloads"
 msgctxt ""
@@ -632,41 +640,41 @@ msgctxt ""
 msgid "Show Most Downloaded First"
 msgstr "Shumica e shkarkimeve"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, fuzzy, kde-format
 #| msgid "New Upload"
 msgid "Upload…"
 msgstr "Ngarkim i ri"
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr ""
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, fuzzy, kde-format
 #| msgid "&Go To..."
 msgid "Go to…"
 msgstr "&Shko Tek..."
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, fuzzy, kde-format
 #| msgid "Search:"
 msgid "Search…"
 msgstr "Kërko:"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "Kategoria:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, fuzzy, kde-format
 #| msgid "Continue operation"
 msgid "Contribute your own…"
 msgstr "Vazhdo veprimin"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, fuzzy, kde-format
 #| msgctxt "@note/rich"
 #| msgid "<i>Note</i>: %1"
@@ -675,7 +683,7 @@ msgctxt ""
 msgid "<i>(no title)</i>"
 msgstr "<i>Shënim</i>: %1"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -683,20 +691,20 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "Të Gjitha Kategoritë"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -704,7 +712,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -712,16 +720,16 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, fuzzy, kde-format
 #| msgid "Download"
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
 msgstr "Shkarko"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, fuzzy, kde-format
 #| msgctxt "Show the author of this item in a list"
 #| msgid "By <i>%1</i>"
@@ -731,7 +739,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "Nga <i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -739,7 +747,7 @@ msgctxt ""
 msgid "Working…"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, fuzzy, kde-format
 #| msgid "Updating"
 msgctxt ""
@@ -748,7 +756,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "Duke Përditësuar"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -759,7 +767,7 @@ msgid ""
 "bug report</a>."
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt "Label for the busy indicator showing an item is installing"
@@ -778,12 +786,12 @@ msgstr ""
 msgid "Please try again later."
 msgstr "Ju lutemi vendosni një emër."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, kde-format
 msgid "None"
 msgstr "Asnjë"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, fuzzy, kde-format
 #| msgid "(%1/s)"
 msgctxt ""
@@ -791,14 +799,14 @@ msgctxt ""
 msgid "(%1/%2)"
 msgstr "(%1/s)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, fuzzy, kde-format
 #| msgid "Download"
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "Shkarko"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, fuzzy, kde-format
 #| msgid "Show license information"
 msgctxt ""
@@ -806,21 +814,21 @@ msgctxt ""
 msgid "Updating information…"
 msgstr "Shfaq informacion për liçensën"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, fuzzy, kde-format
 #| msgid "&Store"
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "&Ruaje"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, fuzzy, kde-format
 #| msgid "Provider:"
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "Dhënësi:"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, fuzzy, kde-format
 #| msgid "Open '%1'"
 msgctxt ""
@@ -829,7 +837,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "Hape '%1'"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, fuzzy, kde-format
 #| msgid "&Send Email"
 msgctxt ""
@@ -838,7 +846,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "&Dërgo Email-in"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -846,10 +854,10 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -861,19 +869,19 @@ msgid ""
 "content added."
 msgstr ""
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, fuzzy, kde-format
 #| msgid "Loading Applet"
 msgid "Loading data"
 msgstr "Duke Ngarkuar Applet"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "Duke Instaluar"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -883,7 +891,7 @@ msgid ""
 "please contact the person in charge of your permissions."
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Back"
@@ -891,19 +899,19 @@ msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "Mbrapsht"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, fuzzy, kde-format
 #| msgctxt "@action:button Restart find & replace"
 #| msgid "Restart"
@@ -911,7 +919,7 @@ msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "Rinis"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "New"
@@ -919,7 +927,7 @@ msgctxt "Knewstuff5"
 msgid "New"
 msgstr "I Ri"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Home"
@@ -927,13 +935,13 @@ msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Shtëpia"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Up"
@@ -941,7 +949,7 @@ msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "Lart"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, fuzzy, kde-format
 #| msgctxt "dictionary variant"
 #| msgid "extended"
@@ -949,7 +957,7 @@ msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "i zgjeruar"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Subscript"
@@ -957,14 +965,14 @@ msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "Poshtëshkrim"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "Të Gjitha Kategoritë"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -995,9 +1003,11 @@ msgid ""
 msgstr ""
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
-#, kde-format
-msgid "Download New Stuff..."
-msgstr ""
+#, fuzzy, kde-format
+#| msgid "Download"
+msgctxt "@action"
+msgid "Download New Stuff…"
+msgstr "Shkarko"
 
 #, fuzzy
 #~| msgid "Installing"
diff -pruN 6.0.0-3/po/sr/knewstuff6.po 6.3.0-1/po/sr/knewstuff6.po
--- 6.0.0-3/po/sr/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/sr/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -7,7 +7,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: knewstuff5\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2017-09-28 17:58+0200\n"
 "Last-Translator: Chusslove Illich <caslav.ilic@gmx.net>\n"
 "Language-Team: Serbian <kde-i18n-sr@kde.org>\n"
@@ -61,7 +61,7 @@ msgstr "Ваш глас је убеле
 msgid "You are now a fan."
 msgstr "Сада сте љубитељ."
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -126,7 +126,7 @@ msgstr "Поставни фајл ниј
 msgid "Use"
 msgstr "Употреби"
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -134,17 +134,17 @@ msgid ""
 "This is a critical error and should be reported to the application author"
 msgstr ""
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr "Учитавање добављача̂ из фајла није успело: „%1“"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr "Не могу да учитам добављаче врућих новотарија из фајла: „%1“"
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr "Грешка у припремању добављача."
@@ -286,7 +286,7 @@ msgid ""
 "the update"
 msgstr ""
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, kde-format
 msgid ""
 "Failed to adopt '%1'\n"
@@ -294,7 +294,7 @@ msgid ""
 msgstr ""
 
 # >> @item:inlistbox
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt ""
@@ -302,7 +302,7 @@ msgctxt ""
 msgid "All Categories"
 msgstr "све категорије"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, fuzzy, kde-format
 #| msgid "Category:"
 msgctxt ""
@@ -328,14 +328,14 @@ msgstr ""
 msgid "Download New %1…"
 msgstr "Преузми новотарије..."
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, fuzzy, kde-format
 #| msgid "Download New Stuff..."
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "Преузми новотарије..."
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, fuzzy, kde-format
 #| msgid "Download New Stuff..."
 msgctxt ""
@@ -344,12 +344,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "Преузми новотарије..."
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -358,12 +358,12 @@ msgid ""
 "this through the naming of the items."
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "Инсталирај"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt ""
@@ -371,7 +371,7 @@ msgctxt ""
 msgid "Installing %1 from %2"
 msgstr "Инсталирам"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -379,10 +379,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -391,10 +391,10 @@ msgctxt ""
 msgid "Install"
 msgstr "Инсталирај"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -402,22 +402,22 @@ msgctxt ""
 msgid "Install…"
 msgstr "Инсталирај"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, kde-format
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "Ажурирај"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, kde-format
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "Деинсталирај"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -425,14 +425,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -443,12 +443,12 @@ msgid ""
 "to the KDE Community in a bug report</a>."
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a new sub page with comments (comments "
@@ -457,20 +457,20 @@ msgid "%1 Reviews and Comments"
 msgstr ""
 
 # >> @option:radio Order by
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, fuzzy, kde-format
 #| msgid "Rating"
 msgid "Rating:"
 msgstr "оцени"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, fuzzy, kde-format
 #| msgctxt "A link to the description of this Get Hot New Stuff item"
 #| msgid "Homepage"
 msgid "Homepage:"
 msgstr "Домаћа страница"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -479,12 +479,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -492,79 +492,87 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr ""
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, kde-format
 msgid "Tiles"
 msgstr ""
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr ""
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, fuzzy, kde-format
 #| msgid "Preview Images"
 msgid "Preview"
 msgstr "Слике прегледа"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, fuzzy, kde-format
 #| msgid "Details view mode"
 msgid "Detailed Tiles View Mode"
 msgstr "Приказ детаља"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, fuzzy, kde-format
 #| msgid "Icons view mode"
 msgid "Icons Only View Mode"
 msgstr "Приказ иконица"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, kde-format
 msgid "Large Preview View Mode"
 msgstr ""
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr ""
 
 # >> @option:radio Order by
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "инсталираном"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, fuzzy, kde-format
 #| msgid "Update"
 msgid "Updateable"
 msgstr "Ажурирај"
 
 # >> @item:inlistbox
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "све категорије"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -572,23 +580,23 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, kde-format
 msgid "Recent"
 msgstr ""
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr ""
 
 # >> @option:radio Order by
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "оцени"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, fuzzy, kde-format
 #| msgid "1 download"
 #| msgid_plural "%1 downloads"
@@ -596,7 +604,7 @@ msgid "Downloads"
 msgstr "%1 преузимање"
 
 # >> @option:radio Order by
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, fuzzy, kde-format
 #| msgid "Most downloads"
 msgctxt ""
@@ -605,7 +613,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "највише преузимања"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -614,7 +622,7 @@ msgid "Sort Alphabetically By Name"
 msgstr ""
 
 # >> @option:radio Order by
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, fuzzy, kde-format
 #| msgid "Most downloads"
 msgctxt "List option which will set the sort order to based on user ratings"
@@ -622,7 +630,7 @@ msgid "Show Highest Rated First"
 msgstr "највише преузимања"
 
 # >> @option:radio Order by
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, fuzzy, kde-format
 #| msgid "Most downloads"
 msgctxt ""
@@ -630,46 +638,46 @@ msgctxt ""
 msgid "Show Most Downloaded First"
 msgstr "највише преузимања"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, fuzzy, kde-format
 #| msgid "New Upload"
 msgid "Upload…"
 msgstr "Ново отпремање"
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr ""
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, kde-format
 msgid "Go to…"
 msgstr ""
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, fuzzy, kde-format
 #| msgid "Search:"
 msgid "Search…"
 msgstr "Претражи:"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "Категорија:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, kde-format
 msgid "Contribute your own…"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, kde-format
 msgctxt ""
 "Placeholder title for when a comment has no subject, but does have a rating"
 msgid "<i>(no title)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -677,19 +685,19 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, kde-format
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -697,7 +705,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -705,8 +713,8 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, fuzzy, kde-format
 #| msgid "1 download"
 #| msgid_plural "%1 downloads"
@@ -714,8 +722,8 @@ msgctxt "The number of times the item ha
 msgid "%1 downloads"
 msgstr "%1 преузимање"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, fuzzy, kde-format
 #| msgctxt "Show the author of this item in a list"
 #| msgid "By <i>%1</i>"
@@ -725,7 +733,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "<i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -733,7 +741,7 @@ msgctxt ""
 msgid "Working…"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, fuzzy, kde-format
 #| msgid "Updating"
 msgctxt ""
@@ -742,7 +750,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "Ажурирам"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -753,7 +761,7 @@ msgid ""
 "bug report</a>."
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt "Label for the busy indicator showing an item is installing"
@@ -771,26 +779,26 @@ msgstr ""
 msgid "Please try again later."
 msgstr ""
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, kde-format
 msgid "None"
 msgstr ""
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, kde-format
 msgctxt ""
 "A text representation of the rating, shown as a fraction of the max value"
 msgid "(%1/%2)"
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, fuzzy, kde-format
 #| msgid "Download New Stuff..."
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "Преузми новотарије..."
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, fuzzy, kde-format
 #| msgid "Fetching provider information..."
 msgctxt ""
@@ -798,20 +806,20 @@ msgctxt ""
 msgid "Updating information…"
 msgstr "Добављам податке о добављачу..."
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, kde-format
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, fuzzy, kde-format
 #| msgid "Provider:"
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "Добављач:"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, kde-format
 msgctxt ""
 "Text for an action which causes the specified website to be opened using the "
@@ -819,7 +827,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, kde-format
 msgctxt ""
 "Text for an action which will attempt to send an email using the user's "
@@ -827,7 +835,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -835,10 +843,10 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -850,18 +858,18 @@ msgid ""
 "content added."
 msgstr ""
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "Учитавам податке"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "Инсталирам"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -871,39 +879,39 @@ msgid ""
 "please contact the person in charge of your permissions."
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Back"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr ""
 
 # >> @option:radio Order by
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, fuzzy, kde-format
 #| msgid "Newest"
 msgctxt "Knewstuff5"
 msgid "New"
 msgstr "најновијем"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, fuzzy, kde-format
 #| msgctxt "A link to the description of this Get Hot New Stuff item"
 #| msgid "Homepage"
@@ -911,25 +919,25 @@ msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Домаћа страница"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Up"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, fuzzy, kde-format
 #| msgid "Description:"
 msgctxt "Knewstuff5"
@@ -937,14 +945,14 @@ msgid "Subscriptions"
 msgstr "Опис:"
 
 # >> @item:inlistbox
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "све категорије"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -975,10 +983,15 @@ msgid ""
 msgstr ""
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
-#, kde-format
-msgid "Download New Stuff..."
+#, fuzzy, kde-format
+#| msgid "Download New Stuff..."
+msgctxt "@action"
+msgid "Download New Stuff…"
 msgstr "Преузми новотарије..."
 
+#~ msgid "Download New Stuff..."
+#~ msgstr "Преузми новотарије..."
+
 #~ msgid "Initializing"
 #~ msgstr "Припремам"
 
diff -pruN 6.0.0-3/po/sr@ijekavian/knewstuff6.po 6.3.0-1/po/sr@ijekavian/knewstuff6.po
--- 6.0.0-3/po/sr@ijekavian/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/sr@ijekavian/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -7,7 +7,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: knewstuff5\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2017-09-28 17:58+0200\n"
 "Last-Translator: Chusslove Illich <caslav.ilic@gmx.net>\n"
 "Language-Team: Serbian <kde-i18n-sr@kde.org>\n"
@@ -60,7 +60,7 @@ msgstr "Ваш глас је убиље
 msgid "You are now a fan."
 msgstr "Сада сте љубитељ."
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -125,7 +125,7 @@ msgstr "Поставни фајл ниј
 msgid "Use"
 msgstr "Употреби"
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -133,17 +133,17 @@ msgid ""
 "This is a critical error and should be reported to the application author"
 msgstr ""
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr "Учитавање добављача̂ из фајла није успјело: „%1“"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr "Не могу да учитам добављаче врућих новотарија из фајла: „%1“"
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr "Грешка у припремању добављача."
@@ -285,7 +285,7 @@ msgid ""
 "the update"
 msgstr ""
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, kde-format
 msgid ""
 "Failed to adopt '%1'\n"
@@ -293,7 +293,7 @@ msgid ""
 msgstr ""
 
 # >> @item:inlistbox
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt ""
@@ -301,7 +301,7 @@ msgctxt ""
 msgid "All Categories"
 msgstr "све категорије"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, fuzzy, kde-format
 #| msgid "Category:"
 msgctxt ""
@@ -327,14 +327,14 @@ msgstr ""
 msgid "Download New %1…"
 msgstr "Преузми новотарије..."
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, fuzzy, kde-format
 #| msgid "Download New Stuff..."
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "Преузми новотарије..."
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, fuzzy, kde-format
 #| msgid "Download New Stuff..."
 msgctxt ""
@@ -343,12 +343,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "Преузми новотарије..."
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -357,12 +357,12 @@ msgid ""
 "this through the naming of the items."
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "Инсталирај"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt ""
@@ -370,7 +370,7 @@ msgctxt ""
 msgid "Installing %1 from %2"
 msgstr "Инсталирам"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -378,10 +378,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -390,10 +390,10 @@ msgctxt ""
 msgid "Install"
 msgstr "Инсталирај"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -401,22 +401,22 @@ msgctxt ""
 msgid "Install…"
 msgstr "Инсталирај"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, kde-format
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "Ажурирај"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, kde-format
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "Деинсталирај"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -424,14 +424,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -442,12 +442,12 @@ msgid ""
 "to the KDE Community in a bug report</a>."
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a new sub page with comments (comments "
@@ -456,20 +456,20 @@ msgid "%1 Reviews and Comments"
 msgstr ""
 
 # >> @option:radio Order by
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, fuzzy, kde-format
 #| msgid "Rating"
 msgid "Rating:"
 msgstr "оцјени"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, fuzzy, kde-format
 #| msgctxt "A link to the description of this Get Hot New Stuff item"
 #| msgid "Homepage"
 msgid "Homepage:"
 msgstr "Домаћа страница"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -478,12 +478,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -491,79 +491,87 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr ""
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, kde-format
 msgid "Tiles"
 msgstr ""
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr ""
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, fuzzy, kde-format
 #| msgid "Preview Images"
 msgid "Preview"
 msgstr "Слике прегледа"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, fuzzy, kde-format
 #| msgid "Details view mode"
 msgid "Detailed Tiles View Mode"
 msgstr "Приказ детаља"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, fuzzy, kde-format
 #| msgid "Icons view mode"
 msgid "Icons Only View Mode"
 msgstr "Приказ иконица"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, kde-format
 msgid "Large Preview View Mode"
 msgstr ""
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr ""
 
 # >> @option:radio Order by
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "инсталираном"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, fuzzy, kde-format
 #| msgid "Update"
 msgid "Updateable"
 msgstr "Ажурирај"
 
 # >> @item:inlistbox
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "све категорије"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -571,23 +579,23 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, kde-format
 msgid "Recent"
 msgstr ""
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr ""
 
 # >> @option:radio Order by
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "оцјени"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, fuzzy, kde-format
 #| msgid "1 download"
 #| msgid_plural "%1 downloads"
@@ -595,7 +603,7 @@ msgid "Downloads"
 msgstr "%1 преузимање"
 
 # >> @option:radio Order by
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, fuzzy, kde-format
 #| msgid "Most downloads"
 msgctxt ""
@@ -604,7 +612,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "највише преузимања"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -613,7 +621,7 @@ msgid "Sort Alphabetically By Name"
 msgstr ""
 
 # >> @option:radio Order by
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, fuzzy, kde-format
 #| msgid "Most downloads"
 msgctxt "List option which will set the sort order to based on user ratings"
@@ -621,7 +629,7 @@ msgid "Show Highest Rated First"
 msgstr "највише преузимања"
 
 # >> @option:radio Order by
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, fuzzy, kde-format
 #| msgid "Most downloads"
 msgctxt ""
@@ -629,46 +637,46 @@ msgctxt ""
 msgid "Show Most Downloaded First"
 msgstr "највише преузимања"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, fuzzy, kde-format
 #| msgid "New Upload"
 msgid "Upload…"
 msgstr "Ново отпремање"
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr ""
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, kde-format
 msgid "Go to…"
 msgstr ""
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, fuzzy, kde-format
 #| msgid "Search:"
 msgid "Search…"
 msgstr "Претражи:"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "Категорија:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, kde-format
 msgid "Contribute your own…"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, kde-format
 msgctxt ""
 "Placeholder title for when a comment has no subject, but does have a rating"
 msgid "<i>(no title)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -676,19 +684,19 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, kde-format
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -696,7 +704,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -704,8 +712,8 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, fuzzy, kde-format
 #| msgid "1 download"
 #| msgid_plural "%1 downloads"
@@ -713,8 +721,8 @@ msgctxt "The number of times the item ha
 msgid "%1 downloads"
 msgstr "%1 преузимање"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, fuzzy, kde-format
 #| msgctxt "Show the author of this item in a list"
 #| msgid "By <i>%1</i>"
@@ -724,7 +732,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "<i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -732,7 +740,7 @@ msgctxt ""
 msgid "Working…"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, fuzzy, kde-format
 #| msgid "Updating"
 msgctxt ""
@@ -741,7 +749,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "Ажурирам"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -752,7 +760,7 @@ msgid ""
 "bug report</a>."
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt "Label for the busy indicator showing an item is installing"
@@ -770,26 +778,26 @@ msgstr ""
 msgid "Please try again later."
 msgstr ""
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, kde-format
 msgid "None"
 msgstr ""
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, kde-format
 msgctxt ""
 "A text representation of the rating, shown as a fraction of the max value"
 msgid "(%1/%2)"
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, fuzzy, kde-format
 #| msgid "Download New Stuff..."
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "Преузми новотарије..."
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, fuzzy, kde-format
 #| msgid "Fetching provider information..."
 msgctxt ""
@@ -797,20 +805,20 @@ msgctxt ""
 msgid "Updating information…"
 msgstr "Добављам податке о добављачу..."
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, kde-format
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, fuzzy, kde-format
 #| msgid "Provider:"
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "Добављач:"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, kde-format
 msgctxt ""
 "Text for an action which causes the specified website to be opened using the "
@@ -818,7 +826,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, kde-format
 msgctxt ""
 "Text for an action which will attempt to send an email using the user's "
@@ -826,7 +834,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -834,10 +842,10 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -849,18 +857,18 @@ msgid ""
 "content added."
 msgstr ""
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "Учитавам податке"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "Инсталирам"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -870,39 +878,39 @@ msgid ""
 "please contact the person in charge of your permissions."
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Back"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr ""
 
 # >> @option:radio Order by
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, fuzzy, kde-format
 #| msgid "Newest"
 msgctxt "Knewstuff5"
 msgid "New"
 msgstr "најновијем"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, fuzzy, kde-format
 #| msgctxt "A link to the description of this Get Hot New Stuff item"
 #| msgid "Homepage"
@@ -910,25 +918,25 @@ msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Домаћа страница"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Up"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, fuzzy, kde-format
 #| msgid "Description:"
 msgctxt "Knewstuff5"
@@ -936,14 +944,14 @@ msgid "Subscriptions"
 msgstr "Опис:"
 
 # >> @item:inlistbox
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "све категорије"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -974,10 +982,15 @@ msgid ""
 msgstr ""
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
-#, kde-format
-msgid "Download New Stuff..."
+#, fuzzy, kde-format
+#| msgid "Download New Stuff..."
+msgctxt "@action"
+msgid "Download New Stuff…"
 msgstr "Преузми новотарије..."
 
+#~ msgid "Download New Stuff..."
+#~ msgstr "Преузми новотарије..."
+
 #~ msgid "Initializing"
 #~ msgstr "Припремам"
 
diff -pruN 6.0.0-3/po/sr@ijekavianlatin/knewstuff6.po 6.3.0-1/po/sr@ijekavianlatin/knewstuff6.po
--- 6.0.0-3/po/sr@ijekavianlatin/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/sr@ijekavianlatin/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -7,7 +7,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: knewstuff5\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2017-09-28 17:58+0200\n"
 "Last-Translator: Chusslove Illich <caslav.ilic@gmx.net>\n"
 "Language-Team: Serbian <kde-i18n-sr@kde.org>\n"
@@ -60,7 +60,7 @@ msgstr "Vaš glas je ubilježen."
 msgid "You are now a fan."
 msgstr "Sada ste ljubitelj."
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -125,7 +125,7 @@ msgstr "Postavni fajl nije dobar: „%1
 msgid "Use"
 msgstr "Upotrebi"
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -133,17 +133,17 @@ msgid ""
 "This is a critical error and should be reported to the application author"
 msgstr ""
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr "Učitavanje dobavljačâ̂ iz fajla nije uspjelo: „%1“"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr "Ne mogu da učitam dobavljače vrućih novotarija iz fajla: „%1“"
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr "Greška u pripremanju dobavljača."
@@ -285,7 +285,7 @@ msgid ""
 "the update"
 msgstr ""
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, kde-format
 msgid ""
 "Failed to adopt '%1'\n"
@@ -293,7 +293,7 @@ msgid ""
 msgstr ""
 
 # >> @item:inlistbox
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt ""
@@ -301,7 +301,7 @@ msgctxt ""
 msgid "All Categories"
 msgstr "sve kategorije"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, fuzzy, kde-format
 #| msgid "Category:"
 msgctxt ""
@@ -327,14 +327,14 @@ msgstr ""
 msgid "Download New %1…"
 msgstr "Preuzmi novotarije..."
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, fuzzy, kde-format
 #| msgid "Download New Stuff..."
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "Preuzmi novotarije..."
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, fuzzy, kde-format
 #| msgid "Download New Stuff..."
 msgctxt ""
@@ -343,12 +343,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "Preuzmi novotarije..."
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -357,12 +357,12 @@ msgid ""
 "this through the naming of the items."
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "Instaliraj"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt ""
@@ -370,7 +370,7 @@ msgctxt ""
 msgid "Installing %1 from %2"
 msgstr "Instaliram"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -378,10 +378,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -390,10 +390,10 @@ msgctxt ""
 msgid "Install"
 msgstr "Instaliraj"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -401,22 +401,22 @@ msgctxt ""
 msgid "Install…"
 msgstr "Instaliraj"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, kde-format
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "Ažuriraj"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, kde-format
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "Deinstaliraj"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -424,14 +424,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -442,12 +442,12 @@ msgid ""
 "to the KDE Community in a bug report</a>."
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a new sub page with comments (comments "
@@ -456,20 +456,20 @@ msgid "%1 Reviews and Comments"
 msgstr ""
 
 # >> @option:radio Order by
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, fuzzy, kde-format
 #| msgid "Rating"
 msgid "Rating:"
 msgstr "ocjeni"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, fuzzy, kde-format
 #| msgctxt "A link to the description of this Get Hot New Stuff item"
 #| msgid "Homepage"
 msgid "Homepage:"
 msgstr "Domaća stranica"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -478,12 +478,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -491,79 +491,87 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr ""
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, kde-format
 msgid "Tiles"
 msgstr ""
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr ""
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, fuzzy, kde-format
 #| msgid "Preview Images"
 msgid "Preview"
 msgstr "Slike pregleda"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, fuzzy, kde-format
 #| msgid "Details view mode"
 msgid "Detailed Tiles View Mode"
 msgstr "Prikaz detalja"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, fuzzy, kde-format
 #| msgid "Icons view mode"
 msgid "Icons Only View Mode"
 msgstr "Prikaz ikonica"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, kde-format
 msgid "Large Preview View Mode"
 msgstr ""
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr ""
 
 # >> @option:radio Order by
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "instaliranom"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, fuzzy, kde-format
 #| msgid "Update"
 msgid "Updateable"
 msgstr "Ažuriraj"
 
 # >> @item:inlistbox
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "sve kategorije"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -571,23 +579,23 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, kde-format
 msgid "Recent"
 msgstr ""
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr ""
 
 # >> @option:radio Order by
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "ocjeni"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, fuzzy, kde-format
 #| msgid "1 download"
 #| msgid_plural "%1 downloads"
@@ -595,7 +603,7 @@ msgid "Downloads"
 msgstr "%1 preuzimanje"
 
 # >> @option:radio Order by
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, fuzzy, kde-format
 #| msgid "Most downloads"
 msgctxt ""
@@ -604,7 +612,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "najviše preuzimanja"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -613,7 +621,7 @@ msgid "Sort Alphabetically By Name"
 msgstr ""
 
 # >> @option:radio Order by
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, fuzzy, kde-format
 #| msgid "Most downloads"
 msgctxt "List option which will set the sort order to based on user ratings"
@@ -621,7 +629,7 @@ msgid "Show Highest Rated First"
 msgstr "najviše preuzimanja"
 
 # >> @option:radio Order by
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, fuzzy, kde-format
 #| msgid "Most downloads"
 msgctxt ""
@@ -629,46 +637,46 @@ msgctxt ""
 msgid "Show Most Downloaded First"
 msgstr "najviše preuzimanja"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, fuzzy, kde-format
 #| msgid "New Upload"
 msgid "Upload…"
 msgstr "Novo otpremanje"
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr ""
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, kde-format
 msgid "Go to…"
 msgstr ""
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, fuzzy, kde-format
 #| msgid "Search:"
 msgid "Search…"
 msgstr "Pretraži:"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "Kategorija:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, kde-format
 msgid "Contribute your own…"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, kde-format
 msgctxt ""
 "Placeholder title for when a comment has no subject, but does have a rating"
 msgid "<i>(no title)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -676,19 +684,19 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, kde-format
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -696,7 +704,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -704,8 +712,8 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, fuzzy, kde-format
 #| msgid "1 download"
 #| msgid_plural "%1 downloads"
@@ -713,8 +721,8 @@ msgctxt "The number of times the item ha
 msgid "%1 downloads"
 msgstr "%1 preuzimanje"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, fuzzy, kde-format
 #| msgctxt "Show the author of this item in a list"
 #| msgid "By <i>%1</i>"
@@ -724,7 +732,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "<i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -732,7 +740,7 @@ msgctxt ""
 msgid "Working…"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, fuzzy, kde-format
 #| msgid "Updating"
 msgctxt ""
@@ -741,7 +749,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "Ažuriram"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -752,7 +760,7 @@ msgid ""
 "bug report</a>."
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt "Label for the busy indicator showing an item is installing"
@@ -770,26 +778,26 @@ msgstr ""
 msgid "Please try again later."
 msgstr ""
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, kde-format
 msgid "None"
 msgstr ""
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, kde-format
 msgctxt ""
 "A text representation of the rating, shown as a fraction of the max value"
 msgid "(%1/%2)"
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, fuzzy, kde-format
 #| msgid "Download New Stuff..."
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "Preuzmi novotarije..."
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, fuzzy, kde-format
 #| msgid "Fetching provider information..."
 msgctxt ""
@@ -797,20 +805,20 @@ msgctxt ""
 msgid "Updating information…"
 msgstr "Dobavljam podatke o dobavljaču..."
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, kde-format
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, fuzzy, kde-format
 #| msgid "Provider:"
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "Dobavljač:"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, kde-format
 msgctxt ""
 "Text for an action which causes the specified website to be opened using the "
@@ -818,7 +826,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, kde-format
 msgctxt ""
 "Text for an action which will attempt to send an email using the user's "
@@ -826,7 +834,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -834,10 +842,10 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -849,18 +857,18 @@ msgid ""
 "content added."
 msgstr ""
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "Učitavam podatke"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "Instaliram"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -870,39 +878,39 @@ msgid ""
 "please contact the person in charge of your permissions."
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Back"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr ""
 
 # >> @option:radio Order by
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, fuzzy, kde-format
 #| msgid "Newest"
 msgctxt "Knewstuff5"
 msgid "New"
 msgstr "najnovijem"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, fuzzy, kde-format
 #| msgctxt "A link to the description of this Get Hot New Stuff item"
 #| msgid "Homepage"
@@ -910,25 +918,25 @@ msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Domaća stranica"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Up"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, fuzzy, kde-format
 #| msgid "Description:"
 msgctxt "Knewstuff5"
@@ -936,14 +944,14 @@ msgid "Subscriptions"
 msgstr "Opis:"
 
 # >> @item:inlistbox
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "sve kategorije"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -974,10 +982,15 @@ msgid ""
 msgstr ""
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
-#, kde-format
-msgid "Download New Stuff..."
+#, fuzzy, kde-format
+#| msgid "Download New Stuff..."
+msgctxt "@action"
+msgid "Download New Stuff…"
 msgstr "Preuzmi novotarije..."
 
+#~ msgid "Download New Stuff..."
+#~ msgstr "Preuzmi novotarije..."
+
 #~ msgid "Initializing"
 #~ msgstr "Pripremam"
 
diff -pruN 6.0.0-3/po/sr@latin/knewstuff6.po 6.3.0-1/po/sr@latin/knewstuff6.po
--- 6.0.0-3/po/sr@latin/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/sr@latin/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -7,7 +7,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: knewstuff5\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2017-09-28 17:58+0200\n"
 "Last-Translator: Chusslove Illich <caslav.ilic@gmx.net>\n"
 "Language-Team: Serbian <kde-i18n-sr@kde.org>\n"
@@ -60,7 +60,7 @@ msgstr "Vaš glas je ubeležen."
 msgid "You are now a fan."
 msgstr "Sada ste ljubitelj."
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -125,7 +125,7 @@ msgstr "Postavni fajl nije dobar: „%1
 msgid "Use"
 msgstr "Upotrebi"
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -133,17 +133,17 @@ msgid ""
 "This is a critical error and should be reported to the application author"
 msgstr ""
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr "Učitavanje dobavljačâ̂ iz fajla nije uspelo: „%1“"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr "Ne mogu da učitam dobavljače vrućih novotarija iz fajla: „%1“"
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr "Greška u pripremanju dobavljača."
@@ -285,7 +285,7 @@ msgid ""
 "the update"
 msgstr ""
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, kde-format
 msgid ""
 "Failed to adopt '%1'\n"
@@ -293,7 +293,7 @@ msgid ""
 msgstr ""
 
 # >> @item:inlistbox
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt ""
@@ -301,7 +301,7 @@ msgctxt ""
 msgid "All Categories"
 msgstr "sve kategorije"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, fuzzy, kde-format
 #| msgid "Category:"
 msgctxt ""
@@ -327,14 +327,14 @@ msgstr ""
 msgid "Download New %1…"
 msgstr "Preuzmi novotarije..."
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, fuzzy, kde-format
 #| msgid "Download New Stuff..."
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "Preuzmi novotarije..."
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, fuzzy, kde-format
 #| msgid "Download New Stuff..."
 msgctxt ""
@@ -343,12 +343,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "Preuzmi novotarije..."
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -357,12 +357,12 @@ msgid ""
 "this through the naming of the items."
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "Instaliraj"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt ""
@@ -370,7 +370,7 @@ msgctxt ""
 msgid "Installing %1 from %2"
 msgstr "Instaliram"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -378,10 +378,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -390,10 +390,10 @@ msgctxt ""
 msgid "Install"
 msgstr "Instaliraj"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -401,22 +401,22 @@ msgctxt ""
 msgid "Install…"
 msgstr "Instaliraj"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, kde-format
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "Ažuriraj"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, kde-format
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "Deinstaliraj"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -424,14 +424,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -442,12 +442,12 @@ msgid ""
 "to the KDE Community in a bug report</a>."
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a new sub page with comments (comments "
@@ -456,20 +456,20 @@ msgid "%1 Reviews and Comments"
 msgstr ""
 
 # >> @option:radio Order by
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, fuzzy, kde-format
 #| msgid "Rating"
 msgid "Rating:"
 msgstr "oceni"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, fuzzy, kde-format
 #| msgctxt "A link to the description of this Get Hot New Stuff item"
 #| msgid "Homepage"
 msgid "Homepage:"
 msgstr "Domaća stranica"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -478,12 +478,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -491,79 +491,87 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr ""
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, kde-format
 msgid "Tiles"
 msgstr ""
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr ""
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, fuzzy, kde-format
 #| msgid "Preview Images"
 msgid "Preview"
 msgstr "Slike pregleda"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, fuzzy, kde-format
 #| msgid "Details view mode"
 msgid "Detailed Tiles View Mode"
 msgstr "Prikaz detalja"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, fuzzy, kde-format
 #| msgid "Icons view mode"
 msgid "Icons Only View Mode"
 msgstr "Prikaz ikonica"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, kde-format
 msgid "Large Preview View Mode"
 msgstr ""
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr ""
 
 # >> @option:radio Order by
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "instaliranom"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, fuzzy, kde-format
 #| msgid "Update"
 msgid "Updateable"
 msgstr "Ažuriraj"
 
 # >> @item:inlistbox
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "sve kategorije"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -571,23 +579,23 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, kde-format
 msgid "Recent"
 msgstr ""
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr ""
 
 # >> @option:radio Order by
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "oceni"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, fuzzy, kde-format
 #| msgid "1 download"
 #| msgid_plural "%1 downloads"
@@ -595,7 +603,7 @@ msgid "Downloads"
 msgstr "%1 preuzimanje"
 
 # >> @option:radio Order by
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, fuzzy, kde-format
 #| msgid "Most downloads"
 msgctxt ""
@@ -604,7 +612,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "najviše preuzimanja"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -613,7 +621,7 @@ msgid "Sort Alphabetically By Name"
 msgstr ""
 
 # >> @option:radio Order by
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, fuzzy, kde-format
 #| msgid "Most downloads"
 msgctxt "List option which will set the sort order to based on user ratings"
@@ -621,7 +629,7 @@ msgid "Show Highest Rated First"
 msgstr "najviše preuzimanja"
 
 # >> @option:radio Order by
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, fuzzy, kde-format
 #| msgid "Most downloads"
 msgctxt ""
@@ -629,46 +637,46 @@ msgctxt ""
 msgid "Show Most Downloaded First"
 msgstr "najviše preuzimanja"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, fuzzy, kde-format
 #| msgid "New Upload"
 msgid "Upload…"
 msgstr "Novo otpremanje"
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr ""
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, kde-format
 msgid "Go to…"
 msgstr ""
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, fuzzy, kde-format
 #| msgid "Search:"
 msgid "Search…"
 msgstr "Pretraži:"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "Kategorija:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, kde-format
 msgid "Contribute your own…"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, kde-format
 msgctxt ""
 "Placeholder title for when a comment has no subject, but does have a rating"
 msgid "<i>(no title)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -676,19 +684,19 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, kde-format
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -696,7 +704,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -704,8 +712,8 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, fuzzy, kde-format
 #| msgid "1 download"
 #| msgid_plural "%1 downloads"
@@ -713,8 +721,8 @@ msgctxt "The number of times the item ha
 msgid "%1 downloads"
 msgstr "%1 preuzimanje"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, fuzzy, kde-format
 #| msgctxt "Show the author of this item in a list"
 #| msgid "By <i>%1</i>"
@@ -724,7 +732,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "<i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -732,7 +740,7 @@ msgctxt ""
 msgid "Working…"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, fuzzy, kde-format
 #| msgid "Updating"
 msgctxt ""
@@ -741,7 +749,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "Ažuriram"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -752,7 +760,7 @@ msgid ""
 "bug report</a>."
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt "Label for the busy indicator showing an item is installing"
@@ -770,26 +778,26 @@ msgstr ""
 msgid "Please try again later."
 msgstr ""
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, kde-format
 msgid "None"
 msgstr ""
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, kde-format
 msgctxt ""
 "A text representation of the rating, shown as a fraction of the max value"
 msgid "(%1/%2)"
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, fuzzy, kde-format
 #| msgid "Download New Stuff..."
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "Preuzmi novotarije..."
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, fuzzy, kde-format
 #| msgid "Fetching provider information..."
 msgctxt ""
@@ -797,20 +805,20 @@ msgctxt ""
 msgid "Updating information…"
 msgstr "Dobavljam podatke o dobavljaču..."
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, kde-format
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, fuzzy, kde-format
 #| msgid "Provider:"
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "Dobavljač:"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, kde-format
 msgctxt ""
 "Text for an action which causes the specified website to be opened using the "
@@ -818,7 +826,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, kde-format
 msgctxt ""
 "Text for an action which will attempt to send an email using the user's "
@@ -826,7 +834,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -834,10 +842,10 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -849,18 +857,18 @@ msgid ""
 "content added."
 msgstr ""
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "Učitavam podatke"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "Instaliram"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -870,39 +878,39 @@ msgid ""
 "please contact the person in charge of your permissions."
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Back"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr ""
 
 # >> @option:radio Order by
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, fuzzy, kde-format
 #| msgid "Newest"
 msgctxt "Knewstuff5"
 msgid "New"
 msgstr "najnovijem"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, fuzzy, kde-format
 #| msgctxt "A link to the description of this Get Hot New Stuff item"
 #| msgid "Homepage"
@@ -910,25 +918,25 @@ msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Domaća stranica"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Up"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, fuzzy, kde-format
 #| msgid "Description:"
 msgctxt "Knewstuff5"
@@ -936,14 +944,14 @@ msgid "Subscriptions"
 msgstr "Opis:"
 
 # >> @item:inlistbox
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "sve kategorije"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -974,10 +982,15 @@ msgid ""
 msgstr ""
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
-#, kde-format
-msgid "Download New Stuff..."
+#, fuzzy, kde-format
+#| msgid "Download New Stuff..."
+msgctxt "@action"
+msgid "Download New Stuff…"
 msgstr "Preuzmi novotarije..."
 
+#~ msgid "Download New Stuff..."
+#~ msgstr "Preuzmi novotarije..."
+
 #~ msgid "Initializing"
 #~ msgstr "Pripremam"
 
diff -pruN 6.0.0-3/po/sv/knewstuff6.po 6.3.0-1/po/sv/knewstuff6.po
--- 6.0.0-3/po/sv/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/sv/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -14,7 +14,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2022-09-24 16:15+0200\n"
 "Last-Translator: Stefan Asserhäll <stefan.asserhall@bredband.net>\n"
 "Language-Team: Swedish <kde-i18n-doc@kde.org>\n"
@@ -63,7 +63,7 @@ msgstr "Din röst har registrerats."
 msgid "You are now a fan."
 msgstr "Du är nu en beundrare."
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -133,7 +133,7 @@ msgstr "Inställningsfil är ogiltig: \"
 msgid "Use"
 msgstr "Använd"
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, fuzzy, kde-format
 #| msgid ""
 #| "Could not initialise the installation handler for %1\n"
@@ -146,17 +146,17 @@ msgstr ""
 "Kunde inte installera installationshanteraren för %1\n"
 "Det är ett kritiskt fel och ska rapporteras till programupphovsmannen"
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr "Inläsning av leverantörer från filen %1 misslyckades"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr "Kunde inte ladda ner leverantörer av heta nyheter från fil: %1"
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr "Fel vid initiering av leverantör."
@@ -324,7 +324,7 @@ msgstr ""
 "Misslyckades identifiera en fungerande länk för att uppdatera %1, och kan "
 "inte utföra uppdateringen"
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, kde-format
 msgid ""
 "Failed to adopt '%1'\n"
@@ -333,14 +333,14 @@ msgstr ""
 "Misslyckades införa '%1'\n"
 "%2"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, kde-format
 msgctxt ""
 "The first entry in the category selection list (also the default value)"
 msgid "All Categories"
 msgstr "Alla kategorier"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, kde-format
 msgctxt ""
 "The string passed back in the case the requested category is not known"
@@ -371,13 +371,13 @@ msgstr "saker"
 msgid "Download New %1…"
 msgstr "Ladda ner nya %1"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, kde-format
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "Ladda ner nya %1"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, kde-format
 msgctxt ""
 "A placeholder title used in the dialog when there is no better title "
@@ -385,12 +385,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "Ladda ner nyheter"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr "Välj installationsalternativ"
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -403,19 +403,19 @@ msgstr ""
 "ska välja, kontakta objektets upphovsman och be att det klargörs via "
 "objektens namngivning."
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "Installera"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, kde-format
 msgctxt ""
 "A passive notification shown when installation of an item is initiated"
 msgid "Installing %1 from %2"
 msgstr "Installerar %1 från %2"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -423,10 +423,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr "%1 av %2"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, kde-format
 msgctxt ""
 "Request installation of this item, available when there is exactly one "
@@ -434,10 +434,10 @@ msgctxt ""
 msgid "Install"
 msgstr "Installera"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -445,22 +445,22 @@ msgctxt ""
 msgid "Install…"
 msgstr "Installera"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, kde-format
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "Uppdatera"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, kde-format
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "Avinstallera"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, fuzzy, kde-format
 #| msgctxt ""
 #| "Status message to be shown when the entry is in the process of being "
@@ -472,7 +472,7 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr "Arbetar för närvarande med objekt %1 av %2. Vänta ..."
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, fuzzy, kde-format
 #| msgctxt ""
 #| "Status message to be shown when the entry is in the process of being "
@@ -483,7 +483,7 @@ msgctxt ""
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr "Håller på att ladda upp objekt %1 av %2. Vänta ..."
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -497,12 +497,12 @@ msgstr ""
 "\"https://bugs.kde.org/enter_bug.cgi?product=frameworks-knewstuff"
 "\">Rapportera det gärna till KDE-gemenskapen med en felrapport</a>."
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr "Kommentarer och omdömen:"
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a new sub page with comments (comments "
@@ -510,17 +510,17 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "%1 omdömen och kommentarer"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, kde-format
 msgid "Rating:"
 msgstr "Betyg:"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, kde-format
 msgid "Homepage:"
 msgstr "Hemsida:"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -529,12 +529,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr "Öppna hemsidan för %1"
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr "Hur man bidrar:"
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -542,74 +542,85 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr "Ta reda på hur man bidrar till projektet"
 
-#: qtquick/qml/Page.qml:141
-#, kde-format
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
+#, fuzzy, kde-format
+#| msgid ""
+#| "The content available here has been uploaded by users like you, and has "
+#| "not been reviewed by your distributor for functionality or stability."
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 "Innehållet som är tillgängligt här har laddats upp av användare som du, och "
 "har inte granskats av distributören avseende funktion eller stabilitet."
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, kde-format
 msgid "Tiles"
 msgstr "Rutor"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "Ikoner"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, kde-format
 msgid "Preview"
 msgstr "Förhandsgranskning"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, kde-format
 msgid "Detailed Tiles View Mode"
 msgstr "Detaljerat visningsläge med rutor"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, kde-format
 msgid "Icons Only View Mode"
 msgstr "Visningsläge enbart med ikoner"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, kde-format
 msgid "Large Preview View Mode"
 msgstr "Stort förhandsgranskningläge"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr "Allting"
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "Installerad"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, kde-format
 msgid "Updateable"
 msgstr "Uppdateringsbara"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, kde-format
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "Visa alla poster"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr "Visa bara installerade poster"
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -617,27 +628,27 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr "Visa bara uppdateringsbara poster"
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, kde-format
 msgid "Recent"
 msgstr "Senaste"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr "Alfabetiskt"
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "Betyg"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, kde-format
 msgid "Downloads"
 msgstr "Nerladdningar"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on when items were most "
@@ -645,7 +656,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "Visa senaste först"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -653,60 +664,60 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr "Sortera alfabetiskt enligt namn"
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, kde-format
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "Visa högst betyg först"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on number of downloads"
 msgid "Show Most Downloaded First"
 msgstr "Visa flest nerladdningar först"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, fuzzy, kde-format
 #| msgid "Upload..."
 msgid "Upload…"
 msgstr "Ladda upp..."
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr "Ta reda på hur du kan lägga till dina egna heta nyheter i listan"
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, fuzzy, kde-format
 #| msgid "Go to..."
 msgid "Go to…"
 msgstr "Gå till..."
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, fuzzy, kde-format
 #| msgid "Search:"
 msgid "Search…"
 msgstr "Sök:"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "Kategori:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, kde-format
 msgid "Contribute your own…"
 msgstr "Bidra din egen…"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, kde-format
 msgctxt ""
 "Placeholder title for when a comment has no subject, but does have a rating"
 msgid "<i>(no title)</i>"
 msgstr "<i>(namnlös)</i>"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -714,19 +725,19 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr "%1 <i>(upphovsman)</i>"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr "Kommentarer och omdömen om %1"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, kde-format
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "Visa alla kommentarer"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -734,7 +745,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr "Visa bara omdömen"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -742,15 +753,15 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr "Visa omdömen och svar"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, kde-format
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
 msgstr "%1 nerladdningar"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, kde-format
 msgctxt ""
 "Subheading for the tile view, located immediately underneath the name of the "
@@ -758,7 +769,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "Av <i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, fuzzy, kde-format
 #| msgctxt ""
 #| "Label for the busy indicator showing an item is being installed OR "
@@ -770,7 +781,7 @@ msgctxt ""
 msgid "Working…"
 msgstr "Arbetar..."
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, fuzzy, kde-format
 #| msgid "Updating"
 msgctxt ""
@@ -779,7 +790,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "Uppdaterar"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -793,7 +804,7 @@ msgstr ""
 "product=frameworks-knewstuff\">Rapportera det gärna till KDE-gemenskapen med "
 "en felrapport</a>."
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt "Label for the busy indicator showing an item is installing"
@@ -811,19 +822,19 @@ msgstr "Ett fel uppstod"
 msgid "Please try again later."
 msgstr "Försök igen senare."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, kde-format
 msgid "None"
 msgstr "Ingen"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, kde-format
 msgctxt ""
 "A text representation of the rating, shown as a fraction of the max value"
 msgid "(%1/%2)"
 msgstr "(%1/%2)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, fuzzy, kde-format
 #| msgctxt "@knewstuff5"
 #| msgid "Upload New Stuff: %1"
@@ -831,7 +842,7 @@ msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "Ladda upp nyheter: %1"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, fuzzy, kde-format
 #| msgctxt ""
 #| "A text shown beside a busy indicator suggesting that data is being fetched"
@@ -841,19 +852,19 @@ msgctxt ""
 msgid "Updating information…"
 msgstr "Uppdaterar information..."
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, kde-format
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "KDE-butik"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, kde-format
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "Din leverantör"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, kde-format
 msgctxt ""
 "Text for an action which causes the specified website to be opened using the "
@@ -861,7 +872,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "Öppna webbplats: %1"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, kde-format
 msgctxt ""
 "Text for an action which will attempt to send an email using the user's "
@@ -869,15 +880,22 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "Skicka e-post till: %1"
 
-#: qtquick/qml/UploadPage.qml:154
-#, kde-format
+#: qtquick/qml/UploadPage.qml:159
+#, fuzzy, kde-format
+#| msgctxt "A description of how to upload content to a generic provider"
+#| msgid ""
+#| "To upload new entries, or to add content to an existing entry on the KDE "
+#| "Store, please open the website and log in. Once you have done this, you "
+#| "will be able to find the My Products entry in the menu which pops up when "
+#| "you click your user icon. Click on this entry to go to the product "
+#| "management system, where you can work on your products ."
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
 "To upload new entries, or to add content to an existing entry on the KDE "
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 "För att ladda upp nya poster, eller lägga till innehåll i en befintlig post "
 "i KDE-butiken, öppna webbplatsen och logga in. När du väl har gjort det, "
@@ -885,7 +903,7 @@ msgstr ""
 "din användarikon. Klicka på alternativet för att gå till "
 "produkthanteringssystemet, där du kan arbeta med dina produkter."
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -903,18 +921,18 @@ msgstr ""
 "att du kontaktar ansvariga för webbplatsen direkt för att få nytt innehåll "
 "tillagt."
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "Laddar data"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "Installerar"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -926,73 +944,73 @@ msgstr ""
 "Du har inte behörighet att hämta heta nyheter. Om du anser att det är "
 "felaktigt, kontakta personen som har hand om din behörighet."
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "Tillbaka"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr "Populära"
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "Presenterade"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "Starta om"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "New"
 msgstr "Ny"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Hem"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr "Hylla"
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "Upp"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "Rekommenderade"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "Prenumerationer"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "Alla poster"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -1049,9 +1067,17 @@ msgstr ""
 "org/1316714"
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
-#, kde-format
-msgid "Download New Stuff..."
-msgstr "Ladda ner nyheter..."
+#, fuzzy, kde-format
+#| msgctxt ""
+#| "A placeholder title used in the dialog when there is no better title "
+#| "available"
+#| msgid "Download New Stuff"
+msgctxt "@action"
+msgid "Download New Stuff…"
+msgstr "Ladda ner nyheter"
+
+#~ msgid "Download New Stuff..."
+#~ msgstr "Ladda ner nyheter..."
 
 #~ msgctxt ""
 #~ "A message which is shown when the user attempts to display a specific "
diff -pruN 6.0.0-3/po/ta/knewstuff6.po 6.3.0-1/po/ta/knewstuff6.po
--- 6.0.0-3/po/ta/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/ta/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -4,13 +4,13 @@
 # Sivakumar Shanmugasundaram <sshanmu@yahoo.com>, 2000.
 # Thuraiappah Vaseeharan <t_vasee@yahoo.com>, 2000-2001.
 # ம. ஸ்ரீ ராமதாஸ் | Sri Ramadoss M <amachu@yavarkkum.org>, 2007-2012.
-# Kishore G <kishore96@gmail.com>, 2022, 2023.
+# SPDX-FileCopyrightText: 2022, 2023, 2024 Kishore G <kishore96@gmail.com>
 msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
-"PO-Revision-Date: 2023-06-11 18:41+0530\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
+"PO-Revision-Date: 2024-05-12 13:13+0530\n"
 "Last-Translator: Kishore G <kishore96@gmail.com>\n"
 "Language-Team: Tamil <kde-i18n-doc@kde.org>\n"
 "Language: ta\n"
@@ -18,7 +18,7 @@ msgstr ""
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=2; plural=n != 1;\n"
-"X-Generator: Lokalize 23.04.2\n"
+"X-Generator: Lokalize 24.02.2\n"
 
 #: attica/atticaprovider.cpp:165
 #, kde-format
@@ -58,7 +58,7 @@ msgstr "உங்கள் வாக்
 msgid "You are now a fan."
 msgstr "நீங்கள் ரசிகராகிவிட்டீர்கள்."
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -129,7 +129,7 @@ msgstr "அமைப்புக் க
 msgid "Use"
 msgstr "பயன்படுத்து"
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -140,17 +140,17 @@ msgstr ""
 "%2\n"
 "இச்சிக்கல், செயலியை இயற்றியவரிடம் தெரிவிக்கப்பட வேண்டும்"
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr "%1 எனும் கோப்பிலிருந்து வழங்கிகளை ஏற்றுவது தோல்வியடைந்த‍து"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr "%1 எனும் கோப்பிலிருந்து வழங்கிகளைப் பற்றிய விவரங்களை ஏற்ற முடியவில்லை"
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr "வழங்கியை தொடங்குவதில் சிக்கல்."
@@ -268,6 +268,10 @@ msgid ""
 "If you think this is incorrect, you can continue or cancel the "
 "uninstallation process"
 msgstr ""
+"நிறுவல்நீக்கத்தின்போது %1 எனும் கட்டளையை இயக்க முடியவில்லை\n"
+"அது வெளியிட்டது: \n"
+"%2\n"
+"இது தவறு என தோன்றினால், இந்த செயலைத் தொடரலாம் அல்லது ரத்து செய்யலாம்"
 
 #: core/jobs/filecopyworker.cpp:49
 #, kde-format
@@ -311,21 +315,21 @@ msgid ""
 msgstr ""
 "%1 என்பதை புதுப்பிப்பதற்கான முகவரியைக் கண்டறிய முடியாத‍தால் அதைப் புதுப்பிக்க முடியவில்லை"
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, kde-format
 msgid ""
 "Failed to adopt '%1'\n"
 "%2"
 msgstr ""
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, kde-format
 msgctxt ""
 "The first entry in the category selection list (also the default value)"
 msgid "All Categories"
 msgstr "அனைத்து பகுப்புகளும்"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, kde-format
 msgctxt ""
 "The string passed back in the case the requested category is not known"
@@ -349,13 +353,13 @@ msgstr "புதியவற்றை"
 msgid "Download New %1…"
 msgstr "%1 பதிவிறக்கு…"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, kde-format
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "%1 பதிவிறக்கு"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, kde-format
 msgctxt ""
 "A placeholder title used in the dialog when there is no better title "
@@ -363,12 +367,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "புதியவற்றைப் பதிவிறக்கு"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr "நிறுவ வேண்டியதைத் தேர்ந்தெடுங்கள்"
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -380,19 +384,19 @@ msgstr ""
 "இருந்தால், இதை இயற்றியவரை தொடர்புகொண்டு கீழுள்ளவற்றிற்கு பொருத்தமான பெயரைகளை இட "
 "சொல்லுங்கள்."
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "நிறுவு"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, kde-format
 msgctxt ""
 "A passive notification shown when installation of an item is initiated"
 msgid "Installing %1 from %2"
 msgstr "%2 வழங்கும் %1 நிறுவப்படுகிறது"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -400,10 +404,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr "%2 வழங்கும் %1"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, kde-format
 msgctxt ""
 "Request installation of this item, available when there is exactly one "
@@ -411,32 +415,32 @@ msgctxt ""
 msgid "Install"
 msgstr "நிறுவு"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, kde-format
 msgctxt ""
 "Show installation options, where there is more than one downloadable item"
 msgid "Install…"
 msgstr "நிறுவு…"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, kde-format
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "புதுப்பி"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, kde-format
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "நிறுவல் நீக்கு"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -444,14 +448,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr "%2 வழங்கும் %1 கையாளப்படுகிறது. காத்திருக்கவும்…"
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr "%2 வழங்கும் %1 புதுப்பிக்கப்படுகிறது. காத்திருக்கவும்…"
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -465,12 +469,12 @@ msgstr ""
 "kde.org/enter_bug.cgi?product=frameworks-knewstuff\">இதை ஓர் பிழையறிக்கை மூலம் "
 "கே.டீ.யீ. சமூகத்திற்குத் தெரிவிக்கவும்</a>."
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr "விமர்சனங்களும் மதிப்பீடுகளும்:"
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a new sub page with comments (comments "
@@ -478,17 +482,17 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "%1 விமர்சனங்களும் மதிப்பீடுகளும்:"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, kde-format
 msgid "Rating:"
 msgstr "மதிப்பீடு:"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, kde-format
 msgid "Homepage:"
 msgstr "முகப்புப்பக்கம்:"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -497,12 +501,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr "%1-க்கான முகப்புப்பக்கத்தை திற"
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr "நன்கொடை அளிப்பது:"
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -510,77 +514,85 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr "இதற்கு எப்படி நன்கொடை அளிப்பது என தெரிந்துகொள்ளுங்கள்"
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+"இங்கு காட்டப்படுபவை, உங்களைப் போன்ற பயனர்களால் உருவாக்கப்பட்டுள்ளவை. அவற்றில் இயக்கவல்ல "
+"சிறுநிரல்கள் இருக்கலாம். அப்படிப்பட்ட சிறுநிரல்கள் கே.டீ.யீ.யாலும் உங்கள் இயங்குதள "
+"வழங்குநராலும் சரிபார்க்கப்படாதவை."
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
-"இங்கு உள்ளவற்றை உங்களைப் போன்ற பயனர்கள் பதிவேற்றியுள்ளனர்.இவை சரியாக வேலை செய்யுமா என்பதை "
-"உங்கள் இயங்குதள பராமரிப்பாளர்கள் சரிபார்த்திருக்க மாட்டார்கள். "
+"இங்கு உள்ளவற்றை உங்களைப் போன்ற பயனர்கள் பதிவேற்றியுள்ளனர். இவைகே.டீ.யீ.யாலும் உங்கள் இயங்குதள "
+"வழங்குநர்களாலும் சோதிக்கப்படாதவை."
 
-#: qtquick/qml/Page.qml:171
-#, fuzzy, kde-format
-#| msgctxt "@option:check Do filter on type - show only files"
-#| msgid "Files"
+#: qtquick/qml/Page.qml:172
+#, kde-format
 msgid "Tiles"
-msgstr "கோப்புகள்"
+msgstr "கட்டங்கள்"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "சின்னங்கள்"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, kde-format
 msgid "Preview"
 msgstr "முன்னோட்டம்"
 
-#: qtquick/qml/Page.qml:191
-#, fuzzy, kde-format
-#| msgid "Details view mode"
+#: qtquick/qml/Page.qml:192
+#, kde-format
 msgid "Detailed Tiles View Mode"
-msgstr "விவரங்கள் காட்டப்படும் காட்சி"
+msgstr "விவரங்களை கொண்ட சதுரங்களை காட்டும் காட்சிமுறை"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, kde-format
 msgid "Icons Only View Mode"
 msgstr "சின்னங்களை மட்டும் காட்டும் காட்சிமுறை"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, kde-format
 msgid "Large Preview View Mode"
 msgstr "பெரிய முன்னோட்டங்களை காட்டும் காட்சிமுறை"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr "அனைத்தும்"
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "நிறுவப்பட்டுள்ளவை"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, kde-format
 msgid "Updateable"
 msgstr "புதுப்பிக்கத்தக்கவை"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, kde-format
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "அனைத்து பதிவுகளையும் காட்டு"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr "நிறுவப்பட்டுள்ளவற்றை மட்டும் காட்டு"
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -588,27 +600,27 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr "புதுப்பிக்கத்தக்கவற்றை மட்டும் காட்டு"
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, kde-format
 msgid "Recent"
 msgstr "சமீபமானவை"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr "அகரவரிசை"
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "மதிப்பீடு"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, kde-format
 msgid "Downloads"
 msgstr "பதிவிறக்கங்கள்"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on when items were most "
@@ -616,7 +628,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "மிகப்புதியவற்றை முதலில் காட்டு"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -624,57 +636,57 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr "பெயரின்படி அகரவரிசையாக வரிசைப்படுத்து"
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, kde-format
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "உயர்வாக மதிப்பிடப்பட்டுள்ளதை முதலில் காட்டு"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on number of downloads"
 msgid "Show Most Downloaded First"
 msgstr "அதிகமாக பதிவிறக்கப்பட்டவற்றை முதலில் காட்டு"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, kde-format
 msgid "Upload…"
 msgstr "பதிவேற்று…"
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr "இப்பட்டியலில் உங்கள் நிரல்களை எவ்வாறு சேர்ப்பதென தெரிந்துகொள்ளங்கள்"
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, kde-format
 msgid "Go to…"
 msgstr "செல்..."
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, kde-format
 msgid "Search…"
 msgstr "தேடு…"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "பகுப்பு:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, kde-format
 msgid "Contribute your own…"
 msgstr "உங்களுடையதை பதிவேற்றுங்கள்…"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, kde-format
 msgctxt ""
 "Placeholder title for when a comment has no subject, but does have a rating"
 msgid "<i>(no title)</i>"
 msgstr "<i>(தலைப்பில்லை)</i>"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -682,19 +694,19 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr "%1 <i>(நிரலாளர்)</i>"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr "%1 என்பதற்கான விமர்சனங்களும் மதிப்பீடுகளும்"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, kde-format
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "அனைத்து கருத்துகளையும் காட்டு"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -702,7 +714,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr "விமர்சனங்களை மட்டும் காட்டு"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -710,15 +722,15 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr "விமர்சனங்களையும் பதில்களையும் காட்டு"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, kde-format
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
 msgstr "%1 பதிவிறக்கங்கள்"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, kde-format
 msgctxt ""
 "Subheading for the tile view, located immediately underneath the name of the "
@@ -726,7 +738,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "இயற்றியவர் <i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -734,7 +746,7 @@ msgctxt ""
 msgid "Working…"
 msgstr "வேலை செய்கிறது…"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is in the process of being "
@@ -742,7 +754,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "புதுப்பிக்கிறது…"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -756,7 +768,7 @@ msgstr ""
 "cgi?product=frameworks-knewstuff\">இதை ஓர் பிழையாக கே.டீ.யீ.யிடம் தெரிவியுங்கள்</"
 "a>."
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, kde-format
 msgctxt "Label for the busy indicator showing an item is installing"
 msgid "Installing…"
@@ -773,44 +785,44 @@ msgstr "சிக்கல் ஏற்
 msgid "Please try again later."
 msgstr "தயவுசெய்து பின்னர் முயற்சிக்கவும்."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, kde-format
 msgid "None"
 msgstr "ஏதுமில்லை "
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, kde-format
 msgctxt ""
 "A text representation of the rating, shown as a fraction of the max value"
 msgid "(%1/%2)"
 msgstr "(%1/%2)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, kde-format
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "புதியதை பதிவேற்று: %1"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, kde-format
 msgctxt ""
 "A text shown beside a busy indicator suggesting that data is being fetched"
 msgid "Updating information…"
 msgstr "விவரங்கள் புதுப்பிக்கப்படுகின்றன…"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, kde-format
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "கே.டீ.யீ. களஞ்சியம்"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, kde-format
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "உங்கள் வழங்குநர்"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, kde-format
 msgctxt ""
 "Text for an action which causes the specified website to be opened using the "
@@ -818,7 +830,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "இணையதளத்தை திற: %1"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, kde-format
 msgctxt ""
 "Text for an action which will attempt to send an email using the user's "
@@ -826,7 +838,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "இவருக்கு மின்னஞ்சல் அனுப்பு: %1"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -834,10 +846,14 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
+"புதியவற்றைப் பதிவேற்ற, அல்லது ஏற்கனவே கே.டீ.யீ. களஞ்சியத்தில் உள்ள ஒன்றில் புதிய "
+"உருப்படிகளை சேர்க்க, உரிய இணையதளத்தைத் திறந்து உள்நுழையவும். உங்கள் பயனர் சின்னத்தை கிளிக் "
+"செய்யும்போது வரும் பட்டியில் 'My Products' என்று ஓர் இணைப்பு இருக்கும். இதன் மூலம் உங்கள்  "
+"பதிவேற்றங்களை நிர்வகிக்கலாம்."
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -848,19 +864,23 @@ msgid ""
 "might be required to contact the managers of the site directly to get new "
 "content added."
 msgstr ""
+"புதியவற்றைப் பதிவேற்ற, அல்லது ஏற்கனவே உள்ள ஒன்றில் புதிய உருப்படிகளை சேர்க்க, வழங்குநரின் "
+"இணையதளத்தைத் திறந்து அங்கு கொடுக்கப்பட்டள்ள செயல்முறையை கடைப்பிடிக்கவும். உங்கள் "
+"பதிவேற்றங்களை நிர்வகிக்க உதவும் தனிப்பட்ட பக்கம் இருக்கலாம், அல்லது இத்தளத்தின் நிர்வாகிகளை "
+"தொடர்புகொள்ள வேண்டியிருக்கலாம்."
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "தரவு ஏற்றப்படுகிறது"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "நிறுவப்படுகிறது"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -869,76 +889,76 @@ msgid ""
 "You are not authorized to Get Hot New Stuff. If you think this is in error, "
 "please contact the person in charge of your permissions."
 msgstr ""
+"புதியவற்றைப் பதிவிறக்குவதற்கான அனுமதி உங்களிடம் இல்லை. இது தவறு என தோன்றினால், உங்கள் "
+"அனுமதிகளை நிர்வகிப்பவரைத் தொடர்புகொள்ளவும்."
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "பின்னே"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr "மக்கள் விரும்புபவை"
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "சிறப்பானவை"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "மீள்துவக்கு"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "New"
 msgstr "புதியவை"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "முகப்பு"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "மேலே"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "பரிந்துரைக்கப்படுபவை"
 
-#: qtquick/searchpresetmodel.cpp:61
-#, fuzzy, kde-format
-#| msgctxt "@action"
-#| msgid "Subscript"
+#: qtquick/searchpresetmodel.cpp:62
+#, kde-format
 msgctxt "Knewstuff5"
 msgid "Subscriptions"
-msgstr "சந்தா செலுத்தியவை"
+msgstr "சந்தாக்கள்"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "அனைத்தும்"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -951,6 +971,8 @@ msgid ""
 "with a dialog which lets you switch between all the config files installed "
 "into the systemwide knsrc file location"
 msgstr ""
+"காட்ட விரும்பும் KNSRC கோப்பு. எதுவும் குறிப்பிடப்படவில்லையெனில், கணினி முழுவதற்கும் "
+"நிறுவப்பட்டுள்ள knsrc கோப்புகளைக் காட்டும் கோப்புத்தேர்வு சாளரம் காட்டப்படும்"
 
 #: tools/knewstuff-dialog/main.cpp:33
 #, kde-format
@@ -970,8 +992,12 @@ msgstr ""
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
 #, kde-format
-msgid "Download New Stuff..."
-msgstr "புதியவற்றை பதிவிறக்கு..."
+msgctxt "@action"
+msgid "Download New Stuff…"
+msgstr "புதியவற்றைப் பதிவிறக்கு…"
+
+#~ msgid "Download New Stuff..."
+#~ msgstr "புதியவற்றை பதிவிறக்கு..."
 
 #~ msgctxt ""
 #~ "A message which is shown when the user attempts to display a specific "
diff -pruN 6.0.0-3/po/te/knewstuff6.po 6.3.0-1/po/te/knewstuff6.po
--- 6.0.0-3/po/te/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/te/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -13,7 +13,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2013-11-04 23:55+0630\n"
 "Last-Translator: Bhuvan Krishna <bhuvan@swecha.org>\n"
 "Language-Team: Telugu <kde-i18n-doc@kde.org>\n"
@@ -63,7 +63,7 @@ msgstr "మీ వోటు నమోద
 msgid "You are now a fan."
 msgstr "మీరు ఇప్పుడు ఒక ఫ్యాన్."
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -131,7 +131,7 @@ msgstr "ఆకృతీకరణ దస
 msgid "Use"
 msgstr ""
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -139,17 +139,17 @@ msgid ""
 "This is a critical error and should be reported to the application author"
 msgstr ""
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr "దస్త్రం యోక్క సరఫరాదారులు నుండి  లోడింగ్ : %1 విఫలమైంది"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr "దస్త్రం నుండి వేడిగా కొత్త అంశాలు సరఫరానుంచి పొందుటకు లోడ్ చేయబడలేదు: %1"
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr "సరఫరా సంసిద్ధసు లోపం."
@@ -294,7 +294,7 @@ msgid ""
 "the update"
 msgstr ""
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, fuzzy, kde-format
 #| msgid "Failed to load file '%1'"
 msgid ""
@@ -302,7 +302,7 @@ msgid ""
 "%2"
 msgstr "%1' దస్త్రాన్ని ఎక్కించలేకపొయాను"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt ""
@@ -310,7 +310,7 @@ msgctxt ""
 msgid "All Categories"
 msgstr "అన్నీ రకా"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, fuzzy, kde-format
 #| msgid "Unknown error"
 msgctxt ""
@@ -336,14 +336,14 @@ msgstr ""
 msgid "Download New %1…"
 msgstr "కొత్తవి డౌన్ లోడ్ చేయుము %1"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, fuzzy, kde-format
 #| msgid "Download New %1"
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "కొత్తవి డౌన్ లోడ్ చేయుము %1"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
 msgctxt ""
@@ -352,12 +352,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "కొత్త వాటిని డౌన్ లోడ్ చెయి"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -366,12 +366,12 @@ msgid ""
 "this through the naming of the items."
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "స్థాపించు"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt ""
@@ -379,7 +379,7 @@ msgctxt ""
 msgid "Installing %1 from %2"
 msgstr "నెలకొల్పుతుం"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -387,10 +387,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -399,10 +399,10 @@ msgctxt ""
 msgid "Install"
 msgstr "స్థాపించు"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -410,24 +410,24 @@ msgctxt ""
 msgid "Install…"
 msgstr "స్థాపించు"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, fuzzy, kde-format
 #| msgid "Update"
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "కొత్త మార్పులు"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, fuzzy, kde-format
 #| msgid "Uninstall"
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "తొలగించు"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -435,14 +435,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -453,12 +453,12 @@ msgid ""
 "to the KDE Community in a bug report</a>."
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, fuzzy, kde-format
 #| msgid "View Comments"
 msgctxt ""
@@ -467,19 +467,19 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "వ్యాఖ్యలను వీక్షించుము"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, fuzzy, kde-format
 #| msgid "Rating: "
 msgid "Rating:"
 msgstr "రేటింగు: "
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, fuzzy, kde-format
 #| msgid "Homepage"
 msgid "Homepage:"
 msgstr "హొమ్ పేజ్"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -488,12 +488,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -501,80 +501,88 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr ""
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, fuzzy, kde-format
 #| msgctxt "@option:check Do filter on type - show only files"
 #| msgid "Files"
 msgid "Tiles"
 msgstr "దస్త్రా"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "ప్రతిమలు"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, fuzzy, kde-format
 #| msgid "No Preview"
 msgid "Preview"
 msgstr "ముందస్తు వీక్షణం లేదు"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, fuzzy, kde-format
 #| msgid "Details view mode"
 msgid "Detailed Tiles View Mode"
 msgstr "వివరాలు వీక్షణ విధం"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, fuzzy, kde-format
 #| msgid "Icons view mode"
 msgid "Icons Only View Mode"
 msgstr "ప్రతిమ వీక్షణ విధం"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, fuzzy, kde-format
 #| msgid "Details view mode"
 msgid "Large Preview View Mode"
 msgstr "వివరాలు వీక్షణ విధం"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr ""
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "స్థాపించబడిన"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, fuzzy, kde-format
 #| msgid "Update"
 msgid "Updateable"
 msgstr "కొత్త మార్పులు"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "అన్నీ రకా"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -582,30 +590,30 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Open Recent"
 msgid "Recent"
 msgstr "ఇటీవలివి తెరువండి"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr ""
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "రేటిం"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, fuzzy, kde-format
 #| msgid "Download"
 msgid "Downloads"
 msgstr "డౌన్ లోడ్"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt ""
@@ -614,7 +622,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "డెరెక్టరీలను ముందుగా చూపుము"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -622,14 +630,14 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr ""
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "డెరెక్టరీలను ముందుగా చూపుము"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, fuzzy, kde-format
 #| msgid "Most downloads"
 msgctxt ""
@@ -637,41 +645,41 @@ msgctxt ""
 msgid "Show Most Downloaded First"
 msgstr "చాలా సార్లు చెసిన దిగుమతి సమాచారం "
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, fuzzy, kde-format
 #| msgid "&Replace..."
 msgid "Upload…"
 msgstr "(&R) ప్రతిస్థాపించుము..."
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr ""
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, fuzzy, kde-format
 #| msgid "&Go To..."
 msgid "Go to…"
 msgstr "(&G) వెళ్ళు..."
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, fuzzy, kde-format
 #| msgid "Search:"
 msgid "Search…"
 msgstr "అన్వేషణ:"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "రక"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, fuzzy, kde-format
 #| msgid "Continue operation"
 msgid "Contribute your own…"
 msgstr "చర్య కొనసాగించు"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, fuzzy, kde-format
 #| msgctxt "@note/rich"
 #| msgid "<i>Note</i>: %1"
@@ -680,7 +688,7 @@ msgctxt ""
 msgid "<i>(no title)</i>"
 msgstr "<i>వ్యాఖ్య</i>: %1"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -688,20 +696,20 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "అన్నీ రకా"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -709,7 +717,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -717,15 +725,15 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, fuzzy, kde-format
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
 msgstr "1 దిగుమతి"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, fuzzy, kde-format
 #| msgctxt "Show the author of this item in a list"
 #| msgid "By <i>%1</i>"
@@ -735,7 +743,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "<i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -743,7 +751,7 @@ msgctxt ""
 msgid "Working…"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, fuzzy, kde-format
 #| msgid "Updating"
 msgctxt ""
@@ -752,7 +760,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "తాజాపరు"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -763,7 +771,7 @@ msgid ""
 "bug report</a>."
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt "Label for the busy indicator showing an item is installing"
@@ -782,14 +790,14 @@ msgstr ""
 msgid "Please try again later."
 msgstr "పేరు వ్రాయండి."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, fuzzy, kde-format
 #| msgctxt "No border line"
 #| msgid "None"
 msgid "None"
 msgstr "ఏదీ వద్దు"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, fuzzy, kde-format
 #| msgid "(%1/s)"
 msgctxt ""
@@ -797,14 +805,14 @@ msgctxt ""
 msgid "(%1/%2)"
 msgstr "(%1/s)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "కొత్త వాటిని డౌన్ లోడ్ చెయి"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, fuzzy, kde-format
 #| msgid "Billing information:"
 msgctxt ""
@@ -812,21 +820,21 @@ msgctxt ""
 msgid "Updating information…"
 msgstr "బిల్లింగ్ సమాచారము:"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, fuzzy, kde-format
 #| msgid "&Store"
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "&దాచు"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, fuzzy, kde-format
 #| msgid "Provider:"
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "ప్రొవైడ"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, fuzzy, kde-format
 #| msgctxt "@label:button"
 #| msgid "&Open with %1"
@@ -836,7 +844,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "&దీనితో తెరువండి '%1'"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, fuzzy, kde-format
 #| msgid "&Send Email"
 msgctxt ""
@@ -845,7 +853,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "(&S) ఈమెయిల్ పంపించు"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -853,10 +861,10 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -868,18 +876,18 @@ msgid ""
 "content added."
 msgstr ""
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "సమాచారం  ఎక్కుతోం"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "నెలకొల్పుతుం"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -889,7 +897,7 @@ msgid ""
 "please contact the person in charge of your permissions."
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Back"
@@ -897,20 +905,20 @@ msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "వెనుకకు"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, fuzzy, kde-format
 #| msgid "Saturday"
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "శనివారం"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, fuzzy, kde-format
 #| msgctxt "@action:button Restart find & replace"
 #| msgid "Restart"
@@ -918,7 +926,7 @@ msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "మరల మొదలుపెట్టు"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "New"
@@ -926,7 +934,7 @@ msgctxt "Knewstuff5"
 msgid "New"
 msgstr "కొత్త"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Home"
@@ -934,13 +942,13 @@ msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "గృహము"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Up"
@@ -948,7 +956,7 @@ msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "పైకి"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, fuzzy, kde-format
 #| msgctxt "dictionary variant"
 #| msgid "extended"
@@ -956,7 +964,7 @@ msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "విస్తారమైన"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Subscript"
@@ -964,14 +972,14 @@ msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "సబ్‌స్క్రిప్‍ట్"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "అన్నీ రకా"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -1002,9 +1010,14 @@ msgid ""
 msgstr ""
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
-#, kde-format
-msgid "Download New Stuff..."
-msgstr "కొత్త వాటిని సమాచారదిగుమ"
+#, fuzzy, kde-format
+#| msgid "Download New Stuff"
+msgctxt "@action"
+msgid "Download New Stuff…"
+msgstr "కొత్త వాటిని డౌన్ లోడ్ చెయి"
+
+#~ msgid "Download New Stuff..."
+#~ msgstr "కొత్త వాటిని సమాచారదిగుమ"
 
 #~ msgid "Initializing"
 #~ msgstr "స్థాపించు "
diff -pruN 6.0.0-3/po/tg/knewstuff6.po 6.3.0-1/po/tg/knewstuff6.po
--- 6.0.0-3/po/tg/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/tg/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -10,7 +10,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2021-09-05 11:57-0700\n"
 "Last-Translator: Victor Ibragimov <victor.ibragimov@gmail.com>\n"
 "Language-Team: Tajik Language Support\n"
@@ -59,7 +59,7 @@ msgstr "Овози шумо сабт к
 msgid "You are now a fan."
 msgstr "Акнун шумо дӯстдор шудед."
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -128,7 +128,7 @@ msgstr "Файли танзимӣ беэ
 msgid "Use"
 msgstr "Истифода кардан"
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -136,17 +136,17 @@ msgid ""
 "This is a critical error and should be reported to the application author"
 msgstr ""
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr "Боркунии рӯйхати таҳвилгарон аз файли %1 қатъ шуд"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr "Рӯйхати таҳвилгарони маводҳои нав аз файли зерин бор карда нашуд: %1"
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr "Хатои омодасозии таҳвилгар."
@@ -291,7 +291,7 @@ msgid ""
 "the update"
 msgstr ""
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, fuzzy, kde-format
 #| msgid "Failed to load file '%1'"
 msgid ""
@@ -299,7 +299,7 @@ msgid ""
 "%2"
 msgstr "Боркунии файли '%1' қатъ шуд"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt ""
@@ -307,7 +307,7 @@ msgctxt ""
 msgid "All Categories"
 msgstr "Ҳамаи категорияҳо"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, fuzzy, kde-format
 #| msgid "Unknown error"
 msgctxt ""
@@ -335,13 +335,13 @@ msgstr ""
 msgid "Download New %1…"
 msgstr "Боргирӣ кардани %1-и нав"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, kde-format
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "Боргирӣ кардани %1-и нав"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, kde-format
 msgctxt ""
 "A placeholder title used in the dialog when there is no better title "
@@ -349,12 +349,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "Боргирӣ кардани чизҳои нав"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -363,12 +363,12 @@ msgid ""
 "this through the naming of the items."
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "Насб кардан"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt ""
@@ -376,7 +376,7 @@ msgctxt ""
 msgid "Installing %1 from %2"
 msgstr "Насбкунӣ"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -384,10 +384,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -396,10 +396,10 @@ msgctxt ""
 msgid "Install"
 msgstr "Насб кардан"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -407,22 +407,22 @@ msgctxt ""
 msgid "Install…"
 msgstr "Насб кардан"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, kde-format
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "Навсозӣ кардан"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, kde-format
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "Лағв кардани насб"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -430,14 +430,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -448,12 +448,12 @@ msgid ""
 "to the KDE Community in a bug report</a>."
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, fuzzy, kde-format
 #| msgid "View Comments"
 msgctxt ""
@@ -462,19 +462,19 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "Намоиши шарҳ"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, fuzzy, kde-format
 #| msgid "Rating: "
 msgid "Rating:"
 msgstr "Рейтинг:"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, fuzzy, kde-format
 #| msgid "Homepage"
 msgid "Homepage:"
 msgstr "Саҳифаи хона"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -483,12 +483,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -496,79 +496,87 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr ""
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, fuzzy, kde-format
 #| msgctxt "@option:check Do filter on type - show only files"
 #| msgid "Files"
 msgid "Tiles"
 msgstr "Файлҳо"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "Нишонаҳо"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, kde-format
 msgid "Preview"
 msgstr "Пешнамоиш"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, fuzzy, kde-format
 #| msgid "Details view mode"
 msgid "Detailed Tiles View Mode"
 msgstr "Реҷаи намоиш бо тафсилот"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, fuzzy, kde-format
 #| msgid "Icons view mode"
 msgid "Icons Only View Mode"
 msgstr "Реҷаи намоиш бо нишонаҳо"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, fuzzy, kde-format
 #| msgid "Details view mode"
 msgid "Large Preview View Mode"
 msgstr "Реҷаи намоиш бо тафсилот"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr ""
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "Насб"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, fuzzy, kde-format
 #| msgid "Update"
 msgid "Updateable"
 msgstr "Навсозӣ кардан"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "Ҳамаи категорияҳо"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -576,30 +584,30 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Open Recent"
 msgid "Recent"
 msgstr "Кушодани қаблӣ"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr ""
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "Баҳодиҳӣ"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, fuzzy, kde-format
 #| msgid "Download"
 msgid "Downloads"
 msgstr "Боркунӣ"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt ""
@@ -608,7 +616,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "Намоиши феҳристҳо дар авваал"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -616,14 +624,14 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr ""
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "Намоиши феҳристҳо дар авваал"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, fuzzy, kde-format
 #| msgid "Most downloads"
 msgctxt ""
@@ -631,41 +639,41 @@ msgctxt ""
 msgid "Show Most Downloaded First"
 msgstr "Боргириҳои зиёд"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, fuzzy, kde-format
 #| msgid "Upload..."
 msgid "Upload…"
 msgstr "&Закачать на сервер"
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr ""
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, fuzzy, kde-format
 #| msgid "&Go To..."
 msgid "Go to…"
 msgstr "&Гузаштан ба..."
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, fuzzy, kde-format
 #| msgid "Search:"
 msgid "Search…"
 msgstr "Ҷустуҷӯ:"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "Категория:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, fuzzy, kde-format
 #| msgid "Contribute your own..."
 msgid "Contribute your own…"
 msgstr "Чизҳои худро ҷойгир кунед..."
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, fuzzy, kde-format
 #| msgctxt "@note/rich"
 #| msgid "<i>Note</i>: %1"
@@ -674,7 +682,7 @@ msgctxt ""
 msgid "<i>(no title)</i>"
 msgstr "<i>Ёддошт</i>: %1"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -682,20 +690,20 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "Ҳамаи категорияҳо"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -703,7 +711,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -711,8 +719,8 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, fuzzy, kde-format
 #| msgid "1 download"
 #| msgid_plural "%1 downloads"
@@ -720,8 +728,8 @@ msgctxt "The number of times the item ha
 msgid "%1 downloads"
 msgstr "1 боргирӣ"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, fuzzy, kde-format
 #| msgctxt "Show the author of this item in a list"
 #| msgid "By <i>%1</i>"
@@ -731,7 +739,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "Аз ҷониби <i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -739,7 +747,7 @@ msgctxt ""
 msgid "Working…"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, fuzzy, kde-format
 #| msgid "Updating"
 msgctxt ""
@@ -748,7 +756,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "Дар ҳоли навсозӣ"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -759,7 +767,7 @@ msgid ""
 "bug report</a>."
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt "Label for the busy indicator showing an item is installing"
@@ -778,14 +786,14 @@ msgstr ""
 msgid "Please try again later."
 msgstr "Лутфан, номро ворид кунед."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, fuzzy, kde-format
 #| msgctxt "No border line"
 #| msgid "None"
 msgid "None"
 msgstr "Ҳеҷ чиз"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, fuzzy, kde-format
 #| msgid "(%1/s)"
 msgctxt ""
@@ -793,14 +801,14 @@ msgctxt ""
 msgid "(%1/%2)"
 msgstr "(%1/с)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "Боргирии чизҳои нав"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, fuzzy, kde-format
 #| msgid "Billing information:"
 msgctxt ""
@@ -808,21 +816,21 @@ msgctxt ""
 msgid "Updating information…"
 msgstr "Иттилооти пардохт:"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, fuzzy, kde-format
 #| msgid "&Store"
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "&Захира кардан"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, fuzzy, kde-format
 #| msgid "Provider:"
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "Таҳвилгар:"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, fuzzy, kde-format
 #| msgctxt "@label:button"
 #| msgid "&Open with %1"
@@ -832,7 +840,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "&Открыть в программе «%1»"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, fuzzy, kde-format
 #| msgid "&Send Email"
 msgctxt ""
@@ -841,7 +849,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "&Ирсоли почта"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -849,10 +857,10 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -864,18 +872,18 @@ msgid ""
 "content added."
 msgstr ""
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "Иттилоот бор шуда истодааст"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "Насбкунӣ"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -885,7 +893,7 @@ msgid ""
 "please contact the person in charge of your permissions."
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Back"
@@ -893,20 +901,20 @@ msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "Ақиб"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, fuzzy, kde-format
 #| msgid "Saturday"
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "Шанбе"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, fuzzy, kde-format
 #| msgctxt "@action:button Restart find & replace"
 #| msgid "Restart"
@@ -914,7 +922,7 @@ msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "Бозоғозӣ"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "New"
@@ -922,7 +930,7 @@ msgctxt "Knewstuff5"
 msgid "New"
 msgstr "Нав"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Home"
@@ -930,13 +938,13 @@ msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Феҳристи хона"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Up"
@@ -944,7 +952,7 @@ msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "Боло"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, fuzzy, kde-format
 #| msgctxt "dictionary variant"
 #| msgid "extended"
@@ -952,7 +960,7 @@ msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "васеъшуда"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Subscript"
@@ -960,14 +968,14 @@ msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "Зерискрипт"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "Ҳамаи категорияҳо"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -998,9 +1006,17 @@ msgid ""
 msgstr ""
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
-#, kde-format
-msgid "Download New Stuff..."
-msgstr "Боргирӣ кардани маводҳои нав..."
+#, fuzzy, kde-format
+#| msgctxt ""
+#| "A placeholder title used in the dialog when there is no better title "
+#| "available"
+#| msgid "Download New Stuff"
+msgctxt "@action"
+msgid "Download New Stuff…"
+msgstr "Боргирӣ кардани чизҳои нав"
+
+#~ msgid "Download New Stuff..."
+#~ msgstr "Боргирӣ кардани маводҳои нав..."
 
 #~ msgid "Initializing"
 #~ msgstr "Омодасозӣ"
diff -pruN 6.0.0-3/po/th/knewstuff6.po 6.3.0-1/po/th/knewstuff6.po
--- 6.0.0-3/po/th/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/th/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -10,7 +10,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2010-12-31 22:47+0700\n"
 "Last-Translator: Phuwanat Sakornsakolpat <narachai@gmail.com>\n"
 "Language-Team: Thai <thai-l10n@googlegroups.com>\n"
@@ -65,7 +65,7 @@ msgstr "การโหวตของ
 msgid "You are now a fan."
 msgstr "คุณเป็นแฟนคลับแล้วในตอนนี้"
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -133,7 +133,7 @@ msgstr "แฟ้มค่าปรั
 msgid "Use"
 msgstr ""
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -141,17 +141,17 @@ msgid ""
 "This is a critical error and should be reported to the application author"
 msgstr ""
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr "การโหลดส่วนผู้จัดทำขึ้นมาจากแฟ้ม: %1 ล้มเหลว"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr "ไม่สามารถโหลดส่วนผู้จัดทำสิ่งใหม่ ๆ ที่เป็นที่นิยมจากแฟ้มต่อไปนี้ได้: %1"
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr "เกิดข้อผิดพลาดในการเริ่มใช้งานส่วนของผู้จัดทำ"
@@ -296,7 +296,7 @@ msgid ""
 "the update"
 msgstr ""
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, fuzzy, kde-format
 #| msgid "Failed to load file '%1'"
 msgid ""
@@ -304,7 +304,7 @@ msgid ""
 "%2"
 msgstr "การโหลดแฟ้ม '%1' ล้มเหลว"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt ""
@@ -312,7 +312,7 @@ msgctxt ""
 msgid "All Categories"
 msgstr "หมวดหมู่ทั้งหมด"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, fuzzy, kde-format
 #| msgid "Unknown error"
 msgctxt ""
@@ -338,14 +338,14 @@ msgstr ""
 msgid "Download New %1…"
 msgstr "ดาวน์โหลด %1 ตัวใหม่"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, fuzzy, kde-format
 #| msgid "Download New %1"
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "ดาวน์โหลด %1 ตัวใหม่"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
 msgctxt ""
@@ -354,12 +354,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "ดาวน์โหลดของใหม่ ๆ ที่เป็นที่นิยม"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -368,12 +368,12 @@ msgid ""
 "this through the naming of the items."
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "ติดตั้ง"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt ""
@@ -381,7 +381,7 @@ msgctxt ""
 msgid "Installing %1 from %2"
 msgstr "ทำการติดตั้ง"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -389,10 +389,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -401,10 +401,10 @@ msgctxt ""
 msgid "Install"
 msgstr "ติดตั้ง"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -412,24 +412,24 @@ msgctxt ""
 msgid "Install…"
 msgstr "ติดตั้ง"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, fuzzy, kde-format
 #| msgid "Update"
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "ปรับรุ่น"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, fuzzy, kde-format
 #| msgid "Uninstall"
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "ถอนการติดตั้ง"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -437,14 +437,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -455,12 +455,12 @@ msgid ""
 "to the KDE Community in a bug report</a>."
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, fuzzy, kde-format
 #| msgid "View Comments"
 msgctxt ""
@@ -469,19 +469,19 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "แสดงความคิดเห็น"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, fuzzy, kde-format
 #| msgid "Rating: "
 msgid "Rating:"
 msgstr "อันดับที่: "
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, fuzzy, kde-format
 #| msgid "Homepage"
 msgid "Homepage:"
 msgstr "หน้าเว็บ"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -490,12 +490,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -503,79 +503,87 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr ""
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, fuzzy, kde-format
 #| msgctxt "@option:check Do filter on type - show only files"
 #| msgid "Files"
 msgid "Tiles"
 msgstr "แฟ้ม"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "ไอคอน"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, kde-format
 msgid "Preview"
 msgstr "แสดงตัวอย่าง"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, fuzzy, kde-format
 #| msgid "Details view mode"
 msgid "Detailed Tiles View Mode"
 msgstr "โหมดมุมมองรายละเอียด"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, fuzzy, kde-format
 #| msgid "Icons view mode"
 msgid "Icons Only View Mode"
 msgstr "โหมดมุมมองไอคอน"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, fuzzy, kde-format
 #| msgid "Details view mode"
 msgid "Large Preview View Mode"
 msgstr "โหมดมุมมองรายละเอียด"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr ""
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "ติดตั้งแล้ว"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, fuzzy, kde-format
 #| msgid "Update"
 msgid "Updateable"
 msgstr "ปรับรุ่น"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "หมวดหมู่ทั้งหมด"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -583,30 +591,30 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Open Recent"
 msgid "Recent"
 msgstr "เปิดที่เคยเรียกใช้"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr ""
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "การจัดอันดับ"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, fuzzy, kde-format
 #| msgid "Download"
 msgid "Downloads"
 msgstr "ดาวน์โหลด"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt ""
@@ -615,7 +623,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "แสดงไดเรกทอรีก่อน"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -623,14 +631,14 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr ""
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "แสดงไดเรกทอรีก่อน"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, fuzzy, kde-format
 #| msgid "Most downloads"
 msgctxt ""
@@ -638,41 +646,41 @@ msgctxt ""
 msgid "Show Most Downloaded First"
 msgstr "ถูกดาวน์โหลดมากที่สุด"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, fuzzy, kde-format
 #| msgid "Upload..."
 msgid "Upload…"
 msgstr "อัปโหลด..."
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr ""
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, fuzzy, kde-format
 #| msgid "&Go To..."
 msgid "Go to…"
 msgstr "ไป&ยัง..."
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, fuzzy, kde-format
 #| msgid "Search:"
 msgid "Search…"
 msgstr "ค้นหา:"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "หมวดหมู่:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, fuzzy, kde-format
 #| msgid "Continue operation"
 msgid "Contribute your own…"
 msgstr "ดำเนินการต่อไป"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, fuzzy, kde-format
 #| msgctxt "@note/rich"
 #| msgid "<i>Note</i>: %1"
@@ -681,7 +689,7 @@ msgctxt ""
 msgid "<i>(no title)</i>"
 msgstr "<i>ข้อควรทราบ</i>: %1"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -689,20 +697,20 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "หมวดหมู่ทั้งหมด"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -710,7 +718,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -718,8 +726,8 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, fuzzy, kde-format
 #| msgid "1 download"
 #| msgid_plural "%1 downloads"
@@ -727,8 +735,8 @@ msgctxt "The number of times the item ha
 msgid "%1 downloads"
 msgstr "ดาวน์โหลด %1 รายการ"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, fuzzy, kde-format
 #| msgctxt "Show the author of this item in a list"
 #| msgid "By <i>%1</i>"
@@ -738,7 +746,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "โดย <i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -746,7 +754,7 @@ msgctxt ""
 msgid "Working…"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, fuzzy, kde-format
 #| msgid "Updating"
 msgctxt ""
@@ -755,7 +763,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "ทำการปรับรุ่น"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -766,7 +774,7 @@ msgid ""
 "bug report</a>."
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt "Label for the busy indicator showing an item is installing"
@@ -785,14 +793,14 @@ msgstr ""
 msgid "Please try again later."
 msgstr "โปรดป้อนชื่อ"
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, fuzzy, kde-format
 #| msgctxt "No border line"
 #| msgid "None"
 msgid "None"
 msgstr "ไม่มี"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, fuzzy, kde-format
 #| msgid "(%1/s)"
 msgctxt ""
@@ -800,14 +808,14 @@ msgctxt ""
 msgid "(%1/%2)"
 msgstr "(%1/วินาที)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "ดาวน์โหลดของใหม่ ๆ ที่เป็นที่นิยม"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, fuzzy, kde-format
 #| msgid "Billing information:"
 msgctxt ""
@@ -815,21 +823,21 @@ msgctxt ""
 msgid "Updating information…"
 msgstr "ข้อมูลค่าใช้จ่าย:"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, fuzzy, kde-format
 #| msgid "&Store"
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "&จัดเก็บ"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, fuzzy, kde-format
 #| msgid "Provider:"
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "ผู้จัดทำ:"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, fuzzy, kde-format
 #| msgctxt "@label:button"
 #| msgid "&Open with %1"
@@ -839,7 +847,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "เปิ&ดด้วย %1"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, fuzzy, kde-format
 #| msgid "&Send Email"
 msgctxt ""
@@ -848,7 +856,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "&ส่งอีเมล"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -856,10 +864,10 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -871,18 +879,18 @@ msgid ""
 "content added."
 msgstr ""
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "ทำการโหลดข้อมูล"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "ทำการติดตั้ง"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -892,7 +900,7 @@ msgid ""
 "please contact the person in charge of your permissions."
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Back"
@@ -900,20 +908,20 @@ msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "ย้อนกลับ"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, fuzzy, kde-format
 #| msgid "Saturday"
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "เสาร์"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, fuzzy, kde-format
 #| msgctxt "@action:button Restart find & replace"
 #| msgid "Restart"
@@ -921,7 +929,7 @@ msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "เริ่มใหม่"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "New"
@@ -929,7 +937,7 @@ msgctxt "Knewstuff5"
 msgid "New"
 msgstr "สร้างใหม่"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Home"
@@ -937,13 +945,13 @@ msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Home"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Up"
@@ -951,7 +959,7 @@ msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "ขึ้น"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, fuzzy, kde-format
 #| msgctxt "dictionary variant"
 #| msgid "extended"
@@ -959,7 +967,7 @@ msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "ส่วนขยาย"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Subscript"
@@ -967,14 +975,14 @@ msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "ตัวห้อย"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "หมวดหมู่ทั้งหมด"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -1005,9 +1013,14 @@ msgid ""
 msgstr ""
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
-#, kde-format
-msgid "Download New Stuff..."
-msgstr "ดาวน์โหลดสิ่งใหม่ ๆ ..."
+#, fuzzy, kde-format
+#| msgid "Download New Stuff"
+msgctxt "@action"
+msgid "Download New Stuff…"
+msgstr "ดาวน์โหลดของใหม่ ๆ ที่เป็นที่นิยม"
+
+#~ msgid "Download New Stuff..."
+#~ msgstr "ดาวน์โหลดสิ่งใหม่ ๆ ..."
 
 #~ msgid "Initializing"
 #~ msgstr "เตรียมการทำงาน"
diff -pruN 6.0.0-3/po/tr/knewstuff6.po 6.3.0-1/po/tr/knewstuff6.po
--- 6.0.0-3/po/tr/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/tr/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -22,8 +22,8 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
-"PO-Revision-Date: 2024-01-19 12:45+0300\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
+"PO-Revision-Date: 2024-05-09 18:58+0300\n"
 "Last-Translator: Emir SARI <emir_sari@icloud.com>\n"
 "Language-Team: Turkish <kde-l10n-tr@kde.org>\n"
 "Language: tr\n"
@@ -31,7 +31,7 @@ msgstr ""
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=2; plural=(n > 1);\n"
-"X-Generator: Lokalize 24.01.95\n"
+"X-Generator: Lokalize 24.07.70\n"
 
 #: attica/atticaprovider.cpp:165
 #, kde-format
@@ -71,7 +71,7 @@ msgstr "Oyunuz kaydedildi."
 msgid "You are now a fan."
 msgstr "Hayranı oldunuz."
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -101,7 +101,7 @@ msgstr "Açık İşbirliği Hizmetleri 
 #: attica/atticaprovider.cpp:600
 #, kde-format
 msgid "Unknown Open Collaboration Service API error. (%1)"
-msgstr "Açık İşbirliği Hizmeti'nde bilinmeyen API hatası. (%1)"
+msgstr "Açık İşbirliği Hizmeti’nde bilinmeyen API hatası. (%1)"
 
 #: core/commentsmodel.cpp:154
 #, kde-format
@@ -122,24 +122,24 @@ msgstr ""
 #: core/enginebase.cpp:79
 #, kde-format
 msgid "Configuration file does not exist: \"%1\""
-msgstr "Yapılandırma dosyası yok: \"%1\""
+msgstr "Yapılandırma dosyası yok: “%1”"
 
 #: core/enginebase.cpp:87
 #, kde-format
 msgid "Configuration file exists, but cannot be opened: \"%1\""
-msgstr "Yapılandırma dosyası var; ancak açılamıyor: \"%1\""
+msgstr "Yapılandırma dosyası var; ancak açılamıyor: “%1”"
 
 #: core/enginebase.cpp:94
 #, kde-format
 msgid "Configuration file is invalid: \"%1\""
-msgstr "Yapılandırma dosyası geçersiz: \"%1\""
+msgstr "Yapılandırma dosyası geçersiz: “%1”"
 
 #: core/enginebase.cpp:103
 #, kde-format
 msgid "Use"
 msgstr "Kullan"
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -150,17 +150,17 @@ msgstr ""
 "%2\n"
 "Bu kritik bir hatadır ve uygulama yazarına bildirilmelidir"
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr "%1 dosyasından sağlayıcılar okunamadı"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
-msgstr "Dosyadan \"Yeni Çıkanlar\" alınamadı: %1"
+msgstr "Dosyadan “Yeni Çıkanlar” alınamadı: %1"
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr "Sağlayıcı başlatılamadı."
@@ -173,12 +173,12 @@ msgstr "Geçersiz öge."
 #: core/installation.cpp:108
 #, kde-format
 msgid "Download of item failed: no download URL for \"%1\"."
-msgstr "Öge indirilemedi: \"%1\" için indirme URL'si yok."
+msgstr "Öge indirilemedi: “%1” için indirme URL’si yok."
 
 #: core/installation.cpp:139
 #, kde-format
 msgid "Download of \"%1\" failed, error: %2"
-msgstr "\"%1\" indirilemedi, hata: %2"
+msgstr "“%1” indirilemedi, hata: %2"
 
 #: core/installation.cpp:148
 #, kde-format
@@ -186,7 +186,7 @@ msgid ""
 "Cannot install '%1' because it points to a web page. Click <a "
 "href='%2'>here</a> to finish the installation."
 msgstr ""
-"'%1' kurulamıyor; çünkü bir web sayfasına işaret ediyor. Kurulumu tamamlamak "
+"“%1” kurulamıyor; çünkü bir web sayfasına işaret ediyor. Kurulumu tamamlamak "
 "için <a href='%2'>buraya</a> tıklayın."
 
 #: core/installation.cpp:186
@@ -330,23 +330,23 @@ msgstr ""
 "%1 güncellemesi için düzgün bir bağlantı tanımlayamadık; bu yüzden "
 "güncellemeyi gerçekleştiremiyoruz"
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, kde-format
 msgid ""
 "Failed to adopt '%1'\n"
 "%2"
 msgstr ""
-"'%1' ayarlanamadı\n"
+"“%1” ayarlanamadı\n"
 "%2"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, kde-format
 msgctxt ""
 "The first entry in the category selection list (also the default value)"
 msgid "All Categories"
 msgstr "Tüm Kategoriler"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, kde-format
 msgctxt ""
 "The string passed back in the case the requested category is not known"
@@ -370,13 +370,13 @@ msgstr "Şeyler"
 msgid "Download New %1…"
 msgstr "Yeni %1 İndir…"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, kde-format
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
-msgstr "Yeni %1 İndir..."
+msgstr "Yeni %1 İndir"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, kde-format
 msgctxt ""
 "A placeholder title used in the dialog when there is no better title "
@@ -384,12 +384,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "Yeni Şeyler İndir"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr "Kurulum Seçeneğini Seç"
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -402,19 +402,19 @@ msgstr ""
 "emin değilseniz bu ögenin yazarıyla iletişime geçin ve bunu ögenin "
 "adlandırması üzerinden açıklığa kavuşturun."
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "Kur"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, kde-format
 msgctxt ""
 "A passive notification shown when installation of an item is initiated"
 msgid "Installing %1 from %2"
 msgstr "%1, %2 konumundan kuruluyor"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -422,10 +422,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr "%2 tarafından yapılan %1"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, kde-format
 msgctxt ""
 "Request installation of this item, available when there is exactly one "
@@ -433,32 +433,32 @@ msgctxt ""
 msgid "Install"
 msgstr "Kur"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, kde-format
 msgctxt ""
 "Show installation options, where there is more than one downloadable item"
 msgid "Install…"
 msgstr "Kur…"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, kde-format
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "Güncelle"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, kde-format
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "Kaldır"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -466,14 +466,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr "%2 tarafından yapılan %1 ögesi üzerinde çalışılıyor. Lütfen bekleyin…"
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr "%2 tarafından yapılan %1 ögesi güncelleniyor. Lütfen bekleyin…"
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -485,14 +485,14 @@ msgid ""
 msgstr ""
 "Bu öge şu anda geçersiz veya bilinmeyen bir durumda. <a href=\"https://bugs."
 "kde.org/enter_bug.cgi?product=frameworks-knewstuff\">Bunu lütfen KDE "
-"Topluluğu'na bir hata raporu ile birlikte bildirin</a>."
+"Topluluğu’na bir hata raporu ile birlikte bildirin</a>."
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr "Yorumlar ve Gözden Geçirmeler"
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a new sub page with comments (comments "
@@ -500,17 +500,17 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "%1 Gözden Geçirmeleri ve Yorumları"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, kde-format
 msgid "Rating:"
 msgstr "Derecelendirme:"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, kde-format
 msgid "Homepage:"
 msgstr "Ana sayfa:"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -519,12 +519,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr "%1 ana sayfasını açın"
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr "Bağış Yapma Yolları"
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -532,74 +532,85 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr "Bu projeye nasıl bağış yapabileceğinizi öğrenin"
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+"KDE veya dağıtımınız tarafından güvenlik, kararlılık veya kalite açısından "
+"sınanmayın yürütülebilir kodlar içerebileceğinden, burada gösterilen "
+"kullanıcı yapımı içeriğe erişirken dikkatli olun"
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
-"Kullanılabilir içerik, sizin gibi kullanıcılar tarafından yüklenir ve "
-"işlevsellik veya kararlılık açısından gözden geçirilmemiştir."
+"Burada gösterilen kullanıcı yapımı içerik, KDE veya dağtımınız tarafından "
+"işlevsellik veya kalite açısından sınanmamıştır."
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, kde-format
 msgid "Tiles"
 msgstr "Karolar"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "Simgeler"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, kde-format
 msgid "Preview"
 msgstr "Önizleme"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, kde-format
 msgid "Detailed Tiles View Mode"
 msgstr "Ayrıntılı Karo Görünüm Kipi"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, kde-format
 msgid "Icons Only View Mode"
 msgstr "Yalnızca Simgeler Görünümü Kipi"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, kde-format
 msgid "Large Preview View Mode"
 msgstr "Büyük Önizleme Görünümü Kipi"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr "Her Şey"
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "Kurulu"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, kde-format
 msgid "Updateable"
 msgstr "Güncellenebilir"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, kde-format
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "Tüm Girdileri Göster"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr "Yalnızca Kurulu Girdileri Göster"
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -607,27 +618,27 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr "Yalnızca Güncellenebilir Girdileri Göster"
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, kde-format
 msgid "Recent"
 msgstr "Son Kullanılan"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr "Abecesel"
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "Derecelendirme"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, kde-format
 msgid "Downloads"
 msgstr "İndirmeler"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on when items were most "
@@ -635,7 +646,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "Önce En Son Kullanılan"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -643,57 +654,57 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr "Ada Göre Abecesel Sırala"
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, kde-format
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "Önce En Yüksek Dereceliler"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on number of downloads"
 msgid "Show Most Downloaded First"
 msgstr "Önce En Çok İndirilen"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, kde-format
 msgid "Upload…"
 msgstr "Karşıya Yükle…"
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr "Bu listeye kendi yeni şeylerinizi nasıl ekleyeceğinizi öğrenin"
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, kde-format
 msgid "Go to…"
 msgstr "Git…"
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, kde-format
 msgid "Search…"
 msgstr "Ara…"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "Kategori:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, kde-format
 msgid "Contribute your own…"
-msgstr "Kendinizinkini katkıda bulunun..."
+msgstr "Kendin Bir Şeyler Koy…"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, kde-format
 msgctxt ""
 "Placeholder title for when a comment has no subject, but does have a rating"
 msgid "<i>(no title)</i>"
 msgstr "<i>(başlıksız)</i>"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -701,19 +712,19 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr "%1 <i>(yazar)</i>"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr "%1 Yorumları ve Gözden Geçirmeleri"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, kde-format
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "Tüm Yorumları Göster"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -721,7 +732,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr "Yalnızca Gözden Geçirmeleri Göster"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -729,15 +740,15 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr "Gözden Geçirmeleri ve Yanıtları Göster"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, kde-format
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
 msgstr "%1 indirme"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, kde-format
 msgctxt ""
 "Subheading for the tile view, located immediately underneath the name of the "
@@ -745,7 +756,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "<i>%1</i> tarafından"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -753,7 +764,7 @@ msgctxt ""
 msgid "Working…"
 msgstr "Çalışıyor…"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is in the process of being "
@@ -761,7 +772,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "Güncelleniyor…"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -772,10 +783,10 @@ msgid ""
 "bug report</a>."
 msgstr ""
 "Geçersiz veya bilinmeyen durum.<a href=\"https://bugs.kde.org/enter_bug.cgi?"
-"product=frameworks-knewstuff\">Bunu lütfen KDE Topluluğu'na bir hata raporu "
+"product=frameworks-knewstuff\">Bunu lütfen KDE Topluluğu’na bir hata raporu "
 "ile birlikte bildirin</a>."
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, kde-format
 msgctxt "Label for the busy indicator showing an item is installing"
 msgid "Installing…"
@@ -792,44 +803,44 @@ msgstr "Bir Hata Oluştu"
 msgid "Please try again later."
 msgstr "Lütfen daha sonra yeniden deneyin."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, kde-format
 msgid "None"
 msgstr "Yok"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, kde-format
 msgctxt ""
 "A text representation of the rating, shown as a fraction of the max value"
 msgid "(%1/%2)"
 msgstr "(%1/%2)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, kde-format
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "Yeni Şeyler Karşıya Yükle: %1"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, kde-format
 msgctxt ""
 "A text shown beside a busy indicator suggesting that data is being fetched"
 msgid "Updating information…"
 msgstr "Bilgi güncelleniyor…"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, kde-format
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "KDE Mağazası"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, kde-format
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "Sağlayıcınız"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, kde-format
 msgctxt ""
 "Text for an action which causes the specified website to be opened using the "
@@ -837,7 +848,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "Web Sitesini Aç: %1"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, kde-format
 msgctxt ""
 "Text for an action which will attempt to send an email using the user's "
@@ -845,7 +856,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "E-posta Gönder: %1"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -853,15 +864,15 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
-"Yeni girdiler yüklemek için veya KDE Mağazası'ndaki var olan bir girdiye "
+"Yeni girdiler yüklemek için veya KDE Mağazası’ndaki var olan bir girdiye "
 "yeni içerik eklemek için önce web sayfasını açın ve oturum açın. Bunu "
 "yaptıktan sonra, kullanıcı simgenize tıkladığınızda açılan menüden "
-"Ürünlerim'i bulun. Buraya tıklayıp ürünleriniz üzerinde çalışabileceğiniz "
+"Ürünlerim’i bulun. Buraya tıklayıp ürünleriniz üzerinde çalışabileceğiniz "
 "ürün yönetimini açın."
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -879,18 +890,18 @@ msgstr ""
 "yeni içeriği ekletmek için doğrudan sitenin yöneticileri ile iletişime "
 "geçebilirsiniz."
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "Veri yükleniyor"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "Kuruluyor"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -902,73 +913,73 @@ msgstr ""
 "Yeni Çıkanlar için yetkiniz yok. Bunun bir hata olduğunu düşünüyorsanız "
 "izinlerinizi yöneten kişiyle iletişime geçin."
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "Geri"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr "Popüler"
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "Öne Çıkan"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "Yeniden Başlat"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "New"
 msgstr "Yeni"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Ev"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr "Raf"
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "Yukarı"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "Önerilen"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "Abonelikler"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "Tüm Girdiler"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -1000,21 +1011,25 @@ msgid ""
 "file.\n"
 " An example of such a url is kns://sddmtheme.knsrc/api.kde-look.org/2059021"
 msgstr ""
-"Bilgi göstermek için bir KNS URL'si. Bir KNS URL'sinin biçimi kns://"
+"Bilgi göstermek için bir KNS URL’si. Bir KNS URL’sinin biçimi kns://"
 "knsrcdosyası/sağlayıcıkimliği/girdikimliği biçimindedir\n"
-"'knsrcdosyası'\n"
+"“knsrcdosyası”\n"
 "bu aracın doğrudan knsrc argümanına geçirilebilecek knsrc dosyasının adıdır\n"
-"'sağlayıcıkimliği'\n"
+"“sağlayıcıkimliği”\n"
 "girdinin var olması gereken sağlayıcı makinesinin adıdır\n"
-"'girdikimliği'\n"
+"“girdikimliği”\n"
 "knsrc dosyasında belirtilen sağlayıcıda bulunan girdinin benzersiz "
 "kimliğidir.\n"
 "Örnek bir URL: kns://sddmtheme.knsrc/api.kde-look.org/2059021"
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
 #, kde-format
-msgid "Download New Stuff..."
-msgstr "Yeni Şeyler İndir..."
+msgctxt "@action"
+msgid "Download New Stuff…"
+msgstr "Yeni Şeyler İndir…"
+
+#~ msgid "Download New Stuff..."
+#~ msgstr "Yeni Şeyler İndir…"
 
 #~ msgctxt ""
 #~ "A message which is shown when the user attempts to display a specific "
diff -pruN 6.0.0-3/po/tt/knewstuff6.po 6.3.0-1/po/tt/knewstuff6.po
--- 6.0.0-3/po/tt/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/tt/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -6,7 +6,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: \n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2011-11-26 15:12+0400\n"
 "Last-Translator: Ainur Shakirov <ainur.shakirov.tt@gmail.com>\n"
 "Language-Team: Tatar <>\n"
@@ -61,7 +61,7 @@ msgstr "Сезнең тавышыгыз
 msgid "You are now a fan."
 msgstr "Хәзер сез бу өстәлмәнең яратучысы."
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -131,7 +131,7 @@ msgstr "Көйләү файлы хата
 msgid "Use"
 msgstr ""
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -139,17 +139,17 @@ msgid ""
 "This is a critical error and should be reported to the application author"
 msgstr ""
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr "Тәэмин итүчеләрен файлдан алып булмады: %1"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr "Тәэмин итүчеләр исемлеген файлдан алып булмады: %1"
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr "Тәэмин итәчесен башлап җибәреп булмады."
@@ -294,7 +294,7 @@ msgid ""
 "the update"
 msgstr ""
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, fuzzy, kde-format
 #| msgid "Failed to load file '%1'"
 msgid ""
@@ -302,7 +302,7 @@ msgid ""
 "%2"
 msgstr "Ошибка открытия файла «%1»"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt ""
@@ -310,7 +310,7 @@ msgctxt ""
 msgid "All Categories"
 msgstr "Барлык төркемнәр"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, fuzzy, kde-format
 #| msgid "Unknown error"
 msgctxt ""
@@ -336,14 +336,14 @@ msgstr ""
 msgid "Download New %1…"
 msgstr "Әсбапларны кабул итү..."
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, fuzzy, kde-format
 #| msgid "Download New Stuff..."
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "Әсбапларны кабул итү..."
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, fuzzy, kde-format
 #| msgid "Download New Stuff..."
 msgctxt ""
@@ -352,12 +352,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "Әсбапларны кабул итү..."
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -366,12 +366,12 @@ msgid ""
 "this through the naming of the items."
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "Урнаштыру"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt ""
@@ -379,7 +379,7 @@ msgctxt ""
 msgid "Installing %1 from %2"
 msgstr "Урнаштыру"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -387,10 +387,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -399,10 +399,10 @@ msgctxt ""
 msgid "Install"
 msgstr "Урнаштыру"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -410,24 +410,24 @@ msgctxt ""
 msgid "Install…"
 msgstr "Урнаштыру"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, fuzzy, kde-format
 #| msgid "Update"
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "Яңарту"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, fuzzy, kde-format
 #| msgid "Uninstall"
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "Бетерү"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -435,14 +435,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -453,12 +453,12 @@ msgid ""
 "to the KDE Community in a bug report</a>."
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, fuzzy, kde-format
 #| msgid "View Comments"
 msgctxt ""
@@ -467,19 +467,19 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "Аңлатмаларны карарга"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, fuzzy, kde-format
 #| msgid "Rating: "
 msgid "Rating:"
 msgstr "Бәя: "
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, fuzzy, kde-format
 #| msgid "Homepage"
 msgid "Homepage:"
 msgstr "Албит"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -488,12 +488,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -501,80 +501,88 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr ""
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, fuzzy, kde-format
 #| msgctxt "@option:check Do filter on type - show only files"
 #| msgid "Files"
 msgid "Tiles"
 msgstr "Файллар"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "Билгечекләр"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, fuzzy, kde-format
 #| msgid "Preview URL:"
 msgid "Preview"
 msgstr "Кече сүрәтнең адресы:"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, fuzzy, kde-format
 #| msgid "Details view mode"
 msgid "Detailed Tiles View Mode"
 msgstr "Исемлек"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, fuzzy, kde-format
 #| msgid "Icons view mode"
 msgid "Icons Only View Mode"
 msgstr "Билгечекләр"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, fuzzy, kde-format
 #| msgid "Details view mode"
 msgid "Large Preview View Mode"
 msgstr "Исемлек"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr ""
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "Урнаштырылган"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, fuzzy, kde-format
 #| msgid "Update"
 msgid "Updateable"
 msgstr "Яңарту"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "Барлык төркемнәр"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -582,30 +590,30 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Open Recent"
 msgid "Recent"
 msgstr "Күптән түгелдәге файллар"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr ""
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "Бәяләү буенча"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, fuzzy, kde-format
 #| msgid "Download"
 msgid "Downloads"
 msgstr "Кабул итү"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt ""
@@ -614,7 +622,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "Каталоглар баштан"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -622,14 +630,14 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr ""
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "Каталоглар баштан"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, fuzzy, kde-format
 #| msgid "Most downloads"
 msgctxt ""
@@ -637,41 +645,41 @@ msgctxt ""
 msgid "Show Most Downloaded First"
 msgstr "Иң таныклы"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, fuzzy, kde-format
 #| msgid "New Upload"
 msgid "Upload…"
 msgstr "Яңа әсбап"
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr ""
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, fuzzy, kde-format
 #| msgid "&Go To..."
 msgid "Go to…"
 msgstr "&Күчү..."
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, fuzzy, kde-format
 #| msgid "Search:"
 msgid "Search…"
 msgstr "Эзләү:"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "Төркем:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, fuzzy, kde-format
 #| msgid "Continue operation"
 msgid "Contribute your own…"
 msgstr "Гамәлне дәвам иттерү"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, fuzzy, kde-format
 #| msgctxt "@note/rich"
 #| msgid "<i>Note</i>: %1"
@@ -680,7 +688,7 @@ msgctxt ""
 msgid "<i>(no title)</i>"
 msgstr "<i>Искәрмә</i>: %1"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -688,20 +696,20 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "Барлык төркемнәр"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -709,7 +717,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -717,8 +725,8 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, fuzzy, kde-format
 #| msgid "1 download"
 #| msgid_plural "%1 downloads"
@@ -726,8 +734,8 @@ msgctxt "The number of times the item ha
 msgid "%1 downloads"
 msgstr "%1 кабул итү"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, fuzzy, kde-format
 #| msgctxt "Show the author of this item in a list"
 #| msgid "By <i>%1</i>"
@@ -737,7 +745,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "Автор: <i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -745,7 +753,7 @@ msgctxt ""
 msgid "Working…"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, fuzzy, kde-format
 #| msgid "Updating"
 msgctxt ""
@@ -754,7 +762,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "Яңарту"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -765,7 +773,7 @@ msgid ""
 "bug report</a>."
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt "Label for the busy indicator showing an item is installing"
@@ -784,14 +792,14 @@ msgstr ""
 msgid "Please try again later."
 msgstr "Исем кертегез."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, fuzzy, kde-format
 #| msgctxt "No border line"
 #| msgid "None"
 msgid "None"
 msgstr "Юк"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, fuzzy, kde-format
 #| msgid "(%1/s)"
 msgctxt ""
@@ -799,14 +807,14 @@ msgctxt ""
 msgid "(%1/%2)"
 msgstr "(%1/с)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, fuzzy, kde-format
 #| msgid "Download New Stuff..."
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "Әсбапларны кабул итү..."
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, fuzzy, kde-format
 #| msgid "Billing information:"
 msgctxt ""
@@ -814,21 +822,21 @@ msgctxt ""
 msgid "Updating information…"
 msgstr "Бастыруның бәясе:"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, fuzzy, kde-format
 #| msgid "&Store"
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "&Саклау"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, fuzzy, kde-format
 #| msgid "Provider:"
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "Тәэмин итүче:"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, fuzzy, kde-format
 #| msgctxt "@label:button"
 #| msgid "&Open with %1"
@@ -838,7 +846,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "«%1» кушымтасы аша &ачу"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, fuzzy, kde-format
 #| msgid "&Send Email"
 msgctxt ""
@@ -847,7 +855,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "&Е-mail тапшыру"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -855,10 +863,10 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -870,18 +878,18 @@ msgid ""
 "content added."
 msgstr ""
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "Мәгълуматны кабул итү"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "Урнаштыру"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -891,7 +899,7 @@ msgid ""
 "please contact the person in charge of your permissions."
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Back"
@@ -899,19 +907,19 @@ msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "Кире кайту"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, fuzzy, kde-format
 #| msgctxt "@action:button Restart find & replace"
 #| msgid "Restart"
@@ -919,7 +927,7 @@ msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "Яңадан җибәрү"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "New"
@@ -927,7 +935,7 @@ msgctxt "Knewstuff5"
 msgid "New"
 msgstr "Яңа"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Home"
@@ -935,13 +943,13 @@ msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Албит"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Up"
@@ -949,7 +957,7 @@ msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "Күтәрү"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, fuzzy, kde-format
 #| msgctxt "dictionary variant"
 #| msgid "extended"
@@ -957,7 +965,7 @@ msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "киңәйтелгән"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Subscript"
@@ -965,14 +973,14 @@ msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "Аскы индекс"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "Барлык төркемнәр"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -1003,10 +1011,15 @@ msgid ""
 msgstr ""
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
-#, kde-format
-msgid "Download New Stuff..."
+#, fuzzy, kde-format
+#| msgid "Download New Stuff..."
+msgctxt "@action"
+msgid "Download New Stuff…"
 msgstr "Әсбапларны кабул итү..."
 
+#~ msgid "Download New Stuff..."
+#~ msgstr "Әсбапларны кабул итү..."
+
 #~ msgid "Initializing"
 #~ msgstr "Башлап җибәрү"
 
diff -pruN 6.0.0-3/po/ug/knewstuff6.po 6.3.0-1/po/ug/knewstuff6.po
--- 6.0.0-3/po/ug/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/ug/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -7,7 +7,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2013-09-08 07:05+0900\n"
 "Last-Translator: Gheyret Kenji <gheyret@gmail.com>\n"
 "Language-Team: Uyghur Computer Science Association <UKIJ@yahoogroups.com>\n"
@@ -57,7 +57,7 @@ msgstr "بېلىتىڭىز خاتىرى
 msgid "You are now a fan."
 msgstr "سىز ھازىر ھەۋەسكار."
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -125,7 +125,7 @@ msgstr "سەپلىمە ھۆججەت ئى
 msgid "Use"
 msgstr ""
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -133,17 +133,17 @@ msgid ""
 "This is a critical error and should be reported to the application author"
 msgstr ""
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr "ھۆججەت %1 دىن تەمىنلىگۈچى ئۇچۇرىنى يۈكلىيەلمىدى"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr "ھۆججەتتىن يېڭى قورالنىڭ تەمىنلىگۈچى ئۇچۇرىنى ئوقۇغىلى بولمىدى: %1"
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr "تەمىنلىگۈچىنى دەسلەپلەشتۈرگەندە خاتالىق كۆرۈلدى."
@@ -288,7 +288,7 @@ msgid ""
 "the update"
 msgstr ""
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, fuzzy, kde-format
 #| msgid "Failed to load file '%1'"
 msgid ""
@@ -296,7 +296,7 @@ msgid ""
 "%2"
 msgstr "ھۆججەت '%1' نى ئوقۇش مەغلۇپ بولدى."
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt ""
@@ -304,7 +304,7 @@ msgctxt ""
 msgid "All Categories"
 msgstr "بارلىق كاتېگورىيەلەر"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, fuzzy, kde-format
 #| msgid "Unknown error"
 msgctxt ""
@@ -330,14 +330,14 @@ msgstr ""
 msgid "Download New %1…"
 msgstr "يېڭى قورال چۈشۈر…"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, fuzzy, kde-format
 #| msgid "Download New Stuff..."
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "يېڭى قورال چۈشۈر…"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, fuzzy, kde-format
 #| msgid "Download New Stuff..."
 msgctxt ""
@@ -346,12 +346,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "يېڭى قورال چۈشۈر…"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -360,12 +360,12 @@ msgid ""
 "this through the naming of the items."
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "ئورنات"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt ""
@@ -373,7 +373,7 @@ msgctxt ""
 msgid "Installing %1 from %2"
 msgstr "ئورنىتىۋاتىدۇ"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -381,10 +381,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -393,10 +393,10 @@ msgctxt ""
 msgid "Install"
 msgstr "ئورنات"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -404,24 +404,24 @@ msgctxt ""
 msgid "Install…"
 msgstr "ئورنات"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, fuzzy, kde-format
 #| msgid "Update"
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "يېڭىلا"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, fuzzy, kde-format
 #| msgid "Uninstall"
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "يوقات"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -429,14 +429,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -447,12 +447,12 @@ msgid ""
 "to the KDE Community in a bug report</a>."
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, fuzzy, kde-format
 #| msgid "View Comments"
 msgctxt ""
@@ -461,19 +461,19 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "ئىزاھات كۆرسەت"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, fuzzy, kde-format
 #| msgid "Rating: "
 msgid "Rating:"
 msgstr "باھالاش: "
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, fuzzy, kde-format
 #| msgid "Homepage"
 msgid "Homepage:"
 msgstr "باش بەت"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -482,12 +482,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -495,80 +495,88 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr ""
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, fuzzy, kde-format
 #| msgctxt "@option:check Do filter on type - show only files"
 #| msgid "Files"
 msgid "Tiles"
 msgstr "ھۆججەتلەر"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "سىنبەلگىلەر"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, fuzzy, kde-format
 #| msgid "Preview URL:"
 msgid "Preview"
 msgstr "ئالدىن كۆزىتىش URL:"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, fuzzy, kde-format
 #| msgid "Details view mode"
 msgid "Detailed Tiles View Mode"
 msgstr "تەپسىلىي كۆرۈنۈش ھالىتى"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, fuzzy, kde-format
 #| msgid "Icons view mode"
 msgid "Icons Only View Mode"
 msgstr "سىنبەلگە كۆرۈنۈش ھالىتى"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, fuzzy, kde-format
 #| msgid "Details view mode"
 msgid "Large Preview View Mode"
 msgstr "تەپسىلىي كۆرۈنۈش ھالىتى"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr ""
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "ئورنىتىلغان"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, fuzzy, kde-format
 #| msgid "Update"
 msgid "Updateable"
 msgstr "يېڭىلا"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "بارلىق كاتېگورىيەلەر"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -576,30 +584,30 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Open Recent"
 msgid "Recent"
 msgstr "يېقىنقىنى ئاچ"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr ""
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "باھالاش"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, fuzzy, kde-format
 #| msgid "Download"
 msgid "Downloads"
 msgstr "چۈشۈرۈش"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt ""
@@ -608,7 +616,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "تۇنجى كۆرسىتىدىغان مۇندەرىجە"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -616,14 +624,14 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr ""
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "تۇنجى كۆرسىتىدىغان مۇندەرىجە"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, fuzzy, kde-format
 #| msgid "Most downloads"
 msgctxt ""
@@ -631,41 +639,41 @@ msgctxt ""
 msgid "Show Most Downloaded First"
 msgstr "ئەڭ كۆپ چۈشۈرۈلمە"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, fuzzy, kde-format
 #| msgid "New Upload"
 msgid "Upload…"
 msgstr "يېڭى يۈك"
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr ""
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, fuzzy, kde-format
 #| msgid "&Go To..."
 msgid "Go to…"
 msgstr "يۆتكەل(&G)…"
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, fuzzy, kde-format
 #| msgid "Search:"
 msgid "Search…"
 msgstr "ئىزدە:"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "تۈرى:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, fuzzy, kde-format
 #| msgid "Continue operation"
 msgid "Contribute your own…"
 msgstr "مەشغۇلاتنى داۋاملاشتۇر"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, fuzzy, kde-format
 #| msgctxt "@note/rich"
 #| msgid "<i>Note</i>: %1"
@@ -674,7 +682,7 @@ msgctxt ""
 msgid "<i>(no title)</i>"
 msgstr "<i>ئىزاھات</i>: %1"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -682,20 +690,20 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "بارلىق كاتېگورىيەلەر"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -703,7 +711,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -711,8 +719,8 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, fuzzy, kde-format
 #| msgid "1 download"
 #| msgid_plural "%1 downloads"
@@ -720,8 +728,8 @@ msgctxt "The number of times the item ha
 msgid "%1 downloads"
 msgstr "%1 چۈشۈرۈش"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, fuzzy, kde-format
 #| msgctxt "Show the author of this item in a list"
 #| msgid "By <i>%1</i>"
@@ -731,7 +739,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "<i>%1</i> غا ئاساسەن"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -739,7 +747,7 @@ msgctxt ""
 msgid "Working…"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, fuzzy, kde-format
 #| msgid "Updating"
 msgctxt ""
@@ -748,7 +756,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "يېڭىلاۋاتىدۇ"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -759,7 +767,7 @@ msgid ""
 "bug report</a>."
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt "Label for the busy indicator showing an item is installing"
@@ -778,14 +786,14 @@ msgstr ""
 msgid "Please try again later."
 msgstr "ئات كىرگۈزۈڭ:"
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, fuzzy, kde-format
 #| msgctxt "No border line"
 #| msgid "None"
 msgid "None"
 msgstr "يوق"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, fuzzy, kde-format
 #| msgid "(%1/s)"
 msgctxt ""
@@ -793,14 +801,14 @@ msgctxt ""
 msgid "(%1/%2)"
 msgstr "(%1/سېكۇنت)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, fuzzy, kde-format
 #| msgid "Download New Stuff..."
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "يېڭى قورال چۈشۈر…"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, fuzzy, kde-format
 #| msgid "Billing information:"
 msgctxt ""
@@ -808,21 +816,21 @@ msgctxt ""
 msgid "Updating information…"
 msgstr "تەرتىپ ئۇچۇرى:"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, fuzzy, kde-format
 #| msgid "&Store"
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "ساقلا(&S)"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, fuzzy, kde-format
 #| msgid "Provider:"
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "تەمىنلىگۈچى:"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, fuzzy, kde-format
 #| msgctxt "@label:button"
 #| msgid "&Open with %1"
@@ -832,7 +840,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "%1 دا ئاچ(&O)"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, fuzzy, kde-format
 #| msgid "&Send Email"
 msgctxt ""
@@ -841,7 +849,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "ئېلخەت ئەۋەت(&S)"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -849,10 +857,10 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -864,18 +872,18 @@ msgid ""
 "content added."
 msgstr ""
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "سانلىق-مەلۇمات يۈكلەۋاتىدۇ"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "ئورنىتىۋاتىدۇ"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -885,7 +893,7 @@ msgid ""
 "please contact the person in charge of your permissions."
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Back"
@@ -893,19 +901,19 @@ msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "كەينى"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, fuzzy, kde-format
 #| msgctxt "@action:button Restart find & replace"
 #| msgid "Restart"
@@ -913,7 +921,7 @@ msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "قايتا قوزغات"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "New"
@@ -921,7 +929,7 @@ msgctxt "Knewstuff5"
 msgid "New"
 msgstr "يېڭى"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Home"
@@ -929,13 +937,13 @@ msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "ماكان"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Up"
@@ -943,7 +951,7 @@ msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "ئۈستى"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, fuzzy, kde-format
 #| msgctxt "dictionary variant"
 #| msgid "extended"
@@ -951,7 +959,7 @@ msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "كېڭەيتىلگەن"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Subscript"
@@ -959,14 +967,14 @@ msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "تۆۋەنكى ئىندېكس"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "بارلىق كاتېگورىيەلەر"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -997,10 +1005,15 @@ msgid ""
 msgstr ""
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
-#, kde-format
-msgid "Download New Stuff..."
+#, fuzzy, kde-format
+#| msgid "Download New Stuff..."
+msgctxt "@action"
+msgid "Download New Stuff…"
 msgstr "يېڭى قورال چۈشۈر…"
 
+#~ msgid "Download New Stuff..."
+#~ msgstr "يېڭى قورال چۈشۈر…"
+
 #~ msgid "Initializing"
 #~ msgstr "دەسلەپلەشتۈرۈۋاتىدۇ"
 
diff -pruN 6.0.0-3/po/uk/knewstuff6.po 6.3.0-1/po/uk/knewstuff6.po
--- 6.0.0-3/po/uk/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/uk/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -11,15 +11,15 @@ msgid ""
 msgstr ""
 "Project-Id-Version: knewstuff5\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
-"PO-Revision-Date: 2024-01-19 09:17+0200\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
+"PO-Revision-Date: 2024-05-08 09:22+0300\n"
 "Last-Translator: Yuri Chornoivan <yurchor@ukr.net>\n"
-"Language-Team: Ukrainian <kde-i18n-uk@kde.org>\n"
+"Language-Team: Ukrainian\n"
 "Language: uk\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Generator: Lokalize 23.04.1\n"
+"X-Generator: Lokalize 23.04.3\n"
 "Plural-Forms: nplurals=4; plural=n==1 ? 3 : n%10==1 && n%100!=11 ? 0 : n"
 "%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;\n"
 
@@ -61,7 +61,7 @@ msgstr "Ваш голос врахова
 msgid "You are now a fan."
 msgstr "Вас додано до списку прихильників."
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -134,7 +134,7 @@ msgstr "Некоректний файл
 msgid "Use"
 msgstr "Використати"
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -145,17 +145,17 @@ msgstr ""
 "%2\n"
 "Це критична помилка, про яку слід повідомити автору програми"
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr "Завантаження параметрів надання з файла: помилка %1"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr "Не вдалося завантажити параметри надання нових даних з файла: %1"
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr "Помилка під час спроби ініціалізація запису надавача послуг."
@@ -327,7 +327,7 @@ msgstr ""
 "Не вдалося визначити добре посилання для оновлення %1, тому оновлення є "
 "неможливим"
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, kde-format
 msgid ""
 "Failed to adopt '%1'\n"
@@ -336,14 +336,14 @@ msgstr ""
 "Не вдалося адаптувати «%1»\n"
 "%2"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, kde-format
 msgctxt ""
 "The first entry in the category selection list (also the default value)"
 msgid "All Categories"
 msgstr "Усі категорії"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, kde-format
 msgctxt ""
 "The string passed back in the case the requested category is not known"
@@ -367,13 +367,13 @@ msgstr "дані"
 msgid "Download New %1…"
 msgstr "Отримання нових даних %1…"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, kde-format
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "Отримання нових даних %1"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, kde-format
 msgctxt ""
 "A placeholder title used in the dialog when there is no better title "
@@ -381,12 +381,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "Отримання нових матеріалів"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr "Виберіть варіант встановлення"
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -400,19 +400,19 @@ msgstr ""
 "вказати потрібний вам варіант, зазначивши список усіх варіантів, які було "
 "показано."
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "Встановити"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, kde-format
 msgctxt ""
 "A passive notification shown when installation of an item is initiated"
 msgid "Installing %1 from %2"
 msgstr "Встановлюємо %1 з %2"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -420,10 +420,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr "%1, автор — %2"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, kde-format
 msgctxt ""
 "Request installation of this item, available when there is exactly one "
@@ -431,32 +431,32 @@ msgctxt ""
 msgid "Install"
 msgstr "Встановити"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, kde-format
 msgctxt ""
 "Show installation options, where there is more than one downloadable item"
 msgid "Install…"
 msgstr "Встановити…"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, kde-format
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "Оновити"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, kde-format
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "Прибрати"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -464,14 +464,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr "Зараз працюємо над записом %1, автор — %2. Будь ласка, зачекайте…"
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr "Зараз оновлюємо %1, автор — %2. Будь ласка, зачекайте…"
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -485,12 +485,12 @@ msgstr ""
 "повідомте про цю помилку спільноті KDE за допомогою <a href=\"https://bugs."
 "kde.org/enter_bug.cgi?product=frameworks-knewstuff\">звіту щодо вади</a>."
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr "Коментарі та рецензії:"
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a new sub page with comments (comments "
@@ -498,17 +498,17 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "Рецензії і коментарі щодо %1"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, kde-format
 msgid "Rating:"
 msgstr "Оцінка:"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, kde-format
 msgid "Homepage:"
 msgstr "Домашня сторінка:"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -517,12 +517,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr "Відкрити домашню сторінку %1"
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr "Як підтримати фінансово:"
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -530,75 +530,85 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr "Дізнайтеся, як фінансово допомогти цьому проєкту"
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+"Тут показано попередження при доступі до створених користувачами даних, "
+"оскільки у них може міститися виконуваний код, який не було перевірено KDE "
+"або авторами вашого дистрибутива на безпечність, стабільність або якість"
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
-"Доступні вам дані було вивантажено користувачами, подібними до вас, і не "
-"було перевірено на функціональність чи стабільність роботи постачальником "
-"вашого дистрибутива."
+"Створені користувачами дані, які тут показано, не було перевірено KDE або "
+"авторами вашого дистрибутива на функціональність та якість."
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, kde-format
 msgid "Tiles"
 msgstr "Плитки"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "Піктограми"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, kde-format
 msgid "Preview"
 msgstr "Перегляд"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, kde-format
 msgid "Detailed Tiles View Mode"
 msgstr "Режим докладного перегляду з плитками"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, kde-format
 msgid "Icons Only View Mode"
 msgstr "Режим перегляду піктограм"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, kde-format
 msgid "Large Preview View Mode"
 msgstr "Режим попереднього перегляду великих зображень"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr "Усе"
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "Встановлено"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, kde-format
 msgid "Updateable"
 msgstr "Оновлюване"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, kde-format
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "Показати всі записи"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr "Показати лише встановлені"
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -606,27 +616,27 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr "Показати лише придатні до оновлення"
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, kde-format
 msgid "Recent"
 msgstr "Нещодавні"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr "За абеткою"
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "Оцінкою"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, kde-format
 msgid "Downloads"
 msgstr "Отримання"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on when items were most "
@@ -634,7 +644,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "Найсвіжіші — першими"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -642,57 +652,57 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr "Упорядкувати назви за абеткою"
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, kde-format
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "Найкращі — першими"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on number of downloads"
 msgid "Show Most Downloaded First"
 msgstr "Найпопулярніші — першими"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, kde-format
 msgid "Upload…"
 msgstr "Вивантажити…"
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr "Дізнайтеся про те, як додати результати вашої роботи до цього списку"
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, kde-format
 msgid "Go to…"
 msgstr "Перейти…"
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, kde-format
 msgid "Search…"
 msgstr "Шукати…"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "Категорія:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, kde-format
 msgid "Contribute your own…"
 msgstr "Додати власну роботу…"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, kde-format
 msgctxt ""
 "Placeholder title for when a comment has no subject, but does have a rating"
 msgid "<i>(no title)</i>"
 msgstr "<i>(без назви)</i>"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -700,19 +710,19 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr "%1 <i>(автор)</i>"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr "Коментарі та рецензії щодо %1"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, kde-format
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "Показати усі коментарі"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -720,7 +730,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr "Показати лише рецензії"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -728,15 +738,15 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr "Показати рецензії і відповіді"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, kde-format
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
 msgstr "%1 отримання"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, kde-format
 msgctxt ""
 "Subheading for the tile view, located immediately underneath the name of the "
@@ -744,7 +754,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "Автор — <i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -752,7 +762,7 @@ msgctxt ""
 msgid "Working…"
 msgstr "Працюємо…"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is in the process of being "
@@ -760,7 +770,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "Оновлення…"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -774,7 +784,7 @@ msgstr ""
 "спільноті KDE за допомогою <a href=\"https://bugs.kde.org/enter_bug.cgi?"
 "product=frameworks-knewstuff\">звіту щодо вади</a>."
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, kde-format
 msgctxt "Label for the busy indicator showing an item is installing"
 msgid "Installing…"
@@ -791,44 +801,44 @@ msgstr "Сталася помилка"
 msgid "Please try again later."
 msgstr "Будь ласка, повторіть спробу пізніше."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, kde-format
 msgid "None"
 msgstr "Немає"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, kde-format
 msgctxt ""
 "A text representation of the rating, shown as a fraction of the max value"
 msgid "(%1/%2)"
 msgstr "(%1 з %2)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, kde-format
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "Вивантаження нових матеріалів: %1"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, kde-format
 msgctxt ""
 "A text shown beside a busy indicator suggesting that data is being fetched"
 msgid "Updating information…"
 msgstr "Оновлення відомостей…"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, kde-format
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "Крамниця KDE"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, kde-format
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "Ваш надавач послуг"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, kde-format
 msgctxt ""
 "Text for an action which causes the specified website to be opened using the "
@@ -836,7 +846,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "Відкрити сайт: %1"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, kde-format
 msgctxt ""
 "Text for an action which will attempt to send an email using the user's "
@@ -844,7 +854,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "Надіслати повідомлення %1"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -852,7 +862,7 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 "Щоб вивантажити нові записи або додати нові дані до наявного запису у "
 "Крамниці KDE, будь ласка, відкрийте сторінку сайта і увійдіть до облікового "
@@ -861,7 +871,7 @@ msgstr ""
 "пункт, щоб перейти до системи 4керування продуктами, де ви зможете "
 "попрацювати із нашою базою даних продуктів."
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -880,18 +890,18 @@ msgstr ""
 "зв'язатися із командою з керування сайтом безпосередньо для додавання нових "
 "даних."
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "Завантаження даних"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "Встановлення"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -904,73 +914,73 @@ msgstr ""
 "вважаєте, що це є помилкою, будь ласка, повідомте про неї особу, яка "
 "відповідає за права доступу у вашій системі."
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "Назад"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr "Популярні"
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "Рекомендовані"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "Перезапустити"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "New"
 msgstr "Нові"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Домівка"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr "Шафа"
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "Вище"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "Рекомендовані"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "Підписки"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "Усі пункти"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -1017,8 +1027,12 @@ msgstr ""
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
 #, kde-format
-msgid "Download New Stuff..."
-msgstr "Отримати нові матеріали..."
+msgctxt "@action"
+msgid "Download New Stuff…"
+msgstr "Отримати нові матеріали…"
+
+#~ msgid "Download New Stuff..."
+#~ msgstr "Отримати нові матеріали..."
 
 #~ msgctxt ""
 #~ "A message which is shown when the user attempts to display a specific "
diff -pruN 6.0.0-3/po/uz/knewstuff6.po 6.3.0-1/po/uz/knewstuff6.po
--- 6.0.0-3/po/uz/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/uz/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -6,7 +6,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2008-05-30 17:29+0200\n"
 "Last-Translator: Mashrab Kuvatov <kmashrab@uni-bremen.de>\n"
 "Language-Team: Uzbek <floss-uz-l10n@googlegroups.com>\n"
@@ -52,7 +52,7 @@ msgstr "Hech qanday matn almashtirilmadi
 msgid "You are now a fan."
 msgstr ""
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -120,7 +120,7 @@ msgstr "Moslama fayllari"
 msgid "Use"
 msgstr "Soyalashni bekor qilish"
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -128,18 +128,18 @@ msgid ""
 "This is a critical error and should be reported to the application author"
 msgstr ""
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, fuzzy, kde-format
 #| msgid "Loading resource '%1' failed!"
 msgid "Loading of providers from file: %1 failed"
 msgstr "Manbani '%1' yuklash muvaffaqiyatsiz tugadi."
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr ""
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, fuzzy, kde-format
 #| msgid "Error parsing providers list."
 msgid "Error initializing provider."
@@ -286,14 +286,14 @@ msgid ""
 "the update"
 msgstr ""
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, fuzzy, kde-format
 msgid ""
 "Failed to adopt '%1'\n"
 "%2"
 msgstr "Manbani (%1) yuklab boʻlmadi."
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, fuzzy, kde-format
 #| msgid "Categories"
 msgctxt ""
@@ -301,7 +301,7 @@ msgctxt ""
 msgid "All Categories"
 msgstr "Toifalar"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, fuzzy, kde-format
 msgctxt ""
 "The string passed back in the case the requested category is not known"
@@ -325,13 +325,13 @@ msgstr ""
 msgid "Download New %1…"
 msgstr "Yangi narsalarni olish"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, fuzzy, kde-format
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "Yangi narsalarni olish"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
 msgctxt ""
@@ -340,13 +340,13 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "Yangi narsalarni olish"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, fuzzy, kde-format
 #| msgid "Resource Installation Error"
 msgid "Pick Your Installation Option"
 msgstr "Oʻrnatishda xato"
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -355,12 +355,12 @@ msgid ""
 "this through the naming of the items."
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "Oʻrnatish"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -368,7 +368,7 @@ msgctxt ""
 msgid "Installing %1 from %2"
 msgstr "Oʻrnatish"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -376,10 +376,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -388,10 +388,10 @@ msgctxt ""
 msgid "Install"
 msgstr "Oʻrnatish"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -399,23 +399,23 @@ msgctxt ""
 msgid "Install…"
 msgstr "Oʻrnatish"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, fuzzy, kde-format
 #| msgid "Update"
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "Yangilash"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, fuzzy, kde-format
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "Oʻrnatish"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -423,14 +423,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -441,12 +441,12 @@ msgid ""
 "to the KDE Community in a bug report</a>."
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, fuzzy, kde-format
 #| msgid "View Comments"
 msgctxt ""
@@ -455,18 +455,18 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "Izohlarni koʻrish"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, fuzzy, kde-format
 msgid "Rating:"
 msgstr "Baho"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, fuzzy, kde-format
 #| msgid "Homepage"
 msgid "Homepage:"
 msgstr "Veb-sahifa"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -475,12 +475,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -488,76 +488,84 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr ""
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, fuzzy, kde-format
 #| msgid "File"
 msgid "Tiles"
 msgstr "Fayl"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "Nishonchalar"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, fuzzy, kde-format
 msgid "Preview"
 msgstr "Koʻrib chiqish URL:"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, fuzzy, kde-format
 msgid "Detailed Tiles View Mode"
 msgstr "Tafsilotlar"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, fuzzy, kde-format
 #| msgid "Icon Size"
 msgid "Icons Only View Mode"
 msgstr "Nishonchaning oʻlchami"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, fuzzy, kde-format
 msgid "Large Preview View Mode"
 msgstr "Tafsilotlar"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr ""
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, fuzzy, kde-format
 #| msgid "Install"
 msgid "Installed"
 msgstr "Oʻrnatish"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, fuzzy, kde-format
 #| msgid "Update"
 msgid "Updateable"
 msgstr "Yangilash"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, fuzzy, kde-format
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "Hamma parametrlarni koʻrsatish"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, fuzzy, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr "Hamma parametrlarni koʻrsatish"
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, fuzzy, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -565,30 +573,30 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr "Hamma parametrlarni koʻrsatish"
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, fuzzy, kde-format
 #| msgctxt "QAccel"
 #| msgid "Percent"
 msgid "Recent"
 msgstr "Foiz"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr ""
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, fuzzy, kde-format
 msgid "Rating"
 msgstr "Baho"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, fuzzy, kde-format
 #| msgid "Download"
 msgid "Downloads"
 msgstr "Yozib olish"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, fuzzy, kde-format
 #| msgid "Most Downloads"
 msgctxt ""
@@ -597,7 +605,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "Eng koʻp yozib olingan"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -605,14 +613,14 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr ""
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, fuzzy, kde-format
 #| msgid "Highest Rated"
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "Eng yuqori baholangan"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, fuzzy, kde-format
 #| msgid "Most Downloads"
 msgctxt ""
@@ -620,49 +628,49 @@ msgctxt ""
 msgid "Show Most Downloaded First"
 msgstr "Eng koʻp yozib olingan"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, fuzzy, kde-format
 #| msgid "&Upload"
 msgid "Upload…"
 msgstr "&Yozib qoʻyish"
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr ""
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, fuzzy, kde-format
 #| msgid "&Go To..."
 msgid "Go to…"
 msgstr "Oʻ&tish..."
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, fuzzy, kde-format
 #| msgid "S&earch:"
 msgid "Search…"
 msgstr "Q&idirish:"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, fuzzy, kde-format
 #| msgid "Categories"
 msgid "Category:"
 msgstr "Toifalar"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, fuzzy, kde-format
 #| msgid "Continue operation"
 msgid "Contribute your own…"
 msgstr "Amalni davom etish"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, kde-format
 msgctxt ""
 "Placeholder title for when a comment has no subject, but does have a rating"
 msgid "<i>(no title)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -670,20 +678,20 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, fuzzy, kde-format
 #| msgid "Categories"
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "Toifalar"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -691,7 +699,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -699,16 +707,16 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, fuzzy, kde-format
 #| msgid "Download"
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
 msgstr "Yozib olish"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, fuzzy, kde-format
 msgctxt ""
 "Subheading for the tile view, located immediately underneath the name of the "
@@ -716,7 +724,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "<b>Xato</b>: %1: %2"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -724,7 +732,7 @@ msgctxt ""
 msgid "Working…"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, fuzzy, kde-format
 #| msgid "Update"
 msgctxt ""
@@ -733,7 +741,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "Yangilash"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -744,7 +752,7 @@ msgid ""
 "bug report</a>."
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt "Label for the busy indicator showing an item is installing"
@@ -765,12 +773,12 @@ msgstr "Hech qanday xato roʻy bermadi"
 msgid "Please try again later."
 msgstr "Iltimos nomini kiriting."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, fuzzy, kde-format
 msgid "None"
 msgstr "Yoʻq"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, fuzzy, kde-format
 #| msgid "(%1/s)"
 msgctxt ""
@@ -778,34 +786,34 @@ msgctxt ""
 msgid "(%1/%2)"
 msgstr "(%1/s)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "Yangi narsalarni olish"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, fuzzy, kde-format
 msgctxt ""
 "A text shown beside a busy indicator suggesting that data is being fetched"
 msgid "Updating information…"
 msgstr "Maʼlumot"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, fuzzy, kde-format
 #| msgid "Store"
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "Saqlash"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, fuzzy, kde-format
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "%1'ni bekitish"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, fuzzy, kde-format
 #| msgid "&Open with '%1'"
 msgctxt ""
@@ -814,7 +822,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "\"%1\" bilan &ochish"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, fuzzy, kde-format
 #| msgid "&Send Email"
 msgctxt ""
@@ -823,7 +831,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "Xat &joʻnatish"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -831,10 +839,10 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -846,20 +854,20 @@ msgid ""
 "content added."
 msgstr ""
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, fuzzy, kde-format
 #| msgid "Loading Applet"
 msgid "Loading data"
 msgstr "Applet yuklanmoqda"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, fuzzy, kde-format
 #| msgid "Install"
 msgid "Installing"
 msgstr "Oʻrnatish"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -869,7 +877,7 @@ msgid ""
 "please contact the person in charge of your permissions."
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Back"
@@ -877,27 +885,27 @@ msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "Orqaga"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, fuzzy, kde-format
 #| msgid "Saturday"
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "Shanba"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, fuzzy, kde-format
 #| msgid "Restart"
 msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "Qaytadan"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "New"
@@ -905,19 +913,19 @@ msgctxt "Knewstuff5"
 msgid "New"
 msgstr "Yangi"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, fuzzy, kde-format
 msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Boshga"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Up"
@@ -925,26 +933,26 @@ msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "Yuqoriga"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, fuzzy, kde-format
 #| msgid "Run &command"
 msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "Buyruqni &bajarish"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, fuzzy, kde-format
 msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "S&kript"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, fuzzy, kde-format
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "Hamma parametrlarni koʻrsatish"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -977,10 +985,16 @@ msgstr ""
 #: widgets/action.cpp:28 widgets/button.cpp:70
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
-msgid "Download New Stuff..."
+msgctxt "@action"
+msgid "Download New Stuff…"
 msgstr "Yangi narsalarni olish"
 
 #, fuzzy
+#~| msgid "Download New Stuff"
+#~ msgid "Download New Stuff..."
+#~ msgstr "Yangi narsalarni olish"
+
+#, fuzzy
 #~| msgid "Install"
 #~ msgid "Initializing"
 #~ msgstr "Oʻrnatish"
diff -pruN 6.0.0-3/po/uz@cyrillic/knewstuff6.po 6.3.0-1/po/uz@cyrillic/knewstuff6.po
--- 6.0.0-3/po/uz@cyrillic/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/uz@cyrillic/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -6,7 +6,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2009-10-17 00:34+0200\n"
 "Last-Translator: Mashrab Kuvatov <kmashrab@uni-bremen.de>\n"
 "Language-Team: Uzbek <floss-uz-l10n@googlegroups.com>\n"
@@ -52,7 +52,7 @@ msgstr "Ҳеч қандай матн а
 msgid "You are now a fan."
 msgstr ""
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -120,7 +120,7 @@ msgstr "Мослама файллари"
 msgid "Use"
 msgstr "Соялашни бекор қилиш"
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -128,18 +128,18 @@ msgid ""
 "This is a critical error and should be reported to the application author"
 msgstr ""
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, fuzzy, kde-format
 #| msgid "Loading resource '%1' failed!"
 msgid "Loading of providers from file: %1 failed"
 msgstr "Манбани '%1' юклаш муваффақиятсиз тугади."
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr ""
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, fuzzy, kde-format
 #| msgid "Error parsing providers list."
 msgid "Error initializing provider."
@@ -286,14 +286,14 @@ msgid ""
 "the update"
 msgstr ""
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, fuzzy, kde-format
 msgid ""
 "Failed to adopt '%1'\n"
 "%2"
 msgstr "Манбани (%1) юклаб бўлмади."
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, fuzzy, kde-format
 #| msgid "Categories"
 msgctxt ""
@@ -301,7 +301,7 @@ msgctxt ""
 msgid "All Categories"
 msgstr "Тоифалар"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, fuzzy, kde-format
 #| msgid "Unknown error"
 msgctxt ""
@@ -326,13 +326,13 @@ msgstr ""
 msgid "Download New %1…"
 msgstr "Янги нарсаларни олиш"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, fuzzy, kde-format
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "Янги нарсаларни олиш"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
 msgctxt ""
@@ -341,13 +341,13 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "Янги нарсаларни олиш"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, fuzzy, kde-format
 #| msgid "Resource Installation Error"
 msgid "Pick Your Installation Option"
 msgstr "Ўрнатишда хато"
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -356,12 +356,12 @@ msgid ""
 "this through the naming of the items."
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "Ўрнатиш"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -369,7 +369,7 @@ msgctxt ""
 msgid "Installing %1 from %2"
 msgstr "Ўрнатиш"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -377,10 +377,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -389,10 +389,10 @@ msgctxt ""
 msgid "Install"
 msgstr "Ўрнатиш"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -400,24 +400,24 @@ msgctxt ""
 msgid "Install…"
 msgstr "Ўрнатиш"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, fuzzy, kde-format
 #| msgid "Update"
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "Янгилаш"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, fuzzy, kde-format
 #| msgid "Uninstall"
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "Олиб ташлаш"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -425,14 +425,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -443,12 +443,12 @@ msgid ""
 "to the KDE Community in a bug report</a>."
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, fuzzy, kde-format
 #| msgid "View Comments"
 msgctxt ""
@@ -457,18 +457,18 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "Изоҳларни кўриш"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, fuzzy, kde-format
 msgid "Rating:"
 msgstr "Баҳо"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, fuzzy, kde-format
 #| msgid "Homepage"
 msgid "Homepage:"
 msgstr "Веб-саҳифа"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -477,12 +477,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -490,76 +490,84 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr ""
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, fuzzy, kde-format
 #| msgid "File"
 msgid "Tiles"
 msgstr "Файл"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "Нишончалар"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, fuzzy, kde-format
 msgid "Preview"
 msgstr "Кўриб чиқиш URL:"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, fuzzy, kde-format
 msgid "Detailed Tiles View Mode"
 msgstr "Тафсилотлар"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, fuzzy, kde-format
 #| msgid "Icon Size"
 msgid "Icons Only View Mode"
 msgstr "Нишончанинг ўлчами"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, fuzzy, kde-format
 msgid "Large Preview View Mode"
 msgstr "Тафсилотлар"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr ""
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, fuzzy, kde-format
 #| msgid "Install"
 msgid "Installed"
 msgstr "Ўрнатиш"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, fuzzy, kde-format
 #| msgid "Update"
 msgid "Updateable"
 msgstr "Янгилаш"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, fuzzy, kde-format
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "Ҳамма параметрларни кўрсатиш"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, fuzzy, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr "Ҳамма параметрларни кўрсатиш"
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, fuzzy, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -567,30 +575,30 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr "Ҳамма параметрларни кўрсатиш"
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, fuzzy, kde-format
 #| msgctxt "QAccel"
 #| msgid "Percent"
 msgid "Recent"
 msgstr "Фоиз"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr ""
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, fuzzy, kde-format
 msgid "Rating"
 msgstr "Баҳо"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, fuzzy, kde-format
 #| msgid "Download"
 msgid "Downloads"
 msgstr "Ёзиб олиш"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, fuzzy, kde-format
 #| msgid "Most Downloads"
 msgctxt ""
@@ -599,7 +607,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "Энг кўп ёзиб олинган"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -607,14 +615,14 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr ""
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, fuzzy, kde-format
 #| msgid "Highest Rated"
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "Энг юқори баҳоланган"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, fuzzy, kde-format
 #| msgid "Most Downloads"
 msgctxt ""
@@ -622,49 +630,49 @@ msgctxt ""
 msgid "Show Most Downloaded First"
 msgstr "Энг кўп ёзиб олинган"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, fuzzy, kde-format
 #| msgid "&Upload"
 msgid "Upload…"
 msgstr "&Ёзиб қўйиш"
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr ""
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, fuzzy, kde-format
 #| msgid "&Go To..."
 msgid "Go to…"
 msgstr "Ў&тиш..."
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, fuzzy, kde-format
 #| msgid "S&earch:"
 msgid "Search…"
 msgstr "Қ&идириш:"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, fuzzy, kde-format
 #| msgid "Categories"
 msgid "Category:"
 msgstr "Тоифалар"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, fuzzy, kde-format
 #| msgid "Continue operation"
 msgid "Contribute your own…"
 msgstr "Амални давом этиш"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, kde-format
 msgctxt ""
 "Placeholder title for when a comment has no subject, but does have a rating"
 msgid "<i>(no title)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -672,20 +680,20 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, fuzzy, kde-format
 #| msgid "Categories"
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "Тоифалар"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -693,7 +701,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -701,16 +709,16 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, fuzzy, kde-format
 #| msgid "Download"
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
 msgstr "Ёзиб олиш"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, fuzzy, kde-format
 msgctxt ""
 "Subheading for the tile view, located immediately underneath the name of the "
@@ -718,7 +726,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "<b>Хато</b>: %1: %2"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -726,7 +734,7 @@ msgctxt ""
 msgid "Working…"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, fuzzy, kde-format
 #| msgid "Update"
 msgctxt ""
@@ -735,7 +743,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "Янгилаш"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -746,7 +754,7 @@ msgid ""
 "bug report</a>."
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt "Label for the busy indicator showing an item is installing"
@@ -767,12 +775,12 @@ msgstr "Ҳеч қандай хато р
 msgid "Please try again later."
 msgstr "Илтимос номини киритинг."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, fuzzy, kde-format
 msgid "None"
 msgstr "Йўқ"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, fuzzy, kde-format
 #| msgid "(%1/s)"
 msgctxt ""
@@ -780,34 +788,34 @@ msgctxt ""
 msgid "(%1/%2)"
 msgstr "(%1/с)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "Янги нарсаларни олиш"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, fuzzy, kde-format
 msgctxt ""
 "A text shown beside a busy indicator suggesting that data is being fetched"
 msgid "Updating information…"
 msgstr "Маълумот"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, fuzzy, kde-format
 #| msgid "&Store"
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "&Сақлаш"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, fuzzy, kde-format
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "%1'ни бекитиш"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, fuzzy, kde-format
 #| msgctxt "@label:button"
 #| msgid "&Open with %1"
@@ -817,7 +825,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "%1 билан &очиш"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, fuzzy, kde-format
 #| msgid "&Send Email"
 msgctxt ""
@@ -826,7 +834,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "Хат &жўнатиш"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -834,10 +842,10 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -849,20 +857,20 @@ msgid ""
 "content added."
 msgstr ""
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, fuzzy, kde-format
 #| msgid "Loading Applet"
 msgid "Loading data"
 msgstr "Апплет юкланмоқда"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, fuzzy, kde-format
 #| msgid "Install"
 msgid "Installing"
 msgstr "Ўрнатиш"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -872,7 +880,7 @@ msgid ""
 "please contact the person in charge of your permissions."
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Back"
@@ -880,20 +888,20 @@ msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "Орқага"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, fuzzy, kde-format
 #| msgid "Saturday"
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "Шанба"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, fuzzy, kde-format
 #| msgctxt "@action:button Restart find & replace"
 #| msgid "Restart"
@@ -901,7 +909,7 @@ msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "Қайтадан"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "New"
@@ -909,19 +917,19 @@ msgctxt "Knewstuff5"
 msgid "New"
 msgstr "Янги"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, fuzzy, kde-format
 msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Бошга"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Up"
@@ -929,26 +937,26 @@ msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "Юқорига"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, fuzzy, kde-format
 #| msgid "Run &command"
 msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "Буйруқни &бажариш"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, fuzzy, kde-format
 msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "С&крипт"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, fuzzy, kde-format
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "Ҳамма параметрларни кўрсатиш"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -981,10 +989,16 @@ msgstr ""
 #: widgets/action.cpp:28 widgets/button.cpp:70
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
-msgid "Download New Stuff..."
+msgctxt "@action"
+msgid "Download New Stuff…"
 msgstr "Янги нарсаларни олиш"
 
 #, fuzzy
+#~| msgid "Download New Stuff"
+#~ msgid "Download New Stuff..."
+#~ msgstr "Янги нарсаларни олиш"
+
+#, fuzzy
 #~| msgid "Install"
 #~ msgid "Initializing"
 #~ msgstr "Ўрнатиш"
diff -pruN 6.0.0-3/po/vi/knewstuff6.po 6.3.0-1/po/vi/knewstuff6.po
--- 6.0.0-3/po/vi/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/vi/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -8,7 +8,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2012-09-23 18:43+0800\n"
 "Last-Translator: Lê Hoàng Phương <herophuong93@gmail.com>\n"
 "Language-Team: American English <kde-i18n-vi@kde.org>\n"
@@ -63,7 +63,7 @@ msgstr "Bình chọn của bạn đã đ
 msgid "You are now a fan."
 msgstr "Giờ bạn đã là một fan rồi."
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -132,7 +132,7 @@ msgstr "Tệp cấu hình không hợp l
 msgid "Use"
 msgstr ""
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -140,17 +140,17 @@ msgid ""
 "This is a critical error and should be reported to the application author"
 msgstr ""
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr "Nạp nhà cung cấp từ tệp: %1 thất bại"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr "Không thể lấy nhà cung cấp thứ hay ho mới từ tệp: %1"
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr "Lỗi khởi tạo nhà cung cấp."
@@ -293,14 +293,14 @@ msgid ""
 "the update"
 msgstr ""
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, kde-format
 msgid ""
 "Failed to adopt '%1'\n"
 "%2"
 msgstr ""
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt ""
@@ -308,7 +308,7 @@ msgctxt ""
 msgid "All Categories"
 msgstr "Tất cả thể loại"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, fuzzy, kde-format
 #| msgid "Unknown error"
 msgctxt ""
@@ -334,14 +334,14 @@ msgstr ""
 msgid "Download New %1…"
 msgstr "Tải về %1 mới"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, fuzzy, kde-format
 #| msgid "Download New %1"
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "Tải về %1 mới"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
 msgctxt ""
@@ -350,12 +350,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "Tải về các thứ mới"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -364,12 +364,12 @@ msgid ""
 "this through the naming of the items."
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "Cài đặt"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt ""
@@ -377,7 +377,7 @@ msgctxt ""
 msgid "Installing %1 from %2"
 msgstr "Đang cài đặt"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -385,10 +385,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -397,10 +397,10 @@ msgctxt ""
 msgid "Install"
 msgstr "Cài đặt"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -408,24 +408,24 @@ msgctxt ""
 msgid "Install…"
 msgstr "Cài đặt"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, fuzzy, kde-format
 #| msgid "Update"
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "Cập nhật"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, fuzzy, kde-format
 #| msgid "Uninstall"
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "Gỡ cài đặt"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -433,14 +433,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -451,12 +451,12 @@ msgid ""
 "to the KDE Community in a bug report</a>."
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, fuzzy, kde-format
 #| msgid "View Comments"
 msgctxt ""
@@ -465,19 +465,19 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "Xem bình luận"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, fuzzy, kde-format
 #| msgid "Rating: "
 msgid "Rating:"
 msgstr "Đánh giá:"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, fuzzy, kde-format
 #| msgid "Homepage"
 msgid "Homepage:"
 msgstr "Trang chủ"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -486,12 +486,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -499,78 +499,86 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr ""
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, kde-format
 msgid "Tiles"
 msgstr ""
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr ""
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, fuzzy, kde-format
 #| msgid "Preview Images"
 msgid "Preview"
 msgstr "Ảnh xem trước"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, fuzzy, kde-format
 #| msgid "Details view mode"
 msgid "Detailed Tiles View Mode"
 msgstr "Xem chi tiết"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, fuzzy, kde-format
 #| msgid "Icons view mode"
 msgid "Icons Only View Mode"
 msgstr "Xem biểu tượng"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, fuzzy, kde-format
 #| msgid "Details view mode"
 msgid "Large Preview View Mode"
 msgstr "Xem chi tiết"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr ""
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "Đã cài"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, fuzzy, kde-format
 #| msgid "Update"
 msgid "Updateable"
 msgstr "Cập nhật"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "Tất cả thể loại"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -578,29 +586,29 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr ""
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, kde-format
 msgid "Recent"
 msgstr ""
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr ""
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "Đánh giá"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, fuzzy, kde-format
 #| msgid "1 download"
 #| msgid_plural "%1 downloads"
 msgid "Downloads"
 msgstr "%1 tải về"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt ""
@@ -609,7 +617,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "Hiện thư mục trước"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -617,14 +625,14 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr ""
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "Hiện thư mục trước"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, fuzzy, kde-format
 #| msgid "Most downloads"
 msgctxt ""
@@ -632,39 +640,39 @@ msgctxt ""
 msgid "Show Most Downloaded First"
 msgstr "Tải về nhiều nhất"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, fuzzy, kde-format
 #| msgid "New Upload"
 msgid "Upload…"
 msgstr "Tải lên mới"
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr ""
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, kde-format
 msgid "Go to…"
 msgstr ""
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, fuzzy, kde-format
 #| msgid "Search:"
 msgid "Search…"
 msgstr "Tìm kiếm:"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "Thể loại:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, kde-format
 msgid "Contribute your own…"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, fuzzy, kde-format
 #| msgctxt "@note/rich"
 #| msgid "<i>Note</i>: %1"
@@ -673,7 +681,7 @@ msgctxt ""
 msgid "<i>(no title)</i>"
 msgstr "<i>Lưu ý</i>: %1"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -681,20 +689,20 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "Tất cả thể loại"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, fuzzy, kde-format
 #| msgid "Show Preview"
 msgctxt ""
@@ -703,7 +711,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr "Hiện ô xem thử"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -711,8 +719,8 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, fuzzy, kde-format
 #| msgid "1 download"
 #| msgid_plural "%1 downloads"
@@ -720,8 +728,8 @@ msgctxt "The number of times the item ha
 msgid "%1 downloads"
 msgstr "%1 tải về"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, fuzzy, kde-format
 #| msgctxt "Show the author of this item in a list"
 #| msgid "By <i>%1</i>"
@@ -731,7 +739,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "Bởi <i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -739,7 +747,7 @@ msgctxt ""
 msgid "Working…"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, fuzzy, kde-format
 #| msgid "Updating"
 msgctxt ""
@@ -748,7 +756,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "Đang cập nhật"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -759,7 +767,7 @@ msgid ""
 "bug report</a>."
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt "Label for the busy indicator showing an item is installing"
@@ -777,28 +785,28 @@ msgstr ""
 msgid "Please try again later."
 msgstr ""
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, fuzzy, kde-format
 #| msgctxt "No border line"
 #| msgid "None"
 msgid "None"
 msgstr "Không"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, kde-format
 msgctxt ""
 "A text representation of the rating, shown as a fraction of the max value"
 msgid "(%1/%2)"
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "Tải về các thứ mới"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, fuzzy, kde-format
 #| msgid "Provider information"
 msgctxt ""
@@ -806,20 +814,20 @@ msgctxt ""
 msgid "Updating information…"
 msgstr "Thông tin về nhà cung cấp"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, kde-format
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, fuzzy, kde-format
 #| msgid "Provider:"
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "Nhà cung cấp:"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, kde-format
 msgctxt ""
 "Text for an action which causes the specified website to be opened using the "
@@ -827,7 +835,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, kde-format
 msgctxt ""
 "Text for an action which will attempt to send an email using the user's "
@@ -835,7 +843,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -843,10 +851,10 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -858,18 +866,18 @@ msgid ""
 "content added."
 msgstr ""
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "Đang tải dữ liệu"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "Đang cài đặt"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -879,38 +887,38 @@ msgid ""
 "please contact the person in charge of your permissions."
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Back"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, fuzzy, kde-format
 #| msgid "Newest"
 msgctxt "Knewstuff5"
 msgid "New"
 msgstr "Mới nhất"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, fuzzy, kde-format
 #| msgctxt "A link to the description of this Get Hot New Stuff item"
 #| msgid "Homepage"
@@ -918,39 +926,39 @@ msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Trang chủ"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Up"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, fuzzy, kde-format
 #| msgid "Description:"
 msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "Mô tả :"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "Tất cả thể loại"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -981,9 +989,14 @@ msgid ""
 msgstr ""
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
-#, kde-format
-msgid "Download New Stuff..."
-msgstr "Tải về các thứ mới..."
+#, fuzzy, kde-format
+#| msgid "Download New Stuff"
+msgctxt "@action"
+msgid "Download New Stuff…"
+msgstr "Tải về các thứ mới"
+
+#~ msgid "Download New Stuff..."
+#~ msgstr "Tải về các thứ mới..."
 
 #~ msgid "Initializing"
 #~ msgstr "Đang khởi chạy"
diff -pruN 6.0.0-3/po/wa/knewstuff6.po 6.3.0-1/po/wa/knewstuff6.po
--- 6.0.0-3/po/wa/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/wa/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -10,7 +10,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2012-07-04 17:33+0200\n"
 "Last-Translator: Jean Cayron <jean.cayron@base.be>\n"
 "Language-Team: Walloon <linux-wa@walon.org>\n"
@@ -66,7 +66,7 @@ msgstr "Vosse vôtaedje a stî eredjistr
 msgid "You are now a fan."
 msgstr "Vos estoz on rafiyant asteure."
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -134,7 +134,7 @@ msgstr "Li fitchî d' apontiaedje est m
 msgid "Use"
 msgstr ""
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -142,17 +142,17 @@ msgid ""
 "This is a critical error and should be reported to the application author"
 msgstr ""
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr "Dji tchedje des ahesseus a pårti do fitchî : %1 a fwait berwete"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr "Dji n' a savou tcherdjî les ahesseus di noveatés a pårti do fitchî: %1"
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr "Åk n' a nén stî come dj' inicialijheu l' ahesseu."
@@ -299,7 +299,7 @@ msgid ""
 "the update"
 msgstr ""
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, fuzzy, kde-format
 #| msgid "Failed to load file '%1'"
 msgid ""
@@ -307,7 +307,7 @@ msgid ""
 "%2"
 msgstr "Dji n' sai tcherdjî l' fitchî «%1»"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt ""
@@ -315,7 +315,7 @@ msgctxt ""
 msgid "All Categories"
 msgstr "Totes les categoreyes"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, fuzzy, kde-format
 #| msgid "Unknown error"
 msgctxt ""
@@ -341,14 +341,14 @@ msgstr ""
 msgid "Download New %1…"
 msgstr "Aberweter li noveaté %1"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, fuzzy, kde-format
 #| msgid "Download New %1"
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "Aberweter li noveaté %1"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
 msgctxt ""
@@ -357,12 +357,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "Aberweter noveaté"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -371,12 +371,12 @@ msgid ""
 "this through the naming of the items."
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "Astaler"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt ""
@@ -384,7 +384,7 @@ msgctxt ""
 msgid "Installing %1 from %2"
 msgstr "Dj' astale"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -392,10 +392,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -404,10 +404,10 @@ msgctxt ""
 msgid "Install"
 msgstr "Astaler"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -415,24 +415,24 @@ msgctxt ""
 msgid "Install…"
 msgstr "Astaler"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, fuzzy, kde-format
 #| msgid "Update"
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "Mete a djoû"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, fuzzy, kde-format
 #| msgid "Uninstall"
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "Disastaler"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -440,14 +440,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -458,12 +458,12 @@ msgid ""
 "to the KDE Community in a bug report</a>."
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, fuzzy, kde-format
 #| msgid "View Comments"
 msgctxt ""
@@ -472,19 +472,19 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "Vey rawetes"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, fuzzy, kde-format
 #| msgid "Rating: "
 msgid "Rating:"
 msgstr "Préjhaedje:"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, fuzzy, kde-format
 #| msgid "Homepage"
 msgid "Homepage:"
 msgstr "Pådje måjhon"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -493,12 +493,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -506,73 +506,81 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr ""
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, fuzzy, kde-format
 #| msgctxt "@option:check Do filter on type - show only files"
 #| msgid "Files"
 msgid "Tiles"
 msgstr "Fitchîs"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "Imådjetes"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, fuzzy, kde-format
 #| msgid "Previews"
 msgid "Preview"
 msgstr "Prévoeyaedjes"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, fuzzy, kde-format
 #| msgid "Detailed Tree View"
 msgid "Detailed Tiles View Mode"
 msgstr "Håyner totafwait"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, fuzzy, kde-format
 #| msgid "Icons view mode"
 msgid "Icons Only View Mode"
 msgstr "Môde di håynaedje èn imådjetes"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, fuzzy, kde-format
 #| msgid "Details view mode"
 msgid "Large Preview View Mode"
 msgstr "Môde di håynaedje avou les detays"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr ""
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "Astalé"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, fuzzy, kde-format
 #| msgid "Update"
 msgid "Updateable"
 msgstr "Mete a djoû"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, fuzzy, kde-format
 #| msgid "&Show All Entries"
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "&Mostrer totes les Intrêyes"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, fuzzy, kde-format
 #| msgid "&Show All Entries"
 msgctxt ""
@@ -580,7 +588,7 @@ msgctxt ""
 msgid "Show Only Installed Entries"
 msgstr "&Mostrer totes les Intrêyes"
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, fuzzy, kde-format
 #| msgid "&Show All Entries"
 msgctxt ""
@@ -589,30 +597,30 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr "&Mostrer totes les Intrêyes"
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "OpenRecent"
 msgid "Recent"
 msgstr "Drovi les &dierins"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr ""
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "Préjhaedje"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, fuzzy, kde-format
 #| msgid "Download"
 msgid "Downloads"
 msgstr "Aberwetaedje"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt ""
@@ -621,7 +629,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "Håyner les ridants å dzeu"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -629,14 +637,14 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr ""
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, fuzzy, kde-format
 #| msgid "Show directories first"
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "Håyner les ridants å dzeu"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, fuzzy, kde-format
 #| msgid "Most downloads"
 msgctxt ""
@@ -644,41 +652,41 @@ msgctxt ""
 msgid "Show Most Downloaded First"
 msgstr "Li pus aberweté"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, fuzzy, kde-format
 #| msgid "Upload..."
 msgid "Upload…"
 msgstr "Eberweter..."
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr ""
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, fuzzy, kde-format
 #| msgid "&Go To..."
 msgid "Go to…"
 msgstr "&Potchî a..."
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, fuzzy, kde-format
 #| msgid "Search:"
 msgid "Search…"
 msgstr "Cweri:"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "Categoreye:"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, fuzzy, kde-format
 #| msgid "Continue operation"
 msgid "Contribute your own…"
 msgstr "Continouwer l' operåcion"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, fuzzy, kde-format
 #| msgctxt "@note/rich"
 #| msgid "<i>Note</i>: %1"
@@ -687,7 +695,7 @@ msgctxt ""
 msgid "<i>(no title)</i>"
 msgstr "<i>Note</i>: %1"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -695,20 +703,20 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, fuzzy, kde-format
 #| msgid "All Categories"
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "Totes les categoreyes"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, fuzzy, kde-format
 #| msgid "Show Preview"
 msgctxt ""
@@ -717,7 +725,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr "Prévey"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -725,8 +733,8 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, fuzzy, kde-format
 #| msgid "1 download"
 #| msgid_plural "%1 downloads"
@@ -734,8 +742,8 @@ msgctxt "The number of times the item ha
 msgid "%1 downloads"
 msgstr "1 aberwetaedje"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, fuzzy, kde-format
 #| msgctxt "Show the author of this item in a list"
 #| msgid "By <i>%1</i>"
@@ -745,7 +753,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "Pa <i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -753,7 +761,7 @@ msgctxt ""
 msgid "Working…"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, fuzzy, kde-format
 #| msgid "Updating"
 msgctxt ""
@@ -762,7 +770,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "Dji met a djoû"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -773,7 +781,7 @@ msgid ""
 "bug report</a>."
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, fuzzy, kde-format
 #| msgid "Installing"
 msgctxt "Label for the busy indicator showing an item is installing"
@@ -792,14 +800,14 @@ msgstr ""
 msgid "Please try again later."
 msgstr "Tapez on no, s' i vs plait:"
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, fuzzy, kde-format
 #| msgctxt "No border line"
 #| msgid "None"
 msgid "None"
 msgstr "Nole"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, fuzzy, kde-format
 #| msgid "(%1/s)"
 msgctxt ""
@@ -807,14 +815,14 @@ msgctxt ""
 msgid "(%1/%2)"
 msgstr "(%1/s)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "Aberweter noveaté"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, fuzzy, kde-format
 #| msgid "Billing information:"
 msgctxt ""
@@ -822,21 +830,21 @@ msgctxt ""
 msgid "Updating information…"
 msgstr "Informåcions sol facturaedje:"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, fuzzy, kde-format
 #| msgid "&Store"
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "&Wårder"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, fuzzy, kde-format
 #| msgid "Provider:"
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "Ahesseu:"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, fuzzy, kde-format
 #| msgid ""
 #| "\n"
@@ -853,7 +861,7 @@ msgstr ""
 "Waibe:\n"
 "%1"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, fuzzy, kde-format
 #| msgid "&Send Email"
 msgctxt ""
@@ -862,7 +870,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "&Evoyî emile"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -870,10 +878,10 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -885,18 +893,18 @@ msgid ""
 "content added."
 msgstr ""
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "Dji tchedje des dnêyes "
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "Dj' astale"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -906,7 +914,7 @@ msgid ""
 "please contact the person in charge of your permissions."
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Back"
@@ -914,20 +922,20 @@ msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "En erî"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, fuzzy, kde-format
 #| msgid "Saturday"
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "semdi"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, fuzzy, kde-format
 #| msgctxt "@action:button Restart find & replace"
 #| msgid "Restart"
@@ -935,7 +943,7 @@ msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "Renonder"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "New"
@@ -943,7 +951,7 @@ msgctxt "Knewstuff5"
 msgid "New"
 msgstr "Novea"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Home"
@@ -951,13 +959,13 @@ msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Måjhon"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, fuzzy, kde-format
 #| msgctxt "keyboard-key-name"
 #| msgid "Up"
@@ -965,7 +973,7 @@ msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "Monter"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, fuzzy, kde-format
 #| msgctxt "dictionary variant"
 #| msgid "extended"
@@ -973,7 +981,7 @@ msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "sitindou"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, fuzzy, kde-format
 #| msgctxt "@action"
 #| msgid "Subscript"
@@ -981,14 +989,14 @@ msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "Dizo l' roye"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, fuzzy, kde-format
 #| msgid "&Show All Entries"
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "&Mostrer totes les Intrêyes"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -1019,9 +1027,14 @@ msgid ""
 msgstr ""
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
-#, kde-format
-msgid "Download New Stuff..."
-msgstr "Aberweter noveaté..."
+#, fuzzy, kde-format
+#| msgid "Download New Stuff"
+msgctxt "@action"
+msgid "Download New Stuff…"
+msgstr "Aberweter noveaté"
+
+#~ msgid "Download New Stuff..."
+#~ msgstr "Aberweter noveaté..."
 
 #~ msgid "Initializing"
 #~ msgstr "Inicialijhaedje"
diff -pruN 6.0.0-3/po/xh/knewstuff6.po 6.3.0-1/po/xh/knewstuff6.po
--- 6.0.0-3/po/xh/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/xh/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -12,7 +12,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2002-12-13 17:20SAST\n"
 "Last-Translator: Lwandle Mgidlana <lwandle@translate.org.za>\n"
 "Language-Team: Xhosa <xhosa@translate.org.za>\n"
@@ -58,7 +58,7 @@ msgstr "Akukho mbhalo okubuyiselweyo."
 msgid "You are now a fan."
 msgstr ""
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -123,7 +123,7 @@ msgstr "Uqwalaselo"
 msgid "Use"
 msgstr "Sukwenza isithunzi"
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -131,17 +131,17 @@ msgid ""
 "This is a critical error and should be reported to the application author"
 msgstr ""
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr ""
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr ""
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr ""
@@ -286,14 +286,14 @@ msgid ""
 "the update"
 msgstr ""
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, fuzzy, kde-format
 msgid ""
 "Failed to adopt '%1'\n"
 "%2"
 msgstr "Ayikwazi ukulayisha icebo '%1'"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, fuzzy, kde-format
 #| msgid "Categories"
 msgctxt ""
@@ -301,7 +301,7 @@ msgctxt ""
 msgid "All Categories"
 msgstr "Iintlobo"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, fuzzy, kde-format
 msgctxt ""
 "The string passed back in the case the requested category is not known"
@@ -325,13 +325,13 @@ msgstr ""
 msgid "Download New %1…"
 msgstr "Yehlela Ngezantsi"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, fuzzy, kde-format
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "Yehlela Ngezantsi"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, fuzzy, kde-format
 msgctxt ""
 "A placeholder title used in the dialog when there is no better title "
@@ -339,12 +339,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "Yehlela Ngezantsi"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, fuzzy, kde-format
 msgid "Pick Your Installation Option"
 msgstr "Ukhetho Lwecebo"
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -353,19 +353,19 @@ msgid ""
 "this through the naming of the items."
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, fuzzy, kde-format
 msgid "Install"
 msgstr "Imizekelo"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, fuzzy, kde-format
 msgctxt ""
 "A passive notification shown when installation of an item is initiated"
 msgid "Installing %1 from %2"
 msgstr "Imizekelo"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -373,10 +373,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, fuzzy, kde-format
 msgctxt ""
 "Request installation of this item, available when there is exactly one "
@@ -384,33 +384,33 @@ msgctxt ""
 msgid "Install"
 msgstr "Imizekelo"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, fuzzy, kde-format
 msgctxt ""
 "Show installation options, where there is more than one downloadable item"
 msgid "Install…"
 msgstr "Imizekelo"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, fuzzy, kde-format
 #| msgid "Update"
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "Gqiba"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, fuzzy, kde-format
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "Imizekelo"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -418,14 +418,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -436,12 +436,12 @@ msgid ""
 "to the KDE Community in a bug report</a>."
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, fuzzy, kde-format
 #| msgid "Comment"
 msgctxt ""
@@ -450,18 +450,18 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "Gqabaza"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, fuzzy, kde-format
 msgid "Rating:"
 msgstr "Iyenza"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, fuzzy, kde-format
 #| msgid "Homepage"
 msgid "Homepage:"
 msgstr "Homepage"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -470,12 +470,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -483,68 +483,76 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr ""
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, fuzzy, kde-format
 msgid "Tiles"
 msgstr "&Ifayile"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, fuzzy, kde-format
 msgid "Icons"
 msgstr "Iintshukumo"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, fuzzy, kde-format
 msgid "Preview"
 msgstr "Imboniselo yasekuqaleni"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, fuzzy, kde-format
 msgid "Detailed Tiles View Mode"
 msgstr "&Iinkcukacha"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, fuzzy, kde-format
 #| msgid "Icon Size"
 msgid "Icons Only View Mode"
 msgstr "Ubungakanani Bphawu lomfanekiso"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, fuzzy, kde-format
 msgid "Large Preview View Mode"
 msgstr "&Iinkcukacha"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr ""
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, fuzzy, kde-format
 msgid "Installed"
 msgstr "Imizekelo"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, fuzzy, kde-format
 #| msgid "Update"
 msgid "Updateable"
 msgstr "Gqiba"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, fuzzy, kde-format
 #| msgid "Show all options"
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "Bonisa zonke iinketho"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, fuzzy, kde-format
 #| msgid "Show all options"
 msgctxt ""
@@ -552,7 +560,7 @@ msgctxt ""
 msgid "Show Only Installed Entries"
 msgstr "Bonisa zonke iinketho"
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, fuzzy, kde-format
 #| msgid "Show all options"
 msgctxt ""
@@ -561,29 +569,29 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr "Bonisa zonke iinketho"
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, fuzzy, kde-format
 #| msgctxt "QAccel"
 #| msgid "Percent"
 msgid "Recent"
 msgstr "Ipesenti"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr ""
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, fuzzy, kde-format
 msgid "Rating"
 msgstr "Iyenza"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, fuzzy, kde-format
 msgid "Downloads"
 msgstr "Yehlela Ngezantsi"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, fuzzy, kde-format
 msgctxt ""
 "List option which will set the sort order to based on when items were most "
@@ -591,7 +599,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "Yehlela Ngezantsi"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -599,60 +607,60 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr ""
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, fuzzy, kde-format
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "Yehlela Ngezantsi"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, fuzzy, kde-format
 msgctxt ""
 "List option which will set the sort order to based on number of downloads"
 msgid "Show Most Downloaded First"
 msgstr "Yehlela Ngezantsi"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, fuzzy, kde-format
 msgid "Upload…"
 msgstr "Ulayisho %1"
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr ""
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, fuzzy, kde-format
 #| msgid "&Go To..."
 msgid "Go to…"
 msgstr "&Yiya Ku..."
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, fuzzy, kde-format
 msgid "Search…"
 msgstr "(phendla)"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, fuzzy, kde-format
 #| msgid "Categories"
 msgid "Category:"
 msgstr "Iintlobo"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, fuzzy, kde-format
 #| msgid "Continue operation"
 msgid "Contribute your own…"
 msgstr "Qhubeka nomsebenzi"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, kde-format
 msgctxt ""
 "Placeholder title for when a comment has no subject, but does have a rating"
 msgid "<i>(no title)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -660,20 +668,20 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, fuzzy, kde-format
 #| msgid "Categories"
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "Iintlobo"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -681,7 +689,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -689,15 +697,15 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, fuzzy, kde-format
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
 msgstr "Yehlela Ngezantsi"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, fuzzy, kde-format
 msgctxt ""
 "Subheading for the tile view, located immediately underneath the name of the "
@@ -705,7 +713,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "<b>Uhlobo</b>: %1<br> "
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -713,7 +721,7 @@ msgctxt ""
 msgid "Working…"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, fuzzy, kde-format
 #| msgid "Update"
 msgctxt ""
@@ -722,7 +730,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "Gqiba"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -733,7 +741,7 @@ msgid ""
 "bug report</a>."
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, fuzzy, kde-format
 msgctxt "Label for the busy indicator showing an item is installing"
 msgid "Installing…"
@@ -752,13 +760,13 @@ msgstr "akukho mposiso eyenzekileyo"
 msgid "Please try again later."
 msgstr "Nceda ngenisa igama."
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, fuzzy, kde-format
 #| msgid "None"
 msgid "None"
 msgstr "Akukho nanye"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, fuzzy, kde-format
 #| msgid "(%1/s)"
 msgctxt ""
@@ -766,13 +774,13 @@ msgctxt ""
 msgid "(%1/%2)"
 msgstr "(%1/s)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, fuzzy, kde-format
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "Yehlela Ngezantsi"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, fuzzy, kde-format
 #| msgid "Information"
 msgctxt ""
@@ -780,20 +788,20 @@ msgctxt ""
 msgid "Updating information…"
 msgstr "Ulwazi"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, fuzzy, kde-format
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "Isitalato"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, fuzzy, kde-format
 #| msgid "Hide %1"
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "Fihla %1"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, fuzzy, kde-format
 msgctxt ""
 "Text for an action which causes the specified website to be opened using the "
@@ -801,7 +809,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "Vula '%1'?"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, fuzzy, kde-format
 msgctxt ""
 "Text for an action which will attempt to send an email using the user's "
@@ -809,7 +817,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "Gcina Umfanekiso Njenge"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -817,10 +825,10 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -832,19 +840,19 @@ msgid ""
 "content added."
 msgstr ""
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, fuzzy, kde-format
 #| msgid "Loading Applet"
 msgid "Loading data"
 msgstr "llayisha i Applet"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, fuzzy, kde-format
 msgid "Installing"
 msgstr "Imizekelo"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -854,79 +862,79 @@ msgid ""
 "please contact the person in charge of your permissions."
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, fuzzy, kde-format
 #| msgid "Back"
 msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "Umva"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, fuzzy, kde-format
 #| msgid "Saturday"
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "Mgqibelo"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, fuzzy, kde-format
 #| msgid "Restart"
 msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "Qala kwakhona"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, fuzzy, kde-format
 #| msgid "New"
 msgctxt "Knewstuff5"
 msgid "New"
 msgstr "Entsha"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, fuzzy, kde-format
 msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "Ekhaya"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, fuzzy, kde-format
 #| msgid "Up"
 msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "Ngentla"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, fuzzy, kde-format
 msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "Oku&shicilelweyo"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, fuzzy, kde-format
 #| msgid "Show all options"
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "Bonisa zonke iinketho"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -957,9 +965,10 @@ msgid ""
 msgstr ""
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
-#, kde-format
-msgid "Download New Stuff..."
-msgstr ""
+#, fuzzy, kde-format
+msgctxt "@action"
+msgid "Download New Stuff…"
+msgstr "Yehlela Ngezantsi"
 
 #, fuzzy
 #~ msgid "Initializing"
diff -pruN 6.0.0-3/po/zh_CN/knewstuff6.po 6.3.0-1/po/zh_CN/knewstuff6.po
--- 6.0.0-3/po/zh_CN/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/zh_CN/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -2,8 +2,8 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdeorg\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
-"PO-Revision-Date: 2024-02-05 11:37\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
+"PO-Revision-Date: 2024-04-22 15:58\n"
 "Last-Translator: \n"
 "Language-Team: Chinese Simplified\n"
 "Language: zh_CN\n"
@@ -55,7 +55,7 @@ msgstr "您的投票已记录。"
 msgid "You are now a fan."
 msgstr "您已成为粉丝。"
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -121,7 +121,7 @@ msgstr "配置文件无效：“%1”"
 msgid "Use"
 msgstr "使用"
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -132,17 +132,17 @@ msgstr ""
 "%2\n"
 "这是一个严重的错误，请向应用程序的作者报告"
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr "无法从文件 %1 中加载内容提供者的信息"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr "无法从文件 %1 中加载资源提供者的信息"
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr "初始化内容提供者时出错。"
@@ -305,7 +305,7 @@ msgid ""
 "the update"
 msgstr "我们无法识别更新 %1 的链接，故无法进行更新"
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, kde-format
 msgid ""
 "Failed to adopt '%1'\n"
@@ -314,14 +314,14 @@ msgstr ""
 "无法使用“%1”\n"
 "%2"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, kde-format
 msgctxt ""
 "The first entry in the category selection list (also the default value)"
 msgid "All Categories"
 msgstr "全部分类"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, kde-format
 msgctxt ""
 "The string passed back in the case the requested category is not known"
@@ -345,13 +345,13 @@ msgstr "资源"
 msgid "Download New %1…"
 msgstr "下载新%1…"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, kde-format
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "下载新%1"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, kde-format
 msgctxt ""
 "A placeholder title used in the dialog when there is no better title "
@@ -359,12 +359,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "下载新资源"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr "选择安装选项"
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -375,19 +375,19 @@ msgstr ""
 "请从下载列表中选择您要安装的项目。如果您不知道选哪个，请联系项目的作者起一个"
 "更清楚的名字。"
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "安装"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, kde-format
 msgctxt ""
 "A passive notification shown when installation of an item is initiated"
 msgid "Installing %1 from %2"
 msgstr "正在从 %2 安装 %1"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -395,10 +395,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr "%2 的 %1"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, kde-format
 msgctxt ""
 "Request installation of this item, available when there is exactly one "
@@ -406,32 +406,32 @@ msgctxt ""
 msgid "Install"
 msgstr "安装"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, kde-format
 msgctxt ""
 "Show installation options, where there is more than one downloadable item"
 msgid "Install…"
 msgstr "安装…"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, kde-format
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "更新"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, kde-format
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "卸载"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -439,14 +439,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr "正在处理 %2 的项目 %1，请稍候…"
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr "正在更新 %2 的项目 %1。请稍候…"
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -459,12 +459,12 @@ msgstr ""
 "此项处于无效或未知状态。<a href=\"https://bugs.kde.org/enter_bug.cgi?"
 "product=frameworks-knewstuff\">请向 KDE 社区报告错误</a>。"
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr "评论："
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a new sub page with comments (comments "
@@ -472,17 +472,17 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "%1 条评论"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, kde-format
 msgid "Rating:"
 msgstr "评分："
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, kde-format
 msgid "Homepage:"
 msgstr "主页："
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -491,12 +491,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr "打开 %1 的主页"
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr "如何捐款："
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -504,74 +504,84 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr "了解如何为此项目捐款"
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+"此处显示的由其他用户创建的内容可能包含未经 KDE 或者本机系统的发行机构测试的可"
+"执行代码，无法保证它们的安全性、稳定性或者内容质量。请谨慎使用。"
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
-"此处提供的内容由像您这样的用户上传，系统软件的发行组织并未对它们功能或稳定性"
-"进行审查。"
+"此处显示的由其他用户创建的内容没有经过 KDE 或者本机系统的发行机构测试，无法保"
+"证它们的功能和内容质量。"
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, kde-format
 msgid "Tiles"
 msgstr "卡片"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "图标"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, kde-format
 msgid "Preview"
 msgstr "预览"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, kde-format
 msgid "Detailed Tiles View Mode"
 msgstr "详细卡片视图模式"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, kde-format
 msgid "Icons Only View Mode"
 msgstr "仅图标视图模式"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, kde-format
 msgid "Large Preview View Mode"
 msgstr "宽大预览视图模式"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr "全部"
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "已安装"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, kde-format
 msgid "Updateable"
 msgstr "可更新"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, kde-format
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "显示所有项"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr "只显示已安装的项目"
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -579,27 +589,27 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr "只显示可更新的项目"
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, kde-format
 msgid "Recent"
 msgstr "最新"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr "字母顺序"
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "评分"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, kde-format
 msgid "Downloads"
 msgstr "下载量"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on when items were most "
@@ -607,7 +617,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "最新的在前"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -615,57 +625,57 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr "按名称的字母排序"
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, kde-format
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "高分在前"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on number of downloads"
 msgid "Show Most Downloaded First"
 msgstr "最多下载在前"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, kde-format
 msgid "Upload…"
 msgstr "上传…"
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr "了解如何向此列表添加您自己的资源"
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, kde-format
 msgid "Go to…"
 msgstr "转到…"
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, kde-format
 msgid "Search…"
 msgstr "搜索…"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "分类："
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, kde-format
 msgid "Contribute your own…"
 msgstr "贡献您的内容…"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, kde-format
 msgctxt ""
 "Placeholder title for when a comment has no subject, but does have a rating"
 msgid "<i>(no title)</i>"
 msgstr "<i>(无标题)</i>"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -673,19 +683,19 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr "%1 <i>(作者)</i>"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr "%1 的评论"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, kde-format
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "显示所有评论"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -693,7 +703,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr "只显示评论"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -701,15 +711,15 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr "显示评论和回复"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, kde-format
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
 msgstr "%1 次下载"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, kde-format
 msgctxt ""
 "Subheading for the tile view, located immediately underneath the name of the "
@@ -717,7 +727,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "作者 <i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -725,7 +735,7 @@ msgctxt ""
 msgid "Working…"
 msgstr "正在处理…"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is in the process of being "
@@ -733,7 +743,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "正在更新…"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -746,7 +756,7 @@ msgstr ""
 "无效或未知状态。<a href=\"https://bugs.kde.org/enter_bug.cgi?"
 "product=frameworks-knewstuff\">请向 KDE 社区报告错误</a>。"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, kde-format
 msgctxt "Label for the busy indicator showing an item is installing"
 msgid "Installing…"
@@ -763,44 +773,44 @@ msgstr "发生错误"
 msgid "Please try again later."
 msgstr "请稍后重试。"
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, kde-format
 msgid "None"
 msgstr "无"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, kde-format
 msgctxt ""
 "A text representation of the rating, shown as a fraction of the max value"
 msgid "(%1/%2)"
 msgstr "(%1/%2)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, kde-format
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "上传新资源：%1"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, kde-format
 msgctxt ""
 "A text shown beside a busy indicator suggesting that data is being fetched"
 msgid "Updating information…"
 msgstr "正在更新信息…"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, kde-format
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "KDE 商店"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, kde-format
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "您添加的内容提供者"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, kde-format
 msgctxt ""
 "Text for an action which causes the specified website to be opened using the "
@@ -808,7 +818,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "打开网站：%1"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, kde-format
 msgctxt ""
 "Text for an action which will attempt to send an email using the user's "
@@ -816,7 +826,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "发送邮件至：%1"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -824,12 +834,12 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 "若要向 KDE 商店上传新条目或为已有条目添加内容，请打开网站并登录。登录后点击您"
 "的用户图标，再点击“我的产品”，即可打开产品管理系统并处理您的产品。"
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -844,18 +854,18 @@ msgstr ""
 "示继续。您可能需要创建新账户并登录到产品管理系统，然后遵循网站上的添加教程；"
 "或者您需要联系网站管理员直接添加新内容。"
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "正在加载数据"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "正在安装"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -865,73 +875,73 @@ msgid ""
 "please contact the person in charge of your permissions."
 msgstr "您未被授权使用百宝箱。如有任何问题，请联系管理员。"
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "返回"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr "热门"
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "精选"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "重新开始"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "New"
 msgstr "最新"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "主页"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr "展示架"
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "向上"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "推荐"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "订阅"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "所有项目"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -970,5 +980,6 @@ msgstr ""
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
 #, kde-format
-msgid "Download New Stuff..."
-msgstr "下载新资源..."
+msgctxt "@action"
+msgid "Download New Stuff…"
+msgstr "下载新资源…"
diff -pruN 6.0.0-3/po/zh_HK/knewstuff6.po 6.3.0-1/po/zh_HK/knewstuff6.po
--- 6.0.0-3/po/zh_HK/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/zh_HK/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -24,7 +24,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2006-01-04 13:32+0800\n"
 "Last-Translator: Abel Cheung <abel@oaka.org>\n"
 "Language-Team: Chinese (Hong Kong) <community@linuxhall.org>\n"
@@ -70,7 +70,7 @@ msgstr "沒有替換任何文字。"
 msgid "You are now a fan."
 msgstr ""
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -141,7 +141,7 @@ msgstr "組態設定檔案"
 msgid "Use"
 msgstr "展開"
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -149,18 +149,18 @@ msgid ""
 "This is a critical error and should be reported to the application author"
 msgstr ""
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, fuzzy, kde-format
 #| msgid "Loading resource '%1' failed!"
 msgid "Loading of providers from file: %1 failed"
 msgstr "載入資源 '%1' 時發生錯誤！"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr ""
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, fuzzy, kde-format
 #| msgid "Error parsing providers list."
 msgid "Error initializing provider."
@@ -308,14 +308,14 @@ msgid ""
 "the update"
 msgstr ""
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, fuzzy, kde-format
 msgid ""
 "Failed to adopt '%1'\n"
 "%2"
 msgstr "無法讀入資源 '%1'"
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, fuzzy, kde-format
 #| msgid "Categories"
 msgctxt ""
@@ -323,7 +323,7 @@ msgctxt ""
 msgid "All Categories"
 msgstr "分類"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, fuzzy, kde-format
 #| msgctxt "QFile"
 #| msgid "Unknown error"
@@ -350,14 +350,14 @@ msgstr ""
 msgid "Download New %1…"
 msgstr "下載新的 %1"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, fuzzy, kde-format
 #| msgid "Download New %1"
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "下載新的 %1"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
 msgctxt ""
@@ -366,13 +366,13 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "下載熱門禮品"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, fuzzy, kde-format
 #| msgid "Resource Installation Error"
 msgid "Pick Your Installation Option"
 msgstr "資源安裝錯誤"
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -381,12 +381,12 @@ msgid ""
 "this through the naming of the items."
 msgstr ""
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "安裝"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -394,7 +394,7 @@ msgctxt ""
 msgid "Installing %1 from %2"
 msgstr "安裝"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -402,10 +402,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -414,10 +414,10 @@ msgctxt ""
 msgid "Install"
 msgstr "安裝"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt ""
@@ -425,24 +425,24 @@ msgctxt ""
 msgid "Install…"
 msgstr "安裝"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, fuzzy, kde-format
 #| msgid "Update"
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "更新"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "安裝"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -450,14 +450,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -468,12 +468,12 @@ msgid ""
 "to the KDE Community in a bug report</a>."
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, fuzzy, kde-format
 #| msgid "Comment"
 msgctxt ""
@@ -482,19 +482,19 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "備註"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, fuzzy, kde-format
 #| msgid "Rating"
 msgid "Rating:"
 msgstr "評分"
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, fuzzy, kde-format
 #| msgid "Homepage"
 msgid "Homepage:"
 msgstr "首頁"
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -503,12 +503,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr ""
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -516,73 +516,81 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr ""
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, fuzzy, kde-format
 #| msgid "&Tile"
 msgid "Tiles"
 msgstr "鋪排(&T)"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "圖示"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, fuzzy, kde-format
 #| msgid "Preview URL:"
 msgid "Preview"
 msgstr "預覽 URL："
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, fuzzy, kde-format
 #| msgid "Details"
 msgid "Detailed Tiles View Mode"
 msgstr "詳細資料"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, fuzzy, kde-format
 #| msgid "Icon Size"
 msgid "Icons Only View Mode"
 msgstr "圖示大小"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, fuzzy, kde-format
 #| msgid "Details"
 msgid "Large Preview View Mode"
 msgstr "詳細資料"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr ""
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, fuzzy, kde-format
 #| msgid "Install"
 msgid "Installed"
 msgstr "安裝"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, fuzzy, kde-format
 #| msgid "Update"
 msgid "Updateable"
 msgstr "更新"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, fuzzy, kde-format
 #| msgid "Show all options"
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "顯示所有選項"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, fuzzy, kde-format
 #| msgid "Show all options"
 msgctxt ""
@@ -590,7 +598,7 @@ msgctxt ""
 msgid "Show Only Installed Entries"
 msgstr "顯示所有選項"
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, fuzzy, kde-format
 #| msgid "Show all options"
 msgctxt ""
@@ -599,31 +607,31 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr "顯示所有選項"
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, fuzzy, kde-format
 #| msgctxt "QAccel"
 #| msgid "Percent"
 msgid "Recent"
 msgstr "百分比符號"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr ""
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, fuzzy, kde-format
 #| msgid "Rating"
 msgid "Rating"
 msgstr "評分"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, fuzzy, kde-format
 #| msgid "Download"
 msgid "Downloads"
 msgstr "下載"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, fuzzy, kde-format
 #| msgid "Most Downloads"
 msgctxt ""
@@ -632,7 +640,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "最多下載次數"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -640,14 +648,14 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr ""
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, fuzzy, kde-format
 #| msgid "Highest Rated"
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "最高評分"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, fuzzy, kde-format
 #| msgid "Most Downloads"
 msgctxt ""
@@ -655,49 +663,49 @@ msgctxt ""
 msgid "Show Most Downloaded First"
 msgstr "最多下載次數"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, fuzzy, kde-format
 #| msgid "&Upload"
 msgid "Upload…"
 msgstr "上傳(&U)"
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr ""
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, fuzzy, kde-format
 #| msgid "&Go To..."
 msgid "Go to…"
 msgstr "移至(&G)..."
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, fuzzy, kde-format
 #| msgid "S&earch:"
 msgid "Search…"
 msgstr "搜尋(&S)："
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, fuzzy, kde-format
 #| msgid "Categories"
 msgid "Category:"
 msgstr "分類"
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, fuzzy, kde-format
 #| msgid "Continue operation"
 msgid "Contribute your own…"
 msgstr "繼續作業"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, kde-format
 msgctxt ""
 "Placeholder title for when a comment has no subject, but does have a rating"
 msgid "<i>(no title)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -705,20 +713,20 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, fuzzy, kde-format
 #| msgid "Categories"
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "分類"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -726,7 +734,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr ""
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -734,16 +742,16 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, fuzzy, kde-format
 #| msgid "Download"
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
 msgstr "下載"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, fuzzy, kde-format
 #| msgid "<b>Error</b>: %1: %2"
 msgctxt ""
@@ -752,7 +760,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "<b>錯誤</b>：%1：%2<br>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -760,7 +768,7 @@ msgctxt ""
 msgid "Working…"
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, fuzzy, kde-format
 #| msgid "Update"
 msgctxt ""
@@ -769,7 +777,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "更新"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -780,7 +788,7 @@ msgid ""
 "bug report</a>."
 msgstr ""
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, fuzzy, kde-format
 #| msgid "Install"
 msgctxt "Label for the busy indicator showing an item is installing"
@@ -801,13 +809,13 @@ msgstr "沒有發生錯誤"
 msgid "Please try again later."
 msgstr "請輸入一個名稱。"
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, fuzzy, kde-format
 #| msgid "None"
 msgid "None"
 msgstr "無"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, fuzzy, kde-format
 #| msgid "(%1/s)"
 msgctxt ""
@@ -815,14 +823,14 @@ msgctxt ""
 msgid "(%1/%2)"
 msgstr "(%1/s)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "下載熱門禮品"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, fuzzy, kde-format
 #| msgid "Information"
 msgctxt ""
@@ -830,21 +838,21 @@ msgctxt ""
 msgid "Updating information…"
 msgstr "資料"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, fuzzy, kde-format
 #| msgid "Store"
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "儲存"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, fuzzy, kde-format
 #| msgid "Hide %1"
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "隱藏 %1"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, fuzzy, kde-format
 #| msgid "&Open with '%1'"
 msgctxt ""
@@ -853,7 +861,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "開啟用 '%1'(&O)"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, fuzzy, kde-format
 #| msgid "&Send Email"
 msgctxt ""
@@ -862,7 +870,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "傳送 &Email"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -870,10 +878,10 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -885,20 +893,20 @@ msgid ""
 "content added."
 msgstr ""
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, fuzzy, kde-format
 #| msgid "Loading Applet"
 msgid "Loading data"
 msgstr "載入 Applet"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, fuzzy, kde-format
 #| msgid "Install"
 msgid "Installing"
 msgstr "安裝"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -908,41 +916,41 @@ msgid ""
 "please contact the person in charge of your permissions."
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, fuzzy, kde-format
 #| msgid "Back"
 msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "上一步"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, fuzzy, kde-format
 #| msgid "Saturday"
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "星期六"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, fuzzy, kde-format
 #| msgid "Restart"
 msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "重新開始"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, fuzzy, kde-format
 #| msgid "New"
 msgctxt "Knewstuff5"
 msgid "New"
 msgstr "新增"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, fuzzy, kde-format
 #| msgctxt "Opposite to End"
 #| msgid "Home"
@@ -950,39 +958,39 @@ msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "開頭"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, fuzzy, kde-format
 #| msgid "Up"
 msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "向上"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, fuzzy, kde-format
 msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "語文(&I)"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, fuzzy, kde-format
 #| msgid "Show all options"
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "顯示所有選項"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -1015,10 +1023,16 @@ msgstr ""
 #: widgets/action.cpp:28 widgets/button.cpp:70
 #, fuzzy, kde-format
 #| msgid "Download New Stuff"
-msgid "Download New Stuff..."
+msgctxt "@action"
+msgid "Download New Stuff…"
 msgstr "下載熱門禮品"
 
 #, fuzzy
+#~| msgid "Download New Stuff"
+#~ msgid "Download New Stuff..."
+#~ msgstr "下載熱門禮品"
+
+#, fuzzy
 #~| msgid "Install"
 #~ msgid "Initializing"
 #~ msgstr "安裝"
diff -pruN 6.0.0-3/po/zh_TW/knewstuff6.po 6.3.0-1/po/zh_TW/knewstuff6.po
--- 6.0.0-3/po/zh_TW/knewstuff6.po	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/po/zh_TW/knewstuff6.po	2024-05-31 13:26:56.000000000 +0000
@@ -18,7 +18,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: kdelibs4\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
-"POT-Creation-Date: 2024-02-09 00:35+0000\n"
+"POT-Creation-Date: 2024-05-08 00:36+0000\n"
 "PO-Revision-Date: 2023-08-08 00:58+0900\n"
 "Last-Translator: Kisaragi Hiu <mail@kisaragi-hiu.com>\n"
 "Language-Team: Traditional Chinese <zh-l10n@lists.slat.org>\n"
@@ -76,7 +76,7 @@ msgstr "已記錄投票。"
 msgid "You are now a fan."
 msgstr "您已成為粉絲。"
 
-#: attica/atticaprovider.cpp:580 core/enginebase.cpp:197
+#: attica/atticaprovider.cpp:580 core/enginebase.cpp:208
 #: opds/opdsprovider.cpp:287
 #, kde-format
 msgid ""
@@ -142,7 +142,7 @@ msgstr "設定檔無效：%1"
 msgid "Use"
 msgstr "使用"
 
-#: core/enginebase.cpp:121
+#: core/enginebase.cpp:132
 #, kde-format
 msgid ""
 "Could not initialise the installation handler for %1:\n"
@@ -153,17 +153,17 @@ msgstr ""
 "%2\n"
 "此為嚴重錯誤，應向應用程式作者回報"
 
-#: core/enginebase.cpp:273
+#: core/enginebase.cpp:284
 #, kde-format
 msgid "Loading of providers from file: %1 failed"
 msgstr "從檔案 %1 載入提供者失敗"
 
-#: core/enginebase.cpp:291
+#: core/enginebase.cpp:302
 #, kde-format
 msgid "Could not load get hot new stuff providers from file: %1"
 msgstr "無法從檔案 %1 載入熱門新玩意的供應者"
 
-#: core/enginebase.cpp:322
+#: core/enginebase.cpp:333
 #, kde-format
 msgid "Error initializing provider."
 msgstr "初始化提供者時發生錯誤。"
@@ -325,21 +325,21 @@ msgid ""
 "the update"
 msgstr "我們無法辨識可用以更新 %1 用的連結，因此無法進行更新"
 
-#: core/transaction.cpp:376
+#: core/transaction.cpp:381
 #, kde-format
 msgid ""
 "Failed to adopt '%1'\n"
 "%2"
 msgstr ""
 
-#: qtquick/categoriesmodel.cpp:50
+#: qtquick/categoriesmodel.cpp:52
 #, kde-format
 msgctxt ""
 "The first entry in the category selection list (also the default value)"
 msgid "All Categories"
 msgstr "所有分類"
 
-#: qtquick/categoriesmodel.cpp:72
+#: qtquick/categoriesmodel.cpp:74
 #, kde-format
 msgctxt ""
 "The string passed back in the case the requested category is not known"
@@ -364,13 +364,13 @@ msgstr "玩意"
 msgid "Download New %1…"
 msgstr "下載新%1…"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:44
 #, kde-format
 msgctxt "The dialog title when we know which type of stuff is being requested"
 msgid "Download New %1"
 msgstr "下載新%1"
 
-#: qtquick/qml/Dialog.qml:42
+#: qtquick/qml/Dialog.qml:45
 #, kde-format
 msgctxt ""
 "A placeholder title used in the dialog when there is no better title "
@@ -378,12 +378,12 @@ msgctxt ""
 msgid "Download New Stuff"
 msgstr "下載熱門玩意"
 
-#: qtquick/qml/DownloadItemsSheet.qml:31
+#: qtquick/qml/DownloadItemsSheet.qml:35
 #, kde-format
 msgid "Pick Your Installation Option"
 msgstr "選擇安裝選項"
 
-#: qtquick/qml/DownloadItemsSheet.qml:41
+#: qtquick/qml/DownloadItemsSheet.qml:47
 #, kde-format
 msgid ""
 "Please select the option you wish to install from the list of downloadable "
@@ -394,19 +394,19 @@ msgstr ""
 "請在下方的可下載項目清單中選擇你要安裝的選項。如果你所要選的可用選項不夠清"
 "楚，請聯絡此項目的作者，並請求他們說明這個項目的命名意義。"
 
-#: qtquick/qml/DownloadItemsSheet.qml:79
+#: qtquick/qml/DownloadItemsSheet.qml:88
 #, kde-format
 msgid "Install"
 msgstr "安裝"
 
-#: qtquick/qml/EntryDetails.qml:87
+#: qtquick/qml/EntryDetails.qml:89
 #, kde-format
 msgctxt ""
 "A passive notification shown when installation of an item is initiated"
 msgid "Installing %1 from %2"
 msgstr "從 %2 安裝 %1"
 
-#: qtquick/qml/EntryDetails.qml:104
+#: qtquick/qml/EntryDetails.qml:106
 #, kde-format
 msgctxt ""
 "Combined title for the entry details page made of the name of the entry, and "
@@ -414,10 +414,10 @@ msgctxt ""
 msgid "%1 by %2"
 msgstr "%1 由 %2"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:111
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:43
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:37
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:48
 #, kde-format
 msgctxt ""
 "Request installation of this item, available when there is exactly one "
@@ -425,32 +425,32 @@ msgctxt ""
 msgid "Install"
 msgstr "安裝"
 
-#: qtquick/qml/EntryDetails.qml:108
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:37
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:34
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:43
+#: qtquick/qml/EntryDetails.qml:112
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:44
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:38
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:49
 #, kde-format
 msgctxt ""
 "Show installation options, where there is more than one downloadable item"
 msgid "Install…"
 msgstr "安裝…"
 
-#: qtquick/qml/EntryDetails.qml:123
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:52
-#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:49
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:58
+#: qtquick/qml/EntryDetails.qml:128
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:59
+#: qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml:53
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:64
 #, kde-format
 msgctxt "Request updating of this item"
 msgid "Update"
 msgstr "更新"
 
-#: qtquick/qml/EntryDetails.qml:130 qtquick/qml/Page.qml:114
+#: qtquick/qml/EntryDetails.qml:135 qtquick/qml/Page.qml:114
 #, kde-format
 msgctxt "Request uninstallation of this item"
 msgid "Uninstall"
 msgstr "解除安裝"
 
-#: qtquick/qml/EntryDetails.qml:152
+#: qtquick/qml/EntryDetails.qml:157
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being "
@@ -458,14 +458,14 @@ msgctxt ""
 msgid "Currently working on the item %1 by %2. Please wait…"
 msgstr "目前正在處理 %2 的項目 %1。請稍候…"
 
-#: qtquick/qml/EntryDetails.qml:154
+#: qtquick/qml/EntryDetails.qml:159
 #, kde-format
 msgctxt ""
 "Status message to be shown when the entry is in the process of being updated"
 msgid "Currently updating the item %1 by %2. Please wait…"
 msgstr "目前正在更新 %2 的項目 %1。請稍候…"
 
-#: qtquick/qml/EntryDetails.qml:156
+#: qtquick/qml/EntryDetails.qml:161
 #, kde-format
 msgctxt ""
 "Status message which should only be shown when the entry has been given some "
@@ -478,12 +478,12 @@ msgstr ""
 "這個項目目前無效或處於不明狀態。<a href=\"https://bugs.kde.org/enter_bug.cgi?"
 "product=frameworks-knewstuff\">請在漏洞回報中回報此問題至 KDE 社群</a>。"
 
-#: qtquick/qml/EntryDetails.qml:209
+#: qtquick/qml/EntryDetails.qml:214
 #, kde-format
 msgid "Comments and Reviews:"
 msgstr "留言及評論："
 
-#: qtquick/qml/EntryDetails.qml:211
+#: qtquick/qml/EntryDetails.qml:216
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a new sub page with comments (comments "
@@ -491,17 +491,17 @@ msgctxt ""
 msgid "%1 Reviews and Comments"
 msgstr "%1 則評論及留言"
 
-#: qtquick/qml/EntryDetails.qml:217
+#: qtquick/qml/EntryDetails.qml:222
 #, kde-format
 msgid "Rating:"
 msgstr "評價："
 
-#: qtquick/qml/EntryDetails.qml:222
+#: qtquick/qml/EntryDetails.qml:227
 #, kde-format
 msgid "Homepage:"
 msgstr "首頁："
 
-#: qtquick/qml/EntryDetails.qml:223
+#: qtquick/qml/EntryDetails.qml:228
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens the website associated with the entry "
@@ -510,12 +510,12 @@ msgctxt ""
 msgid "Open the homepage for %1"
 msgstr "開啟 %1 首頁"
 
-#: qtquick/qml/EntryDetails.qml:229
+#: qtquick/qml/EntryDetails.qml:234
 #, kde-format
 msgid "How To Donate:"
 msgstr "捐助方法："
 
-#: qtquick/qml/EntryDetails.qml:230
+#: qtquick/qml/EntryDetails.qml:235
 #, kde-format
 msgctxt ""
 "A link which, when clicked, opens a website with information on donation in "
@@ -523,72 +523,80 @@ msgctxt ""
 msgid "Find out how to donate to this project"
 msgstr "得知如何捐助此專案"
 
-#: qtquick/qml/Page.qml:141
+#: qtquick/qml/Page.qml:139
+#, kde-kuit-format
+msgid ""
+"Use caution when accessing user-created content shown here, as it may "
+"contain executable code that hasn't been tested by KDE or your distributor "
+"for safety, stability, or quality"
+msgstr ""
+
+#: qtquick/qml/Page.qml:140
 #, kde-format
 msgid ""
-"The content available here has been uploaded by users like you, and has not "
-"been reviewed by your distributor for functionality or stability."
+"User-created content shown here hasn't been tested by KDE or your "
+"distributor for functionality or quality."
 msgstr ""
 
-#: qtquick/qml/Page.qml:171
+#: qtquick/qml/Page.qml:172
 #, kde-format
 msgid "Tiles"
 msgstr "方塊"
 
-#: qtquick/qml/Page.qml:173
+#: qtquick/qml/Page.qml:174
 #, kde-format
 msgid "Icons"
 msgstr "圖示"
 
-#: qtquick/qml/Page.qml:175
+#: qtquick/qml/Page.qml:176
 #, kde-format
 msgid "Preview"
 msgstr "預覽"
 
-#: qtquick/qml/Page.qml:191
+#: qtquick/qml/Page.qml:192
 #, kde-format
 msgid "Detailed Tiles View Mode"
 msgstr "使用詳細方塊的檢視模式"
 
-#: qtquick/qml/Page.qml:200
+#: qtquick/qml/Page.qml:203
 #, kde-format
 msgid "Icons Only View Mode"
 msgstr "只有圖示的檢視模式"
 
-#: qtquick/qml/Page.qml:209
+#: qtquick/qml/Page.qml:214
 #, kde-format
 msgid "Large Preview View Mode"
 msgstr "使用大預覽的檢視模式"
 
-#: qtquick/qml/Page.qml:220
+#: qtquick/qml/Page.qml:227
 #, kde-format
 msgid "Everything"
 msgstr "所有項目"
 
-#: qtquick/qml/Page.qml:222
+#: qtquick/qml/Page.qml:229
 #, kde-format
 msgid "Installed"
 msgstr "已安裝"
 
-#: qtquick/qml/Page.qml:224
+#: qtquick/qml/Page.qml:231
 #, kde-format
 msgid "Updateable"
 msgstr "可更新"
 
-#: qtquick/qml/Page.qml:244
+#: qtquick/qml/Page.qml:251
 #, kde-format
 msgctxt "List option which will set the filter to show everything"
 msgid "Show All Entries"
 msgstr "顯示所有項目"
 
-#: qtquick/qml/Page.qml:253
+#: qtquick/qml/Page.qml:262
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items are shown"
 msgid "Show Only Installed Entries"
 msgstr "僅顯示已安裝項目"
 
-#: qtquick/qml/Page.qml:262
+#: qtquick/qml/Page.qml:273
 #, kde-format
 msgctxt ""
 "List option which will set the filter so only installed items with updates "
@@ -596,27 +604,27 @@ msgctxt ""
 msgid "Show Only Updateable Entries"
 msgstr "僅顯示可更新項目"
 
-#: qtquick/qml/Page.qml:273
+#: qtquick/qml/Page.qml:286
 #, kde-format
 msgid "Recent"
 msgstr "最近"
 
-#: qtquick/qml/Page.qml:275
+#: qtquick/qml/Page.qml:288
 #, kde-format
 msgid "Alphabetical"
 msgstr "按字母順序"
 
-#: qtquick/qml/Page.qml:277
+#: qtquick/qml/Page.qml:290
 #, kde-format
 msgid "Rating"
 msgstr "評分"
 
-#: qtquick/qml/Page.qml:279
+#: qtquick/qml/Page.qml:292
 #, kde-format
 msgid "Downloads"
 msgstr "下載"
 
-#: qtquick/qml/Page.qml:299
+#: qtquick/qml/Page.qml:312
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on when items were most "
@@ -624,7 +632,7 @@ msgctxt ""
 msgid "Show Most Recent First"
 msgstr "先顯示最近的項目"
 
-#: qtquick/qml/Page.qml:308
+#: qtquick/qml/Page.qml:323
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to be alphabetical based on the "
@@ -632,57 +640,57 @@ msgctxt ""
 msgid "Sort Alphabetically By Name"
 msgstr "依名稱字母排序"
 
-#: qtquick/qml/Page.qml:317
+#: qtquick/qml/Page.qml:334
 #, kde-format
 msgctxt "List option which will set the sort order to based on user ratings"
 msgid "Show Highest Rated First"
 msgstr "先顯示評價最高的項目"
 
-#: qtquick/qml/Page.qml:326
+#: qtquick/qml/Page.qml:345
 #, kde-format
 msgctxt ""
 "List option which will set the sort order to based on number of downloads"
 msgid "Show Most Downloaded First"
 msgstr "先顯示下載數最多的項目"
 
-#: qtquick/qml/Page.qml:337
+#: qtquick/qml/Page.qml:358
 #, kde-format
 msgid "Upload…"
 msgstr "上傳…"
 
-#: qtquick/qml/Page.qml:338
+#: qtquick/qml/Page.qml:359
 #, kde-format
 msgid "Learn how to add your own hot new stuff to this list"
 msgstr "了解如何將您自己的新玩意加到這個列表裡"
 
-#: qtquick/qml/Page.qml:348
+#: qtquick/qml/Page.qml:369
 #, kde-format
 msgid "Go to…"
 msgstr "跳到…"
 
-#: qtquick/qml/Page.qml:355 qtquick/qml/Page.qml:364
+#: qtquick/qml/Page.qml:376 qtquick/qml/Page.qml:385
 #, kde-format
 msgid "Search…"
 msgstr "搜尋…"
 
-#: qtquick/qml/Page.qml:418
+#: qtquick/qml/Page.qml:439
 #, kde-format
 msgid "Category:"
 msgstr "類別："
 
-#: qtquick/qml/Page.qml:438
+#: qtquick/qml/Page.qml:459
 #, kde-format
 msgid "Contribute your own…"
 msgstr "貢獻您自己的…"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:110
+#: qtquick/qml/private/EntryCommentDelegate.qml:103
 #, kde-format
 msgctxt ""
 "Placeholder title for when a comment has no subject, but does have a rating"
 msgid "<i>(no title)</i>"
 msgstr "<i>（沒有標題）</i>"
 
-#: qtquick/qml/private/EntryCommentDelegate.qml:142
+#: qtquick/qml/private/EntryCommentDelegate.qml:136
 #, kde-format
 msgctxt ""
 "The author label in case the comment was written by the author of the "
@@ -690,19 +698,19 @@ msgctxt ""
 msgid "%1 <i>(author)</i>"
 msgstr "%1<i>（作者）</i>"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:26
+#: qtquick/qml/private/EntryCommentsPage.qml:27
 #, kde-format
 msgctxt "Title for the page containing a view of the comments for the entry"
 msgid "Comments and Reviews for %1"
 msgstr "%1 的留言及評論"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:29
+#: qtquick/qml/private/EntryCommentsPage.qml:30
 #, kde-format
 msgctxt "Title for the item which is checked when all comments should be shown"
 msgid "Show All Comments"
 msgstr "顯示所有評論"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:35
+#: qtquick/qml/private/EntryCommentsPage.qml:38
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when only comments which are reviews "
@@ -710,7 +718,7 @@ msgctxt ""
 msgid "Show Reviews Only"
 msgstr "只顯示評論"
 
-#: qtquick/qml/private/EntryCommentsPage.qml:41
+#: qtquick/qml/private/EntryCommentsPage.qml:46
 #, kde-format
 msgctxt ""
 "Title for the item which is checked when comments which are reviews, and "
@@ -718,15 +726,15 @@ msgctxt ""
 msgid "Show Reviews and Replies"
 msgstr "顯示評論及回覆"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:129
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:175
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:140
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:185
 #, kde-format
 msgctxt "The number of times the item has been downloaded"
 msgid "%1 downloads"
 msgstr "下載 %1 次"
 
-#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:142
-#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:154
+#: qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml:153
+#: qtquick/qml/private/entrygriddelegates/TileDelegate.qml:164
 #, kde-format
 msgctxt ""
 "Subheading for the tile view, located immediately underneath the name of the "
@@ -734,7 +742,7 @@ msgctxt ""
 msgid "By <i>%1</i>"
 msgstr "由 <i>%1</i>"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:44
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is being installed OR "
@@ -742,7 +750,7 @@ msgctxt ""
 msgid "Working…"
 msgstr "處理中…"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:46
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
 #, kde-format
 msgctxt ""
 "Label for the busy indicator showing an item is in the process of being "
@@ -750,7 +758,7 @@ msgctxt ""
 msgid "Updating…"
 msgstr "更新中…"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:48
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:50
 #, kde-format
 msgctxt ""
 "Label for the busy indicator which should only be shown when the entry has "
@@ -763,7 +771,7 @@ msgstr ""
 "處於無效或未知狀態。<a href=\"https://bugs.kde.org/enter_bug.cgi?"
 "product=frameworks-knewstuff\">請在臭蟲報告中回報此問題至 KDE 社群</a>。"
 
-#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:61
+#: qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml:63
 #, kde-format
 msgctxt "Label for the busy indicator showing an item is installing"
 msgid "Installing…"
@@ -780,44 +788,44 @@ msgstr "發生錯誤"
 msgid "Please try again later."
 msgstr "請稍後再試。"
 
-#: qtquick/qml/private/GridTileDelegate.qml:122
+#: qtquick/qml/private/GridTileDelegate.qml:120
 #, kde-format
 msgid "None"
 msgstr "無"
 
-#: qtquick/qml/private/Rating.qml:80
+#: qtquick/qml/private/Rating.qml:81
 #, kde-format
 msgctxt ""
 "A text representation of the rating, shown as a fraction of the max value"
 msgid "(%1/%2)"
 msgstr "(%1/%2)"
 
-#: qtquick/qml/UploadPage.qml:51
+#: qtquick/qml/UploadPage.qml:50
 #, kde-format
 msgctxt "@knewstuff6"
 msgid "Upload New Stuff: %1"
 msgstr "上傳好玩意：%1"
 
-#: qtquick/qml/UploadPage.qml:110
+#: qtquick/qml/UploadPage.qml:111
 #, kde-format
 msgctxt ""
 "A text shown beside a busy indicator suggesting that data is being fetched"
 msgid "Updating information…"
 msgstr "更新資訊中…"
 
-#: qtquick/qml/UploadPage.qml:125
+#: qtquick/qml/UploadPage.qml:126
 #, kde-format
 msgctxt "The name of the KDE Store"
 msgid "KDE Store"
 msgstr "KDE Store"
 
-#: qtquick/qml/UploadPage.qml:131
+#: qtquick/qml/UploadPage.qml:132
 #, kde-format
 msgctxt "An unnamed provider"
 msgid "Your Provider"
 msgstr "您的提供者"
 
-#: qtquick/qml/UploadPage.qml:140
+#: qtquick/qml/UploadPage.qml:141
 #, kde-format
 msgctxt ""
 "Text for an action which causes the specified website to be opened using the "
@@ -825,7 +833,7 @@ msgctxt ""
 msgid "Open Website: %1"
 msgstr "開始網站：%1"
 
-#: qtquick/qml/UploadPage.qml:146
+#: qtquick/qml/UploadPage.qml:149
 #, kde-format
 msgctxt ""
 "Text for an action which will attempt to send an email using the user's "
@@ -833,7 +841,7 @@ msgctxt ""
 msgid "Send Email To: %1"
 msgstr "傳送電子郵件給：%1"
 
-#: qtquick/qml/UploadPage.qml:154
+#: qtquick/qml/UploadPage.qml:159
 #, kde-format
 msgctxt "A description of how to upload content to a generic provider"
 msgid ""
@@ -841,10 +849,10 @@ msgid ""
 "Store, please open the website and log in. Once you have done this, you will "
 "be able to find the My Products entry in the menu which pops up when you "
 "click your user icon. Click on this entry to go to the product management "
-"system, where you can work on your products ."
+"system, where you can work on your products."
 msgstr ""
 
-#: qtquick/qml/UploadPage.qml:155
+#: qtquick/qml/UploadPage.qml:160
 #, kde-format
 msgctxt "A description of how to upload content to the KDE Store specifically"
 msgid ""
@@ -856,18 +864,18 @@ msgid ""
 "content added."
 msgstr ""
 
-#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:144
-#: qtquick/quickengine.cpp:152
+#: qtquick/quickengine.cpp:54 qtquick/quickengine.cpp:134
+#: qtquick/quickengine.cpp:142
 #, kde-format
 msgid "Loading data"
 msgstr "載入資料中"
 
-#: qtquick/quickengine.cpp:148
+#: qtquick/quickengine.cpp:138
 #, kde-format
 msgid "Installing"
 msgstr "安裝中"
 
-#: qtquick/quickengine.cpp:203
+#: qtquick/quickengine.cpp:193
 #, kde-format
 msgctxt ""
 "An informational message which is shown to inform the user they are not "
@@ -878,73 +886,73 @@ msgid ""
 msgstr ""
 "您未授權使用「取得新熱門項目」。如果你認為這是錯誤，請聯絡負責您權限的人。"
 
-#: qtquick/searchpresetmodel.cpp:43
+#: qtquick/searchpresetmodel.cpp:44
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Back"
 msgstr "返回"
 
-#: qtquick/searchpresetmodel.cpp:45
+#: qtquick/searchpresetmodel.cpp:46
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Popular"
 msgstr "受歡迎"
 
-#: qtquick/searchpresetmodel.cpp:47
+#: qtquick/searchpresetmodel.cpp:48
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Featured"
 msgstr "特色"
 
-#: qtquick/searchpresetmodel.cpp:49
+#: qtquick/searchpresetmodel.cpp:50
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Restart"
 msgstr "重新啟動"
 
-#: qtquick/searchpresetmodel.cpp:51
+#: qtquick/searchpresetmodel.cpp:52
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "New"
 msgstr "新的"
 
-#: qtquick/searchpresetmodel.cpp:53
+#: qtquick/searchpresetmodel.cpp:54
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Home"
 msgstr "首頁"
 
-#: qtquick/searchpresetmodel.cpp:55
+#: qtquick/searchpresetmodel.cpp:56
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Shelf"
 msgstr ""
 
-#: qtquick/searchpresetmodel.cpp:57
+#: qtquick/searchpresetmodel.cpp:58
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Up"
 msgstr "往上"
 
-#: qtquick/searchpresetmodel.cpp:59
+#: qtquick/searchpresetmodel.cpp:60
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Recommended"
 msgstr "建議"
 
-#: qtquick/searchpresetmodel.cpp:61
+#: qtquick/searchpresetmodel.cpp:62
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Subscriptions"
 msgstr "訂閱"
 
-#: qtquick/searchpresetmodel.cpp:63
+#: qtquick/searchpresetmodel.cpp:64
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "All Entries"
 msgstr "所有項目"
 
-#: qtquick/searchpresetmodel.cpp:65
+#: qtquick/searchpresetmodel.cpp:66
 #, kde-format
 msgctxt "Knewstuff5"
 msgid "Search Preset: %1"
@@ -975,9 +983,17 @@ msgid ""
 msgstr ""
 
 #: widgets/action.cpp:28 widgets/button.cpp:70
-#, kde-format
-msgid "Download New Stuff..."
-msgstr "下載熱門玩意..."
+#, fuzzy, kde-format
+#| msgctxt ""
+#| "A placeholder title used in the dialog when there is no better title "
+#| "available"
+#| msgid "Download New Stuff"
+msgctxt "@action"
+msgid "Download New Stuff…"
+msgstr "下載熱門玩意"
+
+#~ msgid "Download New Stuff..."
+#~ msgstr "下載熱門玩意..."
 
 #~ msgid "Initializing"
 #~ msgstr "初始化中"
diff -pruN 6.0.0-3/src/core/enginebase.cpp 6.3.0-1/src/core/enginebase.cpp
--- 6.0.0-3/src/core/enginebase.cpp	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/src/core/enginebase.cpp	2024-05-31 13:26:56.000000000 +0000
@@ -114,6 +114,17 @@ bool EngineBase::init(const QString &con
     d->tagFilter = group.readEntry("TagFilter", QStringList(QStringLiteral("ghns_excluded!=1")));
     d->downloadTagFilter = group.readEntry("DownloadTagFilter", QStringList());
 
+    QByteArray rawContentWarningType = group.readEntry("ContentWarning", QByteArrayLiteral("Static"));
+    bool ok = false;
+    int value = QMetaEnum::fromType<ContentWarningType>().keyToValue(rawContentWarningType.constData(), &ok);
+    if (ok) {
+        d->contentWarningType = static_cast<ContentWarningType>(value);
+    } else {
+        qCWarning(KNEWSTUFFCORE) << "Could not parse ContentWarning, invalid entry" << rawContentWarningType;
+    }
+
+    Q_EMIT contentWarningTypeChanged();
+
     // Make sure that config is valid
     QString error;
     if (!d->installation->readConfig(group, error)) {
@@ -462,6 +473,11 @@ ResultsStream *EngineBase::search(const
     return new ResultsStream(request, this);
 }
 
+EngineBase::ContentWarningType EngineBase::contentWarningType() const
+{
+    return d->contentWarningType;
+}
+
 QList<QSharedPointer<Provider>> EngineBase::providers() const
 {
     return d->providers.values();
diff -pruN 6.0.0-3/src/core/enginebase.h 6.3.0-1/src/core/enginebase.h
--- 6.0.0-3/src/core/enginebase.h	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/src/core/enginebase.h	2024-05-31 13:26:56.000000000 +0000
@@ -10,6 +10,7 @@
 #define KNEWSTUFF3_ENGINEBASE_H
 
 #include <QHash>
+#include <QMetaEnum>
 #include <QObject>
 #include <QSharedPointer>
 #include <QString>
@@ -70,6 +71,11 @@ class KNEWSTUFFCORE_EXPORT EngineBase :
      */
     Q_PROPERTY(QStringList providerIDs READ providerIDs NOTIFY providersChanged)
 
+    /**
+     * @copydoc contentWarningType
+     */
+    Q_PROPERTY(ContentWarningType contentWarningType READ contentWarningType NOTIFY contentWarningTypeChanged)
+
 public:
     EngineBase(QObject *parent = nullptr);
     ~EngineBase();
@@ -335,6 +341,37 @@ public:
      */
     ResultsStream *search(const KNSCore::Provider::SearchRequest &request);
 
+    /**
+     * @brief The ContentWarningType enum
+     * @since 6.1
+     */
+    enum class ContentWarningType {
+        /**
+         * Content consists of static assets only
+         * Installation should not pose a security risk
+         */
+        Static,
+        /**
+         * Content may contain scripts or other executable code
+         * Users should be warned to treat it like any other program
+         */
+        Executables
+    };
+    Q_ENUM(ContentWarningType)
+
+    /**
+     * @brief The level of warning that should be presented to the user
+     * @since 6.1
+     * @see ContentWarningType
+     */
+    ContentWarningType contentWarningType() const;
+
+    /**
+     * Emitted after the initial config load
+     * @since 6.1
+     */
+    Q_SIGNAL void contentWarningTypeChanged();
+
 Q_SIGNALS:
     /**
      * Indicates a message to be added to the ui's log, or sent to a messagebox
diff -pruN 6.0.0-3/src/core/enginebase_p.h 6.3.0-1/src/core/enginebase_p.h
--- 6.0.0-3/src/core/enginebase_p.h	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/src/core/enginebase_p.h	2024-05-31 13:26:56.000000000 +0000
@@ -10,6 +10,7 @@
 #define KNEWSTUFF3_ENGINEBASE_P_H
 
 #include "cache.h"
+#include "enginebase.h"
 #include "installation_p.h"
 #include <Attica/ProviderManager>
 
@@ -31,6 +32,7 @@ public:
     bool shouldRemoveDeletedEntries = false;
     QList<Provider::CategoryMetadata> categoriesMetadata;
     QHash<QString, QSharedPointer<KNSCore::Provider>> providers;
+    KNSCore::EngineBase::ContentWarningType contentWarningType = KNSCore::EngineBase::ContentWarningType::Static;
 };
 
 #endif
diff -pruN 6.0.0-3/src/core/installation.cpp 6.3.0-1/src/core/installation.cpp
--- 6.0.0-3/src/core/installation.cpp	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/src/core/installation.cpp	2024-05-31 13:26:56.000000000 +0000
@@ -460,13 +460,13 @@ QStringList Installation::installDownloa
 
             if (QFile::exists(installpath) && QDir::tempPath() != installdir) {
                 if (!update) {
-                    Question question(Question::YesNoQuestion);
+                    Question question(Question::ContinueCancelQuestion);
                     question.setEntry(entry);
                     question.setQuestion(i18n("This file already exists on disk (possibly due to an earlier failed download attempt). Continuing means "
                                               "overwriting it. Do you wish to overwrite the existing file?")
                                          + QStringLiteral("\n'") + installpath + QLatin1Char('\''));
                     question.setTitle(i18n("Overwrite File"));
-                    if (question.ask() != Question::YesResponse) {
+                    if (question.ask() != Question::ContinueResponse) {
                         return QStringList();
                     }
                 }
diff -pruN 6.0.0-3/src/core/provider.h 6.3.0-1/src/core/provider.h
--- 6.0.0-3/src/core/provider.h	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/src/core/provider.h	2024-05-31 13:26:56.000000000 +0000
@@ -75,7 +75,7 @@ public:
         int page;
         int pageSize;
 
-        SearchRequest(SortMode sortMode_ = Newest,
+        SearchRequest(SortMode sortMode_ = Downloads,
                       Filter filter_ = None,
                       const QString &searchTerm_ = QString(),
                       const QStringList &categories_ = QStringList(),
diff -pruN 6.0.0-3/src/core/providersmodel.cpp 6.3.0-1/src/core/providersmodel.cpp
--- 6.0.0-3/src/core/providersmodel.cpp	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/src/core/providersmodel.cpp	2024-05-31 13:26:56.000000000 +0000
@@ -12,14 +12,34 @@ namespace KNSCore
 {
 class ProvidersModelPrivate
 {
+    ProvidersModel *const q;
+
 public:
+    explicit ProvidersModelPrivate(ProvidersModel *qq)
+        : q(qq)
+    {
+    }
+
+    EngineBase *getEngine() const;
+    void setEngine(EngineBase *engine);
+
     EngineBase *engine = nullptr;
     QStringList knownProviders;
 };
 
+EngineBase *ProvidersModelPrivate::getEngine() const
+{
+    return engine;
+}
+
+void ProvidersModelPrivate::setEngine(EngineBase *engine)
+{
+    q->setEngine(engine);
+}
+
 ProvidersModel::ProvidersModel(QObject *parent)
     : QAbstractListModel(parent)
-    , d(new ProvidersModelPrivate)
+    , d(new ProvidersModelPrivate(this))
 {
 }
 
diff -pruN 6.0.0-3/src/core/providersmodel.h 6.3.0-1/src/core/providersmodel.h
--- 6.0.0-3/src/core/providersmodel.h	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/src/core/providersmodel.h	2024-05-31 13:26:56.000000000 +0000
@@ -9,6 +9,8 @@
 
 #include <QAbstractListModel>
 
+#include "enginebase.h"
+
 #include "knewstuffcore_export.h"
 
 #include <memory>
@@ -27,7 +29,7 @@ class KNEWSTUFFCORE_EXPORT ProvidersMode
     /**
      * The Engine for which this model displays Providers
      */
-    Q_PROPERTY(QObject *engine READ engine WRITE setEngine NOTIFY engineChanged)
+    Q_PRIVATE_PROPERTY(d, EngineBase *engine READ getEngine WRITE setEngine NOTIFY engineChanged)
 public:
     explicit ProvidersModel(QObject *parent = nullptr);
     ~ProvidersModel() override;
@@ -49,6 +51,7 @@ public:
     QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
     int rowCount(const QModelIndex &parent = QModelIndex()) const override;
 
+    // TODO KF7: Port property to back to public getter/setter, narrow types to EngineBase
     QObject *engine() const;
     void setEngine(QObject *engine);
     Q_SIGNAL void engineChanged();
diff -pruN 6.0.0-3/src/core/question.h 6.3.0-1/src/core/question.h
--- 6.0.0-3/src/core/question.h	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/src/core/question.h	2024-05-31 13:26:56.000000000 +0000
@@ -38,7 +38,7 @@ question.setTitle("Pick your option");
 question.setQuestion("Please select which option you would like");
 question.setList(choices);
 question.setEntry(entry);
-if(question.ask() == Question::OKResponse) {
+if (question.ask() == Question::OKResponse) {
     QString theChoice = question.response();
 }
 @endcode
diff -pruN 6.0.0-3/src/core/resultsstream.cpp 6.3.0-1/src/core/resultsstream.cpp
--- 6.0.0-3/src/core/resultsstream.cpp	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/src/core/resultsstream.cpp	2024-05-31 13:26:56.000000000 +0000
@@ -8,29 +8,39 @@
 #include "enginebase_p.h"
 #include "knewstuffcore_debug.h"
 
+#include <QTimer>
+
 using namespace KNSCore;
 
 class KNSCore::ResultsStreamPrivate
 {
 public:
     QList<QSharedPointer<KNSCore::Provider>> providers;
-    EngineBase *engine;
+    EngineBase const *engine;
     Provider::SearchRequest request;
 };
 
 ResultsStream::ResultsStream(const Provider::SearchRequest &request, EngineBase *base)
-    : d(new ResultsStreamPrivate)
+    : d(new ResultsStreamPrivate{
+        .providers = base->d->providers.values(),
+        .engine = base,
+        .request = request,
+    })
 {
-    d->engine = base;
-    d->request = request;
-    d->providers = base->d->providers.values();
     auto finished = [this](const KNSCore::Provider::SearchRequest &request, const KNSCore::Entry::List &entries) {
-        d->providers.removeAll(static_cast<Provider *>(sender()));
+        if (request != d->request) {
+            return;
+        }
+
+        if (d->providers.removeAll(qobject_cast<Provider *>(sender())) <= 0) {
+            qCDebug(KNEWSTUFFCORE) << "Request finished twice, check your provider" << sender() << d->engine << entries.size();
+            return;
+        }
+
         if (entries.isEmpty() && d->providers.isEmpty()) {
             finish();
         }
-
-        if (request == d->request) {
+        if (!entries.isEmpty()) {
             Q_EMIT entriesFound(entries);
         }
     };
@@ -68,7 +78,9 @@ void ResultsStream::fetch()
 
     for (const QSharedPointer<KNSCore::Provider> &p : std::as_const(d->providers)) {
         if (p->isInitialized()) {
-            p->loadEntries(d->request);
+            QTimer::singleShot(0, this, [this, p] {
+                p->loadEntries(d->request);
+            });
         } else {
             connect(p.get(), &KNSCore::Provider::providerInitialized, this, [this, p] {
                 disconnect(p.get(), &KNSCore::Provider::providerInitialized, this, nullptr);
diff -pruN 6.0.0-3/src/core/transaction.cpp 6.3.0-1/src/core/transaction.cpp
--- 6.0.0-3/src/core/transaction.cpp	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/src/core/transaction.cpp	2024-05-31 13:26:56.000000000 +0000
@@ -335,8 +335,13 @@ Transaction *Transaction::uninstall(Engi
         qCDebug(KNEWSTUFFCORE) << "about to uninstall entry " << entry.uniqueId();
         ret->d->m_engine->d->installation->uninstall(actualEntryForUninstall2);
 
+        // Update the correct entry
+        entry.setStatus(actualEntryForUninstall2.status());
+        Q_EMIT ret->signalEntryEvent(entry, Entry::StatusChangedEvent);
+
         ret->d->finish();
     });
+
     return ret;
 }
 
diff -pruN 6.0.0-3/src/qtquick/author.cpp 6.3.0-1/src/qtquick/author.cpp
--- 6.0.0-3/src/qtquick/author.cpp	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/src/qtquick/author.cpp	2024-05-31 13:26:56.000000000 +0000
@@ -11,8 +11,6 @@
 #include "core/author.h"
 #include "core/provider.h"
 
-#include "knewstuffquick_debug.h"
-
 #include <memory>
 
 namespace KNewStuffQuick
@@ -96,15 +94,15 @@ void Author::componentComplete()
     d->resetConnections();
 }
 
-QObject *Author::engine() const
+Engine *Author::engine() const
 {
     return d->engine;
 }
 
-void Author::setEngine(QObject *newEngine)
+void Author::setEngine(Engine *newEngine)
 {
     if (d->engine != newEngine) {
-        d->engine = qobject_cast<Engine *>(newEngine);
+        d->engine = newEngine;
         d->resetConnections();
         Q_EMIT engineChanged();
     }
diff -pruN 6.0.0-3/src/qtquick/author.h 6.3.0-1/src/qtquick/author.h
--- 6.0.0-3/src/qtquick/author.h	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/src/qtquick/author.h	2024-05-31 13:26:56.000000000 +0000
@@ -11,6 +11,8 @@
 #include <QQmlParserStatus>
 #include <entry.h>
 
+#include "quickengine.h"
+
 // TODO This is not a class for exposing data QtQuick, but for implementing it's fetching in the first place.
 // Also it sepnds on the QML parser status, this is kindof ugly...
 namespace KNewStuffQuick
@@ -30,7 +32,7 @@ class Author : public QObject, public QQ
     /**
      * The NewStuffQuickEngine to interact with servers through
      */
-    Q_PROPERTY(QObject *engine READ engine WRITE setEngine NOTIFY engineChanged)
+    Q_PROPERTY(Engine *engine READ engine WRITE setEngine NOTIFY engineChanged)
     /**
      * The ID of the provider which the user is registered on
      */
@@ -51,8 +53,8 @@ public:
     void classBegin() override;
     void componentComplete() override;
 
-    QObject *engine() const;
-    void setEngine(QObject *newEngine);
+    Engine *engine() const;
+    void setEngine(Engine *newEngine);
     Q_SIGNAL void engineChanged();
 
     QString providerId() const;
diff -pruN 6.0.0-3/src/qtquick/categoriesmodel.cpp 6.3.0-1/src/qtquick/categoriesmodel.cpp
--- 6.0.0-3/src/qtquick/categoriesmodel.cpp	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/src/qtquick/categoriesmodel.cpp	2024-05-31 13:26:56.000000000 +0000
@@ -6,6 +6,8 @@
 
 #include "categoriesmodel.h"
 
+#include "provider.h"
+
 #include <KLocalizedString>
 
 CategoriesModel::CategoriesModel(KNSCore::EngineBase *parent)
diff -pruN 6.0.0-3/src/qtquick/categoriesmodel.h 6.3.0-1/src/qtquick/categoriesmodel.h
--- 6.0.0-3/src/qtquick/categoriesmodel.h	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/src/qtquick/categoriesmodel.h	2024-05-31 13:26:56.000000000 +0000
@@ -10,7 +10,6 @@
 #include <QAbstractListModel>
 
 #include "enginebase.h"
-#include "provider.h"
 
 /**
  * @short A model which shows the categories found in an Engine
diff -pruN 6.0.0-3/src/qtquick/commentsmodel.cpp 6.3.0-1/src/qtquick/commentsmodel.cpp
--- 6.0.0-3/src/qtquick/commentsmodel.cpp	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/src/qtquick/commentsmodel.cpp	2024-05-31 13:26:56.000000000 +0000
@@ -6,8 +6,6 @@
 
 #include "commentsmodel.h"
 
-#include "quickitemsmodel.h"
-
 #include "core/commentsmodel.h"
 
 namespace KNewStuffQuick
@@ -73,15 +71,15 @@ void KNewStuffQuick::CommentsModel::comp
     d->resetConnections();
 }
 
-QObject *CommentsModel::itemsModel() const
+ItemsModel *CommentsModel::itemsModel() const
 {
     return d->itemsModel;
 }
 
-void CommentsModel::setItemsModel(QObject *newItemsModel)
+void CommentsModel::setItemsModel(ItemsModel *newItemsModel)
 {
     if (d->itemsModel != newItemsModel) {
-        d->itemsModel = qobject_cast<ItemsModel *>(newItemsModel);
+        d->itemsModel = newItemsModel;
         d->resetConnections();
         Q_EMIT itemsModelChanged();
     }
diff -pruN 6.0.0-3/src/qtquick/commentsmodel.h 6.3.0-1/src/qtquick/commentsmodel.h
--- 6.0.0-3/src/qtquick/commentsmodel.h	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/src/qtquick/commentsmodel.h	2024-05-31 13:26:56.000000000 +0000
@@ -7,9 +7,12 @@
 #ifndef KNSQUICK_COMMENTSMODEL_H
 #define KNSQUICK_COMMENTSMODEL_H
 
+#include "quickitemsmodel.h"
+
+#include <entry.h>
+
 #include <QQmlParserStatus>
 #include <QSortFilterProxyModel>
-#include <entry.h>
 
 #include <memory>
 
@@ -31,7 +34,7 @@ class CommentsModel : public QSortFilter
     /**
      * The KNewStufQuick::ItemsModel to interact with servers through
      */
-    Q_PROPERTY(QObject *itemsModel READ itemsModel WRITE setItemsModel NOTIFY itemsModelChanged)
+    Q_PROPERTY(ItemsModel *itemsModel READ itemsModel WRITE setItemsModel NOTIFY itemsModelChanged)
     /**
      * The index in the model of the entry to fetch comments for
      */
@@ -59,8 +62,8 @@ public:
     void classBegin() override;
     void componentComplete() override;
 
-    QObject *itemsModel() const;
-    void setItemsModel(QObject *newItemsModel);
+    ItemsModel *itemsModel() const;
+    void setItemsModel(ItemsModel *newItemsModel);
     Q_SIGNAL void itemsModelChanged();
 
     KNSCore::Entry entry() const;
diff -pruN 6.0.0-3/src/qtquick/qml/Action.qml 6.3.0-1/src/qtquick/qml/Action.qml
--- 6.0.0-3/src/qtquick/qml/Action.qml	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/src/qtquick/qml/Action.qml	2024-05-31 13:26:56.000000000 +0000
@@ -37,7 +37,7 @@ NewStuff.Action {
  */
 
 import QtQuick
-import org.kde.kirigami 2 as Kirigami
+import org.kde.kirigami as Kirigami
 import org.kde.newstuff as NewStuff
 
 Kirigami.Action {
@@ -82,7 +82,7 @@ Kirigami.Action {
      * This forwards the entry changed event from the QtQuick engine
      * @see Engine::entryEvent
      */
-    signal entryEvent(var entry, int event);
+    signal entryEvent(var entry, int event)
 
     /**
      * If this is true (default is false), the action will be shown when the Kiosk settings are such
@@ -93,6 +93,13 @@ Kirigami.Action {
     property bool visibleWhenDisabled: false
 
     /**
+     * The parent window for the dialog created by invoking the action
+     *
+     * @since 6.1
+     */
+    property Window transientParent
+
+    /**
     * Show the page/dialog (same as activating the action), if allowed by the Kiosk settings
     */
     function showHotNewStuff() {
@@ -185,6 +192,7 @@ Kirigami.Action {
             asynchronous: true
 
             sourceComponent: NewStuff.Dialog {
+                transientParent: component.transientParent
                 configFile: component.configFile
                 viewMode: component.viewMode
             }
diff -pruN 6.0.0-3/src/qtquick/qml/Button.qml 6.3.0-1/src/qtquick/qml/Button.qml
--- 6.0.0-3/src/qtquick/qml/Button.qml	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/src/qtquick/qml/Button.qml	2024-05-31 13:26:56.000000000 +0000
@@ -54,7 +54,7 @@ QQC2.Button {
      * emitted when the Hot New Stuff dialog is about to be shown, usually
      * as a result of the user having click on the button
      */
-    signal aboutToShowDialog();
+    signal aboutToShowDialog()
 
     /**
      * The engine which handles the content in this Button
diff -pruN 6.0.0-3/src/qtquick/qml/Dialog.qml 6.3.0-1/src/qtquick/qml/Dialog.qml
--- 6.0.0-3/src/qtquick/qml/Dialog.qml	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/src/qtquick/qml/Dialog.qml	2024-05-31 13:26:56.000000000 +0000
@@ -16,13 +16,14 @@
  */
 
 import QtQuick
-import QtQuick.Window
-import org.kde.kirigami 2 as Kirigami
+import org.kde.kirigami as Kirigami
 import org.kde.newstuff as NewStuff
 
 Window {
     id: component
 
+    // Keep in sync with the implicit sizes in DialogContent.qml and the default
+    // size in dialog.cpp
     width: Math.min(Kirigami.Units.gridUnit * 44, Screen.width)
     height: Math.min(Kirigami.Units.gridUnit * 30, Screen.height)
 
@@ -39,7 +40,9 @@ Window {
      * @note For the sake of consistency, you should NOT override the title property, just set this one
      */
     property string downloadNewWhat: engine.name
-    title: component.downloadNewWhat.length > 0 ? i18ndc("knewstuff6", "The dialog title when we know which type of stuff is being requested", "Download New %1", component.downloadNewWhat) : i18ndc("knewstuff6", "A placeholder title used in the dialog when there is no better title available", "Download New Stuff")
+    title: component.downloadNewWhat.length > 0
+        ? i18ndc("knewstuff6", "The dialog title when we know which type of stuff is being requested", "Download New %1", component.downloadNewWhat)
+        : i18ndc("knewstuff6", "A placeholder title used in the dialog when there is no better title available", "Download New Stuff")
 
     /**
      * The engine which handles the content in this dialog
@@ -102,7 +105,7 @@ Window {
         id: newStuffPage
         anchors.fill: parent
         downloadNewWhat: component.downloadNewWhat
-        Keys.onEscapePressed: component.close()
+        Keys.onEscapePressed: event => component.close()
     }
 
     Component {
diff -pruN 6.0.0-3/src/qtquick/qml/DialogContent.qml 6.3.0-1/src/qtquick/qml/DialogContent.qml
--- 6.0.0-3/src/qtquick/qml/DialogContent.qml	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/src/qtquick/qml/DialogContent.qml	2024-05-31 13:26:56.000000000 +0000
@@ -17,7 +17,7 @@
 
 import QtQuick
 import QtQuick.Layouts
-import org.kde.kirigami 2 as Kirigami
+import org.kde.kirigami as Kirigami
 import org.kde.newstuff as NewStuff
 
 Kirigami.ApplicationItem {
@@ -45,8 +45,9 @@ Kirigami.ApplicationItem {
         newStuffPage.showEntryDetails(providerId, entryId);
     }
 
-    Layout.preferredWidth: Kirigami.Units.gridUnit * 50
-    Layout.preferredHeight: Kirigami.Units.gridUnit * 40
+    // Keep in sync with the default sizes in Dialog.qml and dialog.cpp
+    implicitWidth: Kirigami.Units.gridUnit * 44
+    implicitHeight: Kirigami.Units.gridUnit * 30
 
     pageStack.defaultColumnWidth: pageStack.width
     pageStack.globalToolBar.style: Kirigami.ApplicationHeaderStyle.Auto
diff -pruN 6.0.0-3/src/qtquick/qml/DownloadItemsSheet.qml 6.3.0-1/src/qtquick/qml/DownloadItemsSheet.qml
--- 6.0.0-3/src/qtquick/qml/DownloadItemsSheet.qml	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/src/qtquick/qml/DownloadItemsSheet.qml	2024-05-31 13:26:56.000000000 +0000
@@ -8,7 +8,7 @@
 import QtQuick
 import QtQuick.Controls as QQC2
 import QtQuick.Layouts
-import org.kde.kirigami 2 as Kirigami
+import org.kde.kirigami as Kirigami
 import org.kde.kirigami.delegates as KirigamiDelegates
 import org.kde.newstuff as NewStuff
 
@@ -18,21 +18,27 @@ import org.kde.newstuff as NewStuff
  * This is used by the NewStuff.Page component
  * @since 5.63
  */
-Kirigami.OverlaySheet {
+Kirigami.Dialog {
     id: component
 
     property var entry
 
+    // Ensure the dialog does not get too small
+    height: Math.max(Math.round(root.height - (root.height / 4)), Kirigami.Units.gridUnit  * 20)
+    width: Math.max(Math.round(root.width - (root.width / 4)), Kirigami.Units.gridUnit  * 25)
+
     property alias downloadLinks: itemsView.model
 
     signal itemPicked(var entry, int downloadItemId, string downloadName)
 
-    showCloseButton: true
+    showCloseButton: false
     title: i18nd("knewstuff6", "Pick Your Installation Option")
 
     ListView {
         id: itemsView
 
+        clip: true
+
         headerPositioning: ListView.InlineHeader
         header: QQC2.Label {
             width: ListView.view.width - ListView.view.leftMargin - ListView.view.rightMargin
@@ -50,6 +56,8 @@ Kirigami.OverlaySheet {
             icon.name: modelData.icon
             text: modelData.name
 
+            Kirigami.Theme.useAlternateBackgroundColor: true
+
             // Don't need a highlight, hover, or pressed effects
             highlighted: false
             hoverEnabled: false
@@ -66,6 +74,7 @@ Kirigami.OverlaySheet {
                     icon.name: delegate.icon.name
                     title: delegate.text
                     selected: delegate.highlighted
+                    wrapMode: Text.WrapAnywhere
                 }
                 QQC2.Label {
                     text: modelData.formattedSize
diff -pruN 6.0.0-3/src/qtquick/qml/EntryDetails.qml 6.3.0-1/src/qtquick/qml/EntryDetails.qml
--- 6.0.0-3/src/qtquick/qml/EntryDetails.qml	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/src/qtquick/qml/EntryDetails.qml	2024-05-31 13:26:56.000000000 +0000
@@ -17,13 +17,13 @@ import QtQuick
 import QtQuick.Controls as QQC2
 import QtQuick.Layouts
 
-import org.kde.kirigami 2 as Kirigami
-import org.kde.kcmutils as KCM
+import org.kde.kirigami as Kirigami
+import org.kde.kcmutils as KCMUtils
 import org.kde.newstuff as NewStuff
 
 import "private" as Private
 
-KCM.SimpleKCM {
+KCMUtils.SimpleKCM {
     id: component
 
     property QtObject newStuffModel
@@ -82,7 +82,9 @@ KCM.SimpleKCM {
     NewStuff.DownloadItemsSheet {
         id: downloadItemsSheet
 
-        onItemPicked: {
+        parent: component.QQC2.Overlay.overlay
+
+        onItemPicked: (entry, downloadItemId, downloadName) => {
             const entryName = newStuffModel.data(newStuffModel.index(entryId, 0), NewStuff.ItemsModel.NameRole);
             applicationWindow().showPassiveNotification(i18ndc("knewstuff6", "A passive notification shown when installation of an item is initiated", "Installing %1 from %2", downloadName, entryName), 1500);
             newStuffModel.engine.install(component.entry, downloadItemId);
@@ -105,10 +107,13 @@ KCM.SimpleKCM {
 
     actions: [
         Kirigami.Action {
-            text: component.downloadLinks.length == 1 ? i18ndc("knewstuff6", "Request installation of this item, available when there is exactly one downloadable item", "Install") : i18ndc("knewstuff6", "Show installation options, where there is more than one downloadable item", "Install…")
+            text: component.downloadLinks.length === 1
+                ? i18ndc("knewstuff6", "Request installation of this item, available when there is exactly one downloadable item", "Install")
+                : i18ndc("knewstuff6", "Show installation options, where there is more than one downloadable item", "Install…")
+
             icon.name: "install"
-            onTriggered: {
-                if (component.downloadLinks.length == 1) {
+            onTriggered: source => {
+                if (component.downloadLinks.length === 1) {
                     newStuffModel.engine.install(component.entry, NewStuff.ItemsModel.FirstLinkId);
                 } else {
                     downloadItemsSheet.downloadLinks = component.downloadLinks;
@@ -116,21 +121,21 @@ KCM.SimpleKCM {
                     downloadItemsSheet.open();
                 }
             }
-            enabled: component.status == NewStuff.Entry.Downloadable || component.status == NewStuff.Entry.Deleted
+            enabled: component.status === NewStuff.Entry.Downloadable || component.status === NewStuff.Entry.Deleted
             visible: enabled
         },
         Kirigami.Action {
             text: i18ndc("knewstuff6", "Request updating of this item", "Update")
             icon.name: "update-none"
-            onTriggered: newStuffModel.update(component.entry, NewStuff.ItemsModel.AutoDetectLinkId)
-            enabled: component.status == NewStuff.Entry.Updateable
+            onTriggered: source => newStuffModel.update(component.entry, NewStuff.ItemsModel.AutoDetectLinkId)
+            enabled: component.status === NewStuff.Entry.Updateable
             visible: enabled
         },
         Kirigami.Action {
             text: i18ndc("knewstuff6", "Request uninstallation of this item", "Uninstall")
             icon.name: "edit-delete"
-            onTriggered: newStuffModel.engine.uninstall(component.entry)
-            enabled: component.status == NewStuff.Entry.Installed || component.status == NewStuff.Entry.Updateable
+            onTriggered: source => newStuffModel.engine.uninstall(component.entry)
+            enabled: component.status === NewStuff.Entry.Installed || component.status === NewStuff.Entry.Updateable
             visible: enabled
         }
     ]
@@ -177,7 +182,7 @@ KCM.SimpleKCM {
                     Layout.fillWidth: true
                     text: statusCard.message
                     wrapMode: Text.Wrap
-                    onLinkActivated: Qt.openUrlExternally(link);
+                    onLinkActivated: link => Qt.openUrlExternally(link)
                 }
 
                 QQC2.BusyIndicator {
@@ -209,7 +214,7 @@ KCM.SimpleKCM {
                 Kirigami.FormData.label: i18nd("knewstuff6", "Comments and Reviews:")
                 enabled: component.commentsCount > 0
                 text: i18ndc("knewstuff6", "A link which, when clicked, opens a new sub page with comments (comments with or without ratings) for this entry", "%1 Reviews and Comments", component.commentsCount)
-                onClicked: pageStack.push(commentsPage)
+                onClicked: mouse => pageStack.push(commentsPage)
             }
 
             Private.Rating {
@@ -222,14 +227,14 @@ KCM.SimpleKCM {
                 Kirigami.FormData.label: i18nd("knewstuff6", "Homepage:")
                 text: i18ndc("knewstuff6", "A link which, when clicked, opens the website associated with the entry (this could be either one specific to the project, the author's homepage, or any other website they have chosen for the purpose)", "Open the homepage for %1", component.name)
                 url: component.homepage
-                visible: component.homepage
+                visible: url !== ""
             }
 
             Kirigami.UrlButton {
                 Kirigami.FormData.label: i18nd("knewstuff6", "How To Donate:")
                 text: i18ndc("knewstuff6", "A link which, when clicked, opens a website with information on donation in support of the entry", "Find out how to donate to this project")
                 url: component.donationLink
-                visible: component.donationLink
+                visible: url !== ""
             }
         }
 
diff -pruN 6.0.0-3/src/qtquick/qml/Page.qml 6.3.0-1/src/qtquick/qml/Page.qml
--- 6.0.0-3/src/qtquick/qml/Page.qml	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/src/qtquick/qml/Page.qml	2024-05-31 13:26:56.000000000 +0000
@@ -17,14 +17,14 @@ import QtQuick
 import QtQuick.Controls as QQC2
 import QtQuick.Layouts
 
-import org.kde.kcmutils as KCM
-import org.kde.kirigami 2 as Kirigami
+import org.kde.kcmutils as KCMUtils
+import org.kde.kirigami as Kirigami
 import org.kde.newstuff as NewStuff
 
 import "private" as Private
 import "private/entrygriddelegates" as EntryGridDelegates
 
-KCM.GridViewKCM {
+KCMUtils.GridViewKCM {
     id: root
 
     /**
@@ -129,24 +129,25 @@ KCM.GridViewKCM {
 
     title: newStuffEngine.name
 
-    view.header: Item {
-        implicitWidth: view.width - Kirigami.Units.gridUnit
-        implicitHeight: Kirigami.Units.gridUnit * 3
+    headerPaddingEnabled: false
+    header: Kirigami.InlineMessage {
+        readonly property bool riskyContent: newStuffEngine.contentWarningType === NewStuff.Engine.Executables
         visible: !loadingOverlay.visible
-
-        Kirigami.InlineMessage {
-            anchors.fill: parent
-            anchors.margins: Kirigami.Units.smallSpacing
-            visible: true
-            text: i18nd("knewstuff6", "The content available here has been uploaded by users like you, and has not been reviewed by your distributor for functionality or stability.")
-        }
+        type: riskyContent ? Kirigami.MessageType.Warning : Kirigami.MessageType.Information
+        position: Kirigami.InlineMessage.Position.Header
+        text: riskyContent
+            ? xi18nd("knewstuff6", "Use caution when accessing user-created content shown here, as it may contain executable code that hasn't been tested by KDE or your distributor for safety, stability, or quality")
+            : i18nd("knewstuff6", "User-created content shown here hasn't been tested by KDE or your distributor for functionality or quality.")
     }
 
     NewStuff.Engine {
         id: newStuffEngine
     }
 
-    NewStuff.QuestionAsker {}
+    NewStuff.QuestionAsker {
+        parent: root.QQC2.Overlay.overlay
+    }
+
     Private.ErrorDisplayer {
         engine: newStuffEngine
         active: root.isCurrentPage
@@ -189,7 +190,9 @@ KCM.GridViewKCM {
             Kirigami.Action {
                 icon.name: "view-list-details"
                 text: i18nd("knewstuff6", "Detailed Tiles View Mode")
-                onTriggered: { root.viewMode = Page.ViewMode.Tiles; }
+                onTriggered: source => {
+                    root.viewMode = Page.ViewMode.Tiles;
+                }
                 checked: root.viewMode === Page.ViewMode.Tiles
                 checkable: true
                 QQC2.ActionGroup.group: viewModeActionGroup
@@ -198,7 +201,9 @@ KCM.GridViewKCM {
             Kirigami.Action {
                 icon.name: "view-list-icons"
                 text: i18nd("knewstuff6", "Icons Only View Mode")
-                onTriggered: { root.viewMode = Page.ViewMode.Icons; }
+                onTriggered: source => {
+                    root.viewMode = Page.ViewMode.Icons;
+                }
                 checked: root.viewMode === Page.ViewMode.Icons
                 checkable: true
                 QQC2.ActionGroup.group: viewModeActionGroup
@@ -207,7 +212,9 @@ KCM.GridViewKCM {
             Kirigami.Action {
                 icon.name: "view-preview"
                 text: i18nd("knewstuff6", "Large Preview View Mode")
-                onTriggered: { root.viewMode = Page.ViewMode.Preview; }
+                onTriggered: source => {
+                    root.viewMode = Page.ViewMode.Preview;
+                }
                 checked: root.viewMode === Page.ViewMode.Preview
                 checkable: true
                 QQC2.ActionGroup.group: viewModeActionGroup
@@ -244,7 +251,9 @@ KCM.GridViewKCM {
                 text: i18ndc("knewstuff6", "List option which will set the filter to show everything", "Show All Entries")
                 checkable: true
                 checked: newStuffEngine.filter === 0
-                onTriggered: { newStuffEngine.filter = 0; }
+                onTriggered: source => {
+                    newStuffEngine.filter = 0;
+                }
                 QQC2.ActionGroup.group: viewFilterActionGroup
             }
 
@@ -253,7 +262,9 @@ KCM.GridViewKCM {
                 text: i18ndc("knewstuff6", "List option which will set the filter so only installed items are shown", "Show Only Installed Entries")
                 checkable: true
                 checked: newStuffEngine.filter === 1
-                onTriggered: { newStuffEngine.filter = 1; }
+                onTriggered: source => {
+                    newStuffEngine.filter = 1;
+                }
                 QQC2.ActionGroup.group: viewFilterActionGroup
             }
 
@@ -262,7 +273,9 @@ KCM.GridViewKCM {
                 text: i18ndc("knewstuff6", "List option which will set the filter so only installed items with updates available are shown", "Show Only Updateable Entries")
                 checkable: true
                 checked: newStuffEngine.filter === 2
-                onTriggered: { newStuffEngine.filter = 2; }
+                onTriggered: source => {
+                    newStuffEngine.filter = 2;
+                }
                 QQC2.ActionGroup.group: viewFilterActionGroup
             }
         },
@@ -299,7 +312,9 @@ KCM.GridViewKCM {
                 text: i18ndc("knewstuff6", "List option which will set the sort order to based on when items were most recently updated", "Show Most Recent First")
                 checkable: true
                 checked: newStuffEngine.sortOrder === 0
-                onTriggered: { newStuffEngine.sortOrder = 0; }
+                onTriggered: source => {
+                    newStuffEngine.sortOrder = 0;
+                }
                 QQC2.ActionGroup.group: viewSortingActionGroup
             }
 
@@ -308,7 +323,9 @@ KCM.GridViewKCM {
                 text: i18ndc("knewstuff6", "List option which will set the sort order to be alphabetical based on the name", "Sort Alphabetically By Name")
                 checkable: true
                 checked: newStuffEngine.sortOrder === 1
-                onTriggered: { newStuffEngine.sortOrder = 1; }
+                onTriggered: source => {
+                    newStuffEngine.sortOrder = 1;
+                }
                 QQC2.ActionGroup.group: viewSortingActionGroup
             }
 
@@ -317,7 +334,9 @@ KCM.GridViewKCM {
                 text: i18ndc("knewstuff6", "List option which will set the sort order to based on user ratings", "Show Highest Rated First")
                 checkable: true
                 checked: newStuffEngine.sortOrder === 2
-                onTriggered: { newStuffEngine.sortOrder = 2; }
+                onTriggered: source => {
+                    newStuffEngine.sortOrder = 2;
+                }
                 QQC2.ActionGroup.group: viewSortingActionGroup
             }
 
@@ -326,7 +345,9 @@ KCM.GridViewKCM {
                 text: i18ndc("knewstuff6", "List option which will set the sort order to based on number of downloads", "Show Most Downloaded First")
                 checkable: true
                 checked: newStuffEngine.sortOrder === 3
-                onTriggered: { newStuffEngine.sortOrder = 3; }
+                onTriggered: source => {
+                    newStuffEngine.sortOrder = 3;
+                }
                 QQC2.ActionGroup.group: viewSortingActionGroup
             }
         },
@@ -339,7 +360,7 @@ KCM.GridViewKCM {
             icon.name: "upload-media"
             visible: newStuffEngine.uploadEnabled
 
-            onTriggered: {
+            onTriggered: source => {
                 pageStack.push(uploadPage);
             }
         },
@@ -388,7 +409,7 @@ KCM.GridViewKCM {
             text: model.displayName
             icon.name: model.iconName
 
-            onTriggered: {
+            onTriggered: source => {
                 const curIndex = newStuffEngine.searchPresetModel.index(index, 0);
                 newStuffEngine.searchPresetModel.loadSearch(curIndex);
             }
@@ -454,6 +475,8 @@ KCM.GridViewKCM {
     NewStuff.DownloadItemsSheet {
         id: downloadItemsSheet
 
+        parent: root.QQC2.Overlay.overlay
+
         onItemPicked: (entry, downloadItemId) => {
             newStuffModel.engine.install(entry, downloadItemId);
         }
@@ -504,7 +527,7 @@ KCM.GridViewKCM {
     Component {
         id: tileDelegate
 
-        EntryGridDelegates.TileDelegate  {
+        EntryGridDelegates.TileDelegate {
             useLabel: root.useLabel
             uninstallLabel: root.uninstallLabel
         }
@@ -537,7 +560,7 @@ KCM.GridViewKCM {
         id: loadingOverlay
 
         anchors.fill: parent
-        
+
         opacity: newStuffEngine.isLoading && !newStuffEngine.needsLazyLoadSpinner ? 1 : 0
         Behavior on opacity {
             NumberAnimation {
diff -pruN 6.0.0-3/src/qtquick/qml/QuestionAsker.qml 6.3.0-1/src/qtquick/qml/QuestionAsker.qml
--- 6.0.0-3/src/qtquick/qml/QuestionAsker.qml	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/src/qtquick/qml/QuestionAsker.qml	2024-05-31 13:26:56.000000000 +0000
@@ -17,7 +17,7 @@
 import QtQuick
 import QtQuick.Controls as QQC2
 import QtQuick.Layouts
-import org.kde.kirigami 2 as Kirigami
+import org.kde.kirigami as Kirigami
 import org.kde.newstuff as NewStuff
 import org.kde.newstuff.core as NewStuffCore
 
@@ -26,7 +26,7 @@ QQC2.Dialog {
 
     property int questionType
 
-    anchors.centerIn: QQC2.Overlay.overlay
+    anchors.centerIn: parent
 
     modal: true
     focus: true
@@ -98,7 +98,7 @@ QQC2.Dialog {
 
     function passResponse(responseIsContinue) {
         let input = "";
-        switch(dialog.questionType) {
+        switch (dialog.questionType) {
         case NewStuffCore.Question.SelectFromListQuestion:
             input = listView.currentItem.text;
             listView.model.clear();
@@ -127,7 +127,13 @@ QQC2.Dialog {
     ColumnLayout {
         id: layout
 
-        property int maxWidth: applicationWindow().width - (dialog.leftPadding + dialog.leftMargin + dialog.rightMargin + dialog.rightPadding)
+        readonly property real maxWidth: {
+            const bounds = dialog.parent;
+            if (!bounds) {
+                return 0;
+            }
+            return bounds.width - (dialog.leftPadding + dialog.leftMargin + dialog.rightMargin + dialog.rightPadding);
+        }
 
         anchors.fill: parent
         spacing: Kirigami.Units.smallSpacing
@@ -140,10 +146,9 @@ QQC2.Dialog {
 
         ListView {
             id: listView
-
+            spacing: Kirigami.Units.smallSpacing
             Layout.maximumWidth: layout.maxWidth
             Layout.fillWidth: true
-            Layout.minimumHeight: Kirigami.Units.gridUnit * 6
 
             visible: false
 
diff -pruN 6.0.0-3/src/qtquick/qml/UploadPage.qml 6.3.0-1/src/qtquick/qml/UploadPage.qml
--- 6.0.0-3/src/qtquick/qml/UploadPage.qml	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/src/qtquick/qml/UploadPage.qml	2024-05-31 13:26:56.000000000 +0000
@@ -24,8 +24,7 @@
 import QtQuick
 import QtQuick.Controls as QQC2
 import QtQuick.Layouts
-import org.kde.kcmutils as KCM
-import org.kde.kirigami 2 as Kirigami
+import org.kde.kirigami as Kirigami
 import org.kde.newstuff as NewStuff
 
 import "private" as Private
@@ -50,7 +49,9 @@ Kirigami.ScrollablePage {
 
     title: i18nc("@knewstuff6", "Upload New Stuff: %1", component.engine.name)
 
-    NewStuff.QuestionAsker { }
+    NewStuff.QuestionAsker {
+        parent: component.QQC2.Overlay.overlay
+    }
 
     Private.ErrorDisplayer {
         engine: component.engine
@@ -113,7 +114,7 @@ Kirigami.ScrollablePage {
 
         Repeater {
             model: NewStuff.ProvidersModel {
-                engine: component.engine.engine
+                engine: component.engine
             }
 
             Kirigami.Card {
@@ -122,7 +123,7 @@ Kirigami.ScrollablePage {
                 banner {
                     title: {
                         if (model.name === "api.kde-look.org") {
-                            return  i18ndc("knewstuff6", "The name of the KDE Store", "KDE Store");
+                            return i18ndc("knewstuff6", "The name of the KDE Store", "KDE Store");
                         } else if (model.name !== "") {
                             return model.name;
                         } else if (component.engine.name !== "") {
@@ -131,27 +132,31 @@ Kirigami.ScrollablePage {
                             return i18ndc("knewstuff6", "An unnamed provider", "Your Provider");
                         }
                     }
-                    titleIcon: model.icon == "" ? "get-hot-new-stuff" : model.icon
+                    titleIcon: model.icon.toString() === "" ? "get-hot-new-stuff" : model.icon
                 }
 
                 actions: [
                     Kirigami.Action {
-                        visible: model.website != ""
+                        visible: model.website !== ""
                         text: i18ndc("knewstuff6", "Text for an action which causes the specified website to be opened using the user's system default browser", "Open Website: %1", model.website)
-                        onTriggered: Qt.openUrlExternally(model.website)
+                        onTriggered: source => {
+                            Qt.openUrlExternally(model.website);
+                        }
                     },
 
                     Kirigami.Action {
-                        visible: model.contactEmail != "" && model.name != "api.kde-look.org"
+                        visible: model.contactEmail !== "" && model.name !== "api.kde-look.org"
                         text: i18ndc("knewstuff6", "Text for an action which will attempt to send an email using the user's system default email client", "Send Email To: %1", model.contactEmail)
-                        onTriggered: Qt.openUrlExternally("mailto:" + model.contactEmail)
+                        onTriggered: source => {
+                            Qt.openUrlExternally("mailto:" + model.contactEmail);
+                        }
                     }
                 ]
 
                 contentItem: QQC2.Label {
                     wrapMode: Text.Wrap
                     text: model.name === "api.kde-look.org"
-                        ? i18ndc("knewstuff6", "A description of how to upload content to a generic provider", "To upload new entries, or to add content to an existing entry on the KDE Store, please open the website and log in. Once you have done this, you will be able to find the My Products entry in the menu which pops up when you click your user icon. Click on this entry to go to the product management system, where you can work on your products .")
+                        ? i18ndc("knewstuff6", "A description of how to upload content to a generic provider", "To upload new entries, or to add content to an existing entry on the KDE Store, please open the website and log in. Once you have done this, you will be able to find the My Products entry in the menu which pops up when you click your user icon. Click on this entry to go to the product management system, where you can work on your products.")
                         : i18ndc("knewstuff6", "A description of how to upload content to the KDE Store specifically", "To upload new entries, or to add content to an existing entry, please open the provider's website and follow the instructions there. You will likely need to create a user and log in to a product management system, where you will need to follow the instructions for how to add. Alternatively, you might be required to contact the managers of the site directly to get new content added.")
                 }
             }
diff -pruN 6.0.0-3/src/qtquick/qml/private/ConditionalLoader.qml 6.3.0-1/src/qtquick/qml/private/ConditionalLoader.qml
--- 6.0.0-3/src/qtquick/qml/private/ConditionalLoader.qml	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/src/qtquick/qml/private/ConditionalLoader.qml	2024-05-31 13:26:56.000000000 +0000
@@ -4,18 +4,15 @@
     SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
-import QtQuick 2.11
-import QtQuick.Layouts 1.11
-
-Loader
-{
-    id: root
+import QtQuick
+import QtQuick.Layouts
 
+Loader {
     property Component componentTrue
     property Component componentFalse
     property bool condition
 
-    Layout.minimumHeight: item && item.Layout ? item.Layout.minimumHeight : 0
-    Layout.minimumWidth: item && item.Layout ? item.Layout.minimumWidth : 0
+    Layout.minimumHeight: item ? item.Layout.minimumHeight : 0
+    Layout.minimumWidth: item ? item.Layout.minimumWidth : 0
     sourceComponent: condition ? componentTrue : componentFalse
 }
diff -pruN 6.0.0-3/src/qtquick/qml/private/EntryCommentDelegate.qml 6.3.0-1/src/qtquick/qml/private/EntryCommentDelegate.qml
--- 6.0.0-3/src/qtquick/qml/private/EntryCommentDelegate.qml	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/src/qtquick/qml/private/EntryCommentDelegate.qml	2024-05-31 13:26:56.000000000 +0000
@@ -8,15 +8,15 @@
  * @brief A card based delegate for showing a comment from a KNewStuffQuick::QuickCommentsModel
  */
 
-import QtQuick 2.11
-import QtQuick.Controls 2.11 as QtControls
-import QtQuick.Layouts 1.11 as QtLayouts
+import QtQuick
+import QtQuick.Controls as QQC2
+import QtQuick.Layouts
 
-import org.kde.kirigami 2.7 as Kirigami
+import org.kde.kirigami as Kirigami
 
-import org.kde.newstuff 1.62 as NewStuff
+import org.kde.newstuff as NewStuff
 
-QtLayouts.RowLayout {
+RowLayout {
     id: component
 
     /**
@@ -63,20 +63,13 @@ QtLayouts.RowLayout {
         username: component.author
     }
 
-    anchors {
-        left: parent.left
-        right: parent.right
-        leftMargin: Kirigami.Units.largeSpacing
-        rightMargin: Kirigami.Units.largeSpacing
-    }
-
     Repeater {
         model: component.depth
         delegate: Rectangle {
-            QtLayouts.Layout.fillHeight: true
-            QtLayouts.Layout.minimumWidth: Kirigami.Units.largeSpacing
-            QtLayouts.Layout.maximumWidth: Kirigami.Units.largeSpacing
-            color: Qt.tint(Kirigami.Theme.textColor, Qt.rgba(Kirigami.Theme.backgroundColor.r, Kirigami.Theme.backgroundColor.g, Kirigami.Theme.backgroundColor.b, 0.8))
+            Layout.fillHeight: true
+            Layout.minimumWidth: Kirigami.Units.largeSpacing
+            Layout.maximumWidth: Kirigami.Units.largeSpacing
+            color: Qt.tint(Kirigami.Theme.textColor, Qt.alpha(Kirigami.Theme.backgroundColor, 0.8))
             Rectangle {
                 anchors {
                     top: parent.top
@@ -89,27 +82,27 @@ QtLayouts.RowLayout {
         }
     }
 
-    QtLayouts.ColumnLayout {
+    ColumnLayout {
         Item {
             visible: component.depth === 0
-            QtLayouts.Layout.fillWidth: true
-            QtLayouts.Layout.minimumHeight: Kirigami.Units.largeSpacing
-            QtLayouts.Layout.maximumHeight: Kirigami.Units.largeSpacing
+            Layout.fillWidth: true
+            Layout.minimumHeight: Kirigami.Units.largeSpacing
+            Layout.maximumHeight: Kirigami.Units.largeSpacing
         }
 
         Kirigami.Separator {
-            QtLayouts.Layout.fillWidth: true
+            Layout.fillWidth: true
         }
 
-        QtLayouts.RowLayout {
+        RowLayout {
             visible: (component.title !== "" || component.score !== 0)
-            QtLayouts.Layout.fillWidth: true
-            QtLayouts.Layout.leftMargin: Kirigami.Units.largeSpacing
+            Layout.fillWidth: true
+            Layout.leftMargin: Kirigami.Units.largeSpacing
             Kirigami.Heading {
                 id: titleLabel
                 text: ((component.title === "") ? i18ndc("knewstuff6", "Placeholder title for when a comment has no subject, but does have a rating", "<i>(no title)</i>") : component.title)
                 level: 4
-                QtLayouts.Layout.fillWidth: true
+                Layout.fillWidth: true
             }
             Rating {
                 id: ratingStars
@@ -117,59 +110,60 @@ QtLayouts.RowLayout {
                 reverseLayout: true
             }
             Item {
-                QtLayouts.Layout.minimumWidth: Kirigami.Units.largeSpacing
-                QtLayouts.Layout.maximumWidth: Kirigami.Units.largeSpacing
+                Layout.minimumWidth: Kirigami.Units.largeSpacing
+                Layout.maximumWidth: Kirigami.Units.largeSpacing
             }
         }
 
-        QtControls.Label {
+        QQC2.Label {
             id: reviewLabel
-            QtLayouts.Layout.fillWidth: true
-            QtLayouts.Layout.leftMargin: Kirigami.Units.largeSpacing
-            QtLayouts.Layout.rightMargin: Kirigami.Units.largeSpacing
+            Layout.fillWidth: true
+            Layout.leftMargin: Kirigami.Units.largeSpacing
+            Layout.rightMargin: Kirigami.Units.largeSpacing
             wrapMode: Text.Wrap
         }
 
-        QtLayouts.RowLayout {
-            QtLayouts.Layout.fillWidth: true
+        RowLayout {
+            Layout.fillWidth: true
             Item {
-                QtLayouts.Layout.fillWidth: true
+                Layout.fillWidth: true
             }
             Kirigami.UrlButton {
                 id: authorLabel
-                visible: (url !== "")
+                visible: url !== ""
                 url: (component.commentAuthor.homepage === "") ? component.commentAuthor.profilepage : component.commentAuthor.homepage
-                text: (component.author === component.entryAuthorId) ? i18ndc("knewstuff6", "The author label in case the comment was written by the author of the content entry the comment is attached to", "%1 <i>(author)</i>", component.commentAuthor.name) : component.commentAuthor.name
+                text: (component.author === component.entryAuthorId)
+                    ? i18ndc("knewstuff6", "The author label in case the comment was written by the author of the content entry the comment is attached to", "%1 <i>(author)</i>", component.commentAuthor.name)
+                    : component.commentAuthor.name
             }
-            QtControls.Label {
+            QQC2.Label {
                 visible: !authorLabel.visible
                 text: authorLabel.text
             }
             Image {
                 id: authorIcon
-                QtLayouts.Layout.maximumWidth: height
-                QtLayouts.Layout.minimumWidth: height
-                QtLayouts.Layout.preferredHeight: Kirigami.Units.iconSizes.medium
+                Layout.maximumWidth: height
+                Layout.minimumWidth: height
+                Layout.preferredHeight: Kirigami.Units.iconSizes.medium
                 fillMode: Image.PreserveAspectFit
                 source: component.commentAuthor.avatarUrl
                 Kirigami.Icon {
                     anchors.fill: parent;
                     source: "user"
                     visible: opacity > 0
-                    opacity: authorIcon.status == Image.Ready ? 0 : 1
+                    opacity: authorIcon.status === Image.Ready ? 0 : 1
                     Behavior on opacity { NumberAnimation { duration: Kirigami.Units.shortDuration; } }
                 }
             }
             Item {
-                QtLayouts.Layout.minimumWidth: Kirigami.Units.largeSpacing
-                QtLayouts.Layout.maximumWidth: Kirigami.Units.largeSpacing
+                Layout.minimumWidth: Kirigami.Units.largeSpacing
+                Layout.maximumWidth: Kirigami.Units.largeSpacing
             }
         }
         Item {
-            QtLayouts.Layout.fillWidth: true
-            QtLayouts.Layout.minimumHeight: Kirigami.Units.largeSpacing
-            QtLayouts.Layout.maximumHeight: Kirigami.Units.largeSpacing
+            Layout.fillWidth: true
+            Layout.minimumHeight: Kirigami.Units.largeSpacing
+            Layout.maximumHeight: Kirigami.Units.largeSpacing
         }
-
     }
 }
diff -pruN 6.0.0-3/src/qtquick/qml/private/EntryCommentsPage.qml 6.3.0-1/src/qtquick/qml/private/EntryCommentsPage.qml
--- 6.0.0-3/src/qtquick/qml/private/EntryCommentsPage.qml	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/src/qtquick/qml/private/EntryCommentsPage.qml	2024-05-31 13:26:56.000000000 +0000
@@ -8,49 +8,59 @@
  * @brief A Kirigami.Page component used for displaying a NewStuff entry's comments
  */
 
-import QtQuick 2.11
-import QtQuick.Controls 2.11 as QtControls
-import QtQuick.Layouts 1.11 as QtLayouts
+import QtQuick
+import QtQuick.Layouts
 
-import org.kde.kirigami 2.7 as Kirigami
+import org.kde.kirigami as Kirigami
 
-import org.kde.newstuff 1.62 as NewStuff
+import org.kde.newstuff as NewStuff
 
 Kirigami.ScrollablePage {
     id: component
+
     property string entryName
     property string entryAuthorId
     property string entryProviderId
     property alias entry: commentsModel.entry
     property alias itemsModel: commentsModel.itemsModel
+
     title: i18ndc("knewstuff6", "Title for the page containing a view of the comments for the entry", "Comments and Reviews for %1", component.entryName)
     actions: [
         Kirigami.Action {
             text: i18ndc("knewstuff6", "Title for the item which is checked when all comments should be shown", "Show All Comments")
-            checked: commentsModel.includedComments == NewStuff.CommentsModel.IncludeAllComments
+            checked: commentsModel.includedComments === NewStuff.CommentsModel.IncludeAllComments
             checkable: true
-            onTriggered: commentsModel.includedComments = NewStuff.CommentsModel.IncludeAllComments
+            onTriggered: source => {
+                commentsModel.includedComments = NewStuff.CommentsModel.IncludeAllComments;
+            }
         },
         Kirigami.Action {
             text: i18ndc("knewstuff6", "Title for the item which is checked when only comments which are reviews should be shown", "Show Reviews Only")
-            checked: commentsModel.includedComments == NewStuff.CommentsModel.IncludeOnlyReviews
+            checked: commentsModel.includedComments === NewStuff.CommentsModel.IncludeOnlyReviews
             checkable: true
-            onTriggered: commentsModel.includedComments = NewStuff.CommentsModel.IncludeOnlyReviews
+            onTriggered: source => {
+                commentsModel.includedComments = NewStuff.CommentsModel.IncludeOnlyReviews;
+            }
         },
         Kirigami.Action {
             text: i18ndc("knewstuff6", "Title for the item which is checked when comments which are reviews, and their children should be shown", "Show Reviews and Replies")
-            checked: commentsModel.includedComments == NewStuff.CommentsModel.IncludeReviewsAndReplies
+            checked: commentsModel.includedComments === NewStuff.CommentsModel.IncludeReviewsAndReplies
             checkable: true
-            onTriggered: commentsModel.includedComments = NewStuff.CommentsModel.IncludeReviewsAndReplies
+            onTriggered: source => {
+                commentsModel.includedComments = NewStuff.CommentsModel.IncludeReviewsAndReplies;
+            }
         }
     ]
-    ErrorDisplayer { engine: component.itemsModel.engine; active: component.isCurrentPage; }
+    ErrorDisplayer {
+        engine: component.itemsModel.engine
+        active: component.isCurrentPage
+    }
     ListView {
         id: commentsView
         model: NewStuff.CommentsModel {
             id: commentsModel
         }
-        QtLayouts.Layout.fillWidth: true
+        Layout.fillWidth: true
         header: Item {
             anchors {
                 left: parent.left
@@ -58,7 +68,15 @@ Kirigami.ScrollablePage {
             }
             height: Kirigami.Units.largeSpacing
         }
+
+        leftMargin: Kirigami.Units.largeSpacing
+        rightMargin: Kirigami.Units.largeSpacing
+
         delegate: EntryCommentDelegate {
+            width: {
+                const view = ListView.view;
+                return view ? view.width - view.leftMargin - view.rightMargin : 0;
+            }
             engine: component.itemsModel.engine
             entryAuthorId: component.entryAuthorId
             entryProviderId: component.entryProviderId
diff -pruN 6.0.0-3/src/qtquick/qml/private/EntryScreenshots.qml 6.3.0-1/src/qtquick/qml/private/EntryScreenshots.qml
--- 6.0.0-3/src/qtquick/qml/private/EntryScreenshots.qml	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/src/qtquick/qml/private/EntryScreenshots.qml	2024-05-31 13:26:56.000000000 +0000
@@ -6,38 +6,45 @@
 */
 
 import QtQuick
-import QtQuick.Controls
+import QtQuick.Controls as QQC2
 import QtQuick.Layouts
-import Qt5Compat.GraphicalEffects
 
 import org.kde.kirigami as Kirigami
 
 Flickable {
     id: root
+
     property alias screenshotsModel: screenshotsRep.model
     readonly property alias count: screenshotsRep.count
     property int currentIndex: -1
     property Item currentItem: screenshotsRep.itemAt(currentIndex)
+
     Layout.preferredHeight: Kirigami.Units.gridUnit * 13
     contentHeight: height
     contentWidth: screenshotsLayout.width
 
-    Popup {
+    QQC2.Popup {
         id: overlay
-        parent: applicationWindow().Overlay.overlay
+        parent: applicationWindow().QQC2.Overlay.overlay
         modal: true
         clip: false
 
-        x: (parent.width - width)/2
-        y: (parent.height - height)/2
-        readonly property real proportion: overlayImage.sourceSize.width>1 ? overlayImage.sourceSize.height/overlayImage.sourceSize.width : 1
-        height: overlayImage.status == Image.Loading ? Kirigami.Units.gridUnit * 5 : Math.min(parent.height * 0.9, (parent.width * 0.9) * proportion, overlayImage.sourceSize.height)
-        width: height/proportion
+        x: (parent.width - width) / 2
+        y: (parent.height - height) / 2
+
+        readonly property real proportion: overlayImage.sourceSize.width > 1
+            ? overlayImage.sourceSize.height / overlayImage.sourceSize.width
+            : 1
+
+        height: overlayImage.status === Image.Loading
+            ? Kirigami.Units.gridUnit * 5
+            : Math.min(parent.height * 0.9, (parent.width * 0.9) * proportion, overlayImage.sourceSize.height)
+        width: height / proportion
 
-        BusyIndicator {
+        QQC2.BusyIndicator {
             id: indicator
             visible: running
-            running: overlayImage.status == Image.Loading
+            running: overlayImage.status === Image.Loading
             anchors.fill: parent
         }
 
@@ -50,7 +57,7 @@ Flickable {
             smooth: true
         }
 
-        Button {
+        QQC2.Button {
             anchors {
                 right: parent.left
                 verticalCenter: parent.verticalCenter
@@ -59,7 +66,7 @@ Flickable {
             visible: leftAction.visible
         }
 
-        Button {
+        QQC2.Button {
             anchors {
                 left: parent.right
                 verticalCenter: parent.verticalCenter
@@ -73,7 +80,9 @@ Flickable {
             icon.name: "arrow-left"
             enabled: overlay.visible && visible
             visible: root.currentIndex >= 1 && !indicator.running
-            onTriggered: root.currentIndex = (root.currentIndex - 1) % root.count
+            onTriggered: source => {
+                root.currentIndex = (root.currentIndex - 1) % root.count;
+            }
         }
 
         Kirigami.Action {
@@ -81,7 +90,9 @@ Flickable {
             icon.name: "arrow-right"
             enabled: overlay.visible && visible
             visible: root.currentIndex < (root.count - 1) && !indicator.running
-            onTriggered: root.currentIndex = (root.currentIndex + 1) % root.count
+            onTriggered: source => {
+                root.currentIndex = (root.currentIndex + 1) % root.count;
+            }
         }
     }
 
@@ -93,38 +104,48 @@ Flickable {
         rightPadding: spacing
         focus: overlay.visible
 
-        Keys.onLeftPressed:  if (leftAction.visible)  leftAction.trigger()
-        Keys.onRightPressed: if (rightAction.visible) rightAction.trigger()
+        Keys.onLeftPressed: event => {
+            if (leftAction.visible) {
+                leftAction.trigger();
+            }
+        }
+        Keys.onRightPressed: event => {
+            if (rightAction.visible) {
+                rightAction.trigger();
+            }
+        }
 
         Repeater {
             id: screenshotsRep
 
             delegate: MouseArea {
                 readonly property url imageSource: modelData
-                readonly property real proportion: thumbnail.sourceSize.width>1 ? thumbnail.sourceSize.height/thumbnail.sourceSize.width : 1
+                readonly property real proportion: thumbnail.sourceSize.width > 1
+                    ? thumbnail.sourceSize.height / thumbnail.sourceSize.width
+                    : 1
+
                 anchors.verticalCenter: parent.verticalCenter
-                width: Math.max(50, height/proportion)
+                width: Math.max(50, height / proportion)
                 height: screenshotsLayout.height - 2 * Kirigami.Units.largeSpacing
 
                 hoverEnabled: true
                 cursorShape: Qt.PointingHandCursor
 
-                onClicked: {
+                onClicked: mouse => {
                     root.currentIndex = index
                     overlay.open()
                 }
 
                 Kirigami.ShadowedRectangle {
-                    visible: thumbnail.status == Image.Ready
+                    visible: thumbnail.status === Image.Ready
                     anchors.fill: thumbnail
                     Kirigami.Theme.colorSet: Kirigami.Theme.View
                     shadow.size: Kirigami.Units.largeSpacing
                     shadow.color: Qt.rgba(0, 0, 0, 0.3)
                 }
 
-                BusyIndicator {
-                    visible: running
-                    running: thumbnail.status == Image.Loading
+                QQC2.BusyIndicator {
+                    running: thumbnail.status === Image.Loading
                     anchors.centerIn: parent
                 }
 
@@ -147,7 +168,7 @@ Flickable {
             bottom: parent.bottom
         }
         edge: Qt.LeftEdge
-        width: Math.max(0, Math.min(root.width/5, root.contentX))
+        width: Math.max(0, Math.min(root.width / 5, root.contentX))
     }
 
     readonly property var rightShadow: Shadow {
@@ -158,6 +179,6 @@ Flickable {
             bottom: parent.bottom
         }
         edge: Qt.RightEdge
-        width: Math.max(0, Math.min(root.contentWidth - root.contentX - root.width)/5)
+        width: Math.max(0, Math.min(root.contentWidth - root.contentX - root.width) / 5)
     }
 }
diff -pruN 6.0.0-3/src/qtquick/qml/private/ErrorDisplayer.qml 6.3.0-1/src/qtquick/qml/private/ErrorDisplayer.qml
--- 6.0.0-3/src/qtquick/qml/private/ErrorDisplayer.qml	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/src/qtquick/qml/private/ErrorDisplayer.qml	2024-05-31 13:26:56.000000000 +0000
@@ -15,8 +15,8 @@ Kirigami.PromptDialog {
     title: i18ndc("knewstuff6", "Title for a dialog box which shows error messages", "An Error Occurred");
     standardButtons: Kirigami.Dialog.NoButton
 
-    property bool active: true;
-    property QtObject engine;
+    property bool active: true
+    property QtObject engine
     property QtObject connection: Connections {
         target: engine
         function onErrorCode(errorCode, message, metadata) {
@@ -38,7 +38,7 @@ Kirigami.PromptDialog {
     onVisibleChanged: displayThrottle.start()
     property QtObject displayThrottle: Timer {
         interval: Kirigami.Units.shortDuration
-        onTriggered: showNextError();
+        onTriggered: showNextError()
     }
     function showNextError() {
         if (visible === false && errorsToShow.length > 0) {
diff -pruN 6.0.0-3/src/qtquick/qml/private/GridTileDelegate.qml 6.3.0-1/src/qtquick/qml/private/GridTileDelegate.qml
--- 6.0.0-3/src/qtquick/qml/private/GridTileDelegate.qml	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/src/qtquick/qml/private/GridTileDelegate.qml	2024-05-31 13:26:56.000000000 +0000
@@ -5,13 +5,12 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-import QtQuick 2.11
-import QtQuick.Controls 2.11 as Controls
-import QtQuick.Templates 2.11 as T2
-import QtQuick.Layouts 1.11
-import Qt5Compat.GraphicalEffects 6.0
+import QtQuick
+import QtQuick.Controls as QQC2
+import QtQuick.Layouts
+import QtQuick.Templates as T
 
-import org.kde.kirigami 2.12 as Kirigami
+import org.kde.kirigami as Kirigami
 
 /**
  * Base delegate for KControlmodules based on Grid views of thumbnails
@@ -20,7 +19,7 @@ import org.kde.kirigami 2.12 as Kirigami
  * from the KCM module
  * @inherits QtQuick.Templates.ItemDelegate
  */
-T2.ItemDelegate {
+T.ItemDelegate {
     id: delegate
 
     /**
@@ -68,7 +67,9 @@ T2.ItemDelegate {
     Kirigami.ShadowedRectangle {
         id: tile
         anchors.centerIn: parent
-        width: Kirigami.Settings.isMobile ? delegate.width - Kirigami.Units.gridUnit : Math.min(delegate.GridView.view.implicitCellWidth, delegate.width - Kirigami.Units.gridUnit)
+        width: Kirigami.Settings.isMobile
+            ? delegate.width - Kirigami.Units.gridUnit
+            : Math.min(delegate.GridView.view.implicitCellWidth, delegate.width - Kirigami.Units.gridUnit)
         height: Math.min(delegate.GridView.view.implicitCellHeight, delegate.height - Kirigami.Units.gridUnit)
         radius: Kirigami.Units.smallSpacing
         Kirigami.Theme.inherit: false
@@ -86,10 +87,7 @@ T2.ItemDelegate {
                 return Kirigami.Theme.highlightColor;
             } else */ if (parent.hovered) {
                 // Match appearance of hovered list items
-                return Qt.rgba(Kirigami.Theme.highlightColor.r,
-                               Kirigami.Theme.highlightColor.g,
-                               Kirigami.Theme.highlightColor.b,
-                               0.5);
+                return Qt.alpha(Kirigami.Theme.highlightColor, 0.5);
 
             } else {
                 return Kirigami.Theme.backgroundColor;
@@ -153,7 +151,7 @@ T2.ItemDelegate {
 
                     Repeater {
                         model: delegate.actions
-                        delegate: Controls.Button {
+                        delegate: QQC2.Button {
                             icon.name: modelData.iconName
                             text: modelData.text
                             activeFocusOnTab: focus || delegate.focus
@@ -161,10 +159,10 @@ T2.ItemDelegate {
                             enabled: modelData.enabled
                             visible: modelData.visible
                             //NOTE: there aren't any global settings where to take "official" tooltip timeouts
-                            Controls.ToolTip.delay: 1000
-                            Controls.ToolTip.timeout: 5000
-                            Controls.ToolTip.visible: (Kirigami.Settings.isMobile ? pressed : hovered) && modelData.tooltip.length > 0
-                            Controls.ToolTip.text: modelData.tooltip
+                            QQC2.ToolTip.delay: 1000
+                            QQC2.ToolTip.timeout: 5000
+                            QQC2.ToolTip.visible: (Kirigami.Settings.isMobile ? pressed : hovered) && modelData.tooltip.length > 0
+                            QQC2.ToolTip.text: modelData.tooltip
                         }
                     }
                 }
@@ -172,8 +170,8 @@ T2.ItemDelegate {
         }
     }
 
-    Controls.ToolTip.delay: 1000
-    Controls.ToolTip.timeout: 5000
-    Controls.ToolTip.visible: hovered && delegate.toolTip.length > 0
-    Controls.ToolTip.text: toolTip
+    QQC2.ToolTip.delay: 1000
+    QQC2.ToolTip.timeout: 5000
+    QQC2.ToolTip.visible: hovered && delegate.toolTip.length > 0
+    QQC2.ToolTip.text: toolTip
 }
diff -pruN 6.0.0-3/src/qtquick/qml/private/Rating.qml 6.3.0-1/src/qtquick/qml/private/Rating.qml
--- 6.0.0-3/src/qtquick/qml/private/Rating.qml	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/src/qtquick/qml/private/Rating.qml	2024-05-31 13:26:56.000000000 +0000
@@ -4,14 +4,13 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-import QtQuick 2.11
-import QtQuick.Layouts 1.11
-import QtQuick.Controls 2.11 as QtControls
+import QtQuick
+import QtQuick.Layouts
+import QtQuick.Controls as QQC2
 
-import org.kde.kirigami 2.0 as Kirigami
+import org.kde.kirigami as Kirigami
 
-RowLayout
-{
+RowLayout {
     id: view
     property bool editable: false
     property int max: 100
@@ -22,10 +21,10 @@ RowLayout
     clip: true
     spacing: 0
 
-    readonly property var ratingIndex: Math.floor((theRepeater.count*view.rating)/view.max)
-    readonly property var ratingHalf: (theRepeater.count*view.rating)%view.max >= view.max / 2
+    readonly property var ratingIndex: Math.floor((theRepeater.count * view.rating) / view.max)
+    readonly property var ratingHalf: (theRepeater.count * view.rating) % view.max >= view.max / 2
 
-    QtControls.Label {
+    QQC2.Label {
         Layout.minimumWidth: view.starSize
         Layout.minimumHeight: view.starSize
         visible: view.reverseLayout
@@ -48,7 +47,7 @@ RowLayout
 
             source: index < view.ratingIndex
                 ? "rating"
-                : (view.ratingHalf && index == view.ratingIndex
+                : (view.ratingHalf && index === view.ratingIndex
                     ? (view.LayoutMirroring.enabled ? "rating-half-rtl" : "rating-half")
                     : "rating-unrated")
             opacity: (view.editable && mouse.item.containsMouse) ? 0.7 : 1
@@ -60,7 +59,9 @@ RowLayout
                 condition: view.editable
                 componentTrue: MouseArea {
                     hoverEnabled: true
-                    onClicked: rating = (max/theRepeater.model*(index+1))
+                    onClicked: mouse => {
+                        rating = (max/theRepeater.model*(index+1));
+                    }
                 }
                 componentFalse: null
             }
@@ -72,7 +73,7 @@ RowLayout
         Layout.minimumWidth: Kirigami.Units.smallSpacing;
         Layout.maximumWidth: Kirigami.Units.smallSpacing;
     }
-    QtControls.Label {
+    QQC2.Label {
         id: ratingAsText
         Layout.minimumWidth: view.starSize
         Layout.minimumHeight: view.starSize
diff -pruN 6.0.0-3/src/qtquick/qml/private/Shadow.qml 6.3.0-1/src/qtquick/qml/private/Shadow.qml
--- 6.0.0-3/src/qtquick/qml/private/Shadow.qml	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/src/qtquick/qml/private/Shadow.qml	2024-05-31 13:26:56.000000000 +0000
@@ -4,33 +4,40 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-import QtQuick 2.11
-import Qt5Compat.GraphicalEffects 6.0
+import QtQuick
 
-import org.kde.kirigami 2.2
+import org.kde.kirigami as Kirigami
 
-LinearGradient {
+Item {
     id: shadow
+
     property int edge: Qt.LeftEdge
 
-    width: Units.gridUnit/2
-    height: Units.gridUnit/2
+    width: Kirigami.Units.gridUnit / 2
+    height: Kirigami.Units.gridUnit / 2
 
-    start: Qt.point((edge !== Qt.RightEdge ? 0 : width), (edge !== Qt.BottomEdge ? 0 : height))
-    end: Qt.point((edge !== Qt.LeftEdge ? 0 : width), (edge !== Qt.TopEdge ? 0 : height))
-    gradient: Gradient {
-        GradientStop {
-            position: 0.0
-            color: Theme.backgroundColor
-        }
-        GradientStop {
-            position: 0.3
-            color: Qt.rgba(0, 0, 0, 0.1)
+    Rectangle {
+        x: shadow.width / 2 - width / 2
+        y: shadow.height / 2 - height / 2
+        width: (shadow.edge === Qt.LeftEdge || shadow.edge === Qt.RightEdge) ? shadow.height : shadow.width
+        height: (shadow.edge === Qt.LeftEdge || shadow.edge === Qt.RightEdge) ? shadow.width : shadow.height
+        rotation: {
+            switch (shadow.edge) {
+                case Qt.TopEdge: return 0;
+                case Qt.LeftEdge: return 270;
+                case Qt.RightEdge: return 90;
+                case Qt.BottomEdge: return 180;
+            }
         }
-        GradientStop {
-            position: 1.0
-            color:  "transparent"
+        gradient: Gradient {
+            GradientStop {
+                position: 0.3
+                color: Qt.rgba(0, 0, 0, 0.1)
+            }
+            GradientStop {
+                position: 1.0
+                color: "transparent"
+            }
         }
     }
 }
-
diff -pruN 6.0.0-3/src/qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml 6.3.0-1/src/qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml
--- 6.0.0-3/src/qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/src/qtquick/qml/private/entrygriddelegates/BigPreviewDelegate.qml	2024-05-31 13:26:56.000000000 +0000
@@ -4,12 +4,11 @@
     SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
-import QtQuick 2.11
-import QtQuick.Controls 2.11 as QtControls
-import QtQuick.Layouts 1.11 as QtLayouts
-import Qt5Compat.GraphicalEffects 6.0 as QtEffects
+import QtQuick
+import QtQuick.Controls as QQC2
+import QtQuick.Layouts
 
-import org.kde.kirigami 2.12 as Kirigami
+import org.kde.kirigami as Kirigami
 
 import org.kde.newstuff as NewStuff
 
@@ -17,26 +16,34 @@ import ".." as Private
 
 Private.GridTileDelegate {
     id: component
+
     property var entry: model.entry
-    actionsAnchors.topMargin: bigPreview.height + Kirigami.Units.smallSpacing * 2
+
     function showDetails() {
         pageStack.push(detailsPage, {
             newStuffModel: GridView.view.model,
             entry: model.entry,
         });
     }
+
+    actionsAnchors.topMargin: bigPreview.height + Kirigami.Units.smallSpacing * 2
+
     actions: [
         Kirigami.Action {
             text: root.useLabel
             icon.name: "dialog-ok-apply"
-            onTriggered: { newStuffModel.adoptEntry(model.entry); }
+            onTriggered: source => {
+                newStuffModel.engine.adoptEntry(model.entry);
+            }
             enabled: (entry.status === NewStuff.Entry.Installed || entry.status === NewStuff.Entry.Updateable) && newStuffEngine.hasAdoptionCommand
             visible: enabled
         },
         Kirigami.Action {
-            text: model.downloadLinks.length === 1 ? i18ndc("knewstuff6", "Request installation of this item, available when there is exactly one downloadable item", "Install") : i18ndc("knewstuff6", "Show installation options, where there is more than one downloadable item", "Install…");
+            text: model.downloadLinks.length === 1
+                ? i18ndc("knewstuff6", "Request installation of this item, available when there is exactly one downloadable item", "Install")
+                : i18ndc("knewstuff6", "Show installation options, where there is more than one downloadable item", "Install…")
             icon.name: "install"
-            onTriggered: {
+            onTriggered: source => {
                 if (model.downloadLinks.length === 1) {
                     newStuffModel.engine.install(model.entry, NewStuff.ItemsModel.FirstLinkId);
                 } else {
@@ -49,16 +56,20 @@ Private.GridTileDelegate {
             visible: enabled
         },
         Kirigami.Action {
-            text: i18ndc("knewstuff6", "Request updating of this item", "Update");
+            text: i18ndc("knewstuff6", "Request updating of this item", "Update")
             icon.name: "update-none"
-            onTriggered: { newStuffModel.engine.install(model.index, NewStuff.ItemsModel.AutoDetectLinkId); }
+            onTriggered: source => {
+                newStuffModel.engine.install(model.index, NewStuff.ItemsModel.AutoDetectLinkId);
+            }
             enabled: entry.status === NewStuff.Entry.Updateable
             visible: enabled
         },
         Kirigami.Action {
             text: root.uninstallLabel
             icon.name: "edit-delete"
-            onTriggered: { newStuffModel.engine.uninstall(model.entry); }
+            onTriggered: source => {
+                newStuffModel.engine.uninstall(model.entry);
+            }
             enabled: entry.status === NewStuff.Entry.Installed || entry.status === NewStuff.Entry.Updateable
             visible: enabled
         }
@@ -70,82 +81,82 @@ Private.GridTileDelegate {
             fill: parent
             margins: Kirigami.Units.smallSpacing
         }
-        QtLayouts.ColumnLayout {
-            anchors.fill: parent;
+        ColumnLayout {
+            anchors.fill: parent
             Item {
-                QtLayouts.Layout.fillWidth: true
-                QtLayouts.Layout.fillHeight: true
-                QtLayouts.Layout.minimumHeight: width / 5
-                QtLayouts.Layout.maximumHeight: width / 1.8
+                Layout.fillWidth: true
+                Layout.fillHeight: true
+                Layout.minimumHeight: width / 5
+                Layout.maximumHeight: width / 1.8
                 Kirigami.ShadowedRectangle {
-                    visible: bigPreview.status == Image.Ready
-                    anchors.centerIn: bigPreview;
-                    width: Math.min(bigPreview.paintedWidth, bigPreview.width);
-                    height: Math.min(bigPreview.paintedHeight, bigPreview.height);
+                    visible: bigPreview.status === Image.Ready
+                    anchors.centerIn: bigPreview
+                    width: Math.min(bigPreview.paintedWidth, bigPreview.width)
+                    height: Math.min(bigPreview.paintedHeight, bigPreview.height)
                     Kirigami.Theme.colorSet: Kirigami.Theme.View
                     shadow.size: 10
                     shadow.color: Qt.rgba(0, 0, 0, 0.3)
                 }
                 Image {
                     id: bigPreview
-                    asynchronous: true;
-                    fillMode: Image.PreserveAspectCrop;
-                    source: thumbnailAvailable ? model.previews[0] : "";
+                    asynchronous: true
+                    fillMode: Image.PreserveAspectCrop
+                    source: thumbnailAvailable ? model.previews[0] : ""
                     anchors.fill: parent
                 }
                 Kirigami.Icon {
-                    id: updateAvailableBadge;
-                    opacity: (entry.status == NewStuff.Entry.Updateable) ? 1 : 0;
-                    Behavior on opacity { NumberAnimation { duration: Kirigami.Units.shortDuration; } }
+                    id: updateAvailableBadge
+                    opacity: (entry.status === NewStuff.Entry.Updateable) ? 1 : 0
+                    Behavior on opacity { NumberAnimation { duration: Kirigami.Units.shortDuration } }
                     anchors {
-                        top: parent.top;
-                        left: parent.left;
+                        top: parent.top
+                        left: parent.left
                     }
-                    height: Kirigami.Units.iconSizes.medium;
-                    width: height;
-                    source: "package-installed-outdated";
+                    height: Kirigami.Units.iconSizes.medium
+                    width: height
+                    source: "package-installed-outdated"
                 }
                 Kirigami.Icon {
-                    id: installedBadge;
-                    opacity: (entry.status === NewStuff.Entry.Installed) ? 1 : 0;
+                    id: installedBadge
+                    opacity: (entry.status === NewStuff.Entry.Installed) ? 1 : 0
                     Behavior on opacity { NumberAnimation { duration: Kirigami.Units.shortDuration; } }
                     anchors {
-                        top: parent.top;
-                        left: parent.left;
+                        top: parent.top
+                        left: parent.left
                     }
-                    height: Kirigami.Units.iconSizes.medium;
-                    width: height;
-                    source: "package-installed-updated";
+                    height: Kirigami.Units.iconSizes.medium
+                    width: height
+                    source: "package-installed-updated"
                 }
             }
             Private.Rating {
-                QtLayouts.Layout.fillWidth: true
+                Layout.fillWidth: true
                 rating: model.rating
             }
             Kirigami.Heading {
-                QtLayouts.Layout.fillWidth: true
+                Layout.fillWidth: true
                 level: 5
                 elide: Text.ElideRight
                 text: i18ndc("knewstuff6", "The number of times the item has been downloaded", "%1 downloads", model.downloadCount)
             }
             Kirigami.Heading {
-                QtLayouts.Layout.fillWidth: true
+                Layout.fillWidth: true
                 elide: Text.ElideRight
                 level: 3
                 text: model.name
             }
             Kirigami.Heading {
-                QtLayouts.Layout.fillWidth: true
+                Layout.fillWidth: true
                 elide: Text.ElideRight
                 level: 4
                 textFormat: Text.StyledText
                 text: i18ndc("knewstuff6", "Subheading for the tile view, located immediately underneath the name of the item", "By <i>%1</i>", model.author.name)
             }
-            QtControls.Label {
-                QtLayouts.Layout.fillWidth: true
-                QtLayouts.Layout.fillHeight: true
-                QtLayouts.Layout.minimumHeight: Kirigami.Units.gridUnit
-                QtLayouts.Layout.maximumHeight: Kirigami.Units.gridUnit * 3
+            QQC2.Label {
+                Layout.fillWidth: true
+                Layout.fillHeight: true
+                Layout.minimumHeight: Kirigami.Units.gridUnit
+                Layout.maximumHeight: Kirigami.Units.gridUnit * 3
                 wrapMode: Text.Wrap
                 text: model.shortSummary.length > 0 ? model.shortSummary : model.summary
                 elide: Text.ElideRight
@@ -157,9 +168,11 @@ Private.GridTileDelegate {
             newStuffModel: component.GridView.view.model
         }
         MouseArea {
-            anchors.fill: parent;
-            cursorShape: Qt.PointingHandCursor;
-            onClicked: component.showDetails();
+            anchors.fill: parent
+            cursorShape: Qt.PointingHandCursor
+            onClicked: mouse => {
+                component.showDetails();
+            }
         }
     }
 }
diff -pruN 6.0.0-3/src/qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml 6.3.0-1/src/qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml
--- 6.0.0-3/src/qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/src/qtquick/qml/private/entrygriddelegates/FeedbackOverlay.qml	2024-05-31 13:26:56.000000000 +0000
@@ -4,24 +4,26 @@
     SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
-import QtQuick 2.11
-import QtQuick.Controls 2.11 as QtControls
+import QtQuick
+import QtQuick.Controls as QQC2
 
-import org.kde.kirigami 2.7 as Kirigami
+import org.kde.kirigami as Kirigami
 
 import org.kde.newstuff as NewStuff
 
 Item {
     property QtObject newStuffModel
+
     visible: opacity > 0
-    opacity: (model.entry.status == NewStuff.Entry.Installing || model.entry.status == NewStuff.Entry.Updating) ? 1 : 0
-    Behavior on opacity { NumberAnimation { duration: Kirigami.Units.longDuration; } }
+    opacity: (model.entry.status === NewStuff.Entry.Installing || model.entry.status === NewStuff.Entry.Updating) ? 1 : 0
+
+    Behavior on opacity { NumberAnimation { duration: Kirigami.Units.longDuration } }
     Rectangle {
         anchors.fill: parent
         color: Kirigami.Theme.backgroundColor
-        opacity: 0.9;
+        opacity: 0.9
     }
-    QtControls.BusyIndicator {
+    QQC2.BusyIndicator {
         anchors {
             horizontalCenter: parent.horizontalCenter
             bottom: parent.verticalCenter
@@ -29,27 +31,27 @@ Item {
         }
         running: parent.visible
     }
-    QtControls.Label {
+    QQC2.Label {
         id: statusLabel
         Connections {
             target: newStuffModel
             function onEntryChanged(entry) {
                 const status = entry.status;
-                if (status == NewStuff.Entry.Downloadable
-                || status == NewStuff.Entry.Installed
-                || status == NewStuff.Entry.Updateable
-                || status == NewStuff.Entry.Deleted) {
+                if (status === NewStuff.Entry.Downloadable
+                    || status === NewStuff.Entry.Installed
+                    || status === NewStuff.Entry.Updateable
+                    || status === NewStuff.Entry.Deleted) {
                     statusLabel.text = "";
-                } else if (status == NewStuff.Entry.Installing) {
+                } else if (status === NewStuff.Entry.Installing) {
                     statusLabel.text = i18ndc("knewstuff6", "Label for the busy indicator showing an item is being installed OR uninstalled", "Working…");
-                } else if (status == NewStuff.Entry.Updating) {
+                } else if (status === NewStuff.Entry.Updating) {
                     statusLabel.text = i18ndc("knewstuff6", "Label for the busy indicator showing an item is in the process of being updated", "Updating…");
                 } else {
                     statusLabel.text = i18ndc("knewstuff6", "Label for the busy indicator which should only be shown when the entry has been given some unknown or invalid status.", "Invalid or unknown state. <a href=\"https://bugs.kde.org/enter_bug.cgi?product=frameworks-knewstuff\">Please report this to the KDE Community in a bug report</a>.");
                 }
             }
         }
-        onLinkActivated: Qt.openUrlExternally(link);
+        onLinkActivated: link => Qt.openUrlExternally(link)
         anchors {
             top: parent.verticalCenter
             left: parent.left
@@ -58,6 +60,6 @@ Item {
         }
         horizontalAlignment: Text.AlignHCenter
         // TODO: This is where we'd want to put the download progress and cancel button as well
-        text: i18ndc("knewstuff6", "Label for the busy indicator showing an item is installing", "Installing…");
+        text: i18ndc("knewstuff6", "Label for the busy indicator showing an item is installing", "Installing…")
     }
 }
diff -pruN 6.0.0-3/src/qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml 6.3.0-1/src/qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml
--- 6.0.0-3/src/qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/src/qtquick/qml/private/entrygriddelegates/ThumbDelegate.qml	2024-05-31 13:26:56.000000000 +0000
@@ -4,36 +4,40 @@
     SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
-import QtQuick 2.11
-import QtQuick.Controls 2.11 as QtControls
-import QtQuick.Layouts 1.11 as QtLayouts
-import Qt5Compat.GraphicalEffects 6.0 as QtEffects
+import QtQuick
 
-import org.kde.kcmutils as KCM
-import org.kde.kirigami 2.7 as Kirigami
+import org.kde.kcmutils as KCMUtils
+import org.kde.kirigami as Kirigami
 
 import org.kde.newstuff as NewStuff
 
 import ".." as Private
 
-KCM.GridDelegate {
+KCMUtils.GridDelegate {
     id: component
+
     property string useLabel
     property string uninstallLabel
-    text: model.name
     property var entry: model.entry
+
+    text: model.name
+
     actions: [
         Kirigami.Action {
             text: component.useLabel
             icon.name: "dialog-ok-apply"
-            onTriggered: { newStuffModel.engine.adoptEntry(entry); }
-            enabled: (entry.status == NewStuff.Entry.Installed || entry.status == NewStuff.Entry.Updateable) && newStuffEngine.hasAdoptionCommand
+            onTriggered: source => {
+                newStuffModel.engine.adoptEntry(entry);
+            }
+            enabled: (entry.status === NewStuff.Entry.Installed || entry.status === NewStuff.Entry.Updateable) && newStuffEngine.hasAdoptionCommand
             visible: enabled
         },
         Kirigami.Action {
-            text: model.downloadLinks.length === 1 ? i18ndc("knewstuff6", "Request installation of this item, available when there is exactly one downloadable item", "Install") : i18ndc("knewstuff6", "Show installation options, where there is more than one downloadable item", "Install…");
+            text: model.downloadLinks.length === 1
+                ? i18ndc("knewstuff6", "Request installation of this item, available when there is exactly one downloadable item", "Install")
+                : i18ndc("knewstuff6", "Show installation options, where there is more than one downloadable item", "Install…")
             icon.name: "install"
-            onTriggered: {
+            onTriggered: source => {
                 if (model.downloadLinks.length === 1) {
                     newStuffModel.engine.install(entry, NewStuff.Entry.FirstLinkId);
                 } else {
@@ -42,71 +46,76 @@ KCM.GridDelegate {
                     downloadItemsSheet.open();
                 }
             }
-            enabled: entry.status == NewStuff.Entry.Downloadable || entry.status == NewStuff.Entry.Deleted
+            enabled: entry.status === NewStuff.Entry.Downloadable || entry.status === NewStuff.Entry.Deleted
             visible: enabled
         },
         Kirigami.Action {
-            text: i18ndc("knewstuff6", "Request updating of this item", "Update");
+            text: i18ndc("knewstuff6", "Request updating of this item", "Update")
             icon.name: "update-none"
-            onTriggered: { newStuffModel.engine.install(entry, NewStuff.ItemsModel.AutoDetectLinkId); }
-            enabled: entry.status == NewStuff.Entry.Updateable
+            onTriggered: source => {
+                newStuffModel.engine.install(entry, NewStuff.ItemsModel.AutoDetectLinkId);
+            }
+            enabled: entry.status === NewStuff.Entry.Updateable
             visible: enabled
         },
         Kirigami.Action {
             text: component.uninstallLabel
             icon.name: "edit-delete"
-            onTriggered: { newStuffModel.engine.uninstall(entry); }
-            enabled: entry.status == NewStuff.Entry.Installed || entry.status == NewStuff.Entry.Updateable
+            onTriggered: source => {
+                newStuffModel.engine.uninstall(entry);
+            }
+            enabled: entry.status === NewStuff.Entry.Installed || entry.status === NewStuff.Entry.Updateable
             visible: enabled
         }
     ]
     thumbnailAvailable: model.previewsSmall.length > 0
     thumbnail: Image {
         anchors {
-            fill: parent;
-            margins: Kirigami.Units.smallSpacing;
+            fill: parent
+            margins: Kirigami.Units.smallSpacing
         }
-        asynchronous: true;
-        fillMode: Image.PreserveAspectFit;
-        source: thumbnailAvailable ? model.previewsSmall[0] : "";
+        asynchronous: true
+        fillMode: Image.PreserveAspectFit
+        source: thumbnailAvailable ? model.previewsSmall[0] : ""
         Kirigami.Icon {
-            id: updateAvailableBadge;
-            opacity: (entry.status == NewStuff.Entry.Updateable) ? 1 : 0;
-            Behavior on opacity { NumberAnimation { duration: Kirigami.Units.shortDuration; } }
+            id: updateAvailableBadge
+            opacity: (entry.status === NewStuff.Entry.Updateable) ? 1 : 0
+            Behavior on opacity { NumberAnimation { duration: Kirigami.Units.shortDuration } }
             anchors {
-                top: parent.top;
-                right: parent.right;
-                margins: -Kirigami.Units.smallSpacing;
-            }
-            height: Kirigami.Units.iconSizes.smallMedium;
-            width: height;
-            source: "package-installed-outdated";
+                top: parent.top
+                right: parent.right
+                margins: -Kirigami.Units.smallSpacing
+            }
+            height: Kirigami.Units.iconSizes.smallMedium
+            width: height
+            source: "package-installed-outdated"
         }
         Kirigami.Icon {
-            id: installedBadge;
-            opacity: (entry.status == NewStuff.Entry.Installed) ? 1 : 0;
-            Behavior on opacity { NumberAnimation { duration: Kirigami.Units.shortDuration; } }
+            id: installedBadge
+            opacity: (entry.status === NewStuff.Entry.Installed) ? 1 : 0
+            Behavior on opacity { NumberAnimation { duration: Kirigami.Units.shortDuration } }
             anchors {
-                top: parent.top;
-                right: parent.right;
-                margins: -Kirigami.Units.smallSpacing;
-            }
-            height: Kirigami.Units.iconSizes.smallMedium;
-            width: height;
-            source: "package-installed-updated";
+                top: parent.top
+                right: parent.right
+                margins: -Kirigami.Units.smallSpacing
+            }
+            height: Kirigami.Units.iconSizes.smallMedium
+            width: height
+            source: "package-installed-updated"
         }
         FeedbackOverlay {
             anchors.fill: parent
             newStuffModel: component.GridView.view.model
         }
         MouseArea {
-            anchors.fill: parent;
-            cursorShape: Qt.PointingHandCursor;
-            onClicked: pageStack.push(detailsPage, {
-                newStuffModel: component.GridView.view.model,
-                entry: entry,
-            });
-
+            anchors.fill: parent
+            cursorShape: Qt.PointingHandCursor
+            onClicked: mouse => {
+                pageStack.push(detailsPage, {
+                    newStuffModel: component.GridView.view.model,
+                    entry: entry,
+                });
+            }
         }
     }
 }
diff -pruN 6.0.0-3/src/qtquick/qml/private/entrygriddelegates/TileDelegate.qml 6.3.0-1/src/qtquick/qml/private/entrygriddelegates/TileDelegate.qml
--- 6.0.0-3/src/qtquick/qml/private/entrygriddelegates/TileDelegate.qml	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/src/qtquick/qml/private/entrygriddelegates/TileDelegate.qml	2024-05-31 13:26:56.000000000 +0000
@@ -4,12 +4,11 @@
     SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
-import QtQuick 2.11
-import QtQuick.Controls 2.11 as QtControls
-import QtQuick.Layouts 1.11 as QtLayouts
-import Qt5Compat.GraphicalEffects 6.0 as QtEffects
+import QtQuick
+import QtQuick.Controls as QQC2
+import QtQuick.Layouts
 
-import org.kde.kirigami 2.12 as Kirigami
+import org.kde.kirigami as Kirigami
 
 import org.kde.newstuff as NewStuff
 
@@ -17,11 +16,13 @@ import ".." as Private
 
 Private.GridTileDelegate {
     id: component
+
     property var entry: model.entry
     property string useLabel
     property string uninstallLabel
+
     function showDetails() {
-        if (entry.entryType == NewStuff.Entry.GroupEntry) {
+        if (entry.entryType === NewStuff.Entry.GroupEntry) {
             newStuffEngine.storeSearch();
             newStuffEngine.searchTerm = model.payload;
         } else {
@@ -31,41 +32,50 @@ Private.GridTileDelegate {
             });
         }
     }
+
     actions: [
         Kirigami.Action {
             text: component.useLabel
             icon.name: "dialog-ok-apply"
-            onTriggered: { newStuffModel.adoptItem(model.index); }
-            enabled: (entry.status == NewStuff.Entry.Installed || entry.status == NewStuff.Entry.Updateable) && newStuffEngine.hasAdoptionCommand
+            onTriggered: source => {
+                newStuffModel.engine.adoptEntry(model.entry);
+            }
+            enabled: (entry.status === NewStuff.Entry.Installed || entry.status === NewStuff.Entry.Updateable) && newStuffEngine.hasAdoptionCommand
             visible: enabled
         },
         Kirigami.Action {
-            text: entry.downloadLinks.length === 1 ? i18ndc("knewstuff6", "Request installation of this item, available when there is exactly one downloadable item", "Install") : i18ndc("knewstuff6", "Show installation options, where there is more than one downloadable item", "Install…");
+            text: model.downloadLinks.length === 1
+                ? i18ndc("knewstuff6", "Request installation of this item, available when there is exactly one downloadable item", "Install")
+                : i18ndc("knewstuff6", "Show installation options, where there is more than one downloadable item", "Install…")
             icon.name: "install"
-            onTriggered: {
-                if (entry.downloadLinks.length === 1) {
-                    newStuffEngine.install(entry.entry, NewStuff.ItemsModel.FirstLinkId);
+            onTriggered: source => {
+                if (model.downloadLinks.length === 1) {
+                    newStuffEngine.install(entry, NewStuff.ItemsModel.FirstLinkId);
                 } else {
-                    downloadItemsSheet.downloadLinks = entry.downloadLinks;
+                    downloadItemsSheet.downloadLinks = model.downloadLinks;
                     downloadItemsSheet.entry = entry;
                     downloadItemsSheet.open();
                 }
             }
-            enabled: entry.status == NewStuff.Entry.Downloadable || entry.status == NewStuff.Entry.Deleted;
-            visible: enabled;
+            enabled: entry.status === NewStuff.Entry.Downloadable || entry.status === NewStuff.Entry.Deleted
+            visible: enabled
         },
         Kirigami.Action {
-            text: i18ndc("knewstuff6", "Request updating of this item", "Update");
+            text: i18ndc("knewstuff6", "Request updating of this item", "Update")
             icon.name: "update-none"
-            onTriggered: { newStuffEngine.install(entry, NewStuff.ItemsModel.AutoDetectLinkId); }
-            enabled: entry.status == NewStuff.Entry.Updateable
+            onTriggered: source => {
+                newStuffEngine.install(entry, NewStuff.ItemsModel.AutoDetectLinkId);
+            }
+            enabled: entry.status === NewStuff.Entry.Updateable
             visible: enabled
         },
         Kirigami.Action {
             text: component.uninstallLabel
             icon.name: "edit-delete"
-            onTriggered: { newStuffEngine.uninstall(model.entry); }
-            enabled: entry.status == NewStuff.Entry.Installed|| entry.status == NewStuff.Entry.Updateable
+            onTriggered: source => {
+                newStuffEngine.uninstall(model.entry);
+            }
+            enabled: entry.status === NewStuff.Entry.Installed || entry.status === NewStuff.Entry.Updateable
             visible: enabled && hovered
         }
     ]
@@ -76,30 +86,30 @@ Private.GridTileDelegate {
             fill: parent
             margins: Kirigami.Units.smallSpacing
         }
-        QtLayouts.GridLayout {
-            anchors.fill: parent;
+        GridLayout {
+            anchors.fill: parent
             columns: 2
-            QtLayouts.ColumnLayout {
-                QtLayouts.Layout.minimumWidth: view.implicitCellWidth / 5
-                QtLayouts.Layout.maximumWidth: view.implicitCellWidth / 5
+            ColumnLayout {
+                Layout.minimumWidth: view.implicitCellWidth / 5
+                Layout.maximumWidth: view.implicitCellWidth / 5
                 Item {
-                    QtLayouts.Layout.fillWidth: true
-                    QtLayouts.Layout.minimumHeight: width
-                    QtLayouts.Layout.maximumHeight: width
+                    Layout.fillWidth: true
+                    Layout.minimumHeight: width
+                    Layout.maximumHeight: width
                     Kirigami.ShadowedRectangle {
-                        visible: tilePreview.status == Image.Ready
-                        anchors.centerIn: tilePreview;
-                        width: Math.min(tilePreview.paintedWidth, tilePreview.width);
-                        height: Math.min(tilePreview.paintedHeight, tilePreview.height);
+                        visible: tilePreview.status === Image.Ready
+                        anchors.centerIn: tilePreview
+                        width: Math.min(tilePreview.paintedWidth, tilePreview.width)
+                        height: Math.min(tilePreview.paintedHeight, tilePreview.height)
                         Kirigami.Theme.colorSet: Kirigami.Theme.View
                         shadow.size: Kirigami.Units.largeSpacing
                         shadow.color: Qt.rgba(0, 0, 0, 0.3)
                     }
                     Image {
                         id: tilePreview
-                        asynchronous: true;
-                        fillMode: Image.PreserveAspectFit;
-                        source: thumbnailAvailable ? model.previewsSmall[0] : "";
+                        asynchronous: true
+                        fillMode: Image.PreserveAspectFit
+                        source: thumbnailAvailable ? model.previewsSmall[0] : ""
                         anchors {
                             fill: parent
                             margins: Kirigami.Units.smallSpacing
@@ -107,55 +117,55 @@ Private.GridTileDelegate {
                         verticalAlignment: Image.AlignTop
                     }
                     Kirigami.Icon {
-                        id: updateAvailableBadge;
-                        opacity: (entry.status == NewStuff.Entry.Updateable) ? 1 : 0;
-                        Behavior on opacity { NumberAnimation { duration: Kirigami.Units.shortDuration; } }
+                        id: updateAvailableBadge
+                        opacity: (entry.status === NewStuff.Entry.Updateable) ? 1 : 0
+                        Behavior on opacity { NumberAnimation { duration: Kirigami.Units.shortDuration } }
                         anchors {
-                            top: parent.top;
-                            left: parent.left;
-                            margins: -Kirigami.Units.smallSpacing;
+                            top: parent.top
+                            left: parent.left
+                            margins: -Kirigami.Units.smallSpacing
                         }
-                        height: Kirigami.Units.iconSizes.smallMedium;
-                        width: height;
-                        source: "package-installed-outdated";
+                        height: Kirigami.Units.iconSizes.smallMedium
+                        width: height
+                        source: "package-installed-outdated"
                     }
                     Kirigami.Icon {
-                        id: installedBadge;
-                        opacity: (entry.status == NewStuff.Entry.Installed) ? 1 : 0;
-                        Behavior on opacity { NumberAnimation { duration: Kirigami.Units.shortDuration; } }
+                        id: installedBadge
+                        opacity: (entry.status === NewStuff.Entry.Installed) ? 1 : 0
+                        Behavior on opacity { NumberAnimation { duration: Kirigami.Units.shortDuration } }
                         anchors {
-                            top: parent.top;
-                            left: parent.left;
-                            margins: -Kirigami.Units.smallSpacing;
+                            top: parent.top
+                            left: parent.left
+                            margins: -Kirigami.Units.smallSpacing
                         }
-                        height: Kirigami.Units.iconSizes.smallMedium;
-                        width: height;
-                        source: "package-installed-updated";
+                        height: Kirigami.Units.iconSizes.smallMedium
+                        width: height
+                        source: "package-installed-updated"
                     }
                 }
                 Item {
-                    QtLayouts.Layout.fillHeight: true
+                    Layout.fillHeight: true
                 }
             }
-            QtLayouts.ColumnLayout {
-                QtLayouts.Layout.fillWidth: true
-                QtLayouts.Layout.fillHeight: true
+            ColumnLayout {
+                Layout.fillWidth: true
+                Layout.fillHeight: true
                 Kirigami.Heading {
-                    QtLayouts.Layout.fillWidth: true
+                    Layout.fillWidth: true
                     elide: Text.ElideRight
                     level: 3
                     text: entry.name
                 }
                 Kirigami.Heading {
-                    QtLayouts.Layout.fillWidth: true
+                    Layout.fillWidth: true
                     elide: Text.ElideRight
                     level: 4
                     textFormat: Text.StyledText
                     text: i18ndc("knewstuff6", "Subheading for the tile view, located immediately underneath the name of the item", "By <i>%1</i>", entry.author.name)
                 }
-                QtControls.Label {
-                    QtLayouts.Layout.fillWidth: true
-                    QtLayouts.Layout.fillHeight: true
+                QQC2.Label {
+                    Layout.fillWidth: true
+                    Layout.fillHeight: true
                     wrapMode: Text.Wrap
                     text: entry.shortSummary.length > 0 ? entry.shortSummary : entry.summary
                     elide: Text.ElideRight
@@ -163,17 +173,17 @@ Private.GridTileDelegate {
                 }
             }
             Private.Rating {
-                QtLayouts.Layout.fillWidth: true
+                Layout.fillWidth: true
                 rating: entry.rating
-                visible: entry.entryType == NewStuff.Entry.CatalogEntry;
+                visible: entry.entryType === NewStuff.Entry.CatalogEntry
             }
             Kirigami.Heading {
-                QtLayouts.Layout.fillWidth: true
+                Layout.fillWidth: true
                 horizontalAlignment: Text.AlignRight
                 level: 5
                 elide: Text.ElideRight
                 text: i18ndc("knewstuff6", "The number of times the item has been downloaded", "%1 downloads", entry.downloadCount)
-                visible: entry.entryType == NewStuff.Entry.CatalogEntry
+                visible: entry.entryType === NewStuff.Entry.CatalogEntry
             }
         }
         FeedbackOverlay {
@@ -181,9 +191,11 @@ Private.GridTileDelegate {
             newStuffModel: component.GridView.view.model
         }
         MouseArea {
-            anchors.fill: parent;
-            cursorShape: Qt.PointingHandCursor;
-            onClicked: component.showDetails();
+            anchors.fill: parent
+            cursorShape: Qt.PointingHandCursor
+            onClicked: mouse => {
+                component.showDetails();
+            }
         }
     }
 }
diff -pruN 6.0.0-3/src/qtquick/quickengine.cpp 6.3.0-1/src/qtquick/quickengine.cpp
--- 6.0.0-3/src/qtquick/quickengine.cpp	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/src/qtquick/quickengine.cpp	2024-05-31 13:26:56.000000000 +0000
@@ -97,16 +97,6 @@ Engine::Engine(QObject *parent)
 
     connect(this, &Engine::signalEntryEvent, this, [this](const KNSCore::Entry &entry, KNSCore::Entry::EntryEvent event) {
         // Just forward the event but not do anything more
-        if (event != KNSCore::Entry::StatusChangedEvent) {
-            Q_EMIT entryEvent(entry, event);
-            return;
-        }
-
-        // We do not want to emit the entries changed signal for intermediate changed
-        // this would cause the KCMs to reload their view unnecessarily, BUG: 431568
-        if (entry.status() == KNSCore::Entry::Installing || entry.status() == KNSCore::Entry::Updating) {
-            return;
-        }
         Q_EMIT entryEvent(entry, event);
     });
     //
@@ -206,7 +196,7 @@ void Engine::setConfigFile(const QString
     }
 }
 
-QObject *Engine::categories() const
+CategoriesModel *Engine::categories() const
 {
     return d->categoriesModel;
 }
@@ -272,7 +262,7 @@ void Engine::setSearchTerm(const QString
     }
 }
 
-QObject *Engine::searchPresetModel() const
+SearchPresetModel *Engine::searchPresetModel() const
 {
     return d->searchPresetModel;
 }
diff -pruN 6.0.0-3/src/qtquick/quickengine.h 6.3.0-1/src/qtquick/quickengine.h
--- 6.0.0-3/src/qtquick/quickengine.h	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/src/qtquick/quickengine.h	2024-05-31 13:26:56.000000000 +0000
@@ -10,10 +10,12 @@
 #include <QObject>
 #include <QQmlListProperty>
 
+#include "categoriesmodel.h"
 #include "enginebase.h"
 #include "entry.h"
 #include "errorcode.h"
 #include "provider.h"
+#include "searchpresetmodel.h"
 #include "transaction.h"
 
 class EnginePrivate;
@@ -33,12 +35,12 @@ class Engine : public KNSCore::EngineBas
     Q_PROPERTY(QString name READ name NOTIFY configFileChanged)
     Q_PROPERTY(bool isValid READ isValid NOTIFY configFileChanged)
 
-    Q_PROPERTY(QObject *categories READ categories NOTIFY categoriesChanged)
+    Q_PROPERTY(CategoriesModel *categories READ categories NOTIFY categoriesChanged)
     Q_PROPERTY(QStringList categoriesFilter READ categoriesFilter WRITE setCategoriesFilter RESET resetCategoriesFilter NOTIFY categoriesFilterChanged)
     Q_PROPERTY(KNSCore::Provider::Filter filter READ filter WRITE setFilter NOTIFY filterChanged)
     Q_PROPERTY(KNSCore::Provider::SortMode sortOrder READ sortOrder WRITE setSortOrder NOTIFY sortOrderChanged)
     Q_PROPERTY(QString searchTerm READ searchTerm WRITE setSearchTerm RESET resetSearchTerm NOTIFY searchTermChanged)
-    Q_PROPERTY(QObject *searchPresetModel READ searchPresetModel NOTIFY searchPresetModelChanged)
+    Q_PROPERTY(SearchPresetModel *searchPresetModel READ searchPresetModel NOTIFY searchPresetModelChanged)
 
     /**
      * Current state of the engine, the state con contain multiple operations
@@ -92,7 +94,7 @@ public:
         return busyState().toInt() != 0 && ((busyState() & BusyOperation::InstallingEntry) != BusyOperation::InstallingEntry);
     }
 
-    QObject *categories() const;
+    CategoriesModel *categories() const;
     Q_SIGNAL void categoriesChanged();
 
     QStringList categoriesFilter() const;
@@ -119,7 +121,7 @@ public:
     }
     Q_SIGNAL void searchTermChanged();
 
-    QObject *searchPresetModel() const;
+    SearchPresetModel *searchPresetModel() const;
     Q_SIGNAL void searchPresetModelChanged();
 
     Q_INVOKABLE void updateEntryContents(const KNSCore::Entry &entry);
diff -pruN 6.0.0-3/src/qtquick/quickitemsmodel.cpp 6.3.0-1/src/qtquick/quickitemsmodel.cpp
--- 6.0.0-3/src/qtquick/quickitemsmodel.cpp	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/src/qtquick/quickitemsmodel.cpp	2024-05-31 13:26:56.000000000 +0000
@@ -292,16 +292,16 @@ void ItemsModel::fetchMore(const QModelI
     d->engine->requestMoreData();
 }
 
-QObject *ItemsModel::engine() const
+Engine *ItemsModel::engine() const
 {
     return d->engine;
 }
 
-void ItemsModel::setEngine(QObject *newEngine)
+void ItemsModel::setEngine(Engine *newEngine)
 {
     if (d->engine != newEngine) {
         beginResetModel();
-        d->engine = qobject_cast<Engine *>(newEngine);
+        d->engine = newEngine;
         if (d->model) {
             d->model->deleteLater();
             d->model = nullptr;
diff -pruN 6.0.0-3/src/qtquick/quickitemsmodel.h 6.3.0-1/src/qtquick/quickitemsmodel.h
--- 6.0.0-3/src/qtquick/quickitemsmodel.h	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/src/qtquick/quickitemsmodel.h	2024-05-31 13:26:56.000000000 +0000
@@ -10,6 +10,7 @@
 #include <QAbstractListModel>
 
 #include "entry.h"
+#include "quickengine.h"
 
 #include <memory>
 
@@ -36,17 +37,17 @@ class ItemsModelPrivate;
  * @see NewStuffEntryComments
  *
  * \code
-    import org.kde.newstuff 1.0 as NewStuff
+    import org.kde.newstuff as NewStuff
     Item {
         NewStuff.ItemsModel {
-            id: newStuffModel;
+            id: newStuffModel
             engine: newStuffEngine
         }
         NewStuff.Engine {
             id: newStuffEngine
             configFile: "/some/filesystem/location/wallpaper.knsrc"
-            onBusyMessageChanged: () => console.log("KNS Message: " + newStuffEngine.busyMessage);
-            onErrorCode: (code, message, metadata) => console.log("KNS Error: " + message);
+            onBusyMessageChanged: () => console.log("KNS Message: " + newStuffEngine.busyMessage)
+            onErrorCode: (code, message, metadata) => console.log("KNS Error: " + message)
         }
     }
     \endcode
@@ -57,7 +58,7 @@ class ItemsModel : public QAbstractListM
     /**
      * The NewStuffQuickEngine to show items from
      */
-    Q_PROPERTY(QObject *engine READ engine WRITE setEngine NOTIFY engineChanged REQUIRED)
+    Q_PROPERTY(Engine *engine READ engine WRITE setEngine NOTIFY engineChanged REQUIRED)
 public:
     explicit ItemsModel(QObject *parent = nullptr);
     ~ItemsModel() override;
@@ -111,8 +112,8 @@ public:
     bool canFetchMore(const QModelIndex &parent) const override;
     void fetchMore(const QModelIndex &parent) override;
 
-    QObject *engine() const;
-    void setEngine(QObject *newEngine);
+    Engine *engine() const;
+    void setEngine(Engine *newEngine);
     Q_SIGNAL void engineChanged();
 
     /**
@@ -132,7 +133,7 @@ public:
     /**
      * @brief Fired when an entry's data changes
      *
-     * @param index The index of the item which has changed
+     * @param entry The entry which has changed
      */
     Q_SIGNAL void entryChanged(const KNSCore::Entry &entry);
 
diff -pruN 6.0.0-3/src/qtquick/quicksettings.h 6.3.0-1/src/qtquick/quicksettings.h
--- 6.0.0-3/src/qtquick/quicksettings.h	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/src/qtquick/quicksettings.h	2024-05-31 13:26:56.000000000 +0000
@@ -8,9 +8,7 @@
 #ifndef KNSQ_QUICKSETTINGS_H
 #define KNSQ_QUICKSETTINGS_H
 
-#include "core/questionlistener.h"
-
-#include <memory>
+#include <QObject>
 
 namespace KNewStuffQuick
 {
diff -pruN 6.0.0-3/src/qtquick/searchpresetmodel.cpp 6.3.0-1/src/qtquick/searchpresetmodel.cpp
--- 6.0.0-3/src/qtquick/searchpresetmodel.cpp	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/src/qtquick/searchpresetmodel.cpp	2024-05-31 13:26:56.000000000 +0000
@@ -7,6 +7,7 @@
 #include "searchpresetmodel.h"
 
 #include "knewstuffquick_debug.h"
+
 #include <KLocalizedString>
 
 SearchPresetModel::SearchPresetModel(KNSCore::EngineBase *engine)
diff -pruN 6.0.0-3/src/qtquick/searchpresetmodel.h 6.3.0-1/src/qtquick/searchpresetmodel.h
--- 6.0.0-3/src/qtquick/searchpresetmodel.h	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/src/qtquick/searchpresetmodel.h	2024-05-31 13:26:56.000000000 +0000
@@ -7,8 +7,8 @@
 #ifndef SEARCHPRESETMODEL_H
 #define SEARCHPRESETMODEL_H
 
-#include "provider.h"
-#include "quickengine.h"
+#include "enginebase.h"
+
 #include <QAbstractListModel>
 
 /**
diff -pruN 6.0.0-3/src/tools/knewstuff-dialog/org.kde.knewstuff-dialog6.desktop 6.3.0-1/src/tools/knewstuff-dialog/org.kde.knewstuff-dialog6.desktop
--- 6.0.0-3/src/tools/knewstuff-dialog/org.kde.knewstuff-dialog6.desktop	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/src/tools/knewstuff-dialog/org.kde.knewstuff-dialog6.desktop	2024-05-31 13:26:56.000000000 +0000
@@ -22,11 +22,13 @@ Comment[it]=Vetrina per la funzionalità
 Comment[ka]=KNewStuff-ის დამატების გადმოწერის ფუნქციონალის საჩვენებელი მაგალითი
 Comment[ko]=KNewStuff 추가 기능 다운로드 데모
 Comment[lt]=KNewStuff papildinių atsiuntimo funkcionalumo demonstravimas
+Comment[lv]=„KNewStuff“ pielikuma lejupielāžu funkcionalitātes parādīšana
 Comment[nl]=Showcase voor KNewStuff functionaliteit van downloaden van add-on
 Comment[nn]=Framvising av KNewStuff-tillegg for nedlastingsfunksjonalitet
 Comment[pl]=Przedstawienie możliwości pobierania dodatków przez KNewStuff
 Comment[pt]=Demonstração da funcionalidade de transferência de extensões do KNewStuff
 Comment[pt_BR]=Demonstração da funcionalidade de download do complemento do KNewStuff
+Comment[ro]=Demonstrează funcționalitatea KNewStuff de descărcare a extensiilor
 Comment[ru]=Демонстрация возможностей загрузки дополнений KNewStuff
 Comment[sk]=Výkladná skriňa pre funkcionalitu sťahovania addonov KNewStuff
 Comment[sl]=Vzorčna predstavitev funkcionalnosti prenosa dodatkov aplikacije knowStuff
@@ -58,11 +60,13 @@ Name[it]=Finestra di KNewStuff
 Name[ka]=KNewStuff -ის ფანჯარა
 Name[ko]=KNewStuff 대화 상자
 Name[lt]=KNewStuff dialogas
+Name[lv]=„KNewStuff“ logs
 Name[nl]=Dialoog van KNewStuff
 Name[nn]=KNewStuff-vindauge
 Name[pl]=Okno dialogowe KNewStuff
 Name[pt]=Janela do KNewStuff
 Name[pt_BR]=Janela do KNewStuff
+Name[ro]=Dialog KNewStuff
 Name[ru]=Диалог KNewStuff
 Name[sk]=Dialóg KNewStuff
 Name[sl]=Dialog KNewStuff
diff -pruN 6.0.0-3/src/tools/knewstuff-dialog/qml/dialog.qml 6.3.0-1/src/tools/knewstuff-dialog/qml/dialog.qml
--- 6.0.0-3/src/tools/knewstuff-dialog/qml/dialog.qml	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/src/tools/knewstuff-dialog/qml/dialog.qml	2024-05-31 13:26:56.000000000 +0000
@@ -4,8 +4,8 @@
     SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
-import QtQuick 2.7
-import org.kde.newstuff 1.62 as NewStuff
+import QtQuick
+import org.kde.newstuff as NewStuff
 
 NewStuff.Dialog {
     id: component
diff -pruN 6.0.0-3/src/tools/knewstuff-dialog/qml/main.qml 6.3.0-1/src/tools/knewstuff-dialog/qml/main.qml
--- 6.0.0-3/src/tools/knewstuff-dialog/qml/main.qml	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/src/tools/knewstuff-dialog/qml/main.qml	2024-05-31 13:26:56.000000000 +0000
@@ -4,11 +4,10 @@
     SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
-import QtQuick 2.7
-import QtQuick.Layouts 1.12 as QtLayouts
-import org.kde.kirigami 2.12 as Kirigami
-import org.kde.newstuff 1.91 as NewStuff
-import org.kde.newstuff.tools.dialog 1.0 as Myself
+import QtQuick
+import org.kde.kirigami as Kirigami
+import org.kde.newstuff as NewStuff
+import org.kde.newstuff.tools.dialog as Myself
 
 Kirigami.ApplicationWindow {
     id: root;
@@ -18,8 +17,8 @@ Kirigami.ApplicationWindow {
         id: globalDrawer
         title: "KNewStuff Dialog"
         titleIcon: "get-hot-new-stuff"
-        drawerOpen: true;
-        modal: false;
+        drawerOpen: true
+        modal: false
 
         actions: []
         Instantiator {
@@ -49,28 +48,28 @@ Kirigami.ApplicationWindow {
         id: startPageComponent
         Kirigami.AboutPage {
             aboutData: {
-                "displayName" : "KNewStuff Dialog",
-                "productName" : "org.kde.knewstuff.tools.dialog",
-                "programLogo" : "get-hot-new-stuff",
-                "componentName" : "knewstuff-dialog",
-                "shortDescription" : "Get All Your Hot New Stuff",
-                "homepage" : "https://kde.org/",
-                "bugAddress" : "https://bugs.kde.org/",
-                "version" : "v1.0",
+                "displayName": "KNewStuff Dialog",
+                "productName": "org.kde.knewstuff.tools.dialog",
+                "programLogo": "get-hot-new-stuff",
+                "componentName": "knewstuff-dialog",
+                "shortDescription": "Get All Your Hot New Stuff",
+                "homepage": "https://kde.org/",
+                "bugAddress": "https://bugs.kde.org/",
+                "version": "v1.0",
                 "otherText": "",
-                "authors" : [
-                            {
-                                "name" : "Dan Leinir Turthra Jensen\n",
-                                "task" : "Lead Developer",
-                                "emailAddress" : "admin@leinir.dk",
-                                "webAddress" : "https://leinir.dk/",
-                                "ocsUsername" : "leinir"
-                            }
-                        ],
-                "credits" : [],
-                "translators" : [],
-                "copyrightStatement" : "© 2020 The KDE Community",
-                "desktopFileName" : "org.kde.knewstuff.tools.dialog"
+                "authors": [
+                    {
+                        "name": "Dan Leinir Turthra Jensen\n",
+                        "task": "Lead Developer",
+                        "emailAddress": "admin@leinir.dk",
+                        "webAddress": "https://leinir.dk/",
+                        "ocsUsername": "leinir",
+                    },
+                ],
+                "credits": [],
+                "translators": [],
+                "copyrightStatement": "© 2020 The KDE Community",
+                "desktopFileName": "org.kde.knewstuff.tools.dialog",
             }
         }
     }
diff -pruN 6.0.0-3/src/widgets/action.cpp 6.3.0-1/src/widgets/action.cpp
--- 6.0.0-3/src/widgets/action.cpp	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/src/widgets/action.cpp	2024-05-31 13:26:56.000000000 +0000
@@ -25,7 +25,7 @@ Action::Action(const QString &text, cons
     , d(new ActionPrivate)
 {
     if (text.isEmpty()) {
-        setText(i18n("Download New Stuff..."));
+        setText(i18nc("@action", "Download New Stuff…"));
     } else {
         setText(text);
     }
diff -pruN 6.0.0-3/src/widgets/button.cpp 6.3.0-1/src/widgets/button.cpp
--- 6.0.0-3/src/widgets/button.cpp	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/src/widgets/button.cpp	2024-05-31 13:26:56.000000000 +0000
@@ -67,7 +67,7 @@ Button::Button(const QString &text, cons
 }
 
 Button::Button(QWidget *parent)
-    : Button(i18n("Download New Stuff..."), QString(), parent)
+    : Button(i18nc("@action", "Download New Stuff…"), QString(), parent)
 {
 }
 
diff -pruN 6.0.0-3/src/widgets/dialog.cpp 6.3.0-1/src/widgets/dialog.cpp
--- 6.0.0-3/src/widgets/dialog.cpp	2024-02-26 23:02:04.000000000 +0000
+++ 6.3.0-1/src/widgets/dialog.cpp	2024-05-31 13:26:56.000000000 +0000
@@ -63,10 +63,12 @@ Dialog::Dialog(const QString &configFile
     auto context = new KLocalizedContext(engine);
     engine->setIncubationController(new PeriodicIncubationController());
 
-    // TODO: It would be best to use a Kirigami.ApplicationWindow and use
-    // a multiple of gridUnit for our default and minimum size
     setMinimumSize(600, 400);
-    resize(600, 400);
+    // Keep in sync with the sizes in Dialog.qml and DialogContent.qml
+    // (reminder that a default gridUnit is 18px).
+    // TODO: It would be best to use a Kirigami.ApplicationWindow and use
+    // a multiple of gridUnit directly!
+    resize(792, 540);
 
     context->setTranslationDomain(QStringLiteral("knewstuff6"));
     engine->rootContext()->setContextObject(context);
